@@ -156,7 +156,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup single_blas_level3
+*> \ingroup trmm
 *
 *> \par Further Details:
 *  =====================
@@ -230,7 +230,8 @@
      +         (.NOT.LSAME(TRANSA,'T')) .AND.
      +         (.NOT.LSAME(TRANSA,'C'))) THEN
           INFO = 3
-      ELSE IF ((.NOT.LSAME(DIAG,'U')) .AND. (.NOT.LSAME(DIAG,'N'))) THEN
+      ELSE IF ((.NOT.LSAME(DIAG,'U')) .AND.
+     +         (.NOT.LSAME(DIAG,'N'))) THEN
           INFO = 4
       ELSE IF (M.LT.0) THEN
           INFO = 5
