@@ -9,9 +9,9 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_dger(const CBLAS_LAYOUT layout, const CBLAS_INDEX M, const CBLAS_INDEX N,
-                const double alpha, const double  *X, const CBLAS_INDEX incX,
-                const double  *Y, const CBLAS_INDEX incY, double  *A, const CBLAS_INDEX lda)
+void API_SUFFIX(cblas_dger)(const CBLAS_LAYOUT layout, const CBLAS_INT M, const CBLAS_INT N,
+                const double alpha, const double  *X, const CBLAS_INT incX,
+                const double  *Y, const CBLAS_INT incY, double  *A, const CBLAS_INT lda)
 {
 #ifdef F77_INT
    F77_INT F77_M=M, F77_N=N, F77_lda=lda, F77_incX=incX, F77_incY=incY;
@@ -40,7 +40,7 @@ void cblas_dger(const CBLAS_LAYOUT layout, const CBLAS_INDEX M, const CBLAS_INDE
                       &F77_lda);
 
    }
-   else cblas_xerbla(1, "cblas_dger", "Illegal layout setting, %d\n", layout);
+   else API_SUFFIX(cblas_xerbla)(1, "cblas_dger", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
