@@ -7,10 +7,10 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
+void API_SUFFIX(cblas_dtbmv)(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
                  const CBLAS_TRANSPOSE TransA, const CBLAS_DIAG Diag,
-                 const CBLAS_INDEX N, const CBLAS_INDEX K, const double  *A, const CBLAS_INDEX lda,
-                 double  *X, const CBLAS_INDEX incX)
+                 const CBLAS_INT N, const CBLAS_INT K, const double  *A, const CBLAS_INT lda,
+                 double  *X, const CBLAS_INT incX)
 {
    char TA;
    char UL;
@@ -41,7 +41,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Uplo == CblasLower) UL = 'L';
       else
       {
-         cblas_xerbla(2, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -51,7 +51,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (TransA == CblasConjTrans) TA = 'C';
       else
       {
-         cblas_xerbla(3, "cblas_dtbmv","Illegal TransA setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_dtbmv","Illegal TransA setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -60,7 +60,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Diag == CblasNonUnit) DI = 'N';
       else
       {
-         cblas_xerbla(4, "cblas_dtbmv","Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_dtbmv","Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -80,7 +80,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Uplo == CblasLower) UL = 'U';
       else
       {
-         cblas_xerbla(2, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -91,7 +91,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (TransA == CblasConjTrans) TA = 'N';
       else
       {
-         cblas_xerbla(3, "cblas_dtbmv","Illegal TransA setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_dtbmv","Illegal TransA setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -101,7 +101,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Diag == CblasNonUnit) DI = 'N';
       else
       {
-         cblas_xerbla(4, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_dtbmv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -116,7 +116,7 @@ void cblas_dtbmv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
                       &F77_incX);
 
    }
-   else cblas_xerbla(1, "cblas_dtbmv", "Illegal layout setting, %d\n", layout);
+   else API_SUFFIX(cblas_xerbla)(1, "cblas_dtbmv", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
 }
