@@ -9,7 +9,7 @@
 #include "cblas_f77.h"
 #include <stdio.h>
 #include <stdlib.h>
-void cblas_zhbmv(const CBLAS_LAYOUT layout,
+void API_SUFFIX(cblas_zhbmv)(const CBLAS_LAYOUT layout,
                  const CBLAS_UPLO Uplo,const CBLAS_INT N,const CBLAS_INT K,
                  const void *alpha, const void  *A, const CBLAS_INT lda,
                  const void  *X, const CBLAS_INT incX, const void *beta,
@@ -46,7 +46,7 @@ void cblas_zhbmv(const CBLAS_LAYOUT layout,
       else if (Uplo == CblasUpper) UL = 'U';
       else
       {
-         cblas_xerbla(2, "cblas_zhbmv","Illegal Uplo setting, %d\n",Uplo );
+         API_SUFFIX(cblas_xerbla)(2, "cblas_zhbmv","Illegal Uplo setting, %d\n",Uplo );
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -120,7 +120,7 @@ void cblas_zhbmv(const CBLAS_LAYOUT layout,
       else if (Uplo == CblasLower) UL = 'U';
       else
       {
-         cblas_xerbla(2, "cblas_zhbmv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_zhbmv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -133,7 +133,7 @@ void cblas_zhbmv(const CBLAS_LAYOUT layout,
    }
    else
    {
-      cblas_xerbla(1, "cblas_zhbmv","Illegal layout setting, %d\n", layout);
+      API_SUFFIX(cblas_xerbla)(1, "cblas_zhbmv","Illegal layout setting, %d\n", layout);
       CBLAS_CallFromC = 0;
       RowMajorStrg = 0;
       return;
