@@ -9,10 +9,10 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
-                 const CBLAS_TRANSPOSE Trans, const CBLAS_INDEX N, const CBLAS_INDEX K,
-                 const void *alpha, const void  *A, const CBLAS_INDEX lda,
-                 const void *beta, void  *C, const CBLAS_INDEX ldc)
+void API_SUFFIX(cblas_zsyrk)(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
+                 const CBLAS_TRANSPOSE Trans, const CBLAS_INT N, const CBLAS_INT K,
+                 const void *alpha, const void  *A, const CBLAS_INT lda,
+                 const void *beta, void  *C, const CBLAS_INT ldc)
 {
    char UL, TR;
 #ifdef F77_CHAR
@@ -44,7 +44,7 @@ void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Uplo == CblasLower ) UL='L';
       else
       {
-         cblas_xerbla(2, "cblas_zsyrk", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_zsyrk", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -55,7 +55,7 @@ void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Trans == CblasNoTrans )   TR='N';
       else
       {
-         cblas_xerbla(3, "cblas_zsyrk", "Illegal Trans setting, %d\n", Trans);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zsyrk", "Illegal Trans setting, %d\n", Trans);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -76,7 +76,7 @@ void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Uplo == CblasLower ) UL='U';
       else
       {
-         cblas_xerbla(3, "cblas_zsyrk", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zsyrk", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -86,7 +86,7 @@ void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Trans == CblasNoTrans )   TR='T';
       else
       {
-         cblas_xerbla(3, "cblas_zsyrk", "Illegal Trans setting, %d\n", Trans);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zsyrk", "Illegal Trans setting, %d\n", Trans);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -100,7 +100,7 @@ void cblas_zsyrk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       F77_zsyrk(F77_UL, F77_TR, &F77_N, &F77_K, alpha, A, &F77_lda,
                      beta, C, &F77_ldc);
    }
-   else  cblas_xerbla(1, "cblas_zsyrk", "Illegal layout setting, %d\n", layout);
+   else  API_SUFFIX(cblas_xerbla)(1, "cblas_zsyrk", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
