@@ -9,7 +9,7 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
+void API_SUFFIX(cblas_ztrmm)(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
                  const CBLAS_UPLO Uplo, const  CBLAS_TRANSPOSE TransA,
                  const CBLAS_DIAG Diag, const CBLAS_INT M, const CBLAS_INT N,
                  const void *alpha, const void  *A, const CBLAS_INT lda,
@@ -45,7 +45,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Side == CblasLeft ) SD='L';
       else
       {
-         cblas_xerbla(2, "cblas_ztrmm", "Illegal Side setting, %d\n", Side);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_ztrmm", "Illegal Side setting, %d\n", Side);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -54,7 +54,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Uplo == CblasLower ) UL='L';
       else
       {
-         cblas_xerbla(3, "cblas_ztrmm", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_ztrmm", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -65,7 +65,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( TransA == CblasNoTrans )   TA='N';
       else
       {
-         cblas_xerbla(4, "cblas_ztrmm", "Illegal Trans setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_ztrmm", "Illegal Trans setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -75,7 +75,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Diag == CblasNonUnit ) DI='N';
       else
       {
-         cblas_xerbla(5, "cblas_ztrmm", "Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(5, "cblas_ztrmm", "Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -96,7 +96,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Side == CblasLeft ) SD='R';
       else
       {
-         cblas_xerbla(2, "cblas_ztrmm", "Illegal Side setting, %d\n", Side);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_ztrmm", "Illegal Side setting, %d\n", Side);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -106,7 +106,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Uplo == CblasLower ) UL='U';
       else
       {
-         cblas_xerbla(3, "cblas_ztrmm", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_ztrmm", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -117,7 +117,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( TransA == CblasNoTrans )   TA='N';
       else
       {
-         cblas_xerbla(4, "cblas_ztrmm", "Illegal Trans setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_ztrmm", "Illegal Trans setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -127,7 +127,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Diag == CblasNonUnit ) DI='N';
       else
       {
-         cblas_xerbla(5, "cblas_ztrmm", "Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(5, "cblas_ztrmm", "Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -142,7 +142,7 @@ void cblas_ztrmm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
 
       F77_ztrmm(F77_SD, F77_UL, F77_TA, F77_DI, &F77_N, &F77_M, alpha, A, &F77_lda, B, &F77_ldb);
    }
-   else  cblas_xerbla(1, "cblas_ztrmm", "Illegal layout setting, %d\n", layout);
+   else  API_SUFFIX(cblas_xerbla)(1, "cblas_ztrmm", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
