@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function cgejsv
 * Author: Intel Corporation
-* Generated June 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
+lapack_int API_SUFFIX(LAPACKE_cgejsv_work)( int matrix_layout, char joba, char jobu,
                                 char jobv, char jobr, char jobt, char jobp,
                                 lapack_int m, lapack_int n, lapack_complex_float* a,
                                 lapack_int lda, float* sva, lapack_complex_float* u,
@@ -52,10 +51,10 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
             info = info - 1;
         }
     } else if( matrix_layout == LAPACK_ROW_MAJOR ) {
-        lapack_int nu = LAPACKE_lsame( jobu, 'n' ) ? 1 : m;
-        lapack_int nv = LAPACKE_lsame( jobv, 'n' ) ? 1 : n;
-        lapack_int ncols_u = LAPACKE_lsame( jobu, 'n' ) ? 1 :
-            LAPACKE_lsame( jobu, 'f' ) ? m : n;
+        lapack_int nu = API_SUFFIX(LAPACKE_lsame)( jobu, 'n' ) ? 1 : m;
+        lapack_int nv = API_SUFFIX(LAPACKE_lsame)( jobv, 'n' ) ? 1 : n;
+        lapack_int ncols_u = API_SUFFIX(LAPACKE_lsame)( jobu, 'n' ) ? 1 :
+            API_SUFFIX(LAPACKE_lsame)( jobu, 'f' ) ? m : n;
         lapack_int lda_t = MAX(1,m);
         lapack_int ldu_t = MAX(1,nu);
         lapack_int ldv_t = MAX(1,nv);
@@ -65,17 +64,17 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -11;
-            LAPACKE_xerbla( "LAPACKE_cgejsv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgejsv_work", info );
             return info;
         }
         if( ldu < ncols_u ) {
             info = -14;
-            LAPACKE_xerbla( "LAPACKE_cgejsv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgejsv_work", info );
             return info;
         }
         if( ldv < n ) {
             info = -16;
-            LAPACKE_xerbla( "LAPACKE_cgejsv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgejsv_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -85,8 +84,8 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
             info = LAPACK_TRANSPOSE_MEMORY_ERROR;
             goto exit_level_0;
         }
-        if( LAPACKE_lsame( jobu, 'f' ) || LAPACKE_lsame( jobu, 'u' ) ||
-            LAPACKE_lsame( jobu, 'w' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobu, 'f' ) || API_SUFFIX(LAPACKE_lsame)( jobu, 'u' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobu, 'w' ) ) {
             u_t = (lapack_complex_float*)
                LAPACKE_malloc( sizeof(lapack_complex_float) * ldu_t * MAX(1,ncols_u) );
             if( u_t == NULL ) {
@@ -94,8 +93,8 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
                 goto exit_level_1;
             }
         }
-        if( LAPACKE_lsame( jobv, 'j' ) || LAPACKE_lsame( jobv, 'v' ) ||
-            LAPACKE_lsame( jobv, 'w' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'j' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobv, 'w' ) ) {
             v_t = (lapack_complex_float*)
                LAPACKE_malloc( sizeof(lapack_complex_float) * ldv_t * MAX(1,n) );
             if( v_t == NULL ) {
@@ -104,7 +103,7 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
             }
         }
         /* Transpose input matrices */
-        LAPACKE_cge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_cge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_cgejsv( &joba, &jobu, &jobv, &jobr, &jobt, &jobp, &m, &n, a_t,
                        &lda_t, sva, u_t, &ldu_t, v_t, &ldv_t, cwork, &lwork,
@@ -113,33 +112,33 @@ lapack_int LAPACKE_cgejsv_work( int matrix_layout, char joba, char jobu,
             info = info - 1;
         }
         /* Transpose output matrices */
-        if( LAPACKE_lsame( jobu, 'f' ) || LAPACKE_lsame( jobu, 'u' ) ||
-            LAPACKE_lsame( jobu, 'w' ) ) {
-            LAPACKE_cge_trans( LAPACK_COL_MAJOR, nu, ncols_u, u_t, ldu_t, u, ldu );
+        if( API_SUFFIX(LAPACKE_lsame)( jobu, 'f' ) || API_SUFFIX(LAPACKE_lsame)( jobu, 'u' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobu, 'w' ) ) {
+            API_SUFFIX(LAPACKE_cge_trans)( LAPACK_COL_MAJOR, nu, ncols_u, u_t, ldu_t, u, ldu );
         }
-        if( LAPACKE_lsame( jobv, 'j' ) || LAPACKE_lsame( jobv, 'v' ) ||
-            LAPACKE_lsame( jobv, 'w' ) ) {
-            LAPACKE_cge_trans( LAPACK_COL_MAJOR, nv, n, v_t, ldv_t, v, ldv );
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'j' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobv, 'w' ) ) {
+            API_SUFFIX(LAPACKE_cge_trans)( LAPACK_COL_MAJOR, nv, n, v_t, ldv_t, v, ldv );
         }
         /* Release memory and exit */
-        if( LAPACKE_lsame( jobv, 'j' ) || LAPACKE_lsame( jobv, 'v' ) ||
-            LAPACKE_lsame( jobv, 'w' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'j' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobv, 'w' ) ) {
             LAPACKE_free( v_t );
         }
 exit_level_2:
-        if( LAPACKE_lsame( jobu, 'f' ) || LAPACKE_lsame( jobu, 'u' ) ||
-            LAPACKE_lsame( jobu, 'w' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobu, 'f' ) || API_SUFFIX(LAPACKE_lsame)( jobu, 'u' ) ||
+            API_SUFFIX(LAPACKE_lsame)( jobu, 'w' ) ) {
             LAPACKE_free( u_t );
         }
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_cgejsv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgejsv_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_cgejsv_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgejsv_work", info );
     }
     return info;
 }
