@@ -28,12 +28,11 @@
 ******************************************************************************
 * Contents: Native high-level C interface to LAPACK function cgemqrt
 * Author: Intel Corporation
-* Generated June 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgemqrt( int matrix_layout, char side, char trans,
+lapack_int API_SUFFIX(LAPACKE_cgemqrt)( int matrix_layout, char side, char trans,
                             lapack_int m, lapack_int n, lapack_int k,
                             lapack_int nb, const lapack_complex_float* v,
                             lapack_int ldv, const lapack_complex_float* t,
@@ -44,21 +43,23 @@ lapack_int LAPACKE_cgemqrt( int matrix_layout, char side, char trans,
     lapack_int info = 0;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgemqrt", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgemqrt", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    nrows_v = LAPACKE_lsame( side, 'L' ) ? m :
-                         ( LAPACKE_lsame( side, 'R' ) ? n : 0 );
-    if( LAPACKE_cge_nancheck( matrix_layout, m, n, c, ldc ) ) {
-        return -12;
-    }
-    if( LAPACKE_cge_nancheck( matrix_layout, nb, k, t, ldt ) ) {
-        return -10;
-    }
-    if( LAPACKE_cge_nancheck( matrix_layout, nrows_v, k, v, ldv ) ) {
-        return -8;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        nrows_v = API_SUFFIX(LAPACKE_lsame)( side, 'L' ) ? m :
+                             ( API_SUFFIX(LAPACKE_lsame)( side, 'R' ) ? n : 0 );
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, m, n, c, ldc ) ) {
+            return -12;
+        }
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, nb, k, t, ldt ) ) {
+            return -10;
+        }
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, nrows_v, k, v, ldv ) ) {
+            return -8;
+        }
     }
 #endif
     /* Allocate memory for working array(s) */
@@ -69,13 +70,13 @@ lapack_int LAPACKE_cgemqrt( int matrix_layout, char side, char trans,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cgemqrt_work( matrix_layout, side, trans, m, n, k, nb, v, ldv,
+    info = API_SUFFIX(LAPACKE_cgemqrt_work)( matrix_layout, side, trans, m, n, k, nb, v, ldv,
                                  t, ldt, c, ldc, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cgemqrt", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgemqrt", info );
     }
     return info;
 }
