@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgeqpf( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cgeqpf)( int matrix_layout, lapack_int m, lapack_int n,
                            lapack_complex_float* a, lapack_int lda,
                            lapack_int* jpvt, lapack_complex_float* tau )
 {
@@ -40,13 +40,13 @@ lapack_int LAPACKE_cgeqpf( int matrix_layout, lapack_int m, lapack_int n,
     float* rwork = NULL;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgeqpf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgeqpf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -4;
         }
     }
@@ -64,7 +64,7 @@ lapack_int LAPACKE_cgeqpf( int matrix_layout, lapack_int m, lapack_int n,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cgeqpf_work( matrix_layout, m, n, a, lda, jpvt, tau, work,
+    info = API_SUFFIX(LAPACKE_cgeqpf_work)( matrix_layout, m, n, a, lda, jpvt, tau, work,
                                 rwork );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -72,7 +72,7 @@ exit_level_1:
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cgeqpf", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgeqpf", info );
     }
     return info;
 }
