@@ -28,26 +28,25 @@
 ******************************************************************************
 * Contents: Native high-level C interface to LAPACK function cgeqrt3
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgeqrt3( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cgeqrt3)( int matrix_layout, lapack_int m, lapack_int n,
                             lapack_complex_float* a, lapack_int lda,
                             lapack_complex_float* t, lapack_int ldt )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgeqrt3", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgeqrt3", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -4;
         }
     }
 #endif
-    return LAPACKE_cgeqrt3_work( matrix_layout, m, n, a, lda, t, ldt );
+    return API_SUFFIX(LAPACKE_cgeqrt3_work)( matrix_layout, m, n, a, lda, t, ldt );
 }
