@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function cgerqf
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgerqf( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cgerqf)( int matrix_layout, lapack_int m, lapack_int n,
                            lapack_complex_float* a, lapack_int lda,
                            lapack_complex_float* tau )
 {
@@ -42,19 +41,19 @@ lapack_int LAPACKE_cgerqf( int matrix_layout, lapack_int m, lapack_int n,
     lapack_complex_float* work = NULL;
     lapack_complex_float work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgerqf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgerqf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -4;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_cgerqf_work( matrix_layout, m, n, a, lda, tau, &work_query,
+    info = API_SUFFIX(LAPACKE_cgerqf_work)( matrix_layout, m, n, a, lda, tau, &work_query,
                                 lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -68,12 +67,12 @@ lapack_int LAPACKE_cgerqf( int matrix_layout, lapack_int m, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cgerqf_work( matrix_layout, m, n, a, lda, tau, work, lwork );
+    info = API_SUFFIX(LAPACKE_cgerqf_work)( matrix_layout, m, n, a, lda, tau, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cgerqf", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgerqf", info );
     }
     return info;
 }
