@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgesvdq( int matrix_layout, char joba, char jobp,
+lapack_int API_SUFFIX(LAPACKE_cgesvdq)( int matrix_layout, char joba, char jobp,
                            char jobr, char jobu, char jobv,
                            lapack_int m, lapack_int n, lapack_complex_float* a,
                            lapack_int lda, float* s, lapack_complex_float* u, lapack_int ldu,
@@ -49,19 +49,19 @@ lapack_int LAPACKE_cgesvdq( int matrix_layout, char joba, char jobp,
     float* rwork = NULL;
     float rwork_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgesvdq", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgesvdq", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -6;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_cgesvdq_work( matrix_layout, joba, jobp, jobr, jobu, jobv,
+    info = API_SUFFIX(LAPACKE_cgesvdq_work)( matrix_layout, joba, jobp, jobr, jobu, jobv,
                                  m, n, a, lda, s, u, ldu, v, ldv, numrank,
                                  &iwork_query, liwork, &cwork_query, lcwork,
                                  &rwork_query, lrwork );
@@ -88,7 +88,7 @@ lapack_int LAPACKE_cgesvdq( int matrix_layout, char joba, char jobp,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cgesvdq_work( matrix_layout, joba, jobp, jobr, jobu, jobv,
+    info = API_SUFFIX(LAPACKE_cgesvdq_work)( matrix_layout, joba, jobp, jobr, jobu, jobv,
                                  m, n, a, lda, s, u, ldu, v, ldv, numrank,
                                  iwork, liwork, cwork, lcwork, rwork, lrwork );
 
@@ -98,7 +98,7 @@ lapack_int LAPACKE_cgesvdq( int matrix_layout, char joba, char jobp,
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cgesvdq", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgesvdq", info );
     }
     return info;
 }
