@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cgghd3( int matrix_layout, char compq, char compz,
+lapack_int API_SUFFIX(LAPACKE_cgghd3)( int matrix_layout, char compq, char compz,
                            lapack_int n, lapack_int ilo, lapack_int ihi,
                            lapack_complex_float* a, lapack_int lda,
                            lapack_complex_float* b, lapack_int ldb,
@@ -45,32 +45,32 @@ lapack_int LAPACKE_cgghd3( int matrix_layout, char compq, char compz,
     lapack_complex_float work_query;
 
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cgghd3", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgghd3", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, n, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, n, a, lda ) ) {
             return -7;
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, n, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, n, b, ldb ) ) {
             return -9;
         }
-        if( LAPACKE_lsame( compq, 'i' ) || LAPACKE_lsame( compq, 'v' ) ) {
-            if( LAPACKE_cge_nancheck( matrix_layout, n, n, q, ldq ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( compq, 'i' ) || API_SUFFIX(LAPACKE_lsame)( compq, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, n, q, ldq ) ) {
                 return -11;
             }
         }
-        if( LAPACKE_lsame( compz, 'i' ) || LAPACKE_lsame( compz, 'v' ) ) {
-            if( LAPACKE_cge_nancheck( matrix_layout, n, n, z, ldz ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( compz, 'i' ) || API_SUFFIX(LAPACKE_lsame)( compz, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, n, z, ldz ) ) {
                 return -13;
             }
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info =  LAPACKE_cgghd3_work( matrix_layout, compq, compz, n, ilo, ihi,
+    info =  API_SUFFIX(LAPACKE_cgghd3_work)( matrix_layout, compq, compz, n, ilo, ihi,
                                  a, lda, b, ldb, q, ldq, z, ldz, &work_query,
                                  lwork );
     if( info != 0 ) {
@@ -85,14 +85,14 @@ lapack_int LAPACKE_cgghd3( int matrix_layout, char compq, char compz,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info =  LAPACKE_cgghd3_work( matrix_layout, compq, compz, n, ilo, ihi,
+    info =  API_SUFFIX(LAPACKE_cgghd3_work)( matrix_layout, compq, compz, n, ilo, ihi,
                                  a, lda, b, ldb, q, ldq, z, ldz, work,
                                  lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cgghd3", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cgghd3", info );
     }
     return info;
 }
