@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cggqrf( int matrix_layout, lapack_int n, lapack_int m,
+lapack_int API_SUFFIX(LAPACKE_cggqrf)( int matrix_layout, lapack_int n, lapack_int m,
                            lapack_int p, lapack_complex_float* a,
                            lapack_int lda, lapack_complex_float* taua,
                            lapack_complex_float* b, lapack_int ldb,
@@ -43,22 +43,22 @@ lapack_int LAPACKE_cggqrf( int matrix_layout, lapack_int n, lapack_int m,
     lapack_complex_float* work = NULL;
     lapack_complex_float work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cggqrf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cggqrf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cge_nancheck( matrix_layout, n, m, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, m, a, lda ) ) {
             return -5;
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, p, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, p, b, ldb ) ) {
             return -8;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_cggqrf_work( matrix_layout, n, m, p, a, lda, taua, b, ldb,
+    info = API_SUFFIX(LAPACKE_cggqrf_work)( matrix_layout, n, m, p, a, lda, taua, b, ldb,
                                 taub, &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -72,13 +72,13 @@ lapack_int LAPACKE_cggqrf( int matrix_layout, lapack_int n, lapack_int m,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cggqrf_work( matrix_layout, n, m, p, a, lda, taua, b, ldb,
+    info = API_SUFFIX(LAPACKE_cggqrf_work)( matrix_layout, n, m, p, a, lda, taua, b, ldb,
                                 taub, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cggqrf", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cggqrf", info );
     }
     return info;
 }
