@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function cheevd
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cheevd( int matrix_layout, char jobz, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cheevd)( int matrix_layout, char jobz, char uplo, lapack_int n,
                            lapack_complex_float* a, lapack_int lda, float* w )
 {
     lapack_int info = 0;
@@ -47,25 +46,25 @@ lapack_int LAPACKE_cheevd( int matrix_layout, char jobz, char uplo, lapack_int n
     float rwork_query;
     lapack_complex_float work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cheevd", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cheevd", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_che_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_cheevd_work( matrix_layout, jobz, uplo, n, a, lda, w,
+    info = API_SUFFIX(LAPACKE_cheevd_work)( matrix_layout, jobz, uplo, n, a, lda, w,
                                 &work_query, lwork, &rwork_query, lrwork,
                                 &iwork_query, liwork );
     if( info != 0 ) {
         goto exit_level_0;
     }
-    liwork = (lapack_int)iwork_query;
+    liwork = iwork_query;
     lrwork = (lapack_int)rwork_query;
     lwork = LAPACK_C2INT( work_query );
     /* Allocate memory for work arrays */
@@ -86,7 +85,7 @@ lapack_int LAPACKE_cheevd( int matrix_layout, char jobz, char uplo, lapack_int n
         goto exit_level_2;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cheevd_work( matrix_layout, jobz, uplo, n, a, lda, w, work,
+    info = API_SUFFIX(LAPACKE_cheevd_work)( matrix_layout, jobz, uplo, n, a, lda, w, work,
                                 lwork, rwork, lrwork, iwork, liwork );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -96,7 +95,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cheevd", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cheevd", info );
     }
     return info;
 }
