@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_chegvd( int matrix_layout, lapack_int itype, char jobz,
+lapack_int API_SUFFIX(LAPACKE_chegvd)( int matrix_layout, lapack_int itype, char jobz,
                            char uplo, lapack_int n, lapack_complex_float* a,
                            lapack_int lda, lapack_complex_float* b,
                            lapack_int ldb, float* w )
@@ -48,22 +48,22 @@ lapack_int LAPACKE_chegvd( int matrix_layout, lapack_int itype, char jobz,
     float rwork_query;
     lapack_complex_float work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_chegvd", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chegvd", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_che_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -6;
         }
-        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_che_nancheck)( matrix_layout, uplo, n, b, ldb ) ) {
             return -8;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_chegvd_work( matrix_layout, itype, jobz, uplo, n, a, lda, b,
+    info = API_SUFFIX(LAPACKE_chegvd_work)( matrix_layout, itype, jobz, uplo, n, a, lda, b,
                                 ldb, w, &work_query, lwork, &rwork_query,
                                 lrwork, &iwork_query, liwork );
     if( info != 0 ) {
@@ -90,7 +90,7 @@ lapack_int LAPACKE_chegvd( int matrix_layout, lapack_int itype, char jobz,
         goto exit_level_2;
     }
     /* Call middle-level interface */
-    info = LAPACKE_chegvd_work( matrix_layout, itype, jobz, uplo, n, a, lda, b,
+    info = API_SUFFIX(LAPACKE_chegvd_work)( matrix_layout, itype, jobz, uplo, n, a, lda, b,
                                 ldb, w, work, lwork, rwork, lrwork, iwork,
                                 liwork );
     /* Release memory and exit */
@@ -101,7 +101,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_chegvd", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chegvd", info );
     }
     return info;
 }
