@@ -32,20 +32,20 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_chetri2x( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_chetri2x)( int matrix_layout, char uplo, lapack_int n,
                              lapack_complex_float* a, lapack_int lda,
                              const lapack_int* ipiv, lapack_int nb )
 {
     lapack_int info = 0;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_chetri2x", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chetri2x", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_che_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_che_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -4;
         }
     }
@@ -58,13 +58,13 @@ lapack_int LAPACKE_chetri2x( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_chetri2x_work( matrix_layout, uplo, n, a, lda, ipiv, work,
+    info = API_SUFFIX(LAPACKE_chetri2x_work)( matrix_layout, uplo, n, a, lda, ipiv, work,
                                   nb );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_chetri2x", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chetri2x", info );
     }
     return info;
 }
