@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_chpgv_work( int matrix_layout, lapack_int itype, char jobz,
+lapack_int API_SUFFIX(LAPACKE_chpgv_work)( int matrix_layout, lapack_int itype, char jobz,
                                char uplo, lapack_int n,
                                lapack_complex_float* ap,
                                lapack_complex_float* bp, float* w,
@@ -55,11 +55,11 @@ lapack_int LAPACKE_chpgv_work( int matrix_layout, lapack_int itype, char jobz,
         /* Check leading dimension(s) */
         if( ldz < n ) {
             info = -10;
-            LAPACKE_xerbla( "LAPACKE_chpgv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chpgv_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
-        if( LAPACKE_lsame( jobz, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobz, 'v' ) ) {
             z_t = (lapack_complex_float*)
                 LAPACKE_malloc( sizeof(lapack_complex_float) *
                                 ldz_t * MAX(1,n) );
@@ -83,8 +83,8 @@ lapack_int LAPACKE_chpgv_work( int matrix_layout, lapack_int itype, char jobz,
             goto exit_level_2;
         }
         /* Transpose input matrices */
-        LAPACKE_chp_trans( matrix_layout, uplo, n, ap, ap_t );
-        LAPACKE_chp_trans( matrix_layout, uplo, n, bp, bp_t );
+        API_SUFFIX(LAPACKE_chp_trans)( matrix_layout, uplo, n, ap, ap_t );
+        API_SUFFIX(LAPACKE_chp_trans)( matrix_layout, uplo, n, bp, bp_t );
         /* Call LAPACK function and adjust info */
         LAPACK_chpgv( &itype, &jobz, &uplo, &n, ap_t, bp_t, w, z_t, &ldz_t,
                       work, rwork, &info );
@@ -92,26 +92,26 @@ lapack_int LAPACKE_chpgv_work( int matrix_layout, lapack_int itype, char jobz,
             info = info - 1;
         }
         /* Transpose output matrices */
-        if( LAPACKE_lsame( jobz, 'v' ) ) {
-            LAPACKE_cge_trans( LAPACK_COL_MAJOR, n, n, z_t, ldz_t, z, ldz );
+        if( API_SUFFIX(LAPACKE_lsame)( jobz, 'v' ) ) {
+            API_SUFFIX(LAPACKE_cge_trans)( LAPACK_COL_MAJOR, n, n, z_t, ldz_t, z, ldz );
         }
-        LAPACKE_chp_trans( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
-        LAPACKE_chp_trans( LAPACK_COL_MAJOR, uplo, n, bp_t, bp );
+        API_SUFFIX(LAPACKE_chp_trans)( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
+        API_SUFFIX(LAPACKE_chp_trans)( LAPACK_COL_MAJOR, uplo, n, bp_t, bp );
         /* Release memory and exit */
         LAPACKE_free( bp_t );
 exit_level_2:
         LAPACKE_free( ap_t );
 exit_level_1:
-        if( LAPACKE_lsame( jobz, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobz, 'v' ) ) {
             LAPACKE_free( z_t );
         }
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_chpgv_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chpgv_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_chpgv_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chpgv_work", info );
     }
     return info;
 }
