@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_chprfs( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_chprfs)( int matrix_layout, char uplo, lapack_int n,
                            lapack_int nrhs, const lapack_complex_float* ap,
                            const lapack_complex_float* afp,
                            const lapack_int* ipiv,
@@ -44,22 +44,22 @@ lapack_int LAPACKE_chprfs( int matrix_layout, char uplo, lapack_int n,
     float* rwork = NULL;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_chprfs", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chprfs", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_chp_nancheck( n, afp ) ) {
+        if( API_SUFFIX(LAPACKE_chp_nancheck)( n, afp ) ) {
             return -6;
         }
-        if( LAPACKE_chp_nancheck( n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_chp_nancheck)( n, ap ) ) {
             return -5;
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -8;
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, x, ldx ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, nrhs, x, ldx ) ) {
             return -10;
         }
     }
@@ -77,7 +77,7 @@ lapack_int LAPACKE_chprfs( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_chprfs_work( matrix_layout, uplo, n, nrhs, ap, afp, ipiv, b,
+    info = API_SUFFIX(LAPACKE_chprfs_work)( matrix_layout, uplo, n, nrhs, ap, afp, ipiv, b,
                                 ldb, x, ldx, ferr, berr, work, rwork );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -85,7 +85,7 @@ exit_level_1:
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_chprfs", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chprfs", info );
     }
     return info;
 }
