@@ -32,19 +32,19 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_chptri( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_chptri)( int matrix_layout, char uplo, lapack_int n,
                            lapack_complex_float* ap, const lapack_int* ipiv )
 {
     lapack_int info = 0;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_chptri", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chptri", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_chp_nancheck( n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_chp_nancheck)( n, ap ) ) {
             return -4;
         }
     }
@@ -57,12 +57,12 @@ lapack_int LAPACKE_chptri( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_chptri_work( matrix_layout, uplo, n, ap, ipiv, work );
+    info = API_SUFFIX(LAPACKE_chptri_work)( matrix_layout, uplo, n, ap, ipiv, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_chptri", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_chptri", info );
     }
     return info;
 }
