@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_clagge( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_clagge)( int matrix_layout, lapack_int m, lapack_int n,
                            lapack_int kl, lapack_int ku, const float* d,
                            lapack_complex_float* a, lapack_int lda,
                            lapack_int* iseed )
@@ -40,13 +40,13 @@ lapack_int LAPACKE_clagge( int matrix_layout, lapack_int m, lapack_int n,
     lapack_int info = 0;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_clagge", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_clagge", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_s_nancheck( MIN(m,n), d, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( MIN(m,n), d, 1 ) ) {
             return -6;
         }
     }
@@ -59,13 +59,13 @@ lapack_int LAPACKE_clagge( int matrix_layout, lapack_int m, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_clagge_work( matrix_layout, m, n, kl, ku, d, a, lda, iseed,
+    info = API_SUFFIX(LAPACKE_clagge_work)( matrix_layout, m, n, kl, ku, d, a, lda, iseed,
                                 work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_clagge", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_clagge", info );
     }
     return info;
 }
