@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-float LAPACKE_clantr_work( int matrix_layout, char norm, char uplo,
+float API_SUFFIX(LAPACKE_clantr_work)( int matrix_layout, char norm, char uplo,
                                 char diag, lapack_int m, lapack_int n,
                                 const lapack_complex_float* a, lapack_int lda,
                                 float* work )
@@ -49,23 +49,23 @@ float LAPACKE_clantr_work( int matrix_layout, char norm, char uplo,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_clantr_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_clantr_work", info );
             return info;
         }
-        if( LAPACKE_lsame( norm, '1' ) || LAPACKE_lsame( norm, 'o' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( norm, '1' ) || API_SUFFIX(LAPACKE_lsame)( norm, 'o' ) ) {
             norm_lapack = 'i';
-        } else if( LAPACKE_lsame( norm, 'i' ) ) {
+        } else if( API_SUFFIX(LAPACKE_lsame)( norm, 'i' ) ) {
             norm_lapack = '1';
         } else {
             norm_lapack = norm;
         }
-        if( LAPACKE_lsame( uplo, 'u' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( uplo, 'u' ) ) {
             uplo_lapack = 'l';
         } else {
             uplo_lapack = 'u';
         }
         /* Allocate memory for work array(s) */
-        if( LAPACKE_lsame( norm_lapack, 'i' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( norm_lapack, 'i' ) ) {
             work_lapack = (float*)LAPACKE_malloc( sizeof(float) * MAX(1,n) );
             if( work_lapack == NULL ) {
                 info = LAPACK_WORK_MEMORY_ERROR;
@@ -80,11 +80,11 @@ float LAPACKE_clantr_work( int matrix_layout, char norm, char uplo,
         }
 exit_level_0:
         if( info == LAPACK_WORK_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_clantr_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_clantr_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_clantr_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_clantr_work", info );
     }
     return res;
 }
