@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_claset_work( int matrix_layout, char uplo, lapack_int m,
+lapack_int API_SUFFIX(LAPACKE_claset_work)( int matrix_layout, char uplo, lapack_int m,
                                 lapack_int n, lapack_complex_float alpha,
                                 lapack_complex_float beta,
                                 lapack_complex_float* a, lapack_int lda )
@@ -47,7 +47,7 @@ lapack_int LAPACKE_claset_work( int matrix_layout, char uplo, lapack_int m,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_claset_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_claset_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -58,21 +58,21 @@ lapack_int LAPACKE_claset_work( int matrix_layout, char uplo, lapack_int m,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_cge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_cge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_claset( &uplo, &m, &n, &alpha, &beta, a_t, &lda_t );
         info = 0;  /* LAPACK call is ok! */
         /* Transpose output matrices */
-        LAPACKE_cge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_cge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_claset_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_claset_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_claset_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_claset_work", info );
     }
     return info;
 }
