@@ -28,26 +28,25 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function cpbstf
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cpbstf( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cpbstf)( int matrix_layout, char uplo, lapack_int n,
                            lapack_int kb, lapack_complex_float* bb,
                            lapack_int ldbb )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cpbstf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cpbstf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cpb_nancheck( matrix_layout, uplo, n, kb, bb, ldbb ) ) {
+        if( API_SUFFIX(LAPACKE_cpb_nancheck)( matrix_layout, uplo, n, kb, bb, ldbb ) ) {
             return -5;
         }
     }
 #endif
-    return LAPACKE_cpbstf_work( matrix_layout, uplo, n, kb, bb, ldbb );
+    return API_SUFFIX(LAPACKE_cpbstf_work)( matrix_layout, uplo, n, kb, bb, ldbb );
 }
