@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cposvxx( int matrix_layout, char fact, char uplo,
+lapack_int API_SUFFIX(LAPACKE_cposvxx)( int matrix_layout, char fact, char uplo,
                             lapack_int n, lapack_int nrhs,
                             lapack_complex_float* a, lapack_int lda,
                             lapack_complex_float* af, lapack_int ldaf,
@@ -47,30 +47,30 @@ lapack_int LAPACKE_cposvxx( int matrix_layout, char fact, char uplo,
     float* rwork = NULL;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cposvxx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cposvxx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cpo_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cpo_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -6;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_cpo_nancheck( matrix_layout, uplo, n, af, ldaf ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_cpo_nancheck)( matrix_layout, uplo, n, af, ldaf ) ) {
                 return -8;
             }
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -12;
         }
         if( nparams>0 ) {
-            if( LAPACKE_s_nancheck( nparams, params, 1 ) ) {
+            if( API_SUFFIX(LAPACKE_s_nancheck)( nparams, params, 1 ) ) {
                 return -23;
             }
         }
-        if( LAPACKE_lsame( fact, 'f' ) && LAPACKE_lsame( *equed, 'y' ) ) {
-            if( LAPACKE_s_nancheck( n, s, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) && API_SUFFIX(LAPACKE_lsame)( *equed, 'y' ) ) {
+            if( API_SUFFIX(LAPACKE_s_nancheck)( n, s, 1 ) ) {
                 return -11;
             }
         }
@@ -89,7 +89,7 @@ lapack_int LAPACKE_cposvxx( int matrix_layout, char fact, char uplo,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cposvxx_work( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
+    info = API_SUFFIX(LAPACKE_cposvxx_work)( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
                                  ldaf, equed, s, b, ldb, x, ldx, rcond, rpvgrw,
                                  berr, n_err_bnds, err_bnds_norm, err_bnds_comp,
                                  nparams, params, work, rwork );
@@ -99,7 +99,7 @@ exit_level_1:
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cposvxx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cposvxx", info );
     }
     return info;
 }
