@@ -32,23 +32,23 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cpstrf( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cpstrf)( int matrix_layout, char uplo, lapack_int n,
                            lapack_complex_float* a, lapack_int lda,
                            lapack_int* piv, lapack_int* rank, float tol )
 {
     lapack_int info = 0;
     float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cpstrf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cpstrf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_cpo_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_cpo_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -4;
         }
-        if( LAPACKE_s_nancheck( 1, &tol, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( 1, &tol, 1 ) ) {
             return -8;
         }
     }
@@ -60,13 +60,13 @@ lapack_int LAPACKE_cpstrf( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cpstrf_work( matrix_layout, uplo, n, a, lda, piv, rank, tol,
+    info = API_SUFFIX(LAPACKE_cpstrf_work)( matrix_layout, uplo, n, a, lda, piv, rank, tol,
                                 work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cpstrf", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cpstrf", info );
     }
     return info;
 }
