@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function cspsvx
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_cspsvx( int matrix_layout, char fact, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_cspsvx)( int matrix_layout, char fact, char uplo, lapack_int n,
                            lapack_int nrhs, const lapack_complex_float* ap,
                            lapack_complex_float* afp, lapack_int* ipiv,
                            const lapack_complex_float* b, lapack_int ldb,
@@ -44,21 +43,21 @@ lapack_int LAPACKE_cspsvx( int matrix_layout, char fact, char uplo, lapack_int n
     float* rwork = NULL;
     lapack_complex_float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_cspsvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cspsvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_csp_nancheck( n, afp ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_csp_nancheck)( n, afp ) ) {
                 return -7;
             }
         }
-        if( LAPACKE_csp_nancheck( n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_csp_nancheck)( n, ap ) ) {
             return -6;
         }
-        if( LAPACKE_cge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_cge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -9;
         }
     }
@@ -76,7 +75,7 @@ lapack_int LAPACKE_cspsvx( int matrix_layout, char fact, char uplo, lapack_int n
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_cspsvx_work( matrix_layout, fact, uplo, n, nrhs, ap, afp,
+    info = API_SUFFIX(LAPACKE_cspsvx_work)( matrix_layout, fact, uplo, n, nrhs, ap, afp,
                                 ipiv, b, ldb, x, ldx, rcond, ferr, berr, work,
                                 rwork );
     /* Release memory and exit */
@@ -85,7 +84,7 @@ exit_level_1:
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_cspsvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_cspsvx", info );
     }
     return info;
 }
