@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_csyequb_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_csyequb_work)( int matrix_layout, char uplo, lapack_int n,
                                  const lapack_complex_float* a, lapack_int lda,
                                  float* s, float* scond, float* amax,
                                  lapack_complex_float* work )
@@ -50,7 +50,7 @@ lapack_int LAPACKE_csyequb_work( int matrix_layout, char uplo, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -5;
-            LAPACKE_xerbla( "LAPACKE_csyequb_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyequb_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -61,7 +61,7 @@ lapack_int LAPACKE_csyequb_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_csy_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_csy_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_csyequb( &uplo, &n, a_t, &lda_t, s, scond, amax, work, &info );
         if( info < 0 ) {
@@ -71,11 +71,11 @@ lapack_int LAPACKE_csyequb_work( int matrix_layout, char uplo, lapack_int n,
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_csyequb_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyequb_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_csyequb_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csyequb_work", info );
     }
     return info;
 }
