@@ -28,13 +28,12 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function csytrs2
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_csytrs2_work( int matrix_layout, char uplo, lapack_int n,
-                                 lapack_int nrhs, lapack_complex_float* a,
+lapack_int API_SUFFIX(LAPACKE_csytrs2_work)( int matrix_layout, char uplo, lapack_int n,
+                                 lapack_int nrhs, const lapack_complex_float* a,
                                  lapack_int lda, const lapack_int* ipiv,
                                  lapack_complex_float* b, lapack_int ldb,
                                  lapack_complex_float* work )
@@ -54,12 +53,12 @@ lapack_int LAPACKE_csytrs2_work( int matrix_layout, char uplo, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_csytrs2_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csytrs2_work", info );
             return info;
         }
         if( ldb < nrhs ) {
             info = -9;
-            LAPACKE_xerbla( "LAPACKE_csytrs2_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csytrs2_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -77,8 +76,8 @@ lapack_int LAPACKE_csytrs2_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_csy_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
-        LAPACKE_cge_trans( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
+        API_SUFFIX(LAPACKE_csy_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_cge_trans)( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
         /* Call LAPACK function and adjust info */
         LAPACK_csytrs2( &uplo, &n, &nrhs, a_t, &lda_t, ipiv, b_t, &ldb_t, work,
                         &info );
@@ -86,18 +85,18 @@ lapack_int LAPACKE_csytrs2_work( int matrix_layout, char uplo, lapack_int n,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_cge_trans( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
+        API_SUFFIX(LAPACKE_cge_trans)( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
         /* Release memory and exit */
         LAPACKE_free( b_t );
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_csytrs2_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csytrs2_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_csytrs2_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_csytrs2_work", info );
     }
     return info;
 }
