@@ -32,20 +32,20 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_ctptri( int matrix_layout, char uplo, char diag, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_ctptri)( int matrix_layout, char uplo, char diag, lapack_int n,
                            lapack_complex_float* ap )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_ctptri", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ctptri", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_ctp_nancheck( matrix_layout, uplo, diag, n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_ctp_nancheck)( matrix_layout, uplo, diag, n, ap ) ) {
             return -5;
         }
     }
 #endif
-    return LAPACKE_ctptri_work( matrix_layout, uplo, diag, n, ap );
+    return API_SUFFIX(LAPACKE_ctptri_work)( matrix_layout, uplo, diag, n, ap );
 }
