@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dgbbrd( int matrix_layout, char vect, lapack_int m,
+lapack_int API_SUFFIX(LAPACKE_dgbbrd)( int matrix_layout, char vect, lapack_int m,
                            lapack_int n, lapack_int ncc, lapack_int kl,
                            lapack_int ku, double* ab, lapack_int ldab,
                            double* d, double* e, double* q, lapack_int ldq,
@@ -42,17 +42,17 @@ lapack_int LAPACKE_dgbbrd( int matrix_layout, char vect, lapack_int m,
     lapack_int info = 0;
     double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dgbbrd", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbbrd", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dgb_nancheck( matrix_layout, m, n, kl, ku, ab, ldab ) ) {
+        if( API_SUFFIX(LAPACKE_dgb_nancheck)( matrix_layout, m, n, kl, ku, ab, ldab ) ) {
             return -8;
         }
         if( ncc != 0 ) {
-            if( LAPACKE_dge_nancheck( matrix_layout, m, ncc, c, ldc ) ) {
+            if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, m, ncc, c, ldc ) ) {
                 return -16;
             }
         }
@@ -65,13 +65,13 @@ lapack_int LAPACKE_dgbbrd( int matrix_layout, char vect, lapack_int m,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dgbbrd_work( matrix_layout, vect, m, n, ncc, kl, ku, ab, ldab,
+    info = API_SUFFIX(LAPACKE_dgbbrd_work)( matrix_layout, vect, m, n, ncc, kl, ku, ab, ldab,
                                 d, e, q, ldq, pt, ldpt, c, ldc, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dgbbrd", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbbrd", info );
     }
     return info;
 }
