@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dgbrfs_work( int matrix_layout, char trans, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dgbrfs_work)( int matrix_layout, char trans, lapack_int n,
                                 lapack_int kl, lapack_int ku, lapack_int nrhs,
                                 const double* ab, lapack_int ldab,
                                 const double* afb, lapack_int ldafb,
@@ -61,22 +61,22 @@ lapack_int LAPACKE_dgbrfs_work( int matrix_layout, char trans, lapack_int n,
         /* Check leading dimension(s) */
         if( ldab < n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
             return info;
         }
         if( ldafb < n ) {
             info = -10;
-            LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
             return info;
         }
         if( ldb < nrhs ) {
             info = -13;
-            LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
             return info;
         }
         if( ldx < nrhs ) {
             info = -15;
-            LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -101,11 +101,11 @@ lapack_int LAPACKE_dgbrfs_work( int matrix_layout, char trans, lapack_int n,
             goto exit_level_3;
         }
         /* Transpose input matrices */
-        LAPACKE_dgb_trans( matrix_layout, n, n, kl, ku, ab, ldab, ab_t, ldab_t );
-        LAPACKE_dgb_trans( matrix_layout, n, n, kl, kl+ku, afb, ldafb, afb_t,
+        API_SUFFIX(LAPACKE_dgb_trans)( matrix_layout, n, n, kl, ku, ab, ldab, ab_t, ldab_t );
+        API_SUFFIX(LAPACKE_dgb_trans)( matrix_layout, n, n, kl, kl+ku, afb, ldafb, afb_t,
                            ldafb_t );
-        LAPACKE_dge_trans( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
-        LAPACKE_dge_trans( matrix_layout, n, nrhs, x, ldx, x_t, ldx_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, n, nrhs, x, ldx, x_t, ldx_t );
         /* Call LAPACK function and adjust info */
         LAPACK_dgbrfs( &trans, &n, &kl, &ku, &nrhs, ab_t, &ldab_t, afb_t,
                        &ldafb_t, ipiv, b_t, &ldb_t, x_t, &ldx_t, ferr, berr,
@@ -114,7 +114,7 @@ lapack_int LAPACKE_dgbrfs_work( int matrix_layout, char trans, lapack_int n,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_dge_trans( LAPACK_COL_MAJOR, n, nrhs, x_t, ldx_t, x, ldx );
+        API_SUFFIX(LAPACKE_dge_trans)( LAPACK_COL_MAJOR, n, nrhs, x_t, ldx_t, x, ldx );
         /* Release memory and exit */
         LAPACKE_free( x_t );
 exit_level_3:
@@ -125,11 +125,11 @@ exit_level_1:
         LAPACKE_free( ab_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_dgbrfs_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgbrfs_work", info );
     }
     return info;
 }
