@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dgerqf( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dgerqf)( int matrix_layout, lapack_int m, lapack_int n,
                            double* a, lapack_int lda, double* tau )
 {
     lapack_int info = 0;
@@ -40,19 +40,19 @@ lapack_int LAPACKE_dgerqf( int matrix_layout, lapack_int m, lapack_int n,
     double* work = NULL;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dgerqf", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgerqf", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -4;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_dgerqf_work( matrix_layout, m, n, a, lda, tau, &work_query,
+    info = API_SUFFIX(LAPACKE_dgerqf_work)( matrix_layout, m, n, a, lda, tau, &work_query,
                                 lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -65,12 +65,12 @@ lapack_int LAPACKE_dgerqf( int matrix_layout, lapack_int m, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dgerqf_work( matrix_layout, m, n, a, lda, tau, work, lwork );
+    info = API_SUFFIX(LAPACKE_dgerqf_work)( matrix_layout, m, n, a, lda, tau, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dgerqf", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dgerqf", info );
     }
     return info;
 }
