@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function dggsvd3
 * Author: Intel Corporation
-* Generated August, 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dggsvd3( int matrix_layout, char jobu, char jobv, char jobq,
+lapack_int API_SUFFIX(LAPACKE_dggsvd3)( int matrix_layout, char jobu, char jobv, char jobq,
                             lapack_int m, lapack_int n, lapack_int p,
                             lapack_int* k, lapack_int* l, double* a,
                             lapack_int lda, double* b, lapack_int ldb,
@@ -46,21 +45,21 @@ lapack_int LAPACKE_dggsvd3( int matrix_layout, char jobu, char jobv, char jobq,
     lapack_int lwork = -1;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dggsvd3", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dggsvd3", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -10;
         }
-        if( LAPACKE_dge_nancheck( matrix_layout, p, n, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, p, n, b, ldb ) ) {
             return -12;
         }
     }
 #endif
-    info = LAPACKE_dggsvd3_work( matrix_layout, jobu, jobv, jobq, m, n, p, k, l,
+    info = API_SUFFIX(LAPACKE_dggsvd3_work)( matrix_layout, jobu, jobv, jobq, m, n, p, k, l,
                                  a, lda, b, ldb, alpha, beta, u, ldu, v, ldv, q,
                                  ldq, &work_query, lwork, iwork );
     if( info != 0 )
@@ -73,14 +72,14 @@ lapack_int LAPACKE_dggsvd3( int matrix_layout, char jobu, char jobv, char jobq,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dggsvd3_work( matrix_layout, jobu, jobv, jobq, m, n, p, k, l,
+    info = API_SUFFIX(LAPACKE_dggsvd3_work)( matrix_layout, jobu, jobv, jobq, m, n, p, k, l,
                                  a, lda, b, ldb, alpha, beta, u, ldu, v, ldv, q,
                                  ldq, work, lwork, iwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dggsvd3", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dggsvd3", info );
     }
     return info;
 }
