@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dlaswp_work( int matrix_layout, lapack_int n, double* a,
+lapack_int API_SUFFIX(LAPACKE_dlaswp_work)( int matrix_layout, lapack_int n, double* a,
                                 lapack_int lda, lapack_int k1, lapack_int k2,
                                 const lapack_int* ipiv, lapack_int incx )
 {
@@ -53,7 +53,7 @@ lapack_int LAPACKE_dlaswp_work( int matrix_layout, lapack_int n, double* a,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -4;
-            LAPACKE_xerbla( "LAPACKE_dlaswp_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dlaswp_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -63,21 +63,21 @@ lapack_int LAPACKE_dlaswp_work( int matrix_layout, lapack_int n, double* a,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_dge_trans( matrix_layout, lda_t, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, lda_t, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_dlaswp( &n, a_t, &lda_t, &k1, &k2, ipiv, &incx );
         info = 0;  /* LAPACK call is ok! */
         /* Transpose output matrices */
-        LAPACKE_dge_trans( LAPACK_COL_MAJOR, lda_t, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_dge_trans)( LAPACK_COL_MAJOR, lda_t, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_dlaswp_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dlaswp_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_dlaswp_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dlaswp_work", info );
     }
     return info;
 }
