@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dopmtr( int matrix_layout, char side, char uplo, char trans,
+lapack_int API_SUFFIX(LAPACKE_dopmtr)( int matrix_layout, char side, char uplo, char trans,
                            lapack_int m, lapack_int n, const double* ap,
                            const double* tau, double* c, lapack_int ldc )
 {
@@ -42,28 +42,28 @@ lapack_int LAPACKE_dopmtr( int matrix_layout, char side, char uplo, char trans,
     double* work = NULL;
     lapack_int r;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dopmtr", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dopmtr", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        r = LAPACKE_lsame( side, 'l' ) ? m : n;
-        if( LAPACKE_dsp_nancheck( r, ap ) ) {
+        r = API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ? m : n;
+        if( API_SUFFIX(LAPACKE_dsp_nancheck)( r, ap ) ) {
             return -7;
         }
-        if( LAPACKE_dge_nancheck( matrix_layout, m, n, c, ldc ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, m, n, c, ldc ) ) {
             return -9;
         }
-        if( LAPACKE_d_nancheck( r-1, tau, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_d_nancheck)( r-1, tau, 1 ) ) {
             return -8;
         }
     }
 #endif
     /* Additional scalars initializations for work arrays */
-    if( LAPACKE_lsame( side, 'l' ) ) {
+    if( API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ) {
         lwork = MAX(1,n);
-    } else if( LAPACKE_lsame( side, 'r' ) ) {
+    } else if( API_SUFFIX(LAPACKE_lsame)( side, 'r' ) ) {
         lwork = MAX(1,m);
     } else {
         lwork = 1; /* Any value */
@@ -75,13 +75,13 @@ lapack_int LAPACKE_dopmtr( int matrix_layout, char side, char uplo, char trans,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dopmtr_work( matrix_layout, side, uplo, trans, m, n, ap, tau,
+    info = API_SUFFIX(LAPACKE_dopmtr_work)( matrix_layout, side, uplo, trans, m, n, ap, tau,
                                 c, ldc, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dopmtr", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dopmtr", info );
     }
     return info;
 }
