@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dorgrq_work( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dorgrq_work)( int matrix_layout, lapack_int m, lapack_int n,
                                 lapack_int k, double* a, lapack_int lda,
                                 const double* tau, double* work,
                                 lapack_int lwork )
@@ -50,7 +50,7 @@ lapack_int LAPACKE_dorgrq_work( int matrix_layout, lapack_int m, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_dorgrq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dorgrq_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -65,23 +65,23 @@ lapack_int LAPACKE_dorgrq_work( int matrix_layout, lapack_int m, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_dge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_dorgrq( &m, &n, &k, a_t, &lda_t, tau, work, &lwork, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_dge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_dge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_dorgrq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dorgrq_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_dorgrq_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dorgrq_work", info );
     }
     return info;
 }
