@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function dpbsvx
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dpbsvx( int matrix_layout, char fact, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dpbsvx)( int matrix_layout, char fact, char uplo, lapack_int n,
                            lapack_int kd, lapack_int nrhs, double* ab,
                            lapack_int ldab, double* afb, lapack_int ldafb,
                            char* equed, double* s, double* b, lapack_int ldb,
@@ -44,25 +43,25 @@ lapack_int LAPACKE_dpbsvx( int matrix_layout, char fact, char uplo, lapack_int n
     lapack_int* iwork = NULL;
     double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dpbsvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dpbsvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dpb_nancheck( matrix_layout, uplo, n, kd, ab, ldab ) ) {
+        if( API_SUFFIX(LAPACKE_dpb_nancheck)( matrix_layout, uplo, n, kd, ab, ldab ) ) {
             return -7;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_dpb_nancheck( matrix_layout, uplo, n, kd, afb, ldafb ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_dpb_nancheck)( matrix_layout, uplo, n, kd, afb, ldafb ) ) {
                 return -9;
             }
         }
-        if( LAPACKE_dge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -13;
         }
-        if( LAPACKE_lsame( fact, 'f' ) && LAPACKE_lsame( *equed, 'y' ) ) {
-            if( LAPACKE_d_nancheck( n, s, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) && API_SUFFIX(LAPACKE_lsame)( *equed, 'y' ) ) {
+            if( API_SUFFIX(LAPACKE_d_nancheck)( n, s, 1 ) ) {
                 return -12;
             }
         }
@@ -80,7 +79,7 @@ lapack_int LAPACKE_dpbsvx( int matrix_layout, char fact, char uplo, lapack_int n
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dpbsvx_work( matrix_layout, fact, uplo, n, kd, nrhs, ab, ldab,
+    info = API_SUFFIX(LAPACKE_dpbsvx_work)( matrix_layout, fact, uplo, n, kd, nrhs, ab, ldab,
                                 afb, ldafb, equed, s, b, ldb, x, ldx, rcond,
                                 ferr, berr, work, iwork );
     /* Release memory and exit */
@@ -89,7 +88,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dpbsvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dpbsvx", info );
     }
     return info;
 }
