@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsposv( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dsposv)( int matrix_layout, char uplo, lapack_int n,
                            lapack_int nrhs, double* a, lapack_int lda,
                            double* b, lapack_int ldb, double* x, lapack_int ldx,
                            lapack_int* iter )
@@ -41,16 +41,16 @@ lapack_int LAPACKE_dsposv( int matrix_layout, char uplo, lapack_int n,
     float* swork = NULL;
     double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dsposv", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsposv", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dpo_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dpo_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
-        if( LAPACKE_dge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -7;
         }
     }
@@ -67,7 +67,7 @@ lapack_int LAPACKE_dsposv( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dsposv_work( matrix_layout, uplo, n, nrhs, a, lda, b, ldb, x,
+    info = API_SUFFIX(LAPACKE_dsposv_work)( matrix_layout, uplo, n, nrhs, a, lda, b, ldb, x,
                                 ldx, work, swork, iter );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -75,7 +75,7 @@ exit_level_1:
     LAPACKE_free( swork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dsposv", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsposv", info );
     }
     return info;
 }
