@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function dstegr
 * Author: Intel Corporation
-* Generated June 2017
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dstegr( int matrix_layout, char jobz, char range,
+lapack_int API_SUFFIX(LAPACKE_dstegr)( int matrix_layout, char jobz, char range,
                            lapack_int n, double* d, double* e, double vl,
                            double vu, lapack_int il, lapack_int iu,
                            double abstol, lapack_int* m, double* w, double* z,
@@ -47,39 +46,41 @@ lapack_int LAPACKE_dstegr( int matrix_layout, char jobz, char range,
     lapack_int iwork_query;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dstegr", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dstegr", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_d_nancheck( 1, &abstol, 1 ) ) {
-        return -11;
-    }
-    if( LAPACKE_d_nancheck( n, d, 1 ) ) {
-        return -5;
-    }
-    if( LAPACKE_d_nancheck( n-1, e, 1 ) ) {
-        return -6;
-    }
-    if( LAPACKE_lsame( range, 'v' ) ) {
-        if( LAPACKE_d_nancheck( 1, &vl, 1 ) ) {
-            return -7;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_d_nancheck)( 1, &abstol, 1 ) ) {
+            return -11;
         }
-    }
-    if( LAPACKE_lsame( range, 'v' ) ) {
-        if( LAPACKE_d_nancheck( 1, &vu, 1 ) ) {
-            return -8;
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n, d, 1 ) ) {
+            return -5;
+        }
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n-1, e, 1 ) ) {
+            return -6;
+        }
+        if( API_SUFFIX(LAPACKE_lsame)( range, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_d_nancheck)( 1, &vl, 1 ) ) {
+                return -7;
+            }
+        }
+        if( API_SUFFIX(LAPACKE_lsame)( range, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_d_nancheck)( 1, &vu, 1 ) ) {
+                return -8;
+            }
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_dstegr_work( matrix_layout, jobz, range, n, d, e, vl, vu, il,
+    info = API_SUFFIX(LAPACKE_dstegr_work)( matrix_layout, jobz, range, n, d, e, vl, vu, il,
                                 iu, abstol, m, w, z, ldz, isuppz, &work_query,
                                 lwork, &iwork_query, liwork );
     if( info != 0 ) {
         goto exit_level_0;
     }
-    liwork = (lapack_int)iwork_query;
+    liwork = iwork_query;
     lwork = (lapack_int)work_query;
     /* Allocate memory for work arrays */
     iwork = (lapack_int*)LAPACKE_malloc( sizeof(lapack_int) * liwork );
@@ -93,7 +94,7 @@ lapack_int LAPACKE_dstegr( int matrix_layout, char jobz, char range,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dstegr_work( matrix_layout, jobz, range, n, d, e, vl, vu, il,
+    info = API_SUFFIX(LAPACKE_dstegr_work)( matrix_layout, jobz, range, n, d, e, vl, vu, il,
                                 iu, abstol, m, w, z, ldz, isuppz, work, lwork,
                                 iwork, liwork );
     /* Release memory and exit */
@@ -102,7 +103,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dstegr", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dstegr", info );
     }
     return info;
 }
