@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsyev( int matrix_layout, char jobz, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dsyev)( int matrix_layout, char jobz, char uplo, lapack_int n,
                           double* a, lapack_int lda, double* w )
 {
     lapack_int info = 0;
@@ -40,19 +40,19 @@ lapack_int LAPACKE_dsyev( int matrix_layout, char jobz, char uplo, lapack_int n,
     double* work = NULL;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dsyev", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsyev", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_dsyev_work( matrix_layout, jobz, uplo, n, a, lda, w,
+    info = API_SUFFIX(LAPACKE_dsyev_work)( matrix_layout, jobz, uplo, n, a, lda, w,
                                &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -65,13 +65,13 @@ lapack_int LAPACKE_dsyev( int matrix_layout, char jobz, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dsyev_work( matrix_layout, jobz, uplo, n, a, lda, w, work,
+    info = API_SUFFIX(LAPACKE_dsyev_work)( matrix_layout, jobz, uplo, n, a, lda, w, work,
                                lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dsyev", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsyev", info );
     }
     return info;
 }
