@@ -32,24 +32,24 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsygst( int matrix_layout, lapack_int itype, char uplo,
+lapack_int API_SUFFIX(LAPACKE_dsygst)( int matrix_layout, lapack_int itype, char uplo,
                            lapack_int n, double* a, lapack_int lda,
                            const double* b, lapack_int ldb )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dsygst", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsygst", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
-        if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, b, ldb ) ) {
             return -7;
         }
     }
 #endif
-    return LAPACKE_dsygst_work( matrix_layout, itype, uplo, n, a, lda, b, ldb );
+    return API_SUFFIX(LAPACKE_dsygst_work)( matrix_layout, itype, uplo, n, a, lda, b, ldb );
 }
