@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsysv_rk_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dsysv_rk_work)( int matrix_layout, char uplo, lapack_int n,
                                lapack_int nrhs, double* a, lapack_int lda,
                                double* e, lapack_int* ipiv, double* b, lapack_int ldb,
                                double* work, lapack_int lwork )
@@ -53,12 +53,12 @@ lapack_int LAPACKE_dsysv_rk_work( int matrix_layout, char uplo, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_dsysv_rk_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysv_rk_work", info );
             return info;
         }
         if( ldb < nrhs ) {
             info = -10;
-            LAPACKE_xerbla( "LAPACKE_dsysv_rk_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysv_rk_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -79,8 +79,8 @@ lapack_int LAPACKE_dsysv_rk_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_dsy_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
-        LAPACKE_dge_trans( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
+        API_SUFFIX(LAPACKE_dsy_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_dge_trans)( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
         /* Call LAPACK function and adjust info */
         LAPACK_dsysv_rk( &uplo, &n, &nrhs, a_t, &lda_t, e, ipiv, b_t, &ldb_t, work,
                       &lwork, &info );
@@ -88,19 +88,19 @@ lapack_int LAPACKE_dsysv_rk_work( int matrix_layout, char uplo, lapack_int n,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_dsy_trans( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
-        LAPACKE_dge_trans( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
+        API_SUFFIX(LAPACKE_dsy_trans)( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_dge_trans)( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
         /* Release memory and exit */
         LAPACKE_free( b_t );
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_dsysv_rk_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysv_rk_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_dsysv_rk_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysv_rk_work", info );
     }
     return info;
 }
