@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsysvx( int matrix_layout, char fact, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dsysvx)( int matrix_layout, char fact, char uplo, lapack_int n,
                            lapack_int nrhs, const double* a, lapack_int lda,
                            double* af, lapack_int ldaf, lapack_int* ipiv,
                            const double* b, lapack_int ldb, double* x,
@@ -45,21 +45,21 @@ lapack_int LAPACKE_dsysvx( int matrix_layout, char fact, char uplo, lapack_int n
     double* work = NULL;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dsysvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -6;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, af, ldaf ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, af, ldaf ) ) {
                 return -8;
             }
         }
-        if( LAPACKE_dge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -11;
         }
     }
@@ -71,7 +71,7 @@ lapack_int LAPACKE_dsysvx( int matrix_layout, char fact, char uplo, lapack_int n
         goto exit_level_0;
     }
     /* Query optimal working array(s) size */
-    info = LAPACKE_dsysvx_work( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
+    info = API_SUFFIX(LAPACKE_dsysvx_work)( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
                                 ldaf, ipiv, b, ldb, x, ldx, rcond, ferr, berr,
                                 &work_query, lwork, iwork );
     if( info != 0 ) {
@@ -85,7 +85,7 @@ lapack_int LAPACKE_dsysvx( int matrix_layout, char fact, char uplo, lapack_int n
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dsysvx_work( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
+    info = API_SUFFIX(LAPACKE_dsysvx_work)( matrix_layout, fact, uplo, n, nrhs, a, lda, af,
                                 ldaf, ipiv, b, ldb, x, ldx, rcond, ferr, berr,
                                 work, lwork, iwork );
     /* Release memory and exit */
@@ -94,7 +94,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dsysvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsysvx", info );
     }
     return info;
 }
