@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function dsytrs_aa
 * Author: Intel Corporation
-* Generated June 2017
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dsytrs_aa( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dsytrs_aa)( int matrix_layout, char uplo, lapack_int n,
                             lapack_int nrhs, const double* a, lapack_int lda,
                             const lapack_int* ipiv, double* b, lapack_int ldb )
 {
@@ -42,20 +41,22 @@ lapack_int LAPACKE_dsytrs_aa( int matrix_layout, char uplo, lapack_int n,
     double* work = NULL;
     double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dsytrs_aa", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsytrs_aa", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_dsy_nancheck( matrix_layout, uplo, n, a, lda ) ) {
-        return -5;
-    }
-    if( LAPACKE_dge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
-        return -8;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_dsy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
+            return -5;
+        }
+        if( API_SUFFIX(LAPACKE_dge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
+            return -8;
+        }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_dsytrs_aa_work( matrix_layout, uplo, n, nrhs, a, lda, ipiv, b,
+    info = API_SUFFIX(LAPACKE_dsytrs_aa_work)( matrix_layout, uplo, n, nrhs, a, lda, ipiv, b,
                                  ldb, &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -69,13 +70,13 @@ lapack_int LAPACKE_dsytrs_aa( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dsytrs_aa_work( matrix_layout, uplo, n, nrhs, a, lda, ipiv, b,
+    info = API_SUFFIX(LAPACKE_dsytrs_aa_work)( matrix_layout, uplo, n, nrhs, a, lda, ipiv, b,
                                  ldb, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dsytrs_aa", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dsytrs_aa", info );
     }
     return info;
 }
