@@ -32,20 +32,20 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dtpcon( int matrix_layout, char norm, char uplo, char diag,
+lapack_int API_SUFFIX(LAPACKE_dtpcon)( int matrix_layout, char norm, char uplo, char diag,
                            lapack_int n, const double* ap, double* rcond )
 {
     lapack_int info = 0;
     lapack_int* iwork = NULL;
     double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dtpcon", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dtpcon", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dtp_nancheck( matrix_layout, uplo, diag, n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_dtp_nancheck)( matrix_layout, uplo, diag, n, ap ) ) {
             return -6;
         }
     }
@@ -62,7 +62,7 @@ lapack_int LAPACKE_dtpcon( int matrix_layout, char norm, char uplo, char diag,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_dtpcon_work( matrix_layout, norm, uplo, diag, n, ap, rcond,
+    info = API_SUFFIX(LAPACKE_dtpcon_work)( matrix_layout, norm, uplo, diag, n, ap, rcond,
                                 work, iwork );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -70,7 +70,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_dtpcon", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dtpcon", info );
     }
     return info;
 }
