@@ -32,20 +32,20 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_dtrtri( int matrix_layout, char uplo, char diag, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_dtrtri)( int matrix_layout, char uplo, char diag, lapack_int n,
                            double* a, lapack_int lda )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_dtrtri", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_dtrtri", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_dtr_nancheck( matrix_layout, uplo, diag, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_dtr_nancheck)( matrix_layout, uplo, diag, n, a, lda ) ) {
             return -5;
         }
     }
 #endif
-    return LAPACKE_dtrtri_work( matrix_layout, uplo, diag, n, a, lda );
+    return API_SUFFIX(LAPACKE_dtrtri_work)( matrix_layout, uplo, diag, n, a, lda );
 }
