@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sgebrd_work( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_sgebrd_work)( int matrix_layout, lapack_int m, lapack_int n,
                                 float* a, lapack_int lda, float* d, float* e,
                                 float* tauq, float* taup, float* work,
                                 lapack_int lwork )
@@ -50,7 +50,7 @@ lapack_int LAPACKE_sgebrd_work( int matrix_layout, lapack_int m, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -5;
-            LAPACKE_xerbla( "LAPACKE_sgebrd_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgebrd_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -66,7 +66,7 @@ lapack_int LAPACKE_sgebrd_work( int matrix_layout, lapack_int m, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_sge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_sgebrd( &m, &n, a_t, &lda_t, d, e, tauq, taup, work, &lwork,
                        &info );
@@ -74,16 +74,16 @@ lapack_int LAPACKE_sgebrd_work( int matrix_layout, lapack_int m, lapack_int n,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_sgebrd_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgebrd_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_sgebrd_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgebrd_work", info );
     }
     return info;
 }
