@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sgeqr2_work( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_sgeqr2_work)( int matrix_layout, lapack_int m, lapack_int n,
                                 float* a, lapack_int lda, float* tau,
                                 float* work )
 {
@@ -49,7 +49,7 @@ lapack_int LAPACKE_sgeqr2_work( int matrix_layout, lapack_int m, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -5;
-            LAPACKE_xerbla( "LAPACKE_sgeqr2_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgeqr2_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -59,23 +59,23 @@ lapack_int LAPACKE_sgeqr2_work( int matrix_layout, lapack_int m, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_sge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_sgeqr2( &m, &n, a_t, &lda_t, tau, work, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_sgeqr2_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgeqr2_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_sgeqr2_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sgeqr2_work", info );
     }
     return info;
 }
