@@ -32,19 +32,19 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_slacn2( lapack_int n, float* v, float* x, lapack_int* isgn,
+lapack_int API_SUFFIX(LAPACKE_slacn2)( lapack_int n, float* v, float* x, lapack_int* isgn,
                            float* est, lapack_int* kase, lapack_int* isave )
 {
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_s_nancheck( 1, est, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( 1, est, 1 ) ) {
             return -5;
         }
-        if( LAPACKE_s_nancheck( n, x, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( n, x, 1 ) ) {
             return -3;
         }
     }
 #endif
-    return LAPACKE_slacn2_work( n, v, x, isgn, est, kase, isave );
+    return API_SUFFIX(LAPACKE_slacn2_work)( n, v, x, isgn, est, kase, isave );
 }
