@@ -28,24 +28,23 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function slarfg
 * Author: Intel Corporation
-* Generated November, 2011
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_slarfg( lapack_int n, float* alpha, float* x,
+lapack_int API_SUFFIX(LAPACKE_slarfg)( lapack_int n, float* alpha, float* x,
                            lapack_int incx, float* tau )
 {
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_s_nancheck( 1, alpha, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( 1, alpha, 1 ) ) {
             return -2;
         }
-        if( LAPACKE_s_nancheck( 1+(n-2)*ABS(incx), x, incx ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( n-1, x, incx ) ) {
             return -3;
         }
     }
 #endif
-    return LAPACKE_slarfg_work( n, alpha, x, incx, tau );
+    return API_SUFFIX(LAPACKE_slarfg_work)( n, alpha, x, incx, tau );
 }
