@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sorghr_work( int matrix_layout, lapack_int n, lapack_int ilo,
+lapack_int API_SUFFIX(LAPACKE_sorghr_work)( int matrix_layout, lapack_int n, lapack_int ilo,
                                 lapack_int ihi, float* a, lapack_int lda,
                                 const float* tau, float* work,
                                 lapack_int lwork )
@@ -50,7 +50,7 @@ lapack_int LAPACKE_sorghr_work( int matrix_layout, lapack_int n, lapack_int ilo,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_sorghr_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sorghr_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -66,23 +66,23 @@ lapack_int LAPACKE_sorghr_work( int matrix_layout, lapack_int n, lapack_int ilo,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_sge_trans( matrix_layout, n, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, n, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_sorghr( &n, &ilo, &ihi, a_t, &lda_t, tau, work, &lwork, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, n, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, n, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_sorghr_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sorghr_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_sorghr_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sorghr_work", info );
     }
     return info;
 }
