@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sormlq_work( int matrix_layout, char side, char trans,
+lapack_int API_SUFFIX(LAPACKE_sormlq_work)( int matrix_layout, char side, char trans,
                                 lapack_int m, lapack_int n, lapack_int k,
                                 const float* a, lapack_int lda,
                                 const float* tau, float* c, lapack_int ldc,
@@ -47,7 +47,7 @@ lapack_int LAPACKE_sormlq_work( int matrix_layout, char side, char trans,
             info = info - 1;
         }
     } else if( matrix_layout == LAPACK_ROW_MAJOR ) {
-        lapack_int r = LAPACKE_lsame( side, 'l' ) ? m : n;
+        lapack_int r = API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ? m : n;
         lapack_int lda_t = MAX(1,k);
         lapack_int ldc_t = MAX(1,m);
         float *a_t = NULL;
@@ -55,12 +55,12 @@ lapack_int LAPACKE_sormlq_work( int matrix_layout, char side, char trans,
         /* Check leading dimension(s) */
         if( lda < r ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_sormlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sormlq_work", info );
             return info;
         }
         if( ldc < n ) {
             info = -11;
-            LAPACKE_xerbla( "LAPACKE_sormlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sormlq_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -81,8 +81,8 @@ lapack_int LAPACKE_sormlq_work( int matrix_layout, char side, char trans,
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_sge_trans( matrix_layout, k, r, a, lda, a_t, lda_t );
-        LAPACKE_sge_trans( matrix_layout, m, n, c, ldc, c_t, ldc_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, k, r, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, m, n, c, ldc, c_t, ldc_t );
         /* Call LAPACK function and adjust info */
         LAPACK_sormlq( &side, &trans, &m, &n, &k, a_t, &lda_t, tau, c_t, &ldc_t,
                        work, &lwork, &info );
@@ -90,18 +90,18 @@ lapack_int LAPACKE_sormlq_work( int matrix_layout, char side, char trans,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, m, n, c_t, ldc_t, c, ldc );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, m, n, c_t, ldc_t, c, ldc );
         /* Release memory and exit */
         LAPACKE_free( c_t );
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_sormlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sormlq_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_sormlq_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sormlq_work", info );
     }
     return info;
 }
