@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_spbsvx( int matrix_layout, char fact, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_spbsvx)( int matrix_layout, char fact, char uplo, lapack_int n,
                            lapack_int kd, lapack_int nrhs, float* ab,
                            lapack_int ldab, float* afb, lapack_int ldafb,
                            char* equed, float* s, float* b, lapack_int ldb,
@@ -43,25 +43,25 @@ lapack_int LAPACKE_spbsvx( int matrix_layout, char fact, char uplo, lapack_int n
     lapack_int* iwork = NULL;
     float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_spbsvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_spbsvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_spb_nancheck( matrix_layout, uplo, n, kd, ab, ldab ) ) {
+        if( API_SUFFIX(LAPACKE_spb_nancheck)( matrix_layout, uplo, n, kd, ab, ldab ) ) {
             return -7;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_spb_nancheck( matrix_layout, uplo, n, kd, afb, ldafb ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_spb_nancheck)( matrix_layout, uplo, n, kd, afb, ldafb ) ) {
                 return -9;
             }
         }
-        if( LAPACKE_sge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -13;
         }
-        if( LAPACKE_lsame( fact, 'f' ) && LAPACKE_lsame( *equed, 'y' ) ) {
-            if( LAPACKE_s_nancheck( n, s, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) && API_SUFFIX(LAPACKE_lsame)( *equed, 'y' ) ) {
+            if( API_SUFFIX(LAPACKE_s_nancheck)( n, s, 1 ) ) {
                 return -12;
             }
         }
@@ -79,7 +79,7 @@ lapack_int LAPACKE_spbsvx( int matrix_layout, char fact, char uplo, lapack_int n
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_spbsvx_work( matrix_layout, fact, uplo, n, kd, nrhs, ab, ldab,
+    info = API_SUFFIX(LAPACKE_spbsvx_work)( matrix_layout, fact, uplo, n, kd, nrhs, ab, ldab,
                                 afb, ldafb, equed, s, b, ldb, x, ldx, rcond,
                                 ferr, berr, work, iwork );
     /* Release memory and exit */
@@ -88,7 +88,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_spbsvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_spbsvx", info );
     }
     return info;
 }
