@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sppsvx_work( int matrix_layout, char fact, char uplo,
+lapack_int API_SUFFIX(LAPACKE_sppsvx_work)( int matrix_layout, char fact, char uplo,
                                 lapack_int n, lapack_int nrhs, float* ap,
                                 float* afp, char* equed, float* s, float* b,
                                 lapack_int ldb, float* x, lapack_int ldx,
@@ -57,12 +57,12 @@ lapack_int LAPACKE_sppsvx_work( int matrix_layout, char fact, char uplo,
         /* Check leading dimension(s) */
         if( ldb < nrhs ) {
             info = -11;
-            LAPACKE_xerbla( "LAPACKE_sppsvx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sppsvx_work", info );
             return info;
         }
         if( ldx < nrhs ) {
             info = -13;
-            LAPACKE_xerbla( "LAPACKE_sppsvx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sppsvx_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -89,10 +89,10 @@ lapack_int LAPACKE_sppsvx_work( int matrix_layout, char fact, char uplo,
             goto exit_level_3;
         }
         /* Transpose input matrices */
-        LAPACKE_sge_trans( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
-        LAPACKE_spp_trans( matrix_layout, uplo, n, ap, ap_t );
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            LAPACKE_spp_trans( matrix_layout, uplo, n, afp, afp_t );
+        API_SUFFIX(LAPACKE_sge_trans)( matrix_layout, n, nrhs, b, ldb, b_t, ldb_t );
+        API_SUFFIX(LAPACKE_spp_trans)( matrix_layout, uplo, n, ap, ap_t );
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            API_SUFFIX(LAPACKE_spp_trans)( matrix_layout, uplo, n, afp, afp_t );
         }
         /* Call LAPACK function and adjust info */
         LAPACK_sppsvx( &fact, &uplo, &n, &nrhs, ap_t, afp_t, equed, s, b_t,
@@ -102,13 +102,13 @@ lapack_int LAPACKE_sppsvx_work( int matrix_layout, char fact, char uplo,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
-        LAPACKE_sge_trans( LAPACK_COL_MAJOR, n, nrhs, x_t, ldx_t, x, ldx );
-        if( LAPACKE_lsame( fact, 'e' ) && LAPACKE_lsame( *equed, 'y' ) ) {
-            LAPACKE_spp_trans( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, n, nrhs, b_t, ldb_t, b, ldb );
+        API_SUFFIX(LAPACKE_sge_trans)( LAPACK_COL_MAJOR, n, nrhs, x_t, ldx_t, x, ldx );
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'e' ) && API_SUFFIX(LAPACKE_lsame)( *equed, 'y' ) ) {
+            API_SUFFIX(LAPACKE_spp_trans)( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
         }
-        if( LAPACKE_lsame( fact, 'e' ) || LAPACKE_lsame( fact, 'n' ) ) {
-            LAPACKE_spp_trans( LAPACK_COL_MAJOR, uplo, n, afp_t, afp );
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'e' ) || API_SUFFIX(LAPACKE_lsame)( fact, 'n' ) ) {
+            API_SUFFIX(LAPACKE_spp_trans)( LAPACK_COL_MAJOR, uplo, n, afp_t, afp );
         }
         /* Release memory and exit */
         LAPACKE_free( afp_t );
@@ -120,11 +120,11 @@ exit_level_1:
         LAPACKE_free( b_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_sppsvx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sppsvx_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_sppsvx_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sppsvx_work", info );
     }
     return info;
 }
