@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_sptsvx( int matrix_layout, char fact, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_sptsvx)( int matrix_layout, char fact, lapack_int n,
                            lapack_int nrhs, const float* d, const float* e,
                            float* df, float* ef, const float* b, lapack_int ldb,
                            float* x, lapack_int ldx, float* rcond, float* ferr,
@@ -41,28 +41,28 @@ lapack_int LAPACKE_sptsvx( int matrix_layout, char fact, lapack_int n,
     lapack_int info = 0;
     float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_sptsvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sptsvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_sge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -9;
         }
-        if( LAPACKE_s_nancheck( n, d, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( n, d, 1 ) ) {
             return -5;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_s_nancheck( n, df, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_s_nancheck)( n, df, 1 ) ) {
                 return -7;
             }
         }
-        if( LAPACKE_s_nancheck( n-1, e, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( n-1, e, 1 ) ) {
             return -6;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_s_nancheck( n-1, ef, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_s_nancheck)( n-1, ef, 1 ) ) {
                 return -8;
             }
         }
@@ -75,13 +75,13 @@ lapack_int LAPACKE_sptsvx( int matrix_layout, char fact, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_sptsvx_work( matrix_layout, fact, n, nrhs, d, e, df, ef, b,
+    info = API_SUFFIX(LAPACKE_sptsvx_work)( matrix_layout, fact, n, nrhs, d, e, df, ef, b,
                                 ldb, x, ldx, rcond, ferr, berr, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_sptsvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_sptsvx", info );
     }
     return info;
 }
