@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_ssycon_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_ssycon_work)( int matrix_layout, char uplo, lapack_int n,
                                 const float* a, lapack_int lda,
                                 const lapack_int* ipiv, float anorm,
                                 float* rcond, float* work, lapack_int* iwork )
@@ -51,7 +51,7 @@ lapack_int LAPACKE_ssycon_work( int matrix_layout, char uplo, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -5;
-            LAPACKE_xerbla( "LAPACKE_ssycon_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ssycon_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -61,7 +61,7 @@ lapack_int LAPACKE_ssycon_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_ssy_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_ssy_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_ssycon( &uplo, &n, a_t, &lda_t, ipiv, &anorm, rcond, work, iwork,
                        &info );
@@ -72,11 +72,11 @@ lapack_int LAPACKE_ssycon_work( int matrix_layout, char uplo, lapack_int n,
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_ssycon_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ssycon_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_ssycon_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ssycon_work", info );
     }
     return info;
 }
