@@ -28,26 +28,25 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function ssyconv
 * Author: Intel Corporation
-* Generated June 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_ssyconv( int matrix_layout, char uplo, char way, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_ssyconv)( int matrix_layout, char uplo, char way, lapack_int n,
                             float* a, lapack_int lda, const lapack_int* ipiv, float* e )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_ssyconv", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_ssyconv", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_sge_nancheck( matrix_layout, n, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_ssy_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -5;
         }
     }
 #endif
     /* Call middle-level interface */
-    return LAPACKE_ssyconv_work( matrix_layout, uplo, way, n, a, lda, ipiv, e );
+    return API_SUFFIX(LAPACKE_ssyconv_work)( matrix_layout, uplo, way, n, a, lda, ipiv, e );
 }
