@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_stgsja( int matrix_layout, char jobu, char jobv, char jobq,
+lapack_int API_SUFFIX(LAPACKE_stgsja)( int matrix_layout, char jobu, char jobv, char jobq,
                            lapack_int m, lapack_int p, lapack_int n,
                            lapack_int k, lapack_int l, float* a, lapack_int lda,
                            float* b, lapack_int ldb, float tola, float tolb,
@@ -43,36 +43,36 @@ lapack_int LAPACKE_stgsja( int matrix_layout, char jobu, char jobv, char jobq,
     lapack_int info = 0;
     float* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_stgsja", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_stgsja", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_sge_nancheck( matrix_layout, m, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, m, n, a, lda ) ) {
             return -10;
         }
-        if( LAPACKE_sge_nancheck( matrix_layout, p, n, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, p, n, b, ldb ) ) {
             return -12;
         }
-        if( LAPACKE_lsame( jobq, 'i' ) || LAPACKE_lsame( jobq, 'q' ) ) {
-            if( LAPACKE_sge_nancheck( matrix_layout, n, n, q, ldq ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobq, 'i' ) || API_SUFFIX(LAPACKE_lsame)( jobq, 'q' ) ) {
+            if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, n, n, q, ldq ) ) {
                 return -22;
             }
         }
-        if( LAPACKE_s_nancheck( 1, &tola, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( 1, &tola, 1 ) ) {
             return -14;
         }
-        if( LAPACKE_s_nancheck( 1, &tolb, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_s_nancheck)( 1, &tolb, 1 ) ) {
             return -15;
         }
-        if( LAPACKE_lsame( jobu, 'i' ) || LAPACKE_lsame( jobu, 'u' ) ) {
-            if( LAPACKE_sge_nancheck( matrix_layout, m, m, u, ldu ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobu, 'i' ) || API_SUFFIX(LAPACKE_lsame)( jobu, 'u' ) ) {
+            if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, m, m, u, ldu ) ) {
                 return -18;
             }
         }
-        if( LAPACKE_lsame( jobv, 'i' ) || LAPACKE_lsame( jobv, 'v' ) ) {
-            if( LAPACKE_sge_nancheck( matrix_layout, p, p, v, ldv ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'i' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_sge_nancheck)( matrix_layout, p, p, v, ldv ) ) {
                 return -20;
             }
         }
@@ -85,14 +85,14 @@ lapack_int LAPACKE_stgsja( int matrix_layout, char jobu, char jobv, char jobq,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_stgsja_work( matrix_layout, jobu, jobv, jobq, m, p, n, k, l,
+    info = API_SUFFIX(LAPACKE_stgsja_work)( matrix_layout, jobu, jobv, jobq, m, p, n, k, l,
                                 a, lda, b, ldb, tola, tolb, alpha, beta, u, ldu,
                                 v, ldv, q, ldq, work, ncycle );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_stgsja", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_stgsja", info );
     }
     return info;
 }
