@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgeesx_work( int matrix_layout, char jobvs, char sort,
+lapack_int API_SUFFIX(LAPACKE_zgeesx_work)( int matrix_layout, char jobvs, char sort,
                                 LAPACK_Z_SELECT1 select, char sense,
                                 lapack_int n, lapack_complex_double* a,
                                 lapack_int lda, lapack_int* sdim,
@@ -59,12 +59,12 @@ lapack_int LAPACKE_zgeesx_work( int matrix_layout, char jobvs, char sort,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_zgeesx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeesx_work", info );
             return info;
         }
         if( ldvs < n ) {
             info = -12;
-            LAPACKE_xerbla( "LAPACKE_zgeesx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeesx_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -81,7 +81,7 @@ lapack_int LAPACKE_zgeesx_work( int matrix_layout, char jobvs, char sort,
             info = LAPACK_TRANSPOSE_MEMORY_ERROR;
             goto exit_level_0;
         }
-        if( LAPACKE_lsame( jobvs, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobvs, 'v' ) ) {
             vs_t = (lapack_complex_double*)
                 LAPACKE_malloc( sizeof(lapack_complex_double) *
                                 ldvs_t * MAX(1,n) );
@@ -91,7 +91,7 @@ lapack_int LAPACKE_zgeesx_work( int matrix_layout, char jobvs, char sort,
             }
         }
         /* Transpose input matrices */
-        LAPACKE_zge_trans( matrix_layout, n, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, n, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zgeesx( &jobvs, &sort, select, &sense, &n, a_t, &lda_t, sdim, w,
                        vs_t, &ldvs_t, rconde, rcondv, work, &lwork, rwork,
@@ -100,23 +100,23 @@ lapack_int LAPACKE_zgeesx_work( int matrix_layout, char jobvs, char sort,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zge_trans( LAPACK_COL_MAJOR, n, n, a_t, lda_t, a, lda );
-        if( LAPACKE_lsame( jobvs, 'v' ) ) {
-            LAPACKE_zge_trans( LAPACK_COL_MAJOR, n, n, vs_t, ldvs_t, vs, ldvs );
+        API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, n, n, a_t, lda_t, a, lda );
+        if( API_SUFFIX(LAPACKE_lsame)( jobvs, 'v' ) ) {
+            API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, n, n, vs_t, ldvs_t, vs, ldvs );
         }
         /* Release memory and exit */
-        if( LAPACKE_lsame( jobvs, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobvs, 'v' ) ) {
             LAPACKE_free( vs_t );
         }
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zgeesx_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeesx_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zgeesx_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeesx_work", info );
     }
     return info;
 }
