@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgehrd( int matrix_layout, lapack_int n, lapack_int ilo,
+lapack_int API_SUFFIX(LAPACKE_zgehrd)( int matrix_layout, lapack_int n, lapack_int ilo,
                            lapack_int ihi, lapack_complex_double* a,
                            lapack_int lda, lapack_complex_double* tau )
 {
@@ -41,19 +41,19 @@ lapack_int LAPACKE_zgehrd( int matrix_layout, lapack_int n, lapack_int ilo,
     lapack_complex_double* work = NULL;
     lapack_complex_double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zgehrd", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgehrd", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_zge_nancheck( matrix_layout, n, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, n, a, lda ) ) {
             return -5;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_zgehrd_work( matrix_layout, n, ilo, ihi, a, lda, tau,
+    info = API_SUFFIX(LAPACKE_zgehrd_work)( matrix_layout, n, ilo, ihi, a, lda, tau,
                                 &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -67,13 +67,13 @@ lapack_int LAPACKE_zgehrd( int matrix_layout, lapack_int n, lapack_int ilo,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zgehrd_work( matrix_layout, n, ilo, ihi, a, lda, tau, work,
+    info = API_SUFFIX(LAPACKE_zgehrd_work)( matrix_layout, n, ilo, ihi, a, lda, tau, work,
                                 lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zgehrd", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgehrd", info );
     }
     return info;
 }
