@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zgemqr
 * Author: Intel Corporation
-* Generated December 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgemqr( int matrix_layout, char side, char trans,
+lapack_int API_SUFFIX(LAPACKE_zgemqr)( int matrix_layout, char side, char trans,
                            lapack_int m, lapack_int n, lapack_int k,
                            const lapack_complex_double* a, lapack_int lda,
                            const lapack_complex_double* t, lapack_int tsize,
@@ -45,26 +44,26 @@ lapack_int LAPACKE_zgemqr( int matrix_layout, char side, char trans,
     lapack_complex_double work_query;
     lapack_int r;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zgemqr", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgemqr", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        r = LAPACKE_lsame( side, 'l' ) ? m : n;
-        if( LAPACKE_zge_nancheck( matrix_layout, r, k, a, lda ) ) {
+        r = API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ? m : n;
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, r, k, a, lda ) ) {
             return -7;
         }
-        if( LAPACKE_zge_nancheck( matrix_layout, m, n, c, ldc ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, m, n, c, ldc ) ) {
             return -10;
         }
-        if( LAPACKE_z_nancheck( tsize, t, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_z_nancheck)( tsize, t, 1 ) ) {
             return -9;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_zgemqr_work( matrix_layout, side, trans, m, n, k, a, lda,
+    info = API_SUFFIX(LAPACKE_zgemqr_work)( matrix_layout, side, trans, m, n, k, a, lda,
                                 t, tsize, c, ldc, &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -78,13 +77,13 @@ lapack_int LAPACKE_zgemqr( int matrix_layout, char side, char trans,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zgemqr_work( matrix_layout, side, trans, m, n, k, a, lda,
+    info = API_SUFFIX(LAPACKE_zgemqr_work)( matrix_layout, side, trans, m, n, k, a, lda,
                                 t, tsize, c, ldc, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zgemqr", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgemqr", info );
     }
     return info;
 }
