@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgeqrt_work( int matrix_layout, lapack_int m, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zgeqrt_work)( int matrix_layout, lapack_int m, lapack_int n,
                                 lapack_int nb, lapack_complex_double* a,
                                 lapack_int lda, lapack_complex_double* t,
                                 lapack_int ldt, lapack_complex_double* work )
@@ -52,12 +52,12 @@ lapack_int LAPACKE_zgeqrt_work( int matrix_layout, lapack_int m, lapack_int n,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_zgeqrt_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeqrt_work", info );
             return info;
         }
         if( ldt < MIN(m,n) ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_zgeqrt_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeqrt_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -75,15 +75,15 @@ lapack_int LAPACKE_zgeqrt_work( int matrix_layout, lapack_int m, lapack_int n,
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_zge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zgeqrt( &m, &n, &nb, a_t, &lda_t, t_t, &ldt_t, work, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
-        LAPACKE_zge_trans( LAPACK_COL_MAJOR, ldt, MIN(m,n), t_t, ldt_t, t,
+        API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, nb, MIN(m,n), t_t, ldt_t, t,
                            ldt );
         /* Release memory and exit */
         LAPACKE_free( t_t );
@@ -91,11 +91,11 @@ exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zgeqrt_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeqrt_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zgeqrt_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgeqrt_work", info );
     }
     return info;
 }
