@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function zgesvj
 * Author: Intel Corporation
-* Generated June 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgesvj_work( int matrix_layout, char joba, char jobu,
+lapack_int API_SUFFIX(LAPACKE_zgesvj_work)( int matrix_layout, char joba, char jobu,
                                 char jobv, lapack_int m, lapack_int n,
                                 lapack_complex_double* a, lapack_int lda,
                                 double* sva, lapack_int mv,
@@ -50,8 +49,8 @@ lapack_int LAPACKE_zgesvj_work( int matrix_layout, char joba, char jobu,
             info = info - 1;
         }
     } else if( matrix_layout == LAPACK_ROW_MAJOR ) {
-        lapack_int nrows_v = LAPACKE_lsame( jobv, 'v' ) ? MAX(0,n) :
-                           ( LAPACKE_lsame( jobv, 'a' ) ? MAX(0,mv) : 0);
+        lapack_int nrows_v = API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ? MAX(0,n) :
+                           ( API_SUFFIX(LAPACKE_lsame)( jobv, 'a' ) ? MAX(0,mv) : 0);
         lapack_int lda_t = MAX(1,m);
         lapack_int ldv_t = MAX(1,nrows_v);
         lapack_complex_double* a_t = NULL;
@@ -59,12 +58,12 @@ lapack_int LAPACKE_zgesvj_work( int matrix_layout, char joba, char jobu,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_zgesvj_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgesvj_work", info );
             return info;
         }
         if( ldv < n ) {
             info = -12;
-            LAPACKE_xerbla( "LAPACKE_zgesvj_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgesvj_work", info );
             return info;
         }
         /* Allocate memory for temporary array(s) */
@@ -74,18 +73,18 @@ lapack_int LAPACKE_zgesvj_work( int matrix_layout, char joba, char jobu,
             info = LAPACK_TRANSPOSE_MEMORY_ERROR;
             goto exit_level_0;
         }
-        if( LAPACKE_lsame( jobv, 'a' ) || LAPACKE_lsame( jobv, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'a' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ) {
             v_t = (lapack_complex_double*)
-            	LAPACKE_malloc( sizeof(lapack_complex_double) * ldv_t * MAX(1,n) );
+               LAPACKE_malloc( sizeof(lapack_complex_double) * ldv_t * MAX(1,n) );
             if( v_t == NULL ) {
                 info = LAPACK_TRANSPOSE_MEMORY_ERROR;
                 goto exit_level_1;
             }
         }
         /* Transpose input matrices */
-        LAPACKE_zge_trans( matrix_layout, m, n, a, lda, a_t, lda_t );
-        if( LAPACKE_lsame( jobv, 'a' ) ) {
-            LAPACKE_zge_trans( matrix_layout, nrows_v, n, v, ldv, v_t, ldv_t );
+        API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, m, n, a, lda, a_t, lda_t );
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'a' ) ) {
+            API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, nrows_v, n, v, ldv, v_t, ldv_t );
         }
         /* Call LAPACK function and adjust info */
         LAPACK_zgesvj( &joba, &jobu, &jobv, &m, &n, a_t, &lda_t, sva, &mv, v_t,
@@ -94,24 +93,24 @@ lapack_int LAPACKE_zgesvj_work( int matrix_layout, char joba, char jobu,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zge_trans( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
-        if( LAPACKE_lsame( jobv, 'a' ) || LAPACKE_lsame( jobv, 'v' ) ) {
-            LAPACKE_zge_trans( LAPACK_COL_MAJOR, nrows_v, n, v_t, ldv_t, v,
+        API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, m, n, a_t, lda_t, a, lda );
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'a' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ) {
+            API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, nrows_v, n, v_t, ldv_t, v,
                                ldv );
         }
         /* Release memory and exit */
-        if( LAPACKE_lsame( jobv, 'a' ) || LAPACKE_lsame( jobv, 'v' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( jobv, 'a' ) || API_SUFFIX(LAPACKE_lsame)( jobv, 'v' ) ) {
             LAPACKE_free( v_t );
         }
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zgesvj_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgesvj_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zgesvj_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgesvj_work", info );
     }
     return info;
 }
