@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function zgghd3
 * Author: Intel Corporation
-* Generated January, 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgghd3( int matrix_layout, char compq, char compz,
+lapack_int API_SUFFIX(LAPACKE_zgghd3)( int matrix_layout, char compq, char compz,
                            lapack_int n, lapack_int ilo, lapack_int ihi,
                            lapack_complex_double* a, lapack_int lda,
                            lapack_complex_double* b, lapack_int ldb,
@@ -46,30 +45,32 @@ lapack_int LAPACKE_zgghd3( int matrix_layout, char compq, char compz,
     lapack_complex_double work_query;
 
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zgghd3", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgghd3", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_zge_nancheck( matrix_layout, n, n, a, lda ) ) {
-        return -7;
-    }
-    if( LAPACKE_zge_nancheck( matrix_layout, n, n, b, ldb ) ) {
-        return -9;
-    }
-    if( LAPACKE_lsame( compq, 'i' ) || LAPACKE_lsame( compq, 'v' ) ) {
-        if( LAPACKE_zge_nancheck( matrix_layout, n, n, q, ldq ) ) {
-            return -11;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, n, a, lda ) ) {
+            return -7;
         }
-    }
-    if( LAPACKE_lsame( compz, 'i' ) || LAPACKE_lsame( compz, 'v' ) ) {
-        if( LAPACKE_zge_nancheck( matrix_layout, n, n, z, ldz ) ) {
-            return -13;
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, n, b, ldb ) ) {
+            return -9;
+        }
+        if( API_SUFFIX(LAPACKE_lsame)( compq, 'i' ) || API_SUFFIX(LAPACKE_lsame)( compq, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, n, q, ldq ) ) {
+                return -11;
+            }
+        }
+        if( API_SUFFIX(LAPACKE_lsame)( compz, 'i' ) || API_SUFFIX(LAPACKE_lsame)( compz, 'v' ) ) {
+            if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, n, z, ldz ) ) {
+                return -13;
+            }
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info =  LAPACKE_zgghd3_work( matrix_layout, compq, compz, n, ilo, ihi,
+    info =  API_SUFFIX(LAPACKE_zgghd3_work)( matrix_layout, compq, compz, n, ilo, ihi,
                                  a, lda, b, ldb, q, ldq, z, ldz, &work_query,
                                  lwork );
     if( info != 0 ) {
@@ -84,14 +85,14 @@ lapack_int LAPACKE_zgghd3( int matrix_layout, char compq, char compz,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info =  LAPACKE_zgghd3_work( matrix_layout, compq, compz, n, ilo, ihi,
+    info =  API_SUFFIX(LAPACKE_zgghd3_work)( matrix_layout, compq, compz, n, ilo, ihi,
                                  a, lda, b, ldb, q, ldq, z, ldz, work,
                                  lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zgghd3", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgghd3", info );
     }
     return info;
 }
