@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zgtsvx
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zgtsvx( int matrix_layout, char fact, char trans,
+lapack_int API_SUFFIX(LAPACKE_zgtsvx)( int matrix_layout, char fact, char trans,
                            lapack_int n, lapack_int nrhs,
                            const lapack_complex_double* dl,
                            const lapack_complex_double* d,
@@ -50,41 +49,41 @@ lapack_int LAPACKE_zgtsvx( int matrix_layout, char fact, char trans,
     double* rwork = NULL;
     lapack_complex_double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zgtsvx", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgtsvx", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_zge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -14;
         }
-        if( LAPACKE_z_nancheck( n, d, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_z_nancheck)( n, d, 1 ) ) {
             return -7;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_z_nancheck( n, df, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_z_nancheck)( n, df, 1 ) ) {
                 return -10;
             }
         }
-        if( LAPACKE_z_nancheck( n-1, dl, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_z_nancheck)( n-1, dl, 1 ) ) {
             return -6;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_z_nancheck( n-1, dlf, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_z_nancheck)( n-1, dlf, 1 ) ) {
                 return -9;
             }
         }
-        if( LAPACKE_z_nancheck( n-1, du, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_z_nancheck)( n-1, du, 1 ) ) {
             return -8;
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_z_nancheck( n-2, du2, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_z_nancheck)( n-2, du2, 1 ) ) {
                 return -12;
             }
         }
-        if( LAPACKE_lsame( fact, 'f' ) ) {
-            if( LAPACKE_z_nancheck( n-1, duf, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( fact, 'f' ) ) {
+            if( API_SUFFIX(LAPACKE_z_nancheck)( n-1, duf, 1 ) ) {
                 return -11;
             }
         }
@@ -103,7 +102,7 @@ lapack_int LAPACKE_zgtsvx( int matrix_layout, char fact, char trans,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zgtsvx_work( matrix_layout, fact, trans, n, nrhs, dl, d, du,
+    info = API_SUFFIX(LAPACKE_zgtsvx_work)( matrix_layout, fact, trans, n, nrhs, dl, d, du,
                                 dlf, df, duf, du2, ipiv, b, ldb, x, ldx, rcond,
                                 ferr, berr, work, rwork );
     /* Release memory and exit */
@@ -112,7 +111,7 @@ exit_level_1:
     LAPACKE_free( rwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zgtsvx", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zgtsvx", info );
     }
     return info;
 }
