@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zhbevd
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zhbevd( int matrix_layout, char jobz, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zhbevd)( int matrix_layout, char jobz, char uplo, lapack_int n,
                            lapack_int kd, lapack_complex_double* ab,
                            lapack_int ldab, double* w, lapack_complex_double* z,
                            lapack_int ldz )
@@ -49,25 +48,25 @@ lapack_int LAPACKE_zhbevd( int matrix_layout, char jobz, char uplo, lapack_int n
     double rwork_query;
     lapack_complex_double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zhbevd", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhbevd", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_zhb_nancheck( matrix_layout, uplo, n, kd, ab, ldab ) ) {
+        if( API_SUFFIX(LAPACKE_zhb_nancheck)( matrix_layout, uplo, n, kd, ab, ldab ) ) {
             return -6;
         }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_zhbevd_work( matrix_layout, jobz, uplo, n, kd, ab, ldab, w, z,
+    info = API_SUFFIX(LAPACKE_zhbevd_work)( matrix_layout, jobz, uplo, n, kd, ab, ldab, w, z,
                                 ldz, &work_query, lwork, &rwork_query, lrwork,
                                 &iwork_query, liwork );
     if( info != 0 ) {
         goto exit_level_0;
     }
-    liwork = (lapack_int)iwork_query;
+    liwork = iwork_query;
     lrwork = (lapack_int)rwork_query;
     lwork = LAPACK_Z2INT( work_query );
     /* Allocate memory for work arrays */
@@ -88,7 +87,7 @@ lapack_int LAPACKE_zhbevd( int matrix_layout, char jobz, char uplo, lapack_int n
         goto exit_level_2;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zhbevd_work( matrix_layout, jobz, uplo, n, kd, ab, ldab, w, z,
+    info = API_SUFFIX(LAPACKE_zhbevd_work)( matrix_layout, jobz, uplo, n, kd, ab, ldab, w, z,
                                 ldz, work, lwork, rwork, lrwork, iwork,
                                 liwork );
     /* Release memory and exit */
@@ -99,7 +98,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zhbevd", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhbevd", info );
     }
     return info;
 }
