@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function zheevd_2stage
 * Author: Intel Corporation
-* Generated December 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zheevd_2stage_work( int matrix_layout, char jobz, char uplo,
+lapack_int API_SUFFIX(LAPACKE_zheevd_2stage_work)( int matrix_layout, char jobz, char uplo,
                                 lapack_int n, lapack_complex_double* a,
                                 lapack_int lda, double* w,
                                 lapack_complex_double* work, lapack_int lwork,
@@ -54,7 +53,7 @@ lapack_int LAPACKE_zheevd_2stage_work( int matrix_layout, char jobz, char uplo,
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_zheevd_2stage_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zheevd_2stage_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -71,7 +70,7 @@ lapack_int LAPACKE_zheevd_2stage_work( int matrix_layout, char jobz, char uplo,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_zhe_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_zhe_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zheevd_2stage( &jobz, &uplo, &n, a_t, &lda_t, w, work, &lwork, rwork,
                        &lrwork, iwork, &liwork, &info );
@@ -79,16 +78,20 @@ lapack_int LAPACKE_zheevd_2stage_work( int matrix_layout, char jobz, char uplo,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zhe_trans( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
+        if ( jobz == 'V' || jobz == 'v' ) {
+            API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, n, n, a_t, lda_t, a, lda );
+        } else {
+            API_SUFFIX(LAPACKE_zhe_trans)( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
+        }
         /* Release memory and exit */
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zheevd_2stage_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zheevd_2stage_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zheevd_2stage_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zheevd_2stage_work", info );
     }
     return info;
 }
