@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zhesv_rk
 * Author: Intel Corporation
-* Generated June 2017
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zhesv_rk( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zhesv_rk)( int matrix_layout, char uplo, lapack_int n,
                           lapack_int nrhs, lapack_complex_double* a,
                           lapack_int lda, lapack_complex_double* e, lapack_int* ipiv,
                           lapack_complex_double* b, lapack_int ldb )
@@ -43,20 +42,22 @@ lapack_int LAPACKE_zhesv_rk( int matrix_layout, char uplo, lapack_int n,
     lapack_complex_double* work = NULL;
     lapack_complex_double work_query;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zhesv_rk", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhesv_rk", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_zhe_nancheck( matrix_layout, uplo, n, a, lda ) ) {
-        return -5;
-    }
-    if( LAPACKE_zge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
-        return -9;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_zhe_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
+            return -5;
+        }
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
+            return -9;
+        }
     }
 #endif
     /* Query optimal working array(s) size */
-    info = LAPACKE_zhesv_rk_work( matrix_layout, uplo, n, nrhs, a, lda, e, ipiv, b,
+    info = API_SUFFIX(LAPACKE_zhesv_rk_work)( matrix_layout, uplo, n, nrhs, a, lda, e, ipiv, b,
                                ldb, &work_query, lwork );
     if( info != 0 ) {
         goto exit_level_0;
@@ -70,13 +71,13 @@ lapack_int LAPACKE_zhesv_rk( int matrix_layout, char uplo, lapack_int n,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zhesv_rk_work( matrix_layout, uplo, n, nrhs, a, lda, e, ipiv, b,
+    info = API_SUFFIX(LAPACKE_zhesv_rk_work)( matrix_layout, uplo, n, nrhs, a, lda, e, ipiv, b,
                                ldb, work, lwork );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zhesv_rk", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhesv_rk", info );
     }
     return info;
 }
