@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zhetrf_aa_2stage_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zhetrf_aa_2stage_work)( int matrix_layout, char uplo, lapack_int n,
                                lapack_complex_double* a, lapack_int lda,
                                lapack_complex_double* tb, lapack_int ltb,  
                                lapack_int* ipiv, lapack_int* ipiv2,
@@ -54,12 +54,12 @@ lapack_int LAPACKE_zhetrf_aa_2stage_work( int matrix_layout, char uplo, lapack_i
         /* Check leading dimension(s) */
         if( lda < n ) {
             info = -6;
-            LAPACKE_xerbla( "LAPACKE_zhetrf_aa_2stage_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhetrf_aa_2stage_work", info );
             return info;
         }
         if( ltb < 4*n ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_zhetrf_aa_2stage_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhetrf_aa_2stage_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -81,7 +81,7 @@ lapack_int LAPACKE_zhetrf_aa_2stage_work( int matrix_layout, char uplo, lapack_i
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_zhe_trans( matrix_layout, uplo, n, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_zhe_trans)( matrix_layout, uplo, n, a, lda, a_t, lda_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zhetrf_aa_2stage( &uplo, &n, a_t, &lda_t, 
         			  tb_t, &ltb, ipiv, ipiv2, work,
@@ -90,18 +90,18 @@ lapack_int LAPACKE_zhetrf_aa_2stage_work( int matrix_layout, char uplo, lapack_i
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zhe_trans( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
+        API_SUFFIX(LAPACKE_zhe_trans)( LAPACK_COL_MAJOR, uplo, n, a_t, lda_t, a, lda );
         /* Release memory and exit */
         LAPACKE_free( tb_t );
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zhetrf_aa_2stage_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhetrf_aa_2stage_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zhetrf_aa_2stage_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhetrf_aa_2stage_work", info );
     }
     return info;
 }
