@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zhptrf_work( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zhptrf_work)( int matrix_layout, char uplo, lapack_int n,
                                 lapack_complex_double* ap, lapack_int* ipiv )
 {
     lapack_int info = 0;
@@ -53,23 +53,23 @@ lapack_int LAPACKE_zhptrf_work( int matrix_layout, char uplo, lapack_int n,
             goto exit_level_0;
         }
         /* Transpose input matrices */
-        LAPACKE_zhp_trans( matrix_layout, uplo, n, ap, ap_t );
+        API_SUFFIX(LAPACKE_zhp_trans)( matrix_layout, uplo, n, ap, ap_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zhptrf( &uplo, &n, ap_t, ipiv, &info );
         if( info < 0 ) {
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zhp_trans( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
+        API_SUFFIX(LAPACKE_zhp_trans)( LAPACK_COL_MAJOR, uplo, n, ap_t, ap );
         /* Release memory and exit */
         LAPACKE_free( ap_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zhptrf_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhptrf_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zhptrf_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zhptrf_work", info );
     }
     return info;
 }
