@@ -32,7 +32,7 @@
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zlarft( int matrix_layout, char direct, char storev,
+lapack_int API_SUFFIX(LAPACKE_zlarft)( int matrix_layout, char direct, char storev,
                            lapack_int n, lapack_int k,
                            const lapack_complex_double* v, lapack_int ldv,
                            const lapack_complex_double* tau,
@@ -40,24 +40,24 @@ lapack_int LAPACKE_zlarft( int matrix_layout, char direct, char storev,
 {
     lapack_int ncols_v, nrows_v;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zlarft", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zlarft", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        ncols_v = LAPACKE_lsame( storev, 'c' ) ? k :
-                             ( LAPACKE_lsame( storev, 'r' ) ? n : 1);
-        nrows_v = LAPACKE_lsame( storev, 'c' ) ? n :
-                             ( LAPACKE_lsame( storev, 'r' ) ? k : 1);
-        if( LAPACKE_z_nancheck( k, tau, 1 ) ) {
+        ncols_v = API_SUFFIX(LAPACKE_lsame)( storev, 'c' ) ? k :
+                             ( API_SUFFIX(LAPACKE_lsame)( storev, 'r' ) ? n : 1);
+        nrows_v = API_SUFFIX(LAPACKE_lsame)( storev, 'c' ) ? n :
+                             ( API_SUFFIX(LAPACKE_lsame)( storev, 'r' ) ? k : 1);
+        if( API_SUFFIX(LAPACKE_z_nancheck)( k, tau, 1 ) ) {
             return -8;
         }
-        if( LAPACKE_zge_nancheck( matrix_layout, nrows_v, ncols_v, v, ldv ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, nrows_v, ncols_v, v, ldv ) ) {
             return -6;
         }
     }
 #endif
-    return LAPACKE_zlarft_work( matrix_layout, direct, storev, n, k, v, ldv, tau,
+    return API_SUFFIX(LAPACKE_zlarft_work)( matrix_layout, direct, storev, n, k, v, ldv, tau,
                                 t, ldt );
 }
