@@ -28,25 +28,24 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zpotrf2
 * Author: Intel Corporation
-* Generated November, 2011
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zpotrf2( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zpotrf2)( int matrix_layout, char uplo, lapack_int n,
                            lapack_complex_double* a, lapack_int lda )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zpotrf2", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zpotrf2", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_zpo_nancheck( matrix_layout, uplo, n, a, lda ) ) {
+        if( API_SUFFIX(LAPACKE_zpo_nancheck)( matrix_layout, uplo, n, a, lda ) ) {
             return -4;
         }
     }
 #endif
-    return LAPACKE_zpotrf2_work( matrix_layout, uplo, n, a, lda );
+    return API_SUFFIX(LAPACKE_zpotrf2_work)( matrix_layout, uplo, n, a, lda );
 }
