@@ -28,29 +28,28 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zppsv
 * Author: Intel Corporation
-* Generated November 2015
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zppsv( int matrix_layout, char uplo, lapack_int n,
+lapack_int API_SUFFIX(LAPACKE_zppsv)( int matrix_layout, char uplo, lapack_int n,
                           lapack_int nrhs, lapack_complex_double* ap,
                           lapack_complex_double* b, lapack_int ldb )
 {
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zppsv", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zppsv", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_zpp_nancheck( n, ap ) ) {
+        if( API_SUFFIX(LAPACKE_zpp_nancheck)( n, ap ) ) {
             return -5;
         }
-        if( LAPACKE_zge_nancheck( matrix_layout, n, nrhs, b, ldb ) ) {
+        if( API_SUFFIX(LAPACKE_zge_nancheck)( matrix_layout, n, nrhs, b, ldb ) ) {
             return -6;
         }
     }
 #endif
-    return LAPACKE_zppsv_work( matrix_layout, uplo, n, nrhs, ap, b, ldb );
+    return API_SUFFIX(LAPACKE_zppsv_work)( matrix_layout, uplo, n, nrhs, ap, b, ldb );
 }
