@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zptcon
 * Author: Intel Corporation
-* Generated November, 2011
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zptcon( lapack_int n, const double* d,
+lapack_int API_SUFFIX(LAPACKE_zptcon)( lapack_int n, const double* d,
                            const lapack_complex_double* e, double anorm,
                            double* rcond )
 {
@@ -42,13 +41,13 @@ lapack_int LAPACKE_zptcon( lapack_int n, const double* d,
 #ifndef LAPACK_DISABLE_NAN_CHECK
     if( LAPACKE_get_nancheck() ) {
         /* Optionally check input matrices for NaNs */
-        if( LAPACKE_d_nancheck( 1, &anorm, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_d_nancheck)( 1, &anorm, 1 ) ) {
             return -4;
         }
-        if( LAPACKE_d_nancheck( n, d, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n, d, 1 ) ) {
             return -2;
         }
-        if( LAPACKE_z_nancheck( n-1, e, 1 ) ) {
+        if( API_SUFFIX(LAPACKE_z_nancheck)( n-1, e, 1 ) ) {
             return -3;
         }
     }
@@ -60,12 +59,12 @@ lapack_int LAPACKE_zptcon( lapack_int n, const double* d,
         goto exit_level_0;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zptcon_work( n, d, e, anorm, rcond, work );
+    info = API_SUFFIX(LAPACKE_zptcon_work)( n, d, e, anorm, rcond, work );
     /* Release memory and exit */
     LAPACKE_free( work );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zptcon", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zptcon", info );
     }
     return info;
 }
