@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native high-level C interface to LAPACK function zstein
 * Author: Intel Corporation
-* Generated June 2017
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zstein( int matrix_layout, lapack_int n, const double* d,
+lapack_int API_SUFFIX(LAPACKE_zstein)( int matrix_layout, lapack_int n, const double* d,
                            const double* e, lapack_int m, const double* w,
                            const lapack_int* iblock, const lapack_int* isplit,
                            lapack_complex_double* z, lapack_int ldz,
@@ -43,19 +42,21 @@ lapack_int LAPACKE_zstein( int matrix_layout, lapack_int n, const double* d,
     lapack_int* iwork = NULL;
     double* work = NULL;
     if( matrix_layout != LAPACK_COL_MAJOR && matrix_layout != LAPACK_ROW_MAJOR ) {
-        LAPACKE_xerbla( "LAPACKE_zstein", -1 );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zstein", -1 );
         return -1;
     }
 #ifndef LAPACK_DISABLE_NAN_CHECK
-    /* Optionally check input matrices for NaNs */
-    if( LAPACKE_d_nancheck( n, d, 1 ) ) {
-        return -3;
-    }
-    if( LAPACKE_d_nancheck( n-1, e, 1 ) ) {
-        return -4;
-    }
-    if( LAPACKE_d_nancheck( n, w, 1 ) ) {
-        return -6;
+    if( LAPACKE_get_nancheck() ) {
+        /* Optionally check input matrices for NaNs */
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n, d, 1 ) ) {
+            return -3;
+        }
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n-1, e, 1 ) ) {
+            return -4;
+        }
+        if( API_SUFFIX(LAPACKE_d_nancheck)( n, w, 1 ) ) {
+            return -6;
+        }
     }
 #endif
     /* Allocate memory for working array(s) */
@@ -70,7 +71,7 @@ lapack_int LAPACKE_zstein( int matrix_layout, lapack_int n, const double* d,
         goto exit_level_1;
     }
     /* Call middle-level interface */
-    info = LAPACKE_zstein_work( matrix_layout, n, d, e, m, w, iblock, isplit, z,
+    info = API_SUFFIX(LAPACKE_zstein_work)( matrix_layout, n, d, e, m, w, iblock, isplit, z,
                                 ldz, work, iwork, ifailv );
     /* Release memory and exit */
     LAPACKE_free( work );
@@ -78,7 +79,7 @@ exit_level_1:
     LAPACKE_free( iwork );
 exit_level_0:
     if( info == LAPACK_WORK_MEMORY_ERROR ) {
-        LAPACKE_xerbla( "LAPACKE_zstein", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zstein", info );
     }
     return info;
 }
