@@ -28,12 +28,11 @@
 *****************************************************************************
 * Contents: Native middle-level C interface to LAPACK function zunmlq
 * Author: Intel Corporation
-* Generated June 2016
 *****************************************************************************/
 
 #include "lapacke_utils.h"
 
-lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
+lapack_int API_SUFFIX(LAPACKE_zunmlq_work)( int matrix_layout, char side, char trans,
                                 lapack_int m, lapack_int n, lapack_int k,
                                 const lapack_complex_double* a, lapack_int lda,
                                 const lapack_complex_double* tau,
@@ -50,7 +49,7 @@ lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
             info = info - 1;
         }
     } else if( matrix_layout == LAPACK_ROW_MAJOR ) {
-        r = LAPACKE_lsame( side, 'l' ) ? m : n;
+        r = API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ? m : n;
         lapack_int lda_t = MAX(1,k);
         lapack_int ldc_t = MAX(1,m);
         lapack_complex_double* a_t = NULL;
@@ -58,12 +57,12 @@ lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
         /* Check leading dimension(s) */
         if( lda < r ) {
             info = -8;
-            LAPACKE_xerbla( "LAPACKE_zunmlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zunmlq_work", info );
             return info;
         }
         if( ldc < n ) {
             info = -11;
-            LAPACKE_xerbla( "LAPACKE_zunmlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zunmlq_work", info );
             return info;
         }
         /* Query optimal working array(s) size if requested */
@@ -73,7 +72,7 @@ lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
             return (info < 0) ? (info - 1) : info;
         }
         /* Allocate memory for temporary array(s) */
-        if( LAPACKE_lsame( side, 'l' ) ) {
+        if( API_SUFFIX(LAPACKE_lsame)( side, 'l' ) ) {
             a_t = (lapack_complex_double*)
                 LAPACKE_malloc( sizeof(lapack_complex_double) * lda_t * MAX(1,m) );
         } else {
@@ -91,8 +90,8 @@ lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
             goto exit_level_1;
         }
         /* Transpose input matrices */
-        LAPACKE_zge_trans( matrix_layout, k, m, a, lda, a_t, lda_t );
-        LAPACKE_zge_trans( matrix_layout, m, n, c, ldc, c_t, ldc_t );
+        API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, k, m, a, lda, a_t, lda_t );
+        API_SUFFIX(LAPACKE_zge_trans)( matrix_layout, m, n, c, ldc, c_t, ldc_t );
         /* Call LAPACK function and adjust info */
         LAPACK_zunmlq( &side, &trans, &m, &n, &k, a_t, &lda_t, tau, c_t, &ldc_t,
                        work, &lwork, &info );
@@ -100,18 +99,18 @@ lapack_int LAPACKE_zunmlq_work( int matrix_layout, char side, char trans,
             info = info - 1;
         }
         /* Transpose output matrices */
-        LAPACKE_zge_trans( LAPACK_COL_MAJOR, m, n, c_t, ldc_t, c, ldc );
+        API_SUFFIX(LAPACKE_zge_trans)( LAPACK_COL_MAJOR, m, n, c_t, ldc_t, c, ldc );
         /* Release memory and exit */
         LAPACKE_free( c_t );
 exit_level_1:
         LAPACKE_free( a_t );
 exit_level_0:
         if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
-            LAPACKE_xerbla( "LAPACKE_zunmlq_work", info );
+            API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zunmlq_work", info );
         }
     } else {
         info = -1;
-        LAPACKE_xerbla( "LAPACKE_zunmlq_work", info );
+        API_SUFFIX(LAPACKE_xerbla)( "LAPACKE_zunmlq_work", info );
     }
     return info;
 }
