@@ -36,7 +36,7 @@
  * column-major(Fortran) layout or vice versa.
  */
 
-void LAPACKE_ctb_trans( int matrix_layout, char uplo, char diag,
+void API_SUFFIX(LAPACKE_ctb_trans)( int matrix_layout, char uplo, char diag,
                         lapack_int n, lapack_int kd,
                         const lapack_complex_float *in, lapack_int ldin,
                         lapack_complex_float *out, lapack_int ldout )
@@ -46,12 +46,12 @@ void LAPACKE_ctb_trans( int matrix_layout, char uplo, char diag,
     if( in == NULL || out == NULL ) return;
 
     colmaj = ( matrix_layout == LAPACK_COL_MAJOR );
-    upper  = LAPACKE_lsame( uplo, 'u' );
-    unit   = LAPACKE_lsame( diag, 'u' );
+    upper  = API_SUFFIX(LAPACKE_lsame)( uplo, 'u' );
+    unit   = API_SUFFIX(LAPACKE_lsame)( diag, 'u' );
 
     if( ( !colmaj && ( matrix_layout != LAPACK_ROW_MAJOR ) ) ||
-        ( !upper  && !LAPACKE_lsame( uplo, 'l' ) ) ||
-        ( !unit   && !LAPACKE_lsame( diag, 'n' ) ) ) {
+        ( !upper  && !API_SUFFIX(LAPACKE_lsame)( uplo, 'l' ) ) ||
+        ( !unit   && !API_SUFFIX(LAPACKE_lsame)( diag, 'n' ) ) ) {
         /* Just exit if any of input parameters are wrong */
         return;
     }
@@ -60,28 +60,28 @@ void LAPACKE_ctb_trans( int matrix_layout, char uplo, char diag,
         /* Unit case, diagonal excluded from transposition */
         if( colmaj ) {
             if( upper ) {
-                LAPACKE_cgb_trans( matrix_layout, n-1, n-1, 0, kd-1,
+                API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n-1, n-1, 0, kd-1,
                                    &in[ldin], ldin, &out[1], ldout );
             } else {
-                LAPACKE_cgb_trans( matrix_layout, n-1, n-1, kd-1, 0,
+                API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n-1, n-1, kd-1, 0,
                                    &in[1], ldin, &out[ldout], ldout );
             }
         } else {
             if( upper ) {
-                LAPACKE_cgb_trans( matrix_layout, n-1, n-1, 0, kd-1,
+                API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n-1, n-1, 0, kd-1,
                                    &in[1], ldin, &out[ldout], ldout );
             } else {
-                LAPACKE_cgb_trans( matrix_layout, n-1, n-1, kd-1, 0,
+                API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n-1, n-1, kd-1, 0,
                                    &in[ldin], ldin, &out[1], ldout );
             }
         }
     } else {
         /* Non-unit case */
         if( upper ) {
-            LAPACKE_cgb_trans( matrix_layout, n, n, 0, kd, in, ldin, out,
+            API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n, n, 0, kd, in, ldin, out,
                                ldout );
         } else {
-            LAPACKE_cgb_trans( matrix_layout, n, n, kd, 0, in, ldin, out,
+            API_SUFFIX(LAPACKE_cgb_trans)( matrix_layout, n, n, kd, 0, in, ldin, out,
                                ldout );
         }
     }
