@@ -240,8 +240,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup realOTHERcomputational
 *
 *> \par Further Details:
@@ -256,10 +254,9 @@
      $                   TOLA, TOLB, K, L, U, LDU, V, LDV, Q, LDQ,
      $                   IWORK, TAU, WORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBQ, JOBU, JOBV
@@ -395,8 +392,8 @@
 *
 *           Update Q := Q*Z**T
 *
-            CALL SORMR2( 'Right', 'Transpose', N, N, L, B, LDB, TAU, Q,
-     $                   LDQ, WORK, INFO )
+            CALL SORMR2( 'Right', 'Transpose', N, N, L, B, LDB, TAU,
+     $                   Q, LDQ, WORK, INFO )
          END IF
 *
 *        Clean up B
@@ -442,8 +439,8 @@
 *
          CALL SLASET( 'Full', M, M, ZERO, ZERO, U, LDU )
          IF( M.GT.1 )
-     $      CALL SLACPY( 'Lower', M-1, N-L, A( 2, 1 ), LDA, U( 2, 1 ),
-     $                   LDU )
+     $      CALL SLACPY( 'Lower', M-1, N-L, A( 2, 1 ), LDA,
+     $                   U( 2, 1 ), LDU )
          CALL SORG2R( M, M, MIN( M, N-L ), U, LDU, TAU, WORK, INFO )
       END IF
 *
@@ -463,7 +460,8 @@
    90    CONTINUE
   100 CONTINUE
       IF( M.GT.K )
-     $   CALL SLASET( 'Full', M-K, N-L, ZERO, ZERO, A( K+1, 1 ), LDA )
+     $   CALL SLASET( 'Full', M-K, N-L, ZERO, ZERO, A( K+1, 1 ),
+     $                LDA )
 *
       IF( N-L.GT.K ) THEN
 *
@@ -475,8 +473,8 @@
 *
 *           Update Q( 1:N,1:N-L ) = Q( 1:N,1:N-L )*Z1**T
 *
-            CALL SORMR2( 'Right', 'Transpose', N, N-L, K, A, LDA, TAU,
-     $                   Q, LDQ, WORK, INFO )
+            CALL SORMR2( 'Right', 'Transpose', N, N-L, K, A, LDA,
+     $                   TAU, Q, LDQ, WORK, INFO )
          END IF
 *
 *        Clean up A
@@ -500,9 +498,9 @@
 *
 *           Update U(:,K+1:M) := U(:,K+1:M)*U1
 *
-            CALL SORM2R( 'Right', 'No transpose', M, M-K, MIN( M-K, L ),
-     $                   A( K+1, N-L+1 ), LDA, TAU, U( 1, K+1 ), LDU,
-     $                   WORK, INFO )
+            CALL SORM2R( 'Right', 'No transpose', M, M-K,
+     $                   MIN( M-K, L ), A( K+1, N-L+1 ), LDA, TAU,
+     $                   U( 1, K+1 ), LDU, WORK, INFO )
          END IF
 *
 *        Clean up
