@@ -322,10 +322,11 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complexOTHERcomputational
+*> \ingroup bbcsd
 *
 *  =====================================================================
-      SUBROUTINE CBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P, Q,
+      SUBROUTINE CBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P,
+     $                   Q,
      $                   THETA, PHI, U1, LDU1, U2, LDU2, V1T, LDV1T,
      $                   V2T, LDV2T, B11D, B11E, B12D, B12E, B21D, B21E,
      $                   B22D, B22E, RWORK, LRWORK, INFO )
@@ -372,7 +373,8 @@
      $                   UNFL, X1, X2, Y1, Y2
 *
 *     .. External Subroutines ..
-      EXTERNAL           CLASR, CSCAL, CSWAP, SLARTGP, SLARTGS, SLAS2,
+      EXTERNAL           CLASR, CSCAL, CSWAP, SLARTGP, SLARTGS,
+     $                   SLAS2,
      $                   XERBLA
 *     ..
 *     .. External Functions ..
@@ -417,7 +419,7 @@
 *
       IF( INFO .EQ. 0 .AND. Q .EQ. 0 ) THEN
          LRWORKMIN = 1
-         RWORK(1) = LRWORKMIN
+         RWORK(1) = REAL( LRWORKMIN )
          RETURN
       END IF
 *
@@ -434,7 +436,7 @@
          IV2TSN = IV2TCS + Q
          LRWORKOPT = IV2TSN + Q - 1
          LRWORKMIN = LRWORKOPT
-         RWORK(1) = LRWORKOPT
+         RWORK(1) = REAL( LRWORKOPT )
          IF( LRWORK .LT. LRWORKMIN .AND. .NOT. LQUERY ) THEN
             INFO = -28
          END IF
@@ -453,7 +455,7 @@
       UNFL = SLAMCH( 'Safe minimum' )
       TOLMUL = MAX( TEN, MIN( HUNDRED, EPS**MEIGHTH ) )
       TOL = TOLMUL*EPS
-      THRESH = MAX( TOL, MAXITR*Q*Q*UNFL )
+      THRESH = MAX( TOL, REAL( MAXITR*Q*Q )*UNFL )
 *
 *     Test for negligible sines or cosines
 *
@@ -559,9 +561,11 @@
 *
 *           Compute shifts for B11 and B21 and use the lesser
 *
-            CALL SLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX), SIGMA11,
+            CALL SLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX),
+     $                  SIGMA11,
      $                  DUMMY )
-            CALL SLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX), SIGMA21,
+            CALL SLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX),
+     $                  SIGMA21,
      $                  DUMMY )
 *
             IF( SIGMA11 .LE. SIGMA21 ) THEN
@@ -718,10 +722,12 @@
                CALL SLARTGP( Y2, Y1, RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( .NOT. RESTART12 .AND. RESTART22 ) THEN
-               CALL SLARTGP( B12BULGE, B12D(I-1), RWORK(IV2TSN+I-1-1),
+               CALL SLARTGP( B12BULGE, B12D(I-1),
+     $                       RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( RESTART12 .AND. .NOT. RESTART22 ) THEN
-               CALL SLARTGP( B22BULGE, B22D(I-1), RWORK(IV2TSN+I-1-1),
+               CALL SLARTGP( B22BULGE, B22D(I-1),
+     $                       RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( NU .LT. MU ) THEN
                CALL SLARTGS( B12E(I-1), B12D(I), NU,
@@ -780,7 +786,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART12 ) THEN
-               CALL SLARTGP( X2, X1, RWORK(IU1SN+I-1), RWORK(IU1CS+I-1),
+               CALL SLARTGP( X2, X1, RWORK(IU1SN+I-1),
+     $                       RWORK(IU1CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART12 ) THEN
                CALL SLARTGP( B11BULGE, B11D(I), RWORK(IU1SN+I-1),
@@ -789,14 +796,16 @@
                CALL SLARTGP( B12BULGE, B12E(I-1), RWORK(IU1SN+I-1),
      $                       RWORK(IU1CS+I-1), R )
             ELSE IF( MU .LE. NU ) THEN
-               CALL SLARTGS( B11E(I), B11D(I+1), MU, RWORK(IU1CS+I-1),
+               CALL SLARTGS( B11E(I), B11D(I+1), MU,
+     $                       RWORK(IU1CS+I-1),
      $                       RWORK(IU1SN+I-1) )
             ELSE
                CALL SLARTGS( B12D(I), B12E(I), NU, RWORK(IU1CS+I-1),
      $                       RWORK(IU1SN+I-1) )
             END IF
             IF( .NOT. RESTART21 .AND. .NOT. RESTART22 ) THEN
-               CALL SLARTGP( Y2, Y1, RWORK(IU2SN+I-1), RWORK(IU2CS+I-1),
+               CALL SLARTGP( Y2, Y1, RWORK(IU2SN+I-1),
+     $                       RWORK(IU2CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART21 .AND. RESTART22 ) THEN
                CALL SLARTGP( B21BULGE, B21D(I), RWORK(IU2SN+I-1),
@@ -805,7 +814,8 @@
                CALL SLARTGP( B22BULGE, B22E(I-1), RWORK(IU2SN+I-1),
      $                       RWORK(IU2CS+I-1), R )
             ELSE IF( NU .LT. MU ) THEN
-               CALL SLARTGS( B21E(I), B21E(I+1), NU, RWORK(IU2CS+I-1),
+               CALL SLARTGS( B21E(I), B21E(I+1), NU,
+     $                       RWORK(IU2CS+I-1),
      $                       RWORK(IU2SN+I-1) )
             ELSE
                CALL SLARTGS( B22D(I), B22E(I), MU, RWORK(IU2CS+I-1),
@@ -991,7 +1001,8 @@
          IF( B12D(IMAX)+B22D(IMAX) .LT. 0 ) THEN
             IF( WANTV2T ) THEN
                IF( COLMAJOR ) THEN
-                  CALL CSCAL( M-Q, NEGONECOMPLEX, V2T(IMAX,1), LDV2T )
+                  CALL CSCAL( M-Q, NEGONECOMPLEX, V2T(IMAX,1),
+     $                        LDV2T )
                ELSE
                   CALL CSCAL( M-Q, NEGONECOMPLEX, V2T(1,IMAX), 1 )
                END IF
@@ -1058,7 +1069,8 @@
                IF( WANTU2 )
      $            CALL CSWAP( M-P, U2(1,I), 1, U2(1,MINI), 1 )
                IF( WANTV1T )
-     $            CALL CSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1), LDV1T )
+     $            CALL CSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1),
+     $                        LDV1T )
                IF( WANTV2T )
      $            CALL CSWAP( M-Q, V2T(I,1), LDV2T, V2T(MINI,1),
      $               LDV2T )
