@@ -138,7 +138,7 @@
 *> \verbatim
 *>          AFB is COMPLEX array, dimension (LDAFB,N)
 *>     Details of the LU factorization of the band matrix A, as
-*>     computed by DGBTRF.  U is stored as an upper triangular band
+*>     computed by CGBTRF.  U is stored as an upper triangular band
 *>     matrix with KL+KU superdiagonals in rows 1 to KL+KU+1, and
 *>     the multipliers used during the factorization are stored in
 *>     rows KL+KU+2 to 2*KL+KU+1.
@@ -153,7 +153,7 @@
 *> \param[in] IPIV
 *> \verbatim
 *>          IPIV is INTEGER array, dimension (N)
-*>     The pivot indices from SGETRF; for 1<=i<=N, row i of the
+*>     The pivot indices from CGETRF; for 1<=i<=N, row i of the
 *>     matrix was interchanged with row IPIV(i).
 *> \endverbatim
 *>
@@ -208,7 +208,7 @@
 *> \param[in,out] X
 *> \verbatim
 *>          X is COMPLEX array, dimension (LDX,NRHS)
-*>     On entry, the solution matrix X, as computed by SGETRS.
+*>     On entry, the solution matrix X, as computed by CGETRS.
 *>     On exit, the improved solution matrix X.
 *> \endverbatim
 *>
@@ -429,21 +429,19 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date April 2012
-*
-*> \ingroup complexGBcomputational
+*> \ingroup gbrfsx
 *
 *  =====================================================================
-      SUBROUTINE CGBRFSX( TRANS, EQUED, N, KL, KU, NRHS, AB, LDAB, AFB,
+      SUBROUTINE CGBRFSX( TRANS, EQUED, N, KL, KU, NRHS, AB, LDAB,
+     $                    AFB,
      $                    LDAFB, IPIV, R, C, B, LDB, X, LDX, RCOND,
      $                    BERR, N_ERR_BNDS, ERR_BNDS_NORM,
      $                    ERR_BNDS_COMP, NPARAMS, PARAMS, WORK, RWORK,
      $                    INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     April 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, EQUED
@@ -499,7 +497,8 @@
 *     ..
 *     .. External Functions ..
       EXTERNAL           LSAME, ILATRANS, ILAPREC
-      EXTERNAL           SLAMCH, CLANGB, CLA_GBRCOND_X, CLA_GBRCOND_C
+      EXTERNAL           SLAMCH, CLANGB, CLA_GBRCOND_X,
+     $                   CLA_GBRCOND_C
       REAL               SLAMCH, CLANGB, CLA_GBRCOND_X, CLA_GBRCOND_C
       LOGICAL            LSAME
       INTEGER            ILATRANS, ILAPREC
@@ -646,7 +645,8 @@
          PREC_TYPE = ILAPREC( 'D' )
 
          IF ( NOTRAN ) THEN
-            CALL CLA_GBRFSX_EXTENDED( PREC_TYPE, TRANS_TYPE,  N, KL, KU,
+            CALL CLA_GBRFSX_EXTENDED( PREC_TYPE, TRANS_TYPE,  N, KL,
+     $                                KU,
      $           NRHS, AB, LDAB, AFB, LDAFB, IPIV, COLEQU, C, B,
      $           LDB, X, LDX, BERR, N_NORMS, ERR_BNDS_NORM,
      $           ERR_BNDS_COMP, WORK, RWORK, WORK(N+1),
@@ -654,7 +654,8 @@
      $           RCOND, ITHRESH, RTHRESH, UNSTABLE_THRESH, IGNORE_CWISE,
      $           INFO )
          ELSE
-            CALL CLA_GBRFSX_EXTENDED( PREC_TYPE, TRANS_TYPE,  N, KL, KU,
+            CALL CLA_GBRFSX_EXTENDED( PREC_TYPE, TRANS_TYPE,  N, KL,
+     $                                KU,
      $           NRHS, AB, LDAB, AFB, LDAFB, IPIV, ROWEQU, R, B,
      $           LDB, X, LDX, BERR, N_NORMS, ERR_BNDS_NORM,
      $           ERR_BNDS_COMP, WORK, RWORK, WORK(N+1),
@@ -670,13 +671,16 @@
 *     Compute scaled normwise condition number cond(A*C).
 *
          IF ( COLEQU .AND. NOTRAN ) THEN
-            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB, AFB,
+            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB,
+     $                                 AFB,
      $           LDAFB, IPIV, C, .TRUE., INFO, WORK, RWORK )
          ELSE IF ( ROWEQU .AND. .NOT. NOTRAN ) THEN
-            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB, AFB,
+            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB,
+     $                                 AFB,
      $           LDAFB, IPIV, R, .TRUE., INFO, WORK, RWORK )
          ELSE
-            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB, AFB,
+            RCOND_TMP = CLA_GBRCOND_C( TRANS, N, KL, KU, AB, LDAB,
+     $                                 AFB,
      $           LDAFB, IPIV, C, .FALSE., INFO, WORK, RWORK )
          END IF
          DO J = 1, NRHS
