@@ -196,7 +196,8 @@
       LOGICAL            SISNAN, LSAME
       INTEGER            ICAMAX
       REAL               SLAMCH, SCNRM2
-      EXTERNAL           SISNAN, LSAME, ICAMAX, SLAMCH, SCNRM2
+      EXTERNAL           SISNAN, LSAME, ICAMAX, SLAMCH,
+     $                   SCNRM2
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           XERBLA, CSSCAL, CSWAP
@@ -207,8 +208,10 @@
 *     Test the input parameters
 *
       INFO = 0
-      IF( .NOT.LSAME( JOB, 'N' ) .AND. .NOT.LSAME( JOB, 'P' ) .AND.
-     $    .NOT.LSAME( JOB, 'S' ) .AND. .NOT.LSAME( JOB, 'B' ) ) THEN
+      IF( .NOT.LSAME( JOB, 'N' ) .AND.
+     $    .NOT.LSAME( JOB, 'P' ) .AND.
+     $    .NOT.LSAME( JOB, 'S' ) .AND.
+     $                .NOT.LSAME( JOB, 'B' ) ) THEN
          INFO = -1
       ELSE IF( N.LT.0 ) THEN
          INFO = -2
@@ -263,10 +266,11 @@
                END DO
 *
                IF( CANSWAP ) THEN
-                  SCALE( L ) = I
+                  SCALE( L ) = REAL( I )
                   IF( I.NE.L ) THEN
                      CALL CSWAP( L, A( 1, I ), 1, A( 1, L ), 1 )
-                     CALL CSWAP( N-K+1, A( I, K ), LDA, A( L, K ), LDA )
+                     CALL CSWAP( N-K+1, A( I, K ), LDA, A( L, K ),
+     $                           LDA )
                   END IF
                   NOCONV = .TRUE.
 *
@@ -299,10 +303,11 @@
                END DO
 *
                IF( CANSWAP ) THEN
-                  SCALE( K ) = J
+                  SCALE( K ) = REAL( J )
                   IF( J.NE.K ) THEN
                      CALL CSWAP( L, A( 1, J ), 1, A( 1, K ), 1 )
-                     CALL CSWAP( N-K+1, A( J, K ), LDA, A( K, K ), LDA )
+                     CALL CSWAP( N-K+1, A( J, K ), LDA, A( K, K ),
+     $                           LDA )
                   END IF
                   NOCONV = .TRUE.
 *
