@@ -180,14 +180,14 @@
 *>
 *> \param[out] WORK
 *> \verbatim
-*>          WORK is COMPLEX array, dimension (LWORK)
+*>          WORK is COMPLEX array, dimension (MAX(1,LWORK))
 *>          On exit, if INFO = 0, WORK(1) returns the optimal LWORK.
 *> \endverbatim
 *>
 *> \param[in]  LWORK
 *> \verbatim
 *>          LWORK is INTEGER
-*>          The length of the array WORK.  LWORK >= 1.
+*>          The length of the array WORK. LWORK >= 1.
 *>          For optimum performance LWORK >= 6*N*NB, where NB is the
 *>          optimal blocksize.
 *>
@@ -226,7 +226,8 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE CGGHD3( COMPQ, COMPZ, N, ILO, IHI, A, LDA, B, LDB, Q,
+      SUBROUTINE CGGHD3( COMPQ, COMPZ, N, ILO, IHI, A, LDA, B, LDB,
+     $                   Q,
      $                   LDQ, Z, LDZ, WORK, LWORK, INFO )
 *
 *  -- LAPACK computational routine --
@@ -265,10 +266,12 @@
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            ILAENV
-      EXTERNAL           ILAENV, LSAME
+      REAL               SROUNDUP_LWORK
+      EXTERNAL           ILAENV, LSAME, SROUNDUP_LWORK
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CGGHRD, CLARTG, CLASET, CUNM22, CROT, CGEMM,
+      EXTERNAL           CGGHRD, CLARTG, CLASET, CUNM22, CROT,
+     $                   CGEMM,
      $                   CGEMV, CTRMV, CLACPY, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -280,8 +283,13 @@
 *
       INFO = 0
       NB = ILAENV( 1, 'CGGHD3', ' ', N, ILO, IHI, -1 )
-      LWKOPT = MAX( 6*N*NB, 1 )
-      WORK( 1 ) = CMPLX( LWKOPT )
+      NH = IHI - ILO + 1
+      IF( NH.LE.1 ) THEN
+         LWKOPT = 1
+      ELSE
+         LWKOPT = 6*N*NB
+      END IF
+      WORK( 1 ) = SROUNDUP_LWORK( LWKOPT )
       INITQ = LSAME( COMPQ, 'I' )
       WANTQ = INITQ .OR. LSAME( COMPQ, 'V' )
       INITZ = LSAME( COMPZ, 'I' )
@@ -330,7 +338,6 @@
 *
 *     Quick return if possible
 *
-      NH = IHI - ILO + 1
       IF( NH.LE.1 ) THEN
          WORK( 1 ) = CONE
          RETURN
@@ -388,7 +395,8 @@
 *
             N2NB = ( IHI-JCOL-1 ) / NNB - 1
             NBLST = IHI - JCOL - N2NB*NNB
-            CALL CLASET( 'All', NBLST, NBLST, CZERO, CONE, WORK, NBLST )
+            CALL CLASET( 'All', NBLST, NBLST, CZERO, CONE, WORK,
+     $                   NBLST )
             PW = NBLST * NBLST + 1
             DO I = 1, N2NB
                CALL CLASET( 'All', 2*NNB, 2*NNB, CZERO, CONE,
@@ -581,10 +589,12 @@
                         WORK( PPW ) = A( I, J+1 )
                         PPW = PPW + 1
                      END DO
-                     CALL CTRMV( 'Upper', 'Conjugate', 'Non-unit', LEN,
+                     CALL CTRMV( 'Upper', 'Conjugate', 'Non-unit',
+     $                           LEN,
      $                           WORK( PPWO + NNB ), 2*NNB, WORK( PW ),
      $                           1 )
-                     CALL CTRMV( 'Lower', 'Conjugate', 'Non-unit', NNB,
+                     CALL CTRMV( 'Lower', 'Conjugate', 'Non-unit',
+     $                           NNB,
      $                           WORK( PPWO + 2*LEN*NNB ),
      $                           2*NNB, WORK( PW + LEN ), 1 )
                      CALL CGEMV( 'Conjugate', NNB, LEN, CONE,
@@ -753,9 +763,11 @@
                END DO
             ELSE
 *
-               CALL CLASET( 'Lower', IHI - JCOL - 1, NNB, CZERO, CZERO,
+               CALL CLASET( 'Lower', IHI - JCOL - 1, NNB, CZERO,
+     $                      CZERO,
      $                      A( JCOL + 2, JCOL ), LDA )
-               CALL CLASET( 'Lower', IHI - JCOL - 1, NNB, CZERO, CZERO,
+               CALL CLASET( 'Lower', IHI - JCOL - 1, NNB, CZERO,
+     $                      CZERO,
      $                      B( JCOL + 2, JCOL ), LDB )
             END IF
 *
@@ -775,7 +787,8 @@
 *
 *                    Exploit the structure of U.
 *
-                     CALL CUNM22( 'Right', 'No Transpose', TOP, 2*NNB,
+                     CALL CUNM22( 'Right', 'No Transpose', TOP,
+     $                            2*NNB,
      $                            NNB, NNB, WORK( PPWO ), 2*NNB,
      $                            A( 1, J ), LDA, WORK( PW ),
      $                            LWORK-PW+1, IERR )
@@ -806,7 +819,8 @@
 *
 *                    Exploit the structure of U.
 *
-                     CALL CUNM22( 'Right', 'No Transpose', TOP, 2*NNB,
+                     CALL CUNM22( 'Right', 'No Transpose', TOP,
+     $                            2*NNB,
      $                            NNB, NNB, WORK( PPWO ), 2*NNB,
      $                            B( 1, J ), LDB, WORK( PW ),
      $                            LWORK-PW+1, IERR )
@@ -886,9 +900,11 @@
       END IF
 *
       IF ( JCOL.LT.IHI )
-     $   CALL CGGHRD( COMPQ2, COMPZ2, N, JCOL, IHI, A, LDA, B, LDB, Q,
+     $   CALL CGGHRD( COMPQ2, COMPZ2, N, JCOL, IHI, A, LDA, B, LDB,
+     $                Q,
      $                LDQ, Z, LDZ, IERR )
-      WORK( 1 ) = CMPLX( LWKOPT )
+*
+      WORK( 1 ) = SROUNDUP_LWORK( LWKOPT )
 *
       RETURN
 *
