@@ -178,7 +178,8 @@
 *> \ingroup hbgv
 *
 *  =====================================================================
-      SUBROUTINE CHBGV( JOBZ, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, W, Z,
+      SUBROUTINE CHBGV( JOBZ, UPLO, N, KA, KB, AB, LDAB, BB, LDBB, W,
+     $                  Z,
      $                  LDZ, WORK, RWORK, INFO )
 *
 *  -- LAPACK driver routine --
@@ -207,7 +208,8 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHBGST, CHBTRD, CPBSTF, CSTEQR, SSTERF, XERBLA
+      EXTERNAL           CHBGST, CHBTRD, CPBSTF, CSTEQR, SSTERF,
+     $                   XERBLA
 *     ..
 *     .. Executable Statements ..
 *
