@@ -192,7 +192,8 @@
       COMPLEX            T, TEMP
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CLACGV, CLAR2V, CLARGV, CLARTG, CLARTV, CLASET,
+      EXTERNAL           CLACGV, CLAR2V, CLARGV, CLARTG, CLARTV,
+     $                   CLASET,
      $                   CROT, CSCAL, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -276,7 +277,8 @@
 *                    generate plane rotations to annihilate nonzero
 *                    elements which have been created outside the band
 *
-                     CALL CLARGV( NR, AB( 1, J1-1 ), INCA, WORK( J1 ),
+                     CALL CLARGV( NR, AB( 1, J1-1 ), INCA,
+     $                            WORK( J1 ),
      $                            KD1, D( J1 ), KD1 )
 *
 *                    apply rotations from the right
@@ -348,7 +350,8 @@
                               NRT = NR
                            END IF
                            IF( NRT.GT.0 )
-     $                        CALL CLARTV( NRT, AB( KD-L, J1+L ), INCA,
+     $                        CALL CLARTV( NRT, AB( KD-L, J1+L ),
+     $                                     INCA,
      $                                     AB( KD-L+1, J1+L ), INCA,
      $                                     D( J1 ), WORK( J1 ), KD1 )
    30                   CONTINUE
@@ -356,7 +359,8 @@
                         J1END = J1 + KD1*( NR-2 )
                         IF( J1END.GE.J1 ) THEN
                            DO 40 JIN = J1, J1END, KD1
-                              CALL CROT( KD-1, AB( KD-1, JIN+1 ), INCX,
+                              CALL CROT( KD-1, AB( KD-1, JIN+1 ),
+     $                                   INCX,
      $                                   AB( KD, JIN+1 ), INCX,
      $                                   D( JIN ), WORK( JIN ) )
    40                      CONTINUE
@@ -391,13 +395,15 @@
                            IQB = MAX( 1, J-IBL )
                            NQ = 1 + IQAEND - IQB
                            IQAEND = MIN( IQAEND+KD, IQEND )
-                           CALL CROT( NQ, Q( IQB, J-1 ), 1, Q( IQB, J ),
+                           CALL CROT( NQ, Q( IQB, J-1 ), 1, Q( IQB,
+     $                                J ),
      $                                1, D( J ), CONJG( WORK( J ) ) )
    50                   CONTINUE
                      ELSE
 *
                         DO 60 J = J1, J2, KD1
-                           CALL CROT( N, Q( 1, J-1 ), 1, Q( 1, J ), 1,
+                           CALL CROT( N, Q( 1, J-1 ), 1, Q( 1, J ),
+     $                                1,
      $                                D( J ), CONJG( WORK( J ) ) )
    60                   CONTINUE
                      END IF
@@ -495,7 +501,8 @@
 *
                      IF( NR.GT.2*KD-1 ) THEN
                         DO 130 L = 1, KD - 1
-                           CALL CLARTV( NR, AB( KD1-L, J1-KD1+L ), INCA,
+                           CALL CLARTV( NR, AB( KD1-L, J1-KD1+L ),
+     $                                  INCA,
      $                                  AB( KD1-L+1, J1-KD1+L ), INCA,
      $                                  D( J1 ), WORK( J1 ), KD1 )
   130                   CONTINUE
@@ -554,7 +561,8 @@
                               NRT = NR
                            END IF
                            IF( NRT.GT.0 )
-     $                        CALL CLARTV( NRT, AB( L+2, J1-1 ), INCA,
+     $                        CALL CLARTV( NRT, AB( L+2, J1-1 ),
+     $                                     INCA,
      $                                     AB( L+1, J1 ), INCA, D( J1 ),
      $                                     WORK( J1 ), KD1 )
   150                   CONTINUE
@@ -599,13 +607,15 @@
                            IQB = MAX( 1, J-IBL )
                            NQ = 1 + IQAEND - IQB
                            IQAEND = MIN( IQAEND+KD, IQEND )
-                           CALL CROT( NQ, Q( IQB, J-1 ), 1, Q( IQB, J ),
+                           CALL CROT( NQ, Q( IQB, J-1 ), 1, Q( IQB,
+     $                                J ),
      $                                1, D( J ), WORK( J ) )
   170                   CONTINUE
                      ELSE
 *
                         DO 180 J = J1, J2, KD1
-                           CALL CROT( N, Q( 1, J-1 ), 1, Q( 1, J ), 1,
+                           CALL CROT( N, Q( 1, J-1 ), 1, Q( 1, J ),
+     $                                1,
      $                                D( J ), WORK( J ) )
   180                   CONTINUE
                      END IF
