@@ -122,18 +122,16 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2016
-*
-*> \ingroup complexPOcomputational
+*> \ingroup la_porcond
 *
 *  =====================================================================
-      REAL FUNCTION CLA_PORCOND_C( UPLO, N, A, LDA, AF, LDAF, C, CAPPLY,
+      REAL FUNCTION CLA_PORCOND_C( UPLO, N, A, LDA, AF, LDAF, C,
+     $                             CAPPLY,
      $                             INFO, WORK, RWORK )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -315,5 +313,7 @@
      $   CLA_PORCOND_C = 1.0E+0 / AINVNM
 *
       RETURN
+*
+*     End of CLA_PORCOND_C
 *
       END
