@@ -385,7 +385,8 @@
 *> \ingroup la_herfsx_extended
 *
 *  =====================================================================
-      SUBROUTINE CLA_SYRFSX_EXTENDED( PREC_TYPE, UPLO, N, NRHS, A, LDA,
+      SUBROUTINE CLA_SYRFSX_EXTENDED( PREC_TYPE, UPLO, N, NRHS, A,
+     $                                LDA,
      $                                AF, LDAF, IPIV, COLEQU, C, B, LDB,
      $                                Y, LDY, BERR_OUT, N_NORMS,
      $                                ERR_BNDS_NORM, ERR_BNDS_COMP, RES,
@@ -457,7 +458,8 @@
       INTEGER            ILAUPLO
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CAXPY, CCOPY, CSYTRS, CSYMV, BLAS_CSYMV_X,
+      EXTERNAL           CAXPY, CCOPY, CSYTRS, CSYMV,
+     $                   BLAS_CSYMV_X,
      $                   BLAS_CSYMV2_X, CLA_SYAMV, CLA_WWADDW,
      $                   CLA_LIN_BERR
       REAL               SLAMCH
