@@ -157,9 +157,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2017
-*
-*> \ingroup complexOTHERauxiliary
+*> \ingroup labrd
 *
 *> \par Further Details:
 *  =====================
@@ -209,13 +207,13 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE CLABRD( M, N, NB, A, LDA, D, E, TAUQ, TAUP, X, LDX, Y,
+      SUBROUTINE CLABRD( M, N, NB, A, LDA, D, E, TAUQ, TAUP, X, LDX,
+     $                   Y,
      $                   LDY )
 *
-*  -- LAPACK auxiliary routine (version 3.7.1) --
+*  -- LAPACK auxiliary routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2017
 *
 *     .. Scalar Arguments ..
       INTEGER            LDA, LDX, LDY, M, N, NB
@@ -270,7 +268,7 @@
             ALPHA = A( I, I )
             CALL CLARFG( M-I+1, ALPHA, A( MIN( I+1, M ), I ), 1,
      $                   TAUQ( I ) )
-            D( I ) = ALPHA
+            D( I ) = REAL( ALPHA )
             IF( I.LT.N ) THEN
                A( I, I ) = ONE
 *
@@ -282,7 +280,8 @@
                CALL CGEMV( 'Conjugate transpose', M-I+1, I-1, ONE,
      $                     A( I, 1 ), LDA, A( I, I ), 1, ZERO,
      $                     Y( 1, I ), 1 )
-               CALL CGEMV( 'No transpose', N-I, I-1, -ONE, Y( I+1, 1 ),
+               CALL CGEMV( 'No transpose', N-I, I-1, -ONE, Y( I+1,
+     $                     1 ),
      $                     LDY, Y( 1, I ), 1, ONE, Y( I+1, I ), 1 )
                CALL CGEMV( 'Conjugate transpose', M-I+1, I-1, ONE,
      $                     X( I, 1 ), LDX, A( I, I ), 1, ZERO,
@@ -310,21 +309,24 @@
                ALPHA = A( I, I+1 )
                CALL CLARFG( N-I, ALPHA, A( I, MIN( I+2, N ) ),
      $                      LDA, TAUP( I ) )
-               E( I ) = ALPHA
+               E( I ) = REAL( ALPHA )
                A( I, I+1 ) = ONE
 *
 *              Compute X(i+1:m,i)
 *
-               CALL CGEMV( 'No transpose', M-I, N-I, ONE, A( I+1, I+1 ),
+               CALL CGEMV( 'No transpose', M-I, N-I, ONE, A( I+1,
+     $                     I+1 ),
      $                     LDA, A( I, I+1 ), LDA, ZERO, X( I+1, I ), 1 )
                CALL CGEMV( 'Conjugate transpose', N-I, I, ONE,
      $                     Y( I+1, 1 ), LDY, A( I, I+1 ), LDA, ZERO,
      $                     X( 1, I ), 1 )
                CALL CGEMV( 'No transpose', M-I, I, -ONE, A( I+1, 1 ),
      $                     LDA, X( 1, I ), 1, ONE, X( I+1, I ), 1 )
-               CALL CGEMV( 'No transpose', I-1, N-I, ONE, A( 1, I+1 ),
+               CALL CGEMV( 'No transpose', I-1, N-I, ONE, A( 1,
+     $                     I+1 ),
      $                     LDA, A( I, I+1 ), LDA, ZERO, X( 1, I ), 1 )
-               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, X( I+1, 1 ),
+               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, X( I+1,
+     $                     1 ),
      $                     LDX, X( 1, I ), 1, ONE, X( I+1, I ), 1 )
                CALL CSCAL( M-I, TAUP( I ), X( I+1, I ), 1 )
                CALL CLACGV( N-I, A( I, I+1 ), LDA )
@@ -354,22 +356,26 @@
             ALPHA = A( I, I )
             CALL CLARFG( N-I+1, ALPHA, A( I, MIN( I+1, N ) ), LDA,
      $                   TAUP( I ) )
-            D( I ) = ALPHA
+            D( I ) = REAL( ALPHA )
             IF( I.LT.M ) THEN
                A( I, I ) = ONE
 *
 *              Compute X(i+1:m,i)
 *
-               CALL CGEMV( 'No transpose', M-I, N-I+1, ONE, A( I+1, I ),
+               CALL CGEMV( 'No transpose', M-I, N-I+1, ONE, A( I+1,
+     $                     I ),
      $                     LDA, A( I, I ), LDA, ZERO, X( I+1, I ), 1 )
                CALL CGEMV( 'Conjugate transpose', N-I+1, I-1, ONE,
      $                     Y( I, 1 ), LDY, A( I, I ), LDA, ZERO,
      $                     X( 1, I ), 1 )
-               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, A( I+1, 1 ),
+               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, A( I+1,
+     $                     1 ),
      $                     LDA, X( 1, I ), 1, ONE, X( I+1, I ), 1 )
-               CALL CGEMV( 'No transpose', I-1, N-I+1, ONE, A( 1, I ),
+               CALL CGEMV( 'No transpose', I-1, N-I+1, ONE, A( 1,
+     $                     I ),
      $                     LDA, A( I, I ), LDA, ZERO, X( 1, I ), 1 )
-               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, X( I+1, 1 ),
+               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, X( I+1,
+     $                     1 ),
      $                     LDX, X( 1, I ), 1, ONE, X( I+1, I ), 1 )
                CALL CSCAL( M-I, TAUP( I ), X( I+1, I ), 1 )
                CALL CLACGV( N-I+1, A( I, I ), LDA )
@@ -377,7 +383,8 @@
 *              Update A(i+1:m,i)
 *
                CALL CLACGV( I-1, Y( I, 1 ), LDY )
-               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, A( I+1, 1 ),
+               CALL CGEMV( 'No transpose', M-I, I-1, -ONE, A( I+1,
+     $                     1 ),
      $                     LDA, Y( I, 1 ), LDY, ONE, A( I+1, I ), 1 )
                CALL CLACGV( I-1, Y( I, 1 ), LDY )
                CALL CGEMV( 'No transpose', M-I, I, -ONE, X( I+1, 1 ),
@@ -388,7 +395,7 @@
                ALPHA = A( I+1, I )
                CALL CLARFG( M-I, ALPHA, A( MIN( I+2, M ), I ), 1,
      $                      TAUQ( I ) )
-               E( I ) = ALPHA
+               E( I ) = REAL( ALPHA )
                A( I+1, I ) = ONE
 *
 *              Compute Y(i+1:n,i)
@@ -399,7 +406,8 @@
                CALL CGEMV( 'Conjugate transpose', M-I, I-1, ONE,
      $                     A( I+1, 1 ), LDA, A( I+1, I ), 1, ZERO,
      $                     Y( 1, I ), 1 )
-               CALL CGEMV( 'No transpose', N-I, I-1, -ONE, Y( I+1, 1 ),
+               CALL CGEMV( 'No transpose', N-I, I-1, -ONE, Y( I+1,
+     $                     1 ),
      $                     LDY, Y( 1, I ), 1, ONE, Y( I+1, I ), 1 )
                CALL CGEMV( 'Conjugate transpose', M-I, I, ONE,
      $                     X( I+1, 1 ), LDX, A( I+1, I ), 1, ZERO,
