@@ -128,7 +128,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complexGEcomputational
+*> \ingroup launhr_col_getrfnp
 *
 *> \par Contributors:
 *  ==================
@@ -166,7 +166,8 @@
       INTEGER            IINFO, J, JB, NB
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CGEMM, CLAUNHR_COL_GETRFNP2, CTRSM, XERBLA
+      EXTERNAL           CGEMM, CLAUNHR_COL_GETRFNP2, CTRSM,
+     $                   XERBLA
 *     ..
 *     .. External Functions ..
       INTEGER            ILAENV
@@ -223,14 +224,16 @@
 *
 *              Compute block row of U.
 *
-               CALL CTRSM( 'Left', 'Lower', 'No transpose', 'Unit', JB,
+               CALL CTRSM( 'Left', 'Lower', 'No transpose', 'Unit',
+     $                     JB,
      $                     N-J-JB+1, CONE, A( J, J ), LDA, A( J, J+JB ),
      $                     LDA )
                IF( J+JB.LE.M ) THEN
 *
 *                 Update trailing submatrix.
 *
-                  CALL CGEMM( 'No transpose', 'No transpose', M-J-JB+1,
+                  CALL CGEMM( 'No transpose', 'No transpose',
+     $                        M-J-JB+1,
      $                        N-J-JB+1, JB, -CONE, A( J+JB, J ), LDA,
      $                        A( J, J+JB ), LDA, CONE, A( J+JB, J+JB ),
      $                        LDA )
