@@ -114,7 +114,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complexOTHERcomputational
+*> \ingroup pbtrs
 *
 *  =====================================================================
       SUBROUTINE CPBTRS( UPLO, N, KD, NRHS, AB, LDAB, B, LDB, INFO )
@@ -184,12 +184,14 @@
 *
 *           Solve U**H *X = B, overwriting B with X.
 *
-            CALL CTBSV( 'Upper', 'Conjugate transpose', 'Non-unit', N,
+            CALL CTBSV( 'Upper', 'Conjugate transpose', 'Non-unit',
+     $                  N,
      $                  KD, AB, LDAB, B( 1, J ), 1 )
 *
 *           Solve U*X = B, overwriting B with X.
 *
-            CALL CTBSV( 'Upper', 'No transpose', 'Non-unit', N, KD, AB,
+            CALL CTBSV( 'Upper', 'No transpose', 'Non-unit', N, KD,
+     $                  AB,
      $                  LDAB, B( 1, J ), 1 )
    10    CONTINUE
       ELSE
@@ -200,12 +202,14 @@
 *
 *           Solve L*X = B, overwriting B with X.
 *
-            CALL CTBSV( 'Lower', 'No transpose', 'Non-unit', N, KD, AB,
+            CALL CTBSV( 'Lower', 'No transpose', 'Non-unit', N, KD,
+     $                  AB,
      $                  LDAB, B( 1, J ), 1 )
 *
 *           Solve L**H *X = B, overwriting B with X.
 *
-            CALL CTBSV( 'Lower', 'Conjugate transpose', 'Non-unit', N,
+            CALL CTBSV( 'Lower', 'Conjugate transpose', 'Non-unit',
+     $                  N,
      $                  KD, AB, LDAB, B( 1, J ), 1 )
    20    CONTINUE
       END IF
