@@ -166,7 +166,8 @@
 *> \ingroup pprfs
 *
 *  =====================================================================
-      SUBROUTINE CPPRFS( UPLO, N, NRHS, AP, AFP, B, LDB, X, LDX, FERR,
+      SUBROUTINE CPPRFS( UPLO, N, NRHS, AP, AFP, B, LDB, X, LDX,
+     $                   FERR,
      $                   BERR, WORK, RWORK, INFO )
 *
 *  -- LAPACK computational routine --
@@ -207,7 +208,8 @@
       INTEGER            ISAVE( 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CAXPY, CCOPY, CHPMV, CLACN2, CPPTRS, XERBLA
+      EXTERNAL           CAXPY, CCOPY, CHPMV, CLACN2, CPPTRS,
+     $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, AIMAG, MAX, REAL
@@ -260,7 +262,7 @@
       NZ = N + 1
       EPS = SLAMCH( 'Epsilon' )
       SAFMIN = SLAMCH( 'Safe minimum' )
-      SAFE1 = NZ*SAFMIN
+      SAFE1 = REAL( NZ )*SAFMIN
       SAFE2 = SAFE1 / EPS
 *
 *     Do for each right hand side
@@ -276,7 +278,8 @@
 *        Compute residual R = B - A * X
 *
          CALL CCOPY( N, B( 1, J ), 1, WORK, 1 )
-         CALL CHPMV( UPLO, N, -CONE, AP, X( 1, J ), 1, CONE, WORK, 1 )
+         CALL CHPMV( UPLO, N, -CONE, AP, X( 1, J ), 1, CONE, WORK,
+     $               1 )
 *
 *        Compute componentwise relative backward error from formula
 *
@@ -376,10 +379,11 @@
 *
          DO 90 I = 1, N
             IF( RWORK( I ).GT.SAFE2 ) THEN
-               RWORK( I ) = CABS1( WORK( I ) ) + NZ*EPS*RWORK( I )
+               RWORK( I ) = CABS1( WORK( I ) ) + REAL( NZ )*
+     $                      EPS*RWORK( I )
             ELSE
-               RWORK( I ) = CABS1( WORK( I ) ) + NZ*EPS*RWORK( I ) +
-     $                      SAFE1
+               RWORK( I ) = CABS1( WORK( I ) ) + REAL( NZ )*
+     $                      EPS*RWORK( I ) + SAFE1
             END IF
    90    CONTINUE
 *
