@@ -264,7 +264,8 @@
       EXTERNAL           LSAME, CLANHT, SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CCOPY, CLACPY, CPTCON, CPTRFS, CPTTRF, CPTTRS,
+      EXTERNAL           CCOPY, CLACPY, CPTCON, CPTRFS, CPTTRF,
+     $                   CPTTRS,
      $                   SCOPY, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -325,7 +326,8 @@
 *     Use iterative refinement to improve the computed solutions and
 *     compute error bounds and backward error estimates for them.
 *
-      CALL CPTRFS( 'Lower', N, NRHS, D, E, DF, EF, B, LDB, X, LDX, FERR,
+      CALL CPTRFS( 'Lower', N, NRHS, D, E, DF, EF, B, LDB, X, LDX,
+     $             FERR,
      $             BERR, WORK, RWORK, INFO )
 *
 *     Set INFO = N+1 if the matrix is singular to working precision.
