@@ -417,7 +417,8 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CCOPY, CLAGS2, CLAPLL, CLASET, CROT, CSSCAL,
+      EXTERNAL           CCOPY, CLAGS2, CLAPLL, CLASET, CROT,
+     $                   CSSCAL,
      $                   SLARTG, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -440,9 +441,13 @@
       INFO = 0
       IF( .NOT.( INITU .OR. WANTU .OR. LSAME( JOBU, 'N' ) ) ) THEN
          INFO = -1
-      ELSE IF( .NOT.( INITV .OR. WANTV .OR. LSAME( JOBV, 'N' ) ) ) THEN
+      ELSE IF( .NOT.( INITV .OR.
+     $         WANTV .OR.
+     $         LSAME( JOBV, 'N' ) ) ) THEN
          INFO = -2
-      ELSE IF( .NOT.( INITQ .OR. WANTQ .OR. LSAME( JOBQ, 'N' ) ) ) THEN
+      ELSE IF( .NOT.( INITQ .OR.
+     $         WANTQ .OR.
+     $         LSAME( JOBQ, 'N' ) ) ) THEN
          INFO = -3
       ELSE IF( M.LT.0 ) THEN
          INFO = -4
@@ -512,7 +517,8 @@
 *              Update (K+I)-th and (K+J)-th rows of matrix A: U**H *A
 *
                IF( K+J.LE.M )
-     $            CALL CROT( L, A( K+J, N-L+1 ), LDA, A( K+I, N-L+1 ),
+     $            CALL CROT( L, A( K+J, N-L+1 ), LDA, A( K+I,
+     $                       N-L+1 ),
      $                       LDA, CSU, CONJG( SNU ) )
 *
 *              Update I-th and J-th rows of matrix B: V**H *B
@@ -555,10 +561,12 @@
      $                       SNU )
 *
                IF( WANTV )
-     $            CALL CROT( P, V( 1, J ), 1, V( 1, I ), 1, CSV, SNV )
+     $            CALL CROT( P, V( 1, J ), 1, V( 1, I ), 1, CSV,
+     $                       SNV )
 *
                IF( WANTQ )
-     $            CALL CROT( N, Q( 1, N-L+J ), 1, Q( 1, N-L+I ), 1, CSQ,
+     $            CALL CROT( N, Q( 1, N-L+J ), 1, Q( 1, N-L+I ), 1,
+     $                       CSQ,
      $                       SNQ )
 *
    10       CONTINUE
@@ -575,7 +583,8 @@
             ERROR = ZERO
             DO 30 I = 1, MIN( L, M-K )
                CALL CCOPY( L-I+1, A( K+I, N-L+I ), LDA, WORK, 1 )
-               CALL CCOPY( L-I+1, B( I, N-L+I ), LDB, WORK( L+1 ), 1 )
+               CALL CCOPY( L-I+1, B( I, N-L+I ), LDB, WORK( L+1 ),
+     $                     1 )
                CALL CLAPLL( L-I+1, WORK, 1, WORK( L+1 ), 1, SSMIN )
                ERROR = MAX( ERROR, SSMIN )
    30       CONTINUE
@@ -618,16 +627,19 @@
      $            CALL CSSCAL( P, -ONE, V( 1, I ), 1 )
             END IF
 *
-            CALL SLARTG( ABS( GAMMA ), ONE, BETA( K+I ), ALPHA( K+I ),
+            CALL SLARTG( ABS( GAMMA ), ONE, BETA( K+I ),
+     $                   ALPHA( K+I ),
      $                   RWK )
 *
             IF( ALPHA( K+I ).GE.BETA( K+I ) ) THEN
-               CALL CSSCAL( L-I+1, ONE / ALPHA( K+I ), A( K+I, N-L+I ),
+               CALL CSSCAL( L-I+1, ONE / ALPHA( K+I ), A( K+I,
+     $                      N-L+I ),
      $                      LDA )
             ELSE
                CALL CSSCAL( L-I+1, ONE / BETA( K+I ), B( I, N-L+I ),
      $                      LDB )
-               CALL CCOPY( L-I+1, B( I, N-L+I ), LDB, A( K+I, N-L+I ),
+               CALL CCOPY( L-I+1, B( I, N-L+I ), LDB, A( K+I,
+     $                     N-L+I ),
      $                     LDA )
             END IF
 *
