@@ -325,7 +325,8 @@
 *> \ingroup bbcsd
 *
 *  =====================================================================
-      SUBROUTINE DBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P, Q,
+      SUBROUTINE DBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P,
+     $                   Q,
      $                   THETA, PHI, U1, LDU1, U2, LDU2, V1T, LDV1T,
      $                   V2T, LDV2T, B11D, B11E, B12D, B12E, B21D, B21E,
      $                   B22D, B22E, WORK, LWORK, INFO )
@@ -372,7 +373,8 @@
      $                   UNFL, X1, X2, Y1, Y2
 *
 *     .. External Subroutines ..
-      EXTERNAL           DLASR, DSCAL, DSWAP, DLARTGP, DLARTGS, DLAS2,
+      EXTERNAL           DLASR, DSCAL, DSWAP, DLARTGP, DLARTGS,
+     $                   DLAS2,
      $                   XERBLA
 *     ..
 *     .. External Functions ..
@@ -559,9 +561,11 @@
 *
 *           Compute shifts for B11 and B21 and use the lesser
 *
-            CALL DLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX), SIGMA11,
+            CALL DLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX),
+     $                  SIGMA11,
      $                  DUMMY )
-            CALL DLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX), SIGMA21,
+            CALL DLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX),
+     $                  SIGMA21,
      $                  DUMMY )
 *
             IF( SIGMA11 .LE. SIGMA21 ) THEN
@@ -697,7 +701,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART21 ) THEN
-               CALL DLARTGP( X2, X1, WORK(IV1TSN+I-1), WORK(IV1TCS+I-1),
+               CALL DLARTGP( X2, X1, WORK(IV1TSN+I-1),
+     $                       WORK(IV1TCS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART21 ) THEN
                CALL DLARTGP( B11BULGE, B11E(I-1), WORK(IV1TSN+I-1),
@@ -724,10 +729,12 @@
                CALL DLARTGP( B22BULGE, B22D(I-1), WORK(IV2TSN+I-1-1),
      $                       WORK(IV2TCS+I-1-1), R )
             ELSE IF( NU .LT. MU ) THEN
-               CALL DLARTGS( B12E(I-1), B12D(I), NU, WORK(IV2TCS+I-1-1),
+               CALL DLARTGS( B12E(I-1), B12D(I), NU,
+     $                       WORK(IV2TCS+I-1-1),
      $                       WORK(IV2TSN+I-1-1) )
             ELSE
-               CALL DLARTGS( B22E(I-1), B22D(I), MU, WORK(IV2TCS+I-1-1),
+               CALL DLARTGS( B22E(I-1), B22D(I), MU,
+     $                       WORK(IV2TCS+I-1-1),
      $                       WORK(IV2TSN+I-1-1) )
             END IF
 *
@@ -780,7 +787,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART12 ) THEN
-               CALL DLARTGP( X2, X1, WORK(IU1SN+I-1), WORK(IU1CS+I-1),
+               CALL DLARTGP( X2, X1, WORK(IU1SN+I-1),
+     $                       WORK(IU1CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART12 ) THEN
                CALL DLARTGP( B11BULGE, B11D(I), WORK(IU1SN+I-1),
@@ -796,7 +804,8 @@
      $                       WORK(IU1SN+I-1) )
             END IF
             IF( .NOT. RESTART21 .AND. .NOT. RESTART22 ) THEN
-               CALL DLARTGP( Y2, Y1, WORK(IU2SN+I-1), WORK(IU2CS+I-1),
+               CALL DLARTGP( Y2, Y1, WORK(IU2SN+I-1),
+     $                       WORK(IU2CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART21 .AND. RESTART22 ) THEN
                CALL DLARTGP( B21BULGE, B21D(I), WORK(IU2SN+I-1),
@@ -862,10 +871,12 @@
             CALL DLARTGP( Y2, Y1, WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( .NOT. RESTART12 .AND. RESTART22 ) THEN
-            CALL DLARTGP( B12BULGE, B12D(IMAX-1), WORK(IV2TSN+IMAX-1-1),
+            CALL DLARTGP( B12BULGE, B12D(IMAX-1),
+     $                    WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( RESTART12 .AND. .NOT. RESTART22 ) THEN
-            CALL DLARTGP( B22BULGE, B22D(IMAX-1), WORK(IV2TSN+IMAX-1-1),
+            CALL DLARTGP( B22BULGE, B22D(IMAX-1),
+     $                    WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( NU .LT. MU ) THEN
             CALL DLARTGS( B12E(IMAX-1), B12D(IMAX), NU,
@@ -1052,7 +1063,8 @@
                IF( WANTU2 )
      $            CALL DSWAP( M-P, U2(1,I), 1, U2(1,MINI), 1 )
                IF( WANTV1T )
-     $            CALL DSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1), LDV1T )
+     $            CALL DSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1),
+     $                        LDV1T )
                IF( WANTV2T )
      $            CALL DSWAP( M-Q, V2T(I,1), LDV2T, V2T(MINI,1),
      $               LDV2T )
