@@ -239,8 +239,7 @@
 *>
 *> \param[out] IWORK
 *> \verbatim
-*>          IWORK is INTEGER array.
-*>         Dimension must be at least (7 * N).
+*>          IWORK is INTEGER array, dimension (7*N)
 *> \endverbatim
 *>
 *> \param[out] INFO
@@ -259,9 +258,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
-*> \ingroup OTHERauxiliary
+*> \ingroup lasda
 *
 *> \par Contributors:
 *  ==================
@@ -270,14 +267,14 @@
 *>     California at Berkeley, USA
 *>
 *  =====================================================================
-      SUBROUTINE DLASDA( ICOMPQ, SMLSIZ, N, SQRE, D, E, U, LDU, VT, K,
+      SUBROUTINE DLASDA( ICOMPQ, SMLSIZ, N, SQRE, D, E, U, LDU, VT,
+     $                   K,
      $                   DIFL, DIFR, Z, POLES, GIVPTR, GIVCOL, LDGCOL,
      $                   PERM, GIVNUM, C, S, WORK, IWORK, INFO )
 *
-*  -- LAPACK auxiliary routine (version 3.7.0) --
+*  -- LAPACK auxiliary routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       INTEGER            ICOMPQ, INFO, LDGCOL, LDU, N, SMLSIZ, SQRE
@@ -305,7 +302,8 @@
       DOUBLE PRECISION   ALPHA, BETA
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DCOPY, DLASD6, DLASDQ, DLASDT, DLASET, XERBLA
+      EXTERNAL           DCOPY, DLASD6, DLASDQ, DLASDT, DLASET,
+     $                   XERBLA
 *     ..
 *     .. Executable Statements ..
 *
@@ -337,10 +335,12 @@
 *
       IF( N.LE.SMLSIZ ) THEN
          IF( ICOMPQ.EQ.0 ) THEN
-            CALL DLASDQ( 'U', SQRE, N, 0, 0, 0, D, E, VT, LDU, U, LDU,
+            CALL DLASDQ( 'U', SQRE, N, 0, 0, 0, D, E, VT, LDU, U,
+     $                   LDU,
      $                   U, LDU, WORK, INFO )
          ELSE
-            CALL DLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDU, U, LDU,
+            CALL DLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDU, U,
+     $                   LDU,
      $                   U, LDU, WORK, INFO )
          END IF
          RETURN
@@ -401,7 +401,8 @@
             CALL DCOPY( NLP1, WORK( ITEMP ), 1, WORK( VLI ), 1 )
          ELSE
             CALL DLASET( 'A', NL, NL, ZERO, ONE, U( NLF, 1 ), LDU )
-            CALL DLASET( 'A', NLP1, NLP1, ZERO, ONE, VT( NLF, 1 ), LDU )
+            CALL DLASET( 'A', NLP1, NLP1, ZERO, ONE, VT( NLF, 1 ),
+     $                   LDU )
             CALL DLASDQ( 'U', SQREI, NL, NLP1, NL, NCC, D( NLF ),
      $                   E( NLF ), VT( NLF, 1 ), LDU, U( NLF, 1 ), LDU,
      $                   U( NLF, 1 ), LDU, WORK( NWORK1 ), INFO )
@@ -435,7 +436,8 @@
             CALL DCOPY( NRP1, WORK( ITEMP ), 1, WORK( VLI ), 1 )
          ELSE
             CALL DLASET( 'A', NR, NR, ZERO, ONE, U( NRF, 1 ), LDU )
-            CALL DLASET( 'A', NRP1, NRP1, ZERO, ONE, VT( NRF, 1 ), LDU )
+            CALL DLASET( 'A', NRP1, NRP1, ZERO, ONE, VT( NRF, 1 ),
+     $                   LDU )
             CALL DLASDQ( 'U', SQREI, NR, NRP1, NR, NCC, D( NRF ),
      $                   E( NRF ), VT( NRF, 1 ), LDU, U( NRF, 1 ), LDU,
      $                   U( NRF, 1 ), LDU, WORK( NWORK1 ), INFO )
