@@ -233,7 +233,8 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      SUBROUTINE DLATRS( UPLO, TRANS, DIAG, NORMIN, N, A, LDA, X, SCALE,
+      SUBROUTINE DLATRS( UPLO, TRANS, DIAG, NORMIN, N, A, LDA, X,
+     $                   SCALE,
      $                   CNORM, INFO )
 *
 *  -- LAPACK auxiliary routine --
@@ -268,7 +269,8 @@
       LOGICAL            LSAME
       INTEGER            IDAMAX
       DOUBLE PRECISION   DASUM, DDOT, DLAMCH, DLANGE
-      EXTERNAL           LSAME, IDAMAX, DASUM, DDOT, DLAMCH, DLANGE
+      EXTERNAL           LSAME, IDAMAX, DASUM, DDOT, DLAMCH,
+     $                   DLANGE
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           DAXPY, DSCAL, DTRSV, XERBLA
@@ -365,8 +367,8 @@
 *              A is upper triangular.
 *
                DO J = 2, N
-                  TMAX = MAX( DLANGE( 'M', J-1, 1, A( 1, J ), 1, WORK ),
-     $                        TMAX )
+                  TMAX = MAX( DLANGE( 'M', J-1, 1, A( 1, J ), 1,
+     $                        WORK ), TMAX )
                END DO
             ELSE
 *
