@@ -151,13 +151,17 @@
 *>
 *> \param[out] WORK
 *> \verbatim
-*>          WORK is DOUBLE PRECISION array, dimension (LWORK).
+*>          WORK is DOUBLE PRECISION array, dimension (MAX(1,LWORK)).
 *>          On exit, if INFO = 0, WORK(1) returns the optimal size of
 *>          WORK.
 *> \endverbatim
 *>
 *> \param[in] LWORK
+*> \verbatim
 *>          LWORK is INTEGER
+*>          The dimension of the array WORK.
+*>
+*>          If MIN(N,NRHS) = 0, LWORK >= 1, else
 *>          LWORK >= MAX(1, 2*NBA * MAX(NBA, MIN(NRHS, 32)), where
 *>          NBA = (N + NB - 1)/NB and NB is the optimal block size.
 *>
@@ -165,6 +169,7 @@
 *>          only calculates the optimal dimensions of the WORK array, returns
 *>          this value as the first entry of the WORK array, and no error
 *>          message related to LWORK is issued by XERBLA.
+*> \endverbatim
 *>
 *> \param[out] INFO
 *> \verbatim
@@ -253,7 +258,7 @@
       LOGICAL            LQUERY, NOTRAN, NOUNIT, UPPER
       INTEGER            AWRK, I, IFIRST, IINC, ILAST, II, I1, I2, J,
      $                   JFIRST, JINC, JLAST, J1, J2, K, KK, K1, K2,
-     $                   LANRM, LDS, LSCALE, NB, NBA, NBX, RHS
+     $                   LANRM, LDS, LSCALE, NB, NBA, NBX, RHS, LWMIN
       DOUBLE PRECISION   ANRM, BIGNUM, BNRM, RSCAL, SCAL, SCALOC,
      $                   SCAMIN, SMLNUM, TMAX
 *     ..
@@ -261,7 +266,8 @@
       LOGICAL            LSAME
       INTEGER            ILAENV
       DOUBLE PRECISION   DLAMCH, DLANGE, DLARMM
-      EXTERNAL           DLAMCH, DLANGE, DLARMM, ILAENV, LSAME
+      EXTERNAL           DLAMCH, DLANGE, DLARMM, ILAENV,
+     $                   LSAME
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           DLATRS, DSCAL, XERBLA
@@ -292,15 +298,24 @@
 *     row. WORK( I+KK*LDS ) is the scale factor of the vector
 *     segment associated with the I-th block row and the KK-th vector
 *     in the block column.
+*
       LSCALE = NBA * MAX( NBA, MIN( NRHS, NBRHS ) )
       LDS = NBA
+*
 *     The second part stores upper bounds of the triangular A. There are
 *     a total of NBA x NBA blocks, of which only the upper triangular
 *     part or the lower triangular part is referenced. The upper bound of
 *     the block A( I, J ) is stored as WORK( AWRK + I + J * NBA ).
+*
       LANRM = NBA * NBA
       AWRK = LSCALE
-      WORK( 1 ) = LSCALE + LANRM
+*
+      IF( MIN( N, NRHS ).EQ.0 ) THEN
+         LWMIN = 1
+      ELSE
+         LWMIN = LSCALE + LANRM
+      END IF
+      WORK( 1 ) = LWMIN
 *
 *     Test the input parameters
 *
@@ -322,7 +337,7 @@
          INFO = -8
       ELSE IF( LDX.LT.MAX( 1, N ) ) THEN
          INFO = -10
-      ELSE IF( .NOT.LQUERY .AND. LWORK.LT.WORK( 1 ) ) THEN
+      ELSE IF( .NOT.LQUERY .AND. LWORK.LT.LWMIN ) THEN
          INFO = -14
       END IF
       IF( INFO.NE.0 ) THEN
@@ -354,7 +369,8 @@
          CALL DLATRS( UPLO, TRANS, DIAG, NORMIN, N, A, LDA, X( 1, 1),
      $                SCALE( 1 ), CNORM, INFO )
          DO K = 2, NRHS
-            CALL DLATRS( UPLO, TRANS, DIAG, 'Y', N, A, LDA, X( 1, K ),
+            CALL DLATRS( UPLO, TRANS, DIAG, 'Y', N, A, LDA, X( 1,
+     $                   K ),
      $                   SCALE( K ), CNORM, INFO )
          END DO
          RETURN
@@ -381,10 +397,12 @@
 *           Compute upper bound of A( I1:I2-1, J1:J2-1 ).
 *
             IF( NOTRAN ) THEN
-               ANRM = DLANGE( 'I', I2-I1, J2-J1, A( I1, J1 ), LDA, W )
+               ANRM = DLANGE( 'I', I2-I1, J2-J1, A( I1, J1 ), LDA,
+     $                        W )
                WORK( AWRK + I+(J-1)*NBA ) = ANRM
             ELSE
-               ANRM = DLANGE( '1', I2-I1, J2-J1, A( I1, J1 ), LDA, W )
+               ANRM = DLANGE( '1', I2-I1, J2-J1, A( I1, J1 ), LDA,
+     $                        W )
                WORK( AWRK + J+(I-1)*NBA ) = ANRM
             END IF
             TMAX = MAX( TMAX, ANRM )
@@ -401,7 +419,8 @@
 *        in the computation of the column norms CNORM.
 *
          DO K = 1, NRHS
-            CALL DLATRS( UPLO, TRANS, DIAG, 'N', N, A, LDA, X( 1, K ),
+            CALL DLATRS( UPLO, TRANS, DIAG, 'N', N, A, LDA, X( 1,
+     $                   K ),
      $                   SCALE( K ), CNORM, INFO )
          END DO
          RETURN
@@ -585,7 +604,8 @@
 *                 Compute scaling factor to survive the linear update
 *                 simulating consistent scaling.
 *
-                  BNRM = DLANGE( 'I', I2-I1, 1, X( I1, RHS ), LDX, W )
+                  BNRM = DLANGE( 'I', I2-I1, 1, X( I1, RHS ), LDX,
+     $                           W )
                   BNRM = BNRM*( SCAMIN / WORK( I+KK*LDS ) )
                   XNRM( KK ) = XNRM( KK )*(SCAMIN / WORK( J+KK*LDS ))
                   ANRM = WORK( AWRK + I+(J-1)*NBA )
@@ -649,6 +669,9 @@
             END IF
          END DO
       END DO
+*
+      WORK( 1 ) = LWMIN
+*
       RETURN
 *
 *     End of DLATRS3
