@@ -88,7 +88,7 @@
 *>    where U is an upper triangular matrix and L is a lower triangular
 *>    matrix.
 *>
-*>    3. If the leading i-by-i principal minor is not positive definite,
+*>    3. If the leading principal minor of order i is not positive,
 *>    then the routine returns with INFO = i. Otherwise, the factored
 *>    form of A is used to estimate the condition number of the matrix
 *>    A (see argument RCOND).  If the reciprocal of the condition number
@@ -484,10 +484,11 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup doublePOsolve
+*> \ingroup posvxx
 *
 *  =====================================================================
-      SUBROUTINE DPOSVXX( FACT, UPLO, N, NRHS, A, LDA, AF, LDAF, EQUED,
+      SUBROUTINE DPOSVXX( FACT, UPLO, N, NRHS, A, LDA, AF, LDAF,
+     $                    EQUED,
      $                    S, B, LDB, X, LDX, RCOND, RPVGRW, BERR,
      $                    N_ERR_BNDS, ERR_BNDS_NORM, ERR_BNDS_COMP,
      $                    NPARAMS, PARAMS, WORK, IWORK, INFO )
@@ -537,7 +538,8 @@
       DOUBLE PRECISION   DLAMCH, DLA_PORPVGRW
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DPOEQUB, DPOTRF, DPOTRS, DLACPY, DLAQSY,
+      EXTERNAL           DPOEQUB, DPOTRF, DPOTRS, DLACPY,
+     $                   DLAQSY,
      $                   XERBLA, DLASCL2, DPORFSX
 *     ..
 *     .. Intrinsic Functions ..
@@ -645,7 +647,8 @@
 *           Compute the reciprocal pivot growth factor of the
 *           leading rank-deficient INFO columns of A.
 *
-            RPVGRW = DLA_PORPVGRW( UPLO, INFO, A, LDA, AF, LDAF, WORK )
+            RPVGRW = DLA_PORPVGRW( UPLO, INFO, A, LDA, AF, LDAF,
+     $                             WORK )
             RETURN
          ENDIF
       END IF
