@@ -188,7 +188,8 @@
       DOUBLE PRECISION   TEMP
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLAR2V, DLARGV, DLARTG, DLARTV, DLASET, DROT,
+      EXTERNAL           DLAR2V, DLARGV, DLARTG, DLARTV, DLASET,
+     $                   DROT,
      $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -270,7 +271,8 @@
 *                    generate plane rotations to annihilate nonzero
 *                    elements which have been created outside the band
 *
-                     CALL DLARGV( NR, AB( 1, J1-1 ), INCA, WORK( J1 ),
+                     CALL DLARGV( NR, AB( 1, J1-1 ), INCA,
+     $                            WORK( J1 ),
      $                            KD1, D( J1 ), KD1 )
 *
 *                    apply rotations from the right
@@ -341,7 +343,8 @@
                               NRT = NR
                            END IF
                            IF( NRT.GT.0 )
-     $                        CALL DLARTV( NRT, AB( KD-L, J1+L ), INCA,
+     $                        CALL DLARTV( NRT, AB( KD-L, J1+L ),
+     $                                     INCA,
      $                                     AB( KD-L+1, J1+L ), INCA,
      $                                     D( J1 ), WORK( J1 ), KD1 )
    30                   CONTINUE
@@ -349,7 +352,8 @@
                         J1END = J1 + KD1*( NR-2 )
                         IF( J1END.GE.J1 ) THEN
                            DO 40 JIN = J1, J1END, KD1
-                              CALL DROT( KD-1, AB( KD-1, JIN+1 ), INCX,
+                              CALL DROT( KD-1, AB( KD-1, JIN+1 ),
+     $                                   INCX,
      $                                   AB( KD, JIN+1 ), INCX,
      $                                   D( JIN ), WORK( JIN ) )
    40                      CONTINUE
@@ -384,13 +388,15 @@
                            IQB = MAX( 1, J-IBL )
                            NQ = 1 + IQAEND - IQB
                            IQAEND = MIN( IQAEND+KD, IQEND )
-                           CALL DROT( NQ, Q( IQB, J-1 ), 1, Q( IQB, J ),
+                           CALL DROT( NQ, Q( IQB, J-1 ), 1, Q( IQB,
+     $                                J ),
      $                                1, D( J ), WORK( J ) )
    50                   CONTINUE
                      ELSE
 *
                         DO 60 J = J1, J2, KD1
-                           CALL DROT( N, Q( 1, J-1 ), 1, Q( 1, J ), 1,
+                           CALL DROT( N, Q( 1, J-1 ), 1, Q( 1, J ),
+     $                                1,
      $                                D( J ), WORK( J ) )
    60                   CONTINUE
                      END IF
@@ -473,7 +479,8 @@
 *
                      IF( NR.GT.2*KD-1 ) THEN
                         DO 130 L = 1, KD - 1
-                           CALL DLARTV( NR, AB( KD1-L, J1-KD1+L ), INCA,
+                           CALL DLARTV( NR, AB( KD1-L, J1-KD1+L ),
+     $                                  INCA,
      $                                  AB( KD1-L+1, J1-KD1+L ), INCA,
      $                                  D( J1 ), WORK( J1 ), KD1 )
   130                   CONTINUE
@@ -531,7 +538,8 @@
                               NRT = NR
                            END IF
                            IF( NRT.GT.0 )
-     $                        CALL DLARTV( NRT, AB( L+2, J1-1 ), INCA,
+     $                        CALL DLARTV( NRT, AB( L+2, J1-1 ),
+     $                                     INCA,
      $                                     AB( L+1, J1 ), INCA, D( J1 ),
      $                                     WORK( J1 ), KD1 )
   150                   CONTINUE
@@ -576,13 +584,15 @@
                            IQB = MAX( 1, J-IBL )
                            NQ = 1 + IQAEND - IQB
                            IQAEND = MIN( IQAEND+KD, IQEND )
-                           CALL DROT( NQ, Q( IQB, J-1 ), 1, Q( IQB, J ),
+                           CALL DROT( NQ, Q( IQB, J-1 ), 1, Q( IQB,
+     $                                J ),
      $                                1, D( J ), WORK( J ) )
   170                   CONTINUE
                      ELSE
 *
                         DO 180 J = J1, J2, KD1
-                           CALL DROT( N, Q( 1, J-1 ), 1, Q( 1, J ), 1,
+                           CALL DROT( N, Q( 1, J-1 ), 1, Q( 1, J ),
+     $                                1,
      $                                D( J ), WORK( J ) )
   180                   CONTINUE
                      END IF
