@@ -155,7 +155,8 @@
 *> \ingroup hpgv
 *
 *  =====================================================================
-      SUBROUTINE DSPGV( ITYPE, JOBZ, UPLO, N, AP, BP, W, Z, LDZ, WORK,
+      SUBROUTINE DSPGV( ITYPE, JOBZ, UPLO, N, AP, BP, W, Z, LDZ,
+     $                  WORK,
      $                  INFO )
 *
 *  -- LAPACK driver routine --
@@ -183,7 +184,8 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DPPTRF, DSPEV, DSPGST, DTPMV, DTPSV, XERBLA
+      EXTERNAL           DPPTRF, DSPEV, DSPGST, DTPMV, DTPSV,
+     $                   XERBLA
 *     ..
 *     .. Executable Statements ..
 *
