@@ -267,7 +267,8 @@
 *           Multiply by inv(U**T(K)), where U(K) is the transformation
 *           stored in column K of A.
 *
-            CALL DGEMV( 'Transpose', K-1, NRHS, -ONE, B, LDB, AP( KC ),
+            CALL DGEMV( 'Transpose', K-1, NRHS, -ONE, B, LDB,
+     $                  AP( KC ),
      $                  1, ONE, B( K, 1 ), LDB )
 *
 *           Interchange rows K and IPIV(K).
@@ -284,7 +285,8 @@
 *           Multiply by inv(U**T(K+1)), where U(K+1) is the transformation
 *           stored in columns K and K+1 of A.
 *
-            CALL DGEMV( 'Transpose', K-1, NRHS, -ONE, B, LDB, AP( KC ),
+            CALL DGEMV( 'Transpose', K-1, NRHS, -ONE, B, LDB,
+     $                  AP( KC ),
      $                  1, ONE, B( K, 1 ), LDB )
             CALL DGEMV( 'Transpose', K-1, NRHS, -ONE, B, LDB,
      $                  AP( KC+K ), 1, ONE, B( K+1, 1 ), LDB )
@@ -355,7 +357,8 @@
 *           stored in columns K and K+1 of A.
 *
             IF( K.LT.N-1 ) THEN
-               CALL DGER( N-K-1, NRHS, -ONE, AP( KC+2 ), 1, B( K, 1 ),
+               CALL DGER( N-K-1, NRHS, -ONE, AP( KC+2 ), 1, B( K,
+     $                    1 ),
      $                    LDB, B( K+2, 1 ), LDB )
                CALL DGER( N-K-1, NRHS, -ONE, AP( KC+N-K+2 ), 1,
      $                    B( K+1, 1 ), LDB, B( K+2, 1 ), LDB )
