@@ -129,7 +129,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup doubleSYcomputational
+*> \ingroup hetf2_rook
 *
 *> \par Further Details:
 *  =====================
@@ -410,7 +410,8 @@
                IF( KP.GT.1 )
      $            CALL DSWAP( KP-1, A( 1, KK ), 1, A( 1, KP ), 1 )
                IF( ( KK.GT.1 ) .AND. ( KP.LT.(KK-1) ) )
-     $            CALL DSWAP( KK-KP-1, A( KP+1, KK ), 1, A( KP, KP+1 ),
+     $            CALL DSWAP( KK-KP-1, A( KP+1, KK ), 1, A( KP,
+     $                        KP+1 ),
      $                     LDA )
                T = A( KK, KK )
                A( KK, KK ) = A( KP, KP )
@@ -444,7 +445,8 @@
 *                       = A - W(k)*1/D(k)*W(k)**T
 *
                      D11 = ONE / A( K, K )
-                     CALL DSYR( UPLO, K-1, -D11, A( 1, K ), 1, A, LDA )
+                     CALL DSYR( UPLO, K-1, -D11, A( 1, K ), 1, A,
+     $                          LDA )
 *
 *                    Store U(k) in column k
 *
@@ -463,7 +465,8 @@
 *                       = A - W(k)*(1/D(k))*W(k)**T
 *                       = A - (W(k)/D(k))*(D(k))*(W(k)/D(K))**T
 *
-                     CALL DSYR( UPLO, K-1, -D11, A( 1, K ), 1, A, LDA )
+                     CALL DSYR( UPLO, K-1, -D11, A( 1, K ), 1, A,
+     $                          LDA )
                   END IF
                END IF
 *
@@ -593,14 +596,16 @@
 *                 Determine both ROWMAX and JMAX.
 *
                   IF( IMAX.NE.K ) THEN
-                     JMAX = K - 1 + IDAMAX( IMAX-K, A( IMAX, K ), LDA )
+                     JMAX = K - 1 + IDAMAX( IMAX-K, A( IMAX, K ),
+     $                                      LDA )
                      ROWMAX = ABS( A( IMAX, JMAX ) )
                   ELSE
                      ROWMAX = ZERO
                   END IF
 *
                   IF( IMAX.LT.N ) THEN
-                     ITEMP = IMAX + IDAMAX( N-IMAX, A( IMAX+1, IMAX ),
+                     ITEMP = IMAX + IDAMAX( N-IMAX, A( IMAX+1,
+     $                                      IMAX ),
      $                                     1 )
                      DTEMP = ABS( A( ITEMP, IMAX ) )
                      IF( DTEMP.GT.ROWMAX ) THEN
@@ -659,7 +664,8 @@
                IF( P.LT.N )
      $            CALL DSWAP( N-P, A( P+1, K ), 1, A( P+1, P ), 1 )
                IF( P.GT.(K+1) )
-     $            CALL DSWAP( P-K-1, A( K+1, K ), 1, A( P, K+1 ), LDA )
+     $            CALL DSWAP( P-K-1, A( K+1, K ), 1, A( P, K+1 ),
+     $                        LDA )
                T = A( K, K )
                A( K, K ) = A( P, P )
                A( P, P ) = T
@@ -674,9 +680,11 @@
 *              submatrix A(k:n,k:n)
 *
                IF( KP.LT.N )
-     $            CALL DSWAP( N-KP, A( KP+1, KK ), 1, A( KP+1, KP ), 1 )
+     $            CALL DSWAP( N-KP, A( KP+1, KK ), 1, A( KP+1, KP ),
+     $                        1 )
                IF( ( KK.LT.N ) .AND. ( KP.GT.(KK+1) ) )
-     $            CALL DSWAP( KP-KK-1, A( KK+1, KK ), 1, A( KP, KK+1 ),
+     $            CALL DSWAP( KP-KK-1, A( KK+1, KK ), 1, A( KP,
+     $                        KK+1 ),
      $                     LDA )
                T = A( KK, KK )
                A( KK, KK ) = A( KP, KP )
