@@ -382,8 +382,10 @@
             DO WHILE ( I .LE. N )
                IF( IPIV(I) .GT. 0 ) THEN
                   IP=IPIV(I)
-                 IF (I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,IP )
-                 IF (I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP ,I )
+                 IF (I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,
+     $                IP )
+                 IF (I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP ,
+     $                I )
                ELSE
                  IP=-IPIV(I)
                  I=I+1
@@ -568,12 +570,16 @@
             DO WHILE ( I .GE. 1 )
                IF( IPIV(I) .GT. 0 ) THEN
                   IP=IPIV(I)
-                 IF (I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,IP  )
-                 IF (I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP ,I )
+                 IF (I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,
+     $                IP  )
+                 IF (I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP ,
+     $                I )
                ELSE
                  IP=-IPIV(I)
-                 IF ( I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,IP )
-                 IF ( I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP, I )
+                 IF ( I .LT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, I ,
+     $                IP )
+                 IF ( I .GT. IP) CALL DSYSWAPR( UPLO, N, A, LDA, IP,
+     $                I )
                  I=I-1
                ENDIF
                I=I-1
