@@ -2,25 +2,25 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *> \htmlonly
-*> Download DTFSM + dependencies 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dtfsm.f"> 
-*> [TGZ]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dtfsm.f"> 
-*> [ZIP]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dtfsm.f"> 
+*> Download DTFSM + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/dtfsm.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/dtfsm.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/dtfsm.f">
 *> [TXT]</a>
-*> \endhtmlonly 
+*> \endhtmlonly
 *
 *  Definition:
 *  ===========
 *
 *       SUBROUTINE DTFSM( TRANSR, SIDE, UPLO, TRANS, DIAG, M, N, ALPHA, A,
 *                         B, LDB )
-* 
+*
 *       .. Scalar Arguments ..
 *       CHARACTER          TRANSR, DIAG, SIDE, TRANS, UPLO
 *       INTEGER            LDB, M, N
@@ -29,7 +29,7 @@
 *       .. Array Arguments ..
 *       DOUBLE PRECISION   A( 0: * ), B( 0: LDB-1, 0: * )
 *       ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -141,7 +141,8 @@
 *> \param[in] A
 *> \verbatim
 *>          A is DOUBLE PRECISION array, dimension (NT)
-*>           NT = N*(N+1)/2. On entry, the matrix A in RFP Format.
+*>           NT = N*(N+1)/2 if SIDE='R' and NT = M*(M+1)/2 otherwise.
+*>           On entry, the matrix A in RFP Format.
 *>           RFP Format is described by TRANSR, UPLO and N as follows:
 *>           If TRANSR='N' then RFP A is (0:N,0:K-1) when N is even;
 *>           K=N/2. RFP A is (0:N-1,0:K) when N is odd; K=N/2. If
@@ -177,14 +178,12 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
-*> \date September 2012
-*
-*> \ingroup doubleOTHERcomputational
+*> \ingroup tfsm
 *
 *> \par Further Details:
 *  =====================
@@ -274,13 +273,13 @@
 *> \endverbatim
 *
 *  =====================================================================
-      SUBROUTINE DTFSM( TRANSR, SIDE, UPLO, TRANS, DIAG, M, N, ALPHA, A,
+      SUBROUTINE DTFSM( TRANSR, SIDE, UPLO, TRANS, DIAG, M, N, ALPHA,
+     $                  A,
      $                  B, LDB )
 *
-*  -- LAPACK computational routine (version 3.4.2) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     September 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANSR, DIAG, SIDE, TRANS, UPLO
@@ -330,7 +329,8 @@
          INFO = -3
       ELSE IF( .NOT.NOTRANS .AND. .NOT.LSAME( TRANS, 'T' ) ) THEN
          INFO = -4
-      ELSE IF( .NOT.LSAME( DIAG, 'N' ) .AND. .NOT.LSAME( DIAG, 'U' ) )
+      ELSE IF( .NOT.LSAME( DIAG, 'N' ) .AND.
+     $         .NOT.LSAME( DIAG, 'U' ) )
      $         THEN
          INFO = -5
       ELSE IF( M.LT.0 ) THEN
@@ -402,12 +402,15 @@
 *                    TRANS = 'N'
 *
                      IF( M.EQ.1 ) THEN
-                        CALL DTRSM( 'L', 'L', 'N', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'L', 'N', DIAG, M1, N,
+     $                              ALPHA,
      $                              A, M, B, LDB )
                      ELSE
-                        CALL DTRSM( 'L', 'L', 'N', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'L', 'N', DIAG, M1, N,
+     $                              ALPHA,
      $                              A( 0 ), M, B, LDB )
-                        CALL DGEMM( 'N', 'N', M2, N, M1, -ONE, A( M1 ),
+                        CALL DGEMM( 'N', 'N', M2, N, M1, -ONE,
+     $                              A( M1 ),
      $                              M, B, LDB, ALPHA, B( M1, 0 ), LDB )
                         CALL DTRSM( 'L', 'U', 'T', DIAG, M2, N, ONE,
      $                              A( M ), M, B( M1, 0 ), LDB )
@@ -419,12 +422,15 @@
 *                    TRANS = 'T'
 *
                      IF( M.EQ.1 ) THEN
-                        CALL DTRSM( 'L', 'L', 'T', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'L', 'T', DIAG, M1, N,
+     $                              ALPHA,
      $                              A( 0 ), M, B, LDB )
                      ELSE
-                        CALL DTRSM( 'L', 'U', 'N', DIAG, M2, N, ALPHA,
+                        CALL DTRSM( 'L', 'U', 'N', DIAG, M2, N,
+     $                              ALPHA,
      $                              A( M ), M, B( M1, 0 ), LDB )
-                        CALL DGEMM( 'T', 'N', M1, N, M2, -ONE, A( M1 ),
+                        CALL DGEMM( 'T', 'N', M1, N, M2, -ONE,
+     $                              A( M1 ),
      $                              M, B( M1, 0 ), LDB, ALPHA, B, LDB )
                         CALL DTRSM( 'L', 'L', 'T', DIAG, M1, N, ONE,
      $                              A( 0 ), M, B, LDB )
@@ -443,7 +449,8 @@
 *
                      CALL DTRSM( 'L', 'L', 'N', DIAG, M1, N, ALPHA,
      $                           A( M2 ), M, B, LDB )
-                     CALL DGEMM( 'T', 'N', M2, N, M1, -ONE, A( 0 ), M,
+                     CALL DGEMM( 'T', 'N', M2, N, M1, -ONE, A( 0 ),
+     $                           M,
      $                           B, LDB, ALPHA, B( M1, 0 ), LDB )
                      CALL DTRSM( 'L', 'U', 'T', DIAG, M2, N, ONE,
      $                           A( M1 ), M, B( M1, 0 ), LDB )
@@ -455,7 +462,8 @@
 *
                      CALL DTRSM( 'L', 'U', 'N', DIAG, M2, N, ALPHA,
      $                           A( M1 ), M, B( M1, 0 ), LDB )
-                     CALL DGEMM( 'N', 'N', M1, N, M2, -ONE, A( 0 ), M,
+                     CALL DGEMM( 'N', 'N', M1, N, M2, -ONE, A( 0 ),
+     $                           M,
      $                           B( M1, 0 ), LDB, ALPHA, B, LDB )
                      CALL DTRSM( 'L', 'L', 'T', DIAG, M1, N, ONE,
      $                           A( M2 ), M, B, LDB )
@@ -478,10 +486,12 @@
 *                    TRANS = 'N'
 *
                      IF( M.EQ.1 ) THEN
-                        CALL DTRSM( 'L', 'U', 'T', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'U', 'T', DIAG, M1, N,
+     $                              ALPHA,
      $                              A( 0 ), M1, B, LDB )
                      ELSE
-                        CALL DTRSM( 'L', 'U', 'T', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'U', 'T', DIAG, M1, N,
+     $                              ALPHA,
      $                              A( 0 ), M1, B, LDB )
                         CALL DGEMM( 'T', 'N', M2, N, M1, -ONE,
      $                              A( M1*M1 ), M1, B, LDB, ALPHA,
@@ -496,10 +506,12 @@
 *                    TRANS = 'T'
 *
                      IF( M.EQ.1 ) THEN
-                        CALL DTRSM( 'L', 'U', 'N', DIAG, M1, N, ALPHA,
+                        CALL DTRSM( 'L', 'U', 'N', DIAG, M1, N,
+     $                              ALPHA,
      $                              A( 0 ), M1, B, LDB )
                      ELSE
-                        CALL DTRSM( 'L', 'L', 'T', DIAG, M2, N, ALPHA,
+                        CALL DTRSM( 'L', 'L', 'T', DIAG, M2, N,
+     $                              ALPHA,
      $                              A( 1 ), M1, B( M1, 0 ), LDB )
                         CALL DGEMM( 'N', 'N', M1, N, M2, -ONE,
      $                              A( M1*M1 ), M1, B( M1, 0 ), LDB,
@@ -521,7 +533,8 @@
 *
                      CALL DTRSM( 'L', 'U', 'T', DIAG, M1, N, ALPHA,
      $                           A( M2*M2 ), M2, B, LDB )
-                     CALL DGEMM( 'N', 'N', M2, N, M1, -ONE, A( 0 ), M2,
+                     CALL DGEMM( 'N', 'N', M2, N, M1, -ONE, A( 0 ),
+     $                           M2,
      $                           B, LDB, ALPHA, B( M1, 0 ), LDB )
                      CALL DTRSM( 'L', 'L', 'N', DIAG, M2, N, ONE,
      $                           A( M1*M2 ), M2, B( M1, 0 ), LDB )
@@ -533,7 +546,8 @@
 *
                      CALL DTRSM( 'L', 'L', 'T', DIAG, M2, N, ALPHA,
      $                           A( M1*M2 ), M2, B( M1, 0 ), LDB )
-                     CALL DGEMM( 'T', 'N', M1, N, M2, -ONE, A( 0 ), M2,
+                     CALL DGEMM( 'T', 'N', M1, N, M2, -ONE, A( 0 ),
+     $                           M2,
      $                           B( M1, 0 ), LDB, ALPHA, B, LDB )
                      CALL DTRSM( 'L', 'U', 'N', DIAG, M1, N, ONE,
      $                           A( M2*M2 ), M2, B, LDB )
@@ -593,7 +607,8 @@
 *
                      CALL DTRSM( 'L', 'L', 'N', DIAG, K, N, ALPHA,
      $                           A( K+1 ), M+1, B, LDB )
-                     CALL DGEMM( 'T', 'N', K, N, K, -ONE, A( 0 ), M+1,
+                     CALL DGEMM( 'T', 'N', K, N, K, -ONE, A( 0 ),
+     $                           M+1,
      $                           B, LDB, ALPHA, B( K, 0 ), LDB )
                      CALL DTRSM( 'L', 'U', 'T', DIAG, K, N, ONE,
      $                           A( K ), M+1, B( K, 0 ), LDB )
@@ -604,7 +619,8 @@
 *                    and TRANS = 'T'
                      CALL DTRSM( 'L', 'U', 'N', DIAG, K, N, ALPHA,
      $                           A( K ), M+1, B( K, 0 ), LDB )
-                     CALL DGEMM( 'N', 'N', K, N, K, -ONE, A( 0 ), M+1,
+                     CALL DGEMM( 'N', 'N', K, N, K, -ONE, A( 0 ),
+     $                           M+1,
      $                           B( K, 0 ), LDB, ALPHA, B, LDB )
                      CALL DTRSM( 'L', 'L', 'T', DIAG, K, N, ONE,
      $                           A( K+1 ), M+1, B, LDB )
@@ -660,7 +676,8 @@
 *
                      CALL DTRSM( 'L', 'U', 'T', DIAG, K, N, ALPHA,
      $                           A( K*( K+1 ) ), K, B, LDB )
-                     CALL DGEMM( 'N', 'N', K, N, K, -ONE, A( 0 ), K, B,
+                     CALL DGEMM( 'N', 'N', K, N, K, -ONE, A( 0 ), K,
+     $                           B,
      $                           LDB, ALPHA, B( K, 0 ), LDB )
                      CALL DTRSM( 'L', 'L', 'N', DIAG, K, N, ONE,
      $                           A( K*K ), K, B( K, 0 ), LDB )
@@ -726,7 +743,8 @@
 *
                      CALL DTRSM( 'R', 'U', 'T', DIAG, M, N2, ALPHA,
      $                           A( N ), N, B( 0, N1 ), LDB )
-                     CALL DGEMM( 'N', 'N', M, N1, N2, -ONE, B( 0, N1 ),
+                     CALL DGEMM( 'N', 'N', M, N1, N2, -ONE, B( 0,
+     $                           N1 ),
      $                           LDB, A( N1 ), N, ALPHA, B( 0, 0 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'L', 'N', DIAG, M, N1, ONE,
@@ -739,7 +757,8 @@
 *
                      CALL DTRSM( 'R', 'L', 'T', DIAG, M, N1, ALPHA,
      $                           A( 0 ), N, B( 0, 0 ), LDB )
-                     CALL DGEMM( 'N', 'T', M, N2, N1, -ONE, B( 0, 0 ),
+                     CALL DGEMM( 'N', 'T', M, N2, N1, -ONE, B( 0,
+     $                           0 ),
      $                           LDB, A( N1 ), N, ALPHA, B( 0, N1 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'U', 'N', DIAG, M, N2, ONE,
@@ -758,7 +777,8 @@
 *
                      CALL DTRSM( 'R', 'L', 'T', DIAG, M, N1, ALPHA,
      $                           A( N2 ), N, B( 0, 0 ), LDB )
-                     CALL DGEMM( 'N', 'N', M, N2, N1, -ONE, B( 0, 0 ),
+                     CALL DGEMM( 'N', 'N', M, N2, N1, -ONE, B( 0,
+     $                           0 ),
      $                           LDB, A( 0 ), N, ALPHA, B( 0, N1 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'U', 'N', DIAG, M, N2, ONE,
@@ -771,7 +791,8 @@
 *
                      CALL DTRSM( 'R', 'U', 'T', DIAG, M, N2, ALPHA,
      $                           A( N1 ), N, B( 0, N1 ), LDB )
-                     CALL DGEMM( 'N', 'T', M, N1, N2, -ONE, B( 0, N1 ),
+                     CALL DGEMM( 'N', 'T', M, N1, N2, -ONE, B( 0,
+     $                           N1 ),
      $                           LDB, A( 0 ), N, ALPHA, B( 0, 0 ), LDB )
                      CALL DTRSM( 'R', 'L', 'N', DIAG, M, N1, ONE,
      $                           A( N2 ), N, B( 0, 0 ), LDB )
@@ -795,7 +816,8 @@
 *
                      CALL DTRSM( 'R', 'L', 'N', DIAG, M, N2, ALPHA,
      $                           A( 1 ), N1, B( 0, N1 ), LDB )
-                     CALL DGEMM( 'N', 'T', M, N1, N2, -ONE, B( 0, N1 ),
+                     CALL DGEMM( 'N', 'T', M, N1, N2, -ONE, B( 0,
+     $                           N1 ),
      $                           LDB, A( N1*N1 ), N1, ALPHA, B( 0, 0 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'U', 'T', DIAG, M, N1, ONE,
@@ -808,7 +830,8 @@
 *
                      CALL DTRSM( 'R', 'U', 'N', DIAG, M, N1, ALPHA,
      $                           A( 0 ), N1, B( 0, 0 ), LDB )
-                     CALL DGEMM( 'N', 'N', M, N2, N1, -ONE, B( 0, 0 ),
+                     CALL DGEMM( 'N', 'N', M, N2, N1, -ONE, B( 0,
+     $                           0 ),
      $                           LDB, A( N1*N1 ), N1, ALPHA, B( 0, N1 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'L', 'T', DIAG, M, N2, ONE,
@@ -827,7 +850,8 @@
 *
                      CALL DTRSM( 'R', 'U', 'N', DIAG, M, N1, ALPHA,
      $                           A( N2*N2 ), N2, B( 0, 0 ), LDB )
-                     CALL DGEMM( 'N', 'T', M, N2, N1, -ONE, B( 0, 0 ),
+                     CALL DGEMM( 'N', 'T', M, N2, N1, -ONE, B( 0,
+     $                           0 ),
      $                           LDB, A( 0 ), N2, ALPHA, B( 0, N1 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'L', 'T', DIAG, M, N2, ONE,
@@ -840,7 +864,8 @@
 *
                      CALL DTRSM( 'R', 'L', 'N', DIAG, M, N2, ALPHA,
      $                           A( N1*N2 ), N2, B( 0, N1 ), LDB )
-                     CALL DGEMM( 'N', 'N', M, N1, N2, -ONE, B( 0, N1 ),
+                     CALL DGEMM( 'N', 'N', M, N1, N2, -ONE, B( 0,
+     $                           N1 ),
      $                           LDB, A( 0 ), N2, ALPHA, B( 0, 0 ),
      $                           LDB )
                      CALL DTRSM( 'R', 'U', 'T', DIAG, M, N1, ONE,
