@@ -230,7 +230,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup doubleOTHERcomputational
+*> \ingroup tgsna
 *
 *> \par Further Details:
 *  =====================
@@ -420,7 +420,8 @@
       EXTERNAL           LSAME, DDOT, DLAMCH, DLAPY2, DNRM2
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DGEMV, DLACPY, DLAG2, DTGEXC, DTGSYL, XERBLA
+      EXTERNAL           DGEMV, DLACPY, DLAG2, DTGEXC, DTGSYL,
+     $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, MIN, SQRT
@@ -558,7 +559,8 @@
      $                DNRM2( N, VR( 1, KS+1 ), 1 ) )
                LNRM = DLAPY2( DNRM2( N, VL( 1, KS ), 1 ),
      $                DNRM2( N, VL( 1, KS+1 ), 1 ) )
-               CALL DGEMV( 'N', N, N, ONE, A, LDA, VR( 1, KS ), 1, ZERO,
+               CALL DGEMV( 'N', N, N, ONE, A, LDA, VR( 1, KS ), 1,
+     $                     ZERO,
      $                     WORK, 1 )
                TMPRR = DDOT( N, WORK, 1, VL( 1, KS ), 1 )
                TMPRI = DDOT( N, WORK, 1, VL( 1, KS+1 ), 1 )
@@ -568,7 +570,8 @@
                TMPIR = DDOT( N, WORK, 1, VL( 1, KS ), 1 )
                UHAV = TMPRR + TMPII
                UHAVI = TMPIR - TMPRI
-               CALL DGEMV( 'N', N, N, ONE, B, LDB, VR( 1, KS ), 1, ZERO,
+               CALL DGEMV( 'N', N, N, ONE, B, LDB, VR( 1, KS ), 1,
+     $                     ZERO,
      $                     WORK, 1 )
                TMPRR = DDOT( N, WORK, 1, VL( 1, KS ), 1 )
                TMPRI = DDOT( N, WORK, 1, VL( 1, KS+1 ), 1 )
@@ -590,10 +593,12 @@
 *
                RNRM = DNRM2( N, VR( 1, KS ), 1 )
                LNRM = DNRM2( N, VL( 1, KS ), 1 )
-               CALL DGEMV( 'N', N, N, ONE, A, LDA, VR( 1, KS ), 1, ZERO,
+               CALL DGEMV( 'N', N, N, ONE, A, LDA, VR( 1, KS ), 1,
+     $                     ZERO,
      $                     WORK, 1 )
                UHAV = DDOT( N, WORK, 1, VL( 1, KS ), 1 )
-               CALL DGEMV( 'N', N, N, ONE, B, LDB, VR( 1, KS ), 1, ZERO,
+               CALL DGEMV( 'N', N, N, ONE, B, LDB, VR( 1, KS ), 1,
+     $                     ZERO,
      $                     WORK, 1 )
                UHBV = DDOT( N, WORK, 1, VL( 1, KS ), 1 )
                COND = DLAPY2( UHAV, UHBV )
@@ -632,8 +637,8 @@
                C1 = TWO*( ALPHAR*ALPHAR+ALPHAI*ALPHAI+BETA*BETA )
                C2 = FOUR*BETA*BETA*ALPHAI*ALPHAI
                ROOT1 = C1 + SQRT( C1*C1-4.0D0*C2 )
-               ROOT2 = C2 / ROOT1
                ROOT1 = ROOT1 / TWO
+               ROOT2 = C2 / ROOT1
                COND = MIN( SQRT( ROOT1 ), SQRT( ROOT2 ) )
             END IF
 *
@@ -645,7 +650,8 @@
             IFST = K
             ILST = 1
 *
-            CALL DTGEXC( .FALSE., .FALSE., N, WORK, N, WORK( N*N+1 ), N,
+            CALL DTGEXC( .FALSE., .FALSE., N, WORK, N, WORK( N*N+1 ),
+     $                   N,
      $                   DUMMY, 1, DUMMY1, 1, IFST, ILST,
      $                   WORK( N*N*2+1 ), LWORK-2*N*N, IERR )
 *
@@ -671,7 +677,8 @@
                ELSE
                   I = N*N + 1
                   IZ = 2*N*N + 1
-                  CALL DTGSYL( 'N', DIFDRI, N2, N1, WORK( N*N1+N1+1 ),
+                  CALL DTGSYL( 'N', DIFDRI, N2, N1,
+     $                         WORK( N*N1+N1+1 ),
      $                         N, WORK, N, WORK( N1+1 ), N,
      $                         WORK( N*N1+N1+I ), N, WORK( I ), N,
      $                         WORK( N1+I ), N, SCALE, DIF( KS ),
