@@ -190,7 +190,7 @@
 *>
 *> \param[in,out] V2T
 *> \verbatim
-*>          V2T is REAL array, dimenison (LDV2T,M-Q)
+*>          V2T is REAL array, dimension (LDV2T,M-Q)
 *>          On entry, an (M-Q)-by-(M-Q) matrix. On exit, V2T is
 *>          premultiplied by the transpose of the right
 *>          singular vector matrix common to [ B12 0 0 ; 0 -I 0 ] and
@@ -322,20 +322,18 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2016
-*
-*> \ingroup realOTHERcomputational
+*> \ingroup bbcsd
 *
 *  =====================================================================
-      SUBROUTINE SBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P, Q,
+      SUBROUTINE SBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P,
+     $                   Q,
      $                   THETA, PHI, U1, LDU1, U2, LDU2, V1T, LDV1T,
      $                   V2T, LDV2T, B11D, B11E, B12D, B12E, B21D, B21E,
      $                   B22D, B22E, WORK, LWORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS
@@ -354,12 +352,13 @@
 *     .. Parameters ..
       INTEGER            MAXITR
       PARAMETER          ( MAXITR = 6 )
-      REAL               HUNDRED, MEIGHTH, ONE, PIOVER2, TEN, ZERO
+      REAL               HUNDRED, MEIGHTH, ONE, TEN, ZERO
       PARAMETER          ( HUNDRED = 100.0E0, MEIGHTH = -0.125E0,
-     $                     ONE = 1.0E0, PIOVER2 = 1.57079632679489662E0,
-     $                     TEN = 10.0E0, ZERO = 0.0E0 )
+     $                     ONE = 1.0E0, TEN = 10.0E0, ZERO = 0.0E0 )
       REAL               NEGONE
       PARAMETER          ( NEGONE = -1.0E0 )
+      REAL               PIOVER2
+      PARAMETER ( PIOVER2 = 1.57079632679489661923132169163975144210E0 )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            COLMAJOR, LQUERY, RESTART11, RESTART12,
@@ -374,7 +373,8 @@
      $                   UNFL, X1, X2, Y1, Y2
 *
 *     .. External Subroutines ..
-      EXTERNAL           SLASR, SSCAL, SSWAP, SLARTGP, SLARTGS, SLAS2,
+      EXTERNAL           SLASR, SSCAL, SSWAP, SLARTGP, SLARTGS,
+     $                   SLAS2,
      $                   XERBLA
 *     ..
 *     .. External Functions ..
@@ -419,7 +419,7 @@
 *
       IF( INFO .EQ. 0 .AND. Q .EQ. 0 ) THEN
          LWORKMIN = 1
-         WORK(1) = LWORKMIN
+         WORK(1) = REAL( LWORKMIN )
          RETURN
       END IF
 *
@@ -436,7 +436,7 @@
          IV2TSN = IV2TCS + Q
          LWORKOPT = IV2TSN + Q - 1
          LWORKMIN = LWORKOPT
-         WORK(1) = LWORKOPT
+         WORK(1) = REAL( LWORKOPT )
          IF( LWORK .LT. LWORKMIN .AND. .NOT. LQUERY ) THEN
             INFO = -28
          END IF
@@ -455,7 +455,7 @@
       UNFL = SLAMCH( 'Safe minimum' )
       TOLMUL = MAX( TEN, MIN( HUNDRED, EPS**MEIGHTH ) )
       TOL = TOLMUL*EPS
-      THRESH = MAX( TOL, MAXITR*Q*Q*UNFL )
+      THRESH = MAX( TOL, REAL( MAXITR*Q*Q )*UNFL )
 *
 *     Test for negligible sines or cosines
 *
@@ -561,9 +561,11 @@
 *
 *           Compute shifts for B11 and B21 and use the lesser
 *
-            CALL SLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX), SIGMA11,
+            CALL SLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX),
+     $                  SIGMA11,
      $                  DUMMY )
-            CALL SLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX), SIGMA21,
+            CALL SLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX),
+     $                  SIGMA21,
      $                  DUMMY )
 *
             IF( SIGMA11 .LE. SIGMA21 ) THEN
@@ -699,7 +701,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART21 ) THEN
-               CALL SLARTGP( X2, X1, WORK(IV1TSN+I-1), WORK(IV1TCS+I-1),
+               CALL SLARTGP( X2, X1, WORK(IV1TSN+I-1),
+     $                       WORK(IV1TCS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART21 ) THEN
                CALL SLARTGP( B11BULGE, B11E(I-1), WORK(IV1TSN+I-1),
@@ -726,10 +729,12 @@
                CALL SLARTGP( B22BULGE, B22D(I-1), WORK(IV2TSN+I-1-1),
      $                       WORK(IV2TCS+I-1-1), R )
             ELSE IF( NU .LT. MU ) THEN
-               CALL SLARTGS( B12E(I-1), B12D(I), NU, WORK(IV2TCS+I-1-1),
+               CALL SLARTGS( B12E(I-1), B12D(I), NU,
+     $                       WORK(IV2TCS+I-1-1),
      $                       WORK(IV2TSN+I-1-1) )
             ELSE
-               CALL SLARTGS( B22E(I-1), B22D(I), MU, WORK(IV2TCS+I-1-1),
+               CALL SLARTGS( B22E(I-1), B22D(I), MU,
+     $                       WORK(IV2TCS+I-1-1),
      $                       WORK(IV2TSN+I-1-1) )
             END IF
 *
@@ -782,7 +787,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART12 ) THEN
-               CALL SLARTGP( X2, X1, WORK(IU1SN+I-1), WORK(IU1CS+I-1),
+               CALL SLARTGP( X2, X1, WORK(IU1SN+I-1),
+     $                       WORK(IU1CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART12 ) THEN
                CALL SLARTGP( B11BULGE, B11D(I), WORK(IU1SN+I-1),
@@ -798,7 +804,8 @@
      $                       WORK(IU1SN+I-1) )
             END IF
             IF( .NOT. RESTART21 .AND. .NOT. RESTART22 ) THEN
-               CALL SLARTGP( Y2, Y1, WORK(IU2SN+I-1), WORK(IU2CS+I-1),
+               CALL SLARTGP( Y2, Y1, WORK(IU2SN+I-1),
+     $                       WORK(IU2CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART21 .AND. RESTART22 ) THEN
                CALL SLARTGP( B21BULGE, B21D(I), WORK(IU2SN+I-1),
@@ -864,10 +871,12 @@
             CALL SLARTGP( Y2, Y1, WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( .NOT. RESTART12 .AND. RESTART22 ) THEN
-            CALL SLARTGP( B12BULGE, B12D(IMAX-1), WORK(IV2TSN+IMAX-1-1),
+            CALL SLARTGP( B12BULGE, B12D(IMAX-1),
+     $                    WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( RESTART12 .AND. .NOT. RESTART22 ) THEN
-            CALL SLARTGP( B22BULGE, B22D(IMAX-1), WORK(IV2TSN+IMAX-1-1),
+            CALL SLARTGP( B22BULGE, B22D(IMAX-1),
+     $                    WORK(IV2TSN+IMAX-1-1),
      $                    WORK(IV2TCS+IMAX-1-1), R )
          ELSE IF( NU .LT. MU ) THEN
             CALL SLARTGS( B12E(IMAX-1), B12D(IMAX), NU,
@@ -1054,7 +1063,8 @@
                IF( WANTU2 )
      $            CALL SSWAP( M-P, U2(1,I), 1, U2(1,MINI), 1 )
                IF( WANTV1T )
-     $            CALL SSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1), LDV1T )
+     $            CALL SSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1),
+     $                        LDV1T )
                IF( WANTV2T )
      $            CALL SSWAP( M-Q, V2T(I,1), LDV2T, V2T(MINI,1),
      $               LDV2T )
