@@ -148,7 +148,8 @@
 *> \ingroup gbequ
 *
 *  =====================================================================
-      SUBROUTINE SGBEQU( M, N, KL, KU, AB, LDAB, R, C, ROWCND, COLCND,
+      SUBROUTINE SGBEQU( M, N, KL, KU, AB, LDAB, R, C, ROWCND,
+     $                   COLCND,
      $                   AMAX, INFO )
 *
 *  -- LAPACK computational routine --
