@@ -155,7 +155,8 @@
 *> \ingroup gbequb
 *
 *  =====================================================================
-      SUBROUTINE SGBEQUB( M, N, KL, KU, AB, LDAB, R, C, ROWCND, COLCND,
+      SUBROUTINE SGBEQUB( M, N, KL, KU, AB, LDAB, R, C, ROWCND,
+     $                    COLCND,
      $                    AMAX, INFO )
 *
 *  -- LAPACK computational routine --
