@@ -160,10 +160,11 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup realGBcomputational
+*> \ingroup la_gbrcond
 *
 *  =====================================================================
-      REAL FUNCTION SLA_GBRCOND( TRANS, N, KL, KU, AB, LDAB, AFB, LDAFB,
+      REAL FUNCTION SLA_GBRCOND( TRANS, N, KL, KU, AB, LDAB, AFB,
+     $                           LDAFB,
      $                           IPIV, CMODE, C, INFO, WORK, IWORK )
 *
 *  -- LAPACK computational routine --
@@ -292,7 +293,8 @@
                CALL SGBTRS( 'No transpose', N, KL, KU, 1, AFB, LDAFB,
      $              IPIV, WORK, N, INFO )
             ELSE
-               CALL SGBTRS( 'Transpose', N, KL, KU, 1, AFB, LDAFB, IPIV,
+               CALL SGBTRS( 'Transpose', N, KL, KU, 1, AFB, LDAFB,
+     $                      IPIV,
      $              WORK, N, INFO )
             END IF
 *
@@ -322,7 +324,8 @@
             END IF
 
             IF ( NOTRANS ) THEN
-               CALL SGBTRS( 'Transpose', N, KL, KU, 1, AFB, LDAFB, IPIV,
+               CALL SGBTRS( 'Transpose', N, KL, KU, 1, AFB, LDAFB,
+     $                      IPIV,
      $              WORK, N, INFO )
             ELSE
                CALL SGBTRS( 'No transpose', N, KL, KU, 1, AFB, LDAFB,
