@@ -166,7 +166,8 @@
       INTEGER            IINFO, J, JB, NB
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SGEMM, SLAORHR_COL_GETRFNP2, STRSM, XERBLA
+      EXTERNAL           SGEMM, SLAORHR_COL_GETRFNP2, STRSM,
+     $                   XERBLA
 *     ..
 *     .. External Functions ..
       INTEGER            ILAENV
@@ -223,14 +224,16 @@
 *
 *              Compute block row of U.
 *
-               CALL STRSM( 'Left', 'Lower', 'No transpose', 'Unit', JB,
+               CALL STRSM( 'Left', 'Lower', 'No transpose', 'Unit',
+     $                     JB,
      $                     N-J-JB+1, ONE, A( J, J ), LDA, A( J, J+JB ),
      $                     LDA )
                IF( J+JB.LE.M ) THEN
 *
 *                 Update trailing submatrix.
 *
-                  CALL SGEMM( 'No transpose', 'No transpose', M-J-JB+1,
+                  CALL SGEMM( 'No transpose', 'No transpose',
+     $                        M-J-JB+1,
      $                        N-J-JB+1, JB, -ONE, A( J+JB, J ), LDA,
      $                        A( J, J+JB ), LDA, ONE, A( J+JB, J+JB ),
      $                        LDA )
