@@ -147,7 +147,8 @@
 *>     California at Berkeley, USA
 *>
 *  =====================================================================
-      SUBROUTINE SLASD0( N, SQRE, D, E, U, LDU, VT, LDVT, SMLSIZ, IWORK,
+      SUBROUTINE SLASD0( N, SQRE, D, E, U, LDU, VT, LDVT, SMLSIZ,
+     $                   IWORK,
      $                   WORK, INFO )
 *
 *  -- LAPACK auxiliary routine --
@@ -203,7 +204,8 @@
 *     If the input matrix is too small, call SLASDQ to find the SVD.
 *
       IF( N.LE.SMLSIZ ) THEN
-         CALL SLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDVT, U, LDU, U,
+         CALL SLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDVT, U, LDU,
+     $                U,
      $                LDU, WORK, INFO )
          RETURN
       END IF
@@ -240,7 +242,8 @@
          NLF = IC - NL
          NRF = IC + 1
          SQREI = 1
-         CALL SLASDQ( 'U', SQREI, NL, NLP1, NL, NCC, D( NLF ), E( NLF ),
+         CALL SLASDQ( 'U', SQREI, NL, NLP1, NL, NCC, D( NLF ),
+     $                E( NLF ),
      $                VT( NLF, NLF ), LDVT, U( NLF, NLF ), LDU,
      $                U( NLF, NLF ), LDU, WORK, INFO )
          IF( INFO.NE.0 ) THEN
@@ -256,7 +259,8 @@
             SQREI = 1
          END IF
          NRP1 = NR + SQREI
-         CALL SLASDQ( 'U', SQREI, NR, NRP1, NR, NCC, D( NRF ), E( NRF ),
+         CALL SLASDQ( 'U', SQREI, NR, NRP1, NR, NCC, D( NRF ),
+     $                E( NRF ),
      $                VT( NRF, NRF ), LDVT, U( NRF, NRF ), LDU,
      $                U( NRF, NRF ), LDU, WORK, INFO )
          IF( INFO.NE.0 ) THEN
