@@ -267,7 +267,8 @@
 *>     California at Berkeley, USA
 *>
 *  =====================================================================
-      SUBROUTINE SLASDA( ICOMPQ, SMLSIZ, N, SQRE, D, E, U, LDU, VT, K,
+      SUBROUTINE SLASDA( ICOMPQ, SMLSIZ, N, SQRE, D, E, U, LDU, VT,
+     $                   K,
      $                   DIFL, DIFR, Z, POLES, GIVPTR, GIVCOL, LDGCOL,
      $                   PERM, GIVNUM, C, S, WORK, IWORK, INFO )
 *
@@ -301,7 +302,8 @@
       REAL               ALPHA, BETA
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SCOPY, SLASD6, SLASDQ, SLASDT, SLASET, XERBLA
+      EXTERNAL           SCOPY, SLASD6, SLASDQ, SLASDT, SLASET,
+     $                   XERBLA
 *     ..
 *     .. Executable Statements ..
 *
@@ -333,10 +335,12 @@
 *
       IF( N.LE.SMLSIZ ) THEN
          IF( ICOMPQ.EQ.0 ) THEN
-            CALL SLASDQ( 'U', SQRE, N, 0, 0, 0, D, E, VT, LDU, U, LDU,
+            CALL SLASDQ( 'U', SQRE, N, 0, 0, 0, D, E, VT, LDU, U,
+     $                   LDU,
      $                   U, LDU, WORK, INFO )
          ELSE
-            CALL SLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDU, U, LDU,
+            CALL SLASDQ( 'U', SQRE, N, M, N, 0, D, E, VT, LDU, U,
+     $                   LDU,
      $                   U, LDU, WORK, INFO )
          END IF
          RETURN
@@ -397,7 +401,8 @@
             CALL SCOPY( NLP1, WORK( ITEMP ), 1, WORK( VLI ), 1 )
          ELSE
             CALL SLASET( 'A', NL, NL, ZERO, ONE, U( NLF, 1 ), LDU )
-            CALL SLASET( 'A', NLP1, NLP1, ZERO, ONE, VT( NLF, 1 ), LDU )
+            CALL SLASET( 'A', NLP1, NLP1, ZERO, ONE, VT( NLF, 1 ),
+     $                   LDU )
             CALL SLASDQ( 'U', SQREI, NL, NLP1, NL, NCC, D( NLF ),
      $                   E( NLF ), VT( NLF, 1 ), LDU, U( NLF, 1 ), LDU,
      $                   U( NLF, 1 ), LDU, WORK( NWORK1 ), INFO )
@@ -431,7 +436,8 @@
             CALL SCOPY( NRP1, WORK( ITEMP ), 1, WORK( VLI ), 1 )
          ELSE
             CALL SLASET( 'A', NR, NR, ZERO, ONE, U( NRF, 1 ), LDU )
-            CALL SLASET( 'A', NRP1, NRP1, ZERO, ONE, VT( NRF, 1 ), LDU )
+            CALL SLASET( 'A', NRP1, NRP1, ZERO, ONE, VT( NRF, 1 ),
+     $                   LDU )
             CALL SLASDQ( 'U', SQREI, NR, NRP1, NR, NCC, D( NRF ),
      $                   E( NRF ), VT( NRF, 1 ), LDU, U( NRF, 1 ), LDU,
      $                   U( NRF, 1 ), LDU, WORK( NWORK1 ), INFO )
