@@ -248,7 +248,8 @@
 *
                CALL SGEMV( 'No transpose', I, N-I, -ONE, A( 1, I+1 ),
      $                     LDA, W( I, IW+1 ), LDW, ONE, A( 1, I ), 1 )
-               CALL SGEMV( 'No transpose', I, N-I, -ONE, W( 1, IW+1 ),
+               CALL SGEMV( 'No transpose', I, N-I, -ONE, W( 1,
+     $                     IW+1 ),
      $                     LDW, A( I, I+1 ), LDA, ONE, A( 1, I ), 1 )
             END IF
             IF( I.GT.1 ) THEN
@@ -256,7 +257,8 @@
 *              Generate elementary reflector H(i) to annihilate
 *              A(1:i-2,i)
 *
-               CALL SLARFG( I-1, A( I-1, I ), A( 1, I ), 1, TAU( I-1 ) )
+               CALL SLARFG( I-1, A( I-1, I ), A( 1, I ), 1,
+     $                      TAU( I-1 ) )
                E( I-1 ) = A( I-1, I )
                A( I-1, I ) = ONE
 *
@@ -265,12 +267,14 @@
                CALL SSYMV( 'Upper', I-1, ONE, A, LDA, A( 1, I ), 1,
      $                     ZERO, W( 1, IW ), 1 )
                IF( I.LT.N ) THEN
-                  CALL SGEMV( 'Transpose', I-1, N-I, ONE, W( 1, IW+1 ),
+                  CALL SGEMV( 'Transpose', I-1, N-I, ONE, W( 1,
+     $                        IW+1 ),
      $                        LDW, A( 1, I ), 1, ZERO, W( I+1, IW ), 1 )
                   CALL SGEMV( 'No transpose', I-1, N-I, -ONE,
      $                        A( 1, I+1 ), LDA, W( I+1, IW ), 1, ONE,
      $                        W( 1, IW ), 1 )
-                  CALL SGEMV( 'Transpose', I-1, N-I, ONE, A( 1, I+1 ),
+                  CALL SGEMV( 'Transpose', I-1, N-I, ONE, A( 1,
+     $                        I+1 ),
      $                        LDA, A( 1, I ), 1, ZERO, W( I+1, IW ), 1 )
                   CALL SGEMV( 'No transpose', I-1, N-I, -ONE,
      $                        W( 1, IW+1 ), LDW, W( I+1, IW ), 1, ONE,
@@ -300,7 +304,8 @@
 *              Generate elementary reflector H(i) to annihilate
 *              A(i+2:n,i)
 *
-               CALL SLARFG( N-I, A( I+1, I ), A( MIN( I+2, N ), I ), 1,
+               CALL SLARFG( N-I, A( I+1, I ), A( MIN( I+2, N ), I ),
+     $                      1,
      $                      TAU( I ) )
                E( I ) = A( I+1, I )
                A( I+1, I ) = ONE
@@ -309,18 +314,23 @@
 *
                CALL SSYMV( 'Lower', N-I, ONE, A( I+1, I+1 ), LDA,
      $                     A( I+1, I ), 1, ZERO, W( I+1, I ), 1 )
-               CALL SGEMV( 'Transpose', N-I, I-1, ONE, W( I+1, 1 ), LDW,
+               CALL SGEMV( 'Transpose', N-I, I-1, ONE, W( I+1, 1 ),
+     $                     LDW,
      $                     A( I+1, I ), 1, ZERO, W( 1, I ), 1 )
-               CALL SGEMV( 'No transpose', N-I, I-1, -ONE, A( I+1, 1 ),
+               CALL SGEMV( 'No transpose', N-I, I-1, -ONE, A( I+1,
+     $                     1 ),
      $                     LDA, W( 1, I ), 1, ONE, W( I+1, I ), 1 )
-               CALL SGEMV( 'Transpose', N-I, I-1, ONE, A( I+1, 1 ), LDA,
+               CALL SGEMV( 'Transpose', N-I, I-1, ONE, A( I+1, 1 ),
+     $                     LDA,
      $                     A( I+1, I ), 1, ZERO, W( 1, I ), 1 )
-               CALL SGEMV( 'No transpose', N-I, I-1, -ONE, W( I+1, 1 ),
+               CALL SGEMV( 'No transpose', N-I, I-1, -ONE, W( I+1,
+     $                     1 ),
      $                     LDW, W( 1, I ), 1, ONE, W( I+1, I ), 1 )
                CALL SSCAL( N-I, TAU( I ), W( I+1, I ), 1 )
                ALPHA = -HALF*TAU( I )*SDOT( N-I, W( I+1, I ), 1,
      $                 A( I+1, I ), 1 )
-               CALL SAXPY( N-I, ALPHA, A( I+1, I ), 1, W( I+1, I ), 1 )
+               CALL SAXPY( N-I, ALPHA, A( I+1, I ), 1, W( I+1, I ),
+     $                     1 )
             END IF
 *
    20    CONTINUE
