@@ -196,7 +196,8 @@
 *>      Algorithms, 50(1):33-65, 2009.
 *>
 *  =====================================================================
-      SUBROUTINE SORBDB2( M, P, Q, X11, LDX11, X21, LDX21, THETA, PHI,
+      SUBROUTINE SORBDB2( M, P, Q, X11, LDX11, X21, LDX21, THETA,
+     $                    PHI,
      $                    TAUP1, TAUP2, TAUQ1, WORK, LWORK, INFO )
 *
 *  -- LAPACK computational routine --
@@ -215,8 +216,8 @@
 *  ====================================================================
 *
 *     .. Parameters ..
-      REAL               NEGONE, ONE
-      PARAMETER          ( NEGONE = -1.0E0, ONE = 1.0E0 )
+      REAL               NEGONE
+      PARAMETER          ( NEGONE = -1.0E0 )
 *     ..
 *     .. Local Scalars ..
       REAL               C, S
@@ -225,7 +226,8 @@
       LOGICAL            LQUERY
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SLARF, SLARFGP, SORBDB5, SROT, SSCAL, XERBLA
+      EXTERNAL           SLARF1F, SLARFGP, SORBDB5, SROT, SSCAL,
+     $                   XERBLA
 *     ..
 *     .. External Functions ..
       REAL               SNRM2
@@ -262,7 +264,7 @@
          LORBDB5 = Q-1
          LWORKOPT = MAX( ILARF+LLARF-1, IORBDB5+LORBDB5-1 )
          LWORKMIN = LWORKOPT
-         WORK(1) = LWORKOPT
+         WORK(1) = REAL( LWORKOPT )
          IF( LWORK .LT. LWORKMIN .AND. .NOT.LQUERY ) THEN
            INFO = -14
          END IF
@@ -279,15 +281,15 @@
       DO I = 1, P
 *
          IF( I .GT. 1 ) THEN
-            CALL SROT( Q-I+1, X11(I,I), LDX11, X21(I-1,I), LDX21, C, S )
+            CALL SROT( Q-I+1, X11(I,I), LDX11, X21(I-1,I), LDX21, C,
+     $                 S )
          END IF
          CALL SLARFGP( Q-I+1, X11(I,I), X11(I,I+1), LDX11, TAUQ1(I) )
          C = X11(I,I)
-         X11(I,I) = ONE
-         CALL SLARF( 'R', P-I, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
-     $               X11(I+1,I), LDX11, WORK(ILARF) )
-         CALL SLARF( 'R', M-P-I+1, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
-     $               X21(I,I), LDX21, WORK(ILARF) )
+         CALL SLARF1F( 'R', P-I, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
+     $                 X11(I+1,I), LDX11, WORK(ILARF) )
+         CALL SLARF1F( 'R', M-P-I+1, Q-I+1, X11(I,I), LDX11,
+     $                 TAUQ1(I), X21(I,I), LDX21, WORK(ILARF) )
          S = SQRT( SNRM2( P-I, X11(I+1,I), 1 )**2
      $           + SNRM2( M-P-I+1, X21(I,I), 1 )**2 )
          THETA(I) = ATAN2( S, C )
@@ -302,13 +304,11 @@
             PHI(I) = ATAN2( X11(I+1,I), X21(I,I) )
             C = COS( PHI(I) )
             S = SIN( PHI(I) )
-            X11(I+1,I) = ONE
-            CALL SLARF( 'L', P-I, Q-I, X11(I+1,I), 1, TAUP1(I),
-     $                  X11(I+1,I+1), LDX11, WORK(ILARF) )
+            CALL SLARF1F( 'L', P-I, Q-I, X11(I+1,I), 1, TAUP1(I),
+     $                    X11(I+1,I+1), LDX11, WORK(ILARF) )
          END IF
-         X21(I,I) = ONE
-         CALL SLARF( 'L', M-P-I+1, Q-I, X21(I,I), 1, TAUP2(I),
-     $               X21(I,I+1), LDX21, WORK(ILARF) )
+         CALL SLARF1F( 'L', M-P-I+1, Q-I, X21(I,I), 1, TAUP2(I),
+     $                 X21(I,I+1), LDX21, WORK(ILARF) )
 *
       END DO
 *
@@ -316,9 +316,8 @@
 *
       DO I = P + 1, Q
          CALL SLARFGP( M-P-I+1, X21(I,I), X21(I+1,I), 1, TAUP2(I) )
-         X21(I,I) = ONE
-         CALL SLARF( 'L', M-P-I+1, Q-I, X21(I,I), 1, TAUP2(I),
-     $               X21(I,I+1), LDX21, WORK(ILARF) )
+         CALL SLARF1F( 'L', M-P-I+1, Q-I, X21(I,I), 1, TAUP2(I),
+     $                 X21(I,I+1), LDX21, WORK(ILARF) )
       END DO
 *
       RETURN
