@@ -350,9 +350,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
-*> \ingroup realOTHERcomputational
+*> \ingroup tgsja
 *
 *> \par Further Details:
 *  =====================
@@ -378,10 +376,9 @@
      $                   LDB, TOLA, TOLB, ALPHA, BETA, U, LDU, V, LDV,
      $                   Q, LDQ, WORK, NCYCLE, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBQ, JOBU, JOBV
@@ -400,7 +397,7 @@
 *     .. Parameters ..
       INTEGER            MAXIT
       PARAMETER          ( MAXIT = 40 )
-      REAL               ZERO, ONE
+      REAL               ZERO, ONE, HUGENUM
       PARAMETER          ( ZERO = 0.0E+0, ONE = 1.0E+0 )
 *     ..
 *     .. Local Scalars ..
@@ -415,11 +412,13 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SCOPY, SLAGS2, SLAPLL, SLARTG, SLASET, SROT,
+      EXTERNAL           SCOPY, SLAGS2, SLAPLL, SLARTG, SLASET,
+     $                   SROT,
      $                   SSCAL, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ABS, MAX, MIN
+      INTRINSIC          ABS, MAX, MIN, HUGE
+      PARAMETER          ( HUGENUM = HUGE(ZERO) )
 *     ..
 *     .. Executable Statements ..
 *
@@ -437,9 +436,13 @@
       INFO = 0
       IF( .NOT.( INITU .OR. WANTU .OR. LSAME( JOBU, 'N' ) ) ) THEN
          INFO = -1
-      ELSE IF( .NOT.( INITV .OR. WANTV .OR. LSAME( JOBV, 'N' ) ) ) THEN
+      ELSE IF( .NOT.( INITV .OR.
+     $         WANTV .OR.
+     $         LSAME( JOBV, 'N' ) ) ) THEN
          INFO = -2
-      ELSE IF( .NOT.( INITQ .OR. WANTQ .OR. LSAME( JOBQ, 'N' ) ) ) THEN
+      ELSE IF( .NOT.( INITQ .OR.
+     $         WANTQ .OR.
+     $         LSAME( JOBQ, 'N' ) ) ) THEN
          INFO = -3
       ELSE IF( M.LT.0 ) THEN
          INFO = -4
@@ -509,7 +512,8 @@
 *              Update (K+I)-th and (K+J)-th rows of matrix A: U**T *A
 *
                IF( K+J.LE.M )
-     $            CALL SROT( L, A( K+J, N-L+1 ), LDA, A( K+I, N-L+1 ),
+     $            CALL SROT( L, A( K+J, N-L+1 ), LDA, A( K+I,
+     $                       N-L+1 ),
      $                       LDA, CSU, SNU )
 *
 *              Update I-th and J-th rows of matrix B: V**T *B
@@ -543,10 +547,12 @@
      $                       SNU )
 *
                IF( WANTV )
-     $            CALL SROT( P, V( 1, J ), 1, V( 1, I ), 1, CSV, SNV )
+     $            CALL SROT( P, V( 1, J ), 1, V( 1, I ), 1, CSV,
+     $                       SNV )
 *
                IF( WANTQ )
-     $            CALL SROT( N, Q( 1, N-L+J ), 1, Q( 1, N-L+I ), 1, CSQ,
+     $            CALL SROT( N, Q( 1, N-L+J ), 1, Q( 1, N-L+I ), 1,
+     $                       CSQ,
      $                       SNQ )
 *
    10       CONTINUE
@@ -563,7 +569,8 @@
             ERROR = ZERO
             DO 30 I = 1, MIN( L, M-K )
                CALL SCOPY( L-I+1, A( K+I, N-L+I ), LDA, WORK, 1 )
-               CALL SCOPY( L-I+1, B( I, N-L+I ), LDB, WORK( L+1 ), 1 )
+               CALL SCOPY( L-I+1, B( I, N-L+I ), LDB, WORK( L+1 ),
+     $                     1 )
                CALL SLAPLL( L-I+1, WORK, 1, WORK( L+1 ), 1, SSMIN )
                ERROR = MAX( ERROR, SSMIN )
    30       CONTINUE
@@ -596,9 +603,9 @@
 *
          A1 = A( K+I, N-L+I )
          B1 = B( I, N-L+I )
+         GAMMA = B1 / A1
 *
-         IF( A1.NE.ZERO ) THEN
-            GAMMA = B1 / A1
+         IF( (GAMMA.LE.HUGENUM).AND.(GAMMA.GE.-HUGENUM) ) THEN
 *
 *           change sign if necessary
 *
@@ -608,16 +615,19 @@
      $            CALL SSCAL( P, -ONE, V( 1, I ), 1 )
             END IF
 *
-            CALL SLARTG( ABS( GAMMA ), ONE, BETA( K+I ), ALPHA( K+I ),
+            CALL SLARTG( ABS( GAMMA ), ONE, BETA( K+I ),
+     $                   ALPHA( K+I ),
      $                   RWK )
 *
             IF( ALPHA( K+I ).GE.BETA( K+I ) ) THEN
-               CALL SSCAL( L-I+1, ONE / ALPHA( K+I ), A( K+I, N-L+I ),
+               CALL SSCAL( L-I+1, ONE / ALPHA( K+I ), A( K+I,
+     $                     N-L+I ),
      $                     LDA )
             ELSE
                CALL SSCAL( L-I+1, ONE / BETA( K+I ), B( I, N-L+I ),
      $                     LDB )
-               CALL SCOPY( L-I+1, B( I, N-L+I ), LDB, A( K+I, N-L+I ),
+               CALL SCOPY( L-I+1, B( I, N-L+I ), LDB, A( K+I,
+     $                     N-L+I ),
      $                     LDA )
             END IF
 *
