@@ -2,18 +2,18 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *> \htmlonly
-*> Download ZBBCSD + dependencies 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zbbcsd.f"> 
-*> [TGZ]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zbbcsd.f"> 
-*> [ZIP]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zbbcsd.f"> 
+*> Download ZBBCSD + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/zbbcsd.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/zbbcsd.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/zbbcsd.f">
 *> [TXT]</a>
-*> \endhtmlonly 
+*> \endhtmlonly
 *
 *  Definition:
 *  ===========
@@ -22,7 +22,7 @@
 *                          THETA, PHI, U1, LDU1, U2, LDU2, V1T, LDV1T,
 *                          V2T, LDV2T, B11D, B11E, B12D, B12E, B21D, B21E,
 *                          B22D, B22E, RWORK, LRWORK, INFO )
-* 
+*
 *       .. Scalar Arguments ..
 *       CHARACTER          JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS
 *       INTEGER            INFO, LDU1, LDU2, LDV1T, LDV2T, LRWORK, M, P, Q
@@ -34,7 +34,7 @@
 *       COMPLEX*16         U1( LDU1, * ), U2( LDU2, * ), V1T( LDV1T, * ),
 *      $                   V2T( LDV2T, * )
 *       ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -149,7 +149,7 @@
 *> \param[in,out] U1
 *> \verbatim
 *>          U1 is COMPLEX*16 array, dimension (LDU1,P)
-*>          On entry, an LDU1-by-P matrix. On exit, U1 is postmultiplied
+*>          On entry, a P-by-P matrix. On exit, U1 is postmultiplied
 *>          by the left singular vector matrix common to [ B11 ; 0 ] and
 *>          [ B12 0 0 ; 0 -I 0 0 ].
 *> \endverbatim
@@ -157,13 +157,13 @@
 *> \param[in] LDU1
 *> \verbatim
 *>          LDU1 is INTEGER
-*>          The leading dimension of the array U1.
+*>          The leading dimension of the array U1, LDU1 >= MAX(1,P).
 *> \endverbatim
 *>
 *> \param[in,out] U2
 *> \verbatim
 *>          U2 is COMPLEX*16 array, dimension (LDU2,M-P)
-*>          On entry, an LDU2-by-(M-P) matrix. On exit, U2 is
+*>          On entry, an (M-P)-by-(M-P) matrix. On exit, U2 is
 *>          postmultiplied by the left singular vector matrix common to
 *>          [ B21 ; 0 ] and [ B22 0 0 ; 0 0 I ].
 *> \endverbatim
@@ -171,13 +171,13 @@
 *> \param[in] LDU2
 *> \verbatim
 *>          LDU2 is INTEGER
-*>          The leading dimension of the array U2.
+*>          The leading dimension of the array U2, LDU2 >= MAX(1,M-P).
 *> \endverbatim
 *>
 *> \param[in,out] V1T
 *> \verbatim
 *>          V1T is COMPLEX*16 array, dimension (LDV1T,Q)
-*>          On entry, a LDV1T-by-Q matrix. On exit, V1T is premultiplied
+*>          On entry, a Q-by-Q matrix. On exit, V1T is premultiplied
 *>          by the conjugate transpose of the right singular vector
 *>          matrix common to [ B11 ; 0 ] and [ B21 ; 0 ].
 *> \endverbatim
@@ -185,13 +185,13 @@
 *> \param[in] LDV1T
 *> \verbatim
 *>          LDV1T is INTEGER
-*>          The leading dimension of the array V1T.
+*>          The leading dimension of the array V1T, LDV1T >= MAX(1,Q).
 *> \endverbatim
 *>
 *> \param[in,out] V2T
 *> \verbatim
-*>          V2T is COMPLEX*16 array, dimenison (LDV2T,M-Q)
-*>          On entry, a LDV2T-by-(M-Q) matrix. On exit, V2T is
+*>          V2T is COMPLEX*16 array, dimension (LDV2T,M-Q)
+*>          On entry, an (M-Q)-by-(M-Q) matrix. On exit, V2T is
 *>          premultiplied by the conjugate transpose of the right
 *>          singular vector matrix common to [ B12 0 0 ; 0 -I 0 ] and
 *>          [ B22 0 0 ; 0 0 I ].
@@ -200,7 +200,7 @@
 *> \param[in] LDV2T
 *> \verbatim
 *>          LDV2T is INTEGER
-*>          The leading dimension of the array V2T.
+*>          The leading dimension of the array V2T, LDV2T >= MAX(1,M-Q).
 *> \endverbatim
 *>
 *> \param[out] B11D
@@ -273,8 +273,8 @@
 *>
 *> \param[out] RWORK
 *> \verbatim
-*>          RWORK is DOUBLE PRECISION array, dimension (MAX(1,LWORK))
-*>          On exit, if INFO = 0, WORK(1) returns the optimal LWORK.
+*>          RWORK is DOUBLE PRECISION array, dimension (MAX(1,LRWORK))
+*>          On exit, if INFO = 0, RWORK(1) returns the optimal LRWORK.
 *> \endverbatim
 *>
 *> \param[in] LRWORK
@@ -317,25 +317,23 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
-*> \date November 2015
-*
-*> \ingroup complex16OTHERcomputational
+*> \ingroup bbcsd
 *
 *  =====================================================================
-      SUBROUTINE ZBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P, Q,
+      SUBROUTINE ZBBCSD( JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS, M, P,
+     $                   Q,
      $                   THETA, PHI, U1, LDU1, U2, LDU2, V1T, LDV1T,
      $                   V2T, LDV2T, B11D, B11E, B12D, B12E, B21D, B21E,
      $                   B22D, B22E, RWORK, LRWORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.6.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBU1, JOBU2, JOBV1T, JOBV2T, TRANS
@@ -354,12 +352,13 @@
 *     .. Parameters ..
       INTEGER            MAXITR
       PARAMETER          ( MAXITR = 6 )
-      DOUBLE PRECISION   HUNDRED, MEIGHTH, ONE, PIOVER2, TEN, ZERO
+      DOUBLE PRECISION   HUNDRED, MEIGHTH, ONE, TEN, ZERO
       PARAMETER          ( HUNDRED = 100.0D0, MEIGHTH = -0.125D0,
-     $                     ONE = 1.0D0, PIOVER2 = 1.57079632679489662D0,
-     $                     TEN = 10.0D0, ZERO = 0.0D0 )
+     $                     ONE = 1.0D0, TEN = 10.0D0, ZERO = 0.0D0 )
       COMPLEX*16         NEGONECOMPLEX
       PARAMETER          ( NEGONECOMPLEX = (-1.0D0,0.0D0) )
+      DOUBLE PRECISION   PIOVER2
+      PARAMETER ( PIOVER2 = 1.57079632679489661923132169163975144210D0 )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            COLMAJOR, LQUERY, RESTART11, RESTART12,
@@ -373,7 +372,8 @@
      $                   TEMP, THETAMAX, THETAMIN, THRESH, TOL, TOLMUL,
      $                   UNFL, X1, X2, Y1, Y2
 *
-      EXTERNAL           DLARTGP, DLARTGS, DLAS2, XERBLA, ZLASR, ZSCAL,
+      EXTERNAL           DLARTGP, DLARTGS, DLAS2, XERBLA, ZLASR,
+     $                   ZSCAL,
      $                   ZSWAP
 *     ..
 *     .. External Functions ..
@@ -560,9 +560,11 @@
 *
 *           Compute shifts for B11 and B21 and use the lesser
 *
-            CALL DLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX), SIGMA11,
+            CALL DLAS2( B11D(IMAX-1), B11E(IMAX-1), B11D(IMAX),
+     $                  SIGMA11,
      $                  DUMMY )
-            CALL DLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX), SIGMA21,
+            CALL DLAS2( B21D(IMAX-1), B21E(IMAX-1), B21D(IMAX),
+     $                  SIGMA21,
      $                  DUMMY )
 *
             IF( SIGMA11 .LE. SIGMA21 ) THEN
@@ -719,10 +721,12 @@
                CALL DLARTGP( Y2, Y1, RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( .NOT. RESTART12 .AND. RESTART22 ) THEN
-               CALL DLARTGP( B12BULGE, B12D(I-1), RWORK(IV2TSN+I-1-1),
+               CALL DLARTGP( B12BULGE, B12D(I-1),
+     $                       RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( RESTART12 .AND. .NOT. RESTART22 ) THEN
-               CALL DLARTGP( B22BULGE, B22D(I-1), RWORK(IV2TSN+I-1-1),
+               CALL DLARTGP( B22BULGE, B22D(I-1),
+     $                       RWORK(IV2TSN+I-1-1),
      $                       RWORK(IV2TCS+I-1-1), R )
             ELSE IF( NU .LT. MU ) THEN
                CALL DLARTGS( B12E(I-1), B12D(I), NU,
@@ -781,7 +785,8 @@
 *           chasing by applying the original shift again.
 *
             IF( .NOT. RESTART11 .AND. .NOT. RESTART12 ) THEN
-               CALL DLARTGP( X2, X1, RWORK(IU1SN+I-1), RWORK(IU1CS+I-1),
+               CALL DLARTGP( X2, X1, RWORK(IU1SN+I-1),
+     $                       RWORK(IU1CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART11 .AND. RESTART12 ) THEN
                CALL DLARTGP( B11BULGE, B11D(I), RWORK(IU1SN+I-1),
@@ -790,14 +795,16 @@
                CALL DLARTGP( B12BULGE, B12E(I-1), RWORK(IU1SN+I-1),
      $                       RWORK(IU1CS+I-1), R )
             ELSE IF( MU .LE. NU ) THEN
-               CALL DLARTGS( B11E(I), B11D(I+1), MU, RWORK(IU1CS+I-1),
+               CALL DLARTGS( B11E(I), B11D(I+1), MU,
+     $                       RWORK(IU1CS+I-1),
      $                       RWORK(IU1SN+I-1) )
             ELSE
                CALL DLARTGS( B12D(I), B12E(I), NU, RWORK(IU1CS+I-1),
      $                       RWORK(IU1SN+I-1) )
             END IF
             IF( .NOT. RESTART21 .AND. .NOT. RESTART22 ) THEN
-               CALL DLARTGP( Y2, Y1, RWORK(IU2SN+I-1), RWORK(IU2CS+I-1),
+               CALL DLARTGP( Y2, Y1, RWORK(IU2SN+I-1),
+     $                       RWORK(IU2CS+I-1),
      $                       R )
             ELSE IF( .NOT. RESTART21 .AND. RESTART22 ) THEN
                CALL DLARTGP( B21BULGE, B21D(I), RWORK(IU2SN+I-1),
@@ -806,7 +813,8 @@
                CALL DLARTGP( B22BULGE, B22E(I-1), RWORK(IU2SN+I-1),
      $                       RWORK(IU2CS+I-1), R )
             ELSE IF( NU .LT. MU ) THEN
-               CALL DLARTGS( B21E(I), B21E(I+1), NU, RWORK(IU2CS+I-1),
+               CALL DLARTGS( B21E(I), B21E(I+1), NU,
+     $                       RWORK(IU2CS+I-1),
      $                       RWORK(IU2SN+I-1) )
             ELSE
                CALL DLARTGS( B22D(I), B22E(I), MU, RWORK(IU2CS+I-1),
@@ -992,7 +1000,8 @@
          IF( B12D(IMAX)+B22D(IMAX) .LT. 0 ) THEN
             IF( WANTV2T ) THEN
                IF( COLMAJOR ) THEN
-                  CALL ZSCAL( M-Q, NEGONECOMPLEX, V2T(IMAX,1), LDV2T )
+                  CALL ZSCAL( M-Q, NEGONECOMPLEX, V2T(IMAX,1),
+     $                        LDV2T )
                ELSE
                   CALL ZSCAL( M-Q, NEGONECOMPLEX, V2T(1,IMAX), 1 )
                END IF
@@ -1059,7 +1068,8 @@
                IF( WANTU2 )
      $            CALL ZSWAP( M-P, U2(1,I), 1, U2(1,MINI), 1 )
                IF( WANTV1T )
-     $            CALL ZSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1), LDV1T )
+     $            CALL ZSWAP( Q, V1T(I,1), LDV1T, V1T(MINI,1),
+     $                        LDV1T )
                IF( WANTV2T )
      $            CALL ZSWAP( M-Q, V2T(I,1), LDV2T, V2T(MINI,1),
      $               LDV2T )
