@@ -130,10 +130,11 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complex16GBcomputational
+*> \ingroup gbtrs
 *
 *  =====================================================================
-      SUBROUTINE ZGBTRS( TRANS, N, KL, KU, NRHS, AB, LDAB, IPIV, B, LDB,
+      SUBROUTINE ZGBTRS( TRANS, N, KL, KU, NRHS, AB, LDAB, IPIV, B,
+     $                   LDB,
      $                   INFO )
 *
 *  -- LAPACK computational routine --
@@ -164,7 +165,8 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           XERBLA, ZGEMV, ZGERU, ZLACGV, ZSWAP, ZTBSV
+      EXTERNAL           XERBLA, ZGEMV, ZGERU, ZLACGV, ZSWAP,
+     $                   ZTBSV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          MAX, MIN
@@ -221,7 +223,8 @@
                L = IPIV( J )
                IF( L.NE.J )
      $            CALL ZSWAP( NRHS, B( L, 1 ), LDB, B( J, 1 ), LDB )
-               CALL ZGERU( LM, NRHS, -ONE, AB( KD+1, J ), 1, B( J, 1 ),
+               CALL ZGERU( LM, NRHS, -ONE, AB( KD+1, J ), 1, B( J,
+     $                     1 ),
      $                     LDB, B( J+1, 1 ), LDB )
    10       CONTINUE
          END IF
@@ -230,7 +233,8 @@
 *
 *           Solve U*X = B, overwriting B with X.
 *
-            CALL ZTBSV( 'Upper', 'No transpose', 'Non-unit', N, KL+KU,
+            CALL ZTBSV( 'Upper', 'No transpose', 'Non-unit', N,
+     $                  KL+KU,
      $                  AB, LDAB, B( 1, I ), 1 )
    20    CONTINUE
 *
@@ -242,7 +246,8 @@
 *
 *           Solve U**T * X = B, overwriting B with X.
 *
-            CALL ZTBSV( 'Upper', 'Transpose', 'Non-unit', N, KL+KU, AB,
+            CALL ZTBSV( 'Upper', 'Transpose', 'Non-unit', N, KL+KU,
+     $                  AB,
      $                  LDAB, B( 1, I ), 1 )
    30    CONTINUE
 *
@@ -267,7 +272,8 @@
 *
 *           Solve U**H * X = B, overwriting B with X.
 *
-            CALL ZTBSV( 'Upper', 'Conjugate transpose', 'Non-unit', N,
+            CALL ZTBSV( 'Upper', 'Conjugate transpose', 'Non-unit',
+     $                  N,
      $                  KL+KU, AB, LDAB, B( 1, I ), 1 )
    50    CONTINUE
 *
