@@ -11,10 +11,10 @@
 !                         W, LDW,  S, LDS, ZWORK,  LZWORK,   &
 !                         RWORK, LRWORK, IWORK, LIWORK, INFO )
 !......
-!      USE                   iso_fortran_env
+!      USE, INTRINSIC :: iso_fortran_env, only: real64
 !      IMPLICIT NONE
 !      INTEGER, PARAMETER :: WP = real64
-! 
+!
 !......
 !      Scalar arguments
 !      CHARACTER, INTENT(IN)   :: JOBS,   JOBZ,  JOBR,  JOBF
@@ -199,7 +199,7 @@
 !>    (the number of columns of X and Y).
 !>    \endverbatim
 !.....
-!>    \param[in] LDX
+!>    \param[in,out] X
 !>    \verbatim
 !>    X (input/output) COMPLEX(KIND=WP) M-by-N array
 !>    > On entry, X contains the data snapshot matrix X. It is
@@ -210,7 +210,10 @@
 !>    data matrix X, U(:,1:K). All N columns of X contain all
 !>    left singular vectors of the input matrix X.
 !>    See the descriptions of K, Z and W.
+!>    \endverbatim
 !.....
+!>    \param[in] LDX
+!>    \verbatim
 !>    LDX (input) INTEGER, LDX >= M
 !>    The leading dimension of the array X.
 !>    \endverbatim
@@ -503,7 +506,7 @@
 !  -- Colorado Denver and NAG Ltd..                                   --
 !
 !.....
-      USE                   iso_fortran_env
+      USE, INTRINSIC :: iso_fortran_env, only: real64
       IMPLICIT NONE
       INTEGER, PARAMETER :: WP = real64
 !
@@ -758,7 +761,8 @@
           K = 0
           DO i = 1, N
             !WORK(i) = DZNRM2( M, X(1,i), 1 )
-            SCALE  = ZERO
+            SSUM  = ONE
+            SCALE = ZERO
             CALL ZLASSQ( M, X(1,i), 1, SCALE, SSUM )
             IF ( DISNAN(SCALE) .OR. DISNAN(SSUM) ) THEN
                 K    =  0
@@ -831,7 +835,8 @@
           ! carefully computed using ZLASSQ.
           DO i = 1, N
             !RWORK(i) = DZNRM2( M, Y(1,i), 1 )
-            SCALE  = ZERO
+            SSUM  = ONE
+            SCALE = ZERO
             CALL ZLASSQ( M, Y(1,i), 1, SCALE, SSUM )
             IF ( DISNAN(SCALE) .OR. DISNAN(SSUM) ) THEN
                 K    =  0
@@ -1143,4 +1148,3 @@
       RETURN
 !     ......
       END SUBROUTINE ZGEDMD
-
