@@ -8,23 +8,23 @@
 !     SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
 !                         WHTSVD,   M, N, F, LDF,  X, LDX,  Y,   &
 !                         LDY,   NRNK,  TOL,   K,  EIGS,         &
-!                         Z, LDZ, RES,  B,     LDB,   V, LDV,    & 
+!                         Z, LDZ, RES,  B,     LDB,   V, LDV,    &
 !                         S, LDS, ZWORK, LZWORK, WORK,  LWORK,   &
 !                         IWORK, LIWORK, INFO )
 !.....
-!     USE                   iso_fortran_env
+!     USE, INTRINSIC :: iso_fortran_env, only: real64
 !     IMPLICIT NONE
 !     INTEGER, PARAMETER :: WP = real64
-!.....      
-!     Scalar arguments       
+!.....
+!     Scalar arguments
 !     CHARACTER, INTENT(IN)  :: JOBS, JOBZ, JOBR, JOBQ,    &
 !                               JOBT, JOBF
 !     INTEGER,   INTENT(IN)  :: WHTSVD, M, N,   LDF, LDX,  &
 !                               LDY, NRNK, LDZ, LDB, LDV,  &
 !                               LDS, LZWORK,  LWORK, LIWORK
-!     INTEGER,   INTENT(OUT) :: INFO,   K      
-!     REAL(KIND=WP), INTENT(IN)    ::   TOL     
-!     Array arguments      
+!     INTEGER,   INTENT(OUT) :: INFO,   K
+!     REAL(KIND=WP), INTENT(IN)    ::   TOL
+!     Array arguments
 !     COMPLEX(KIND=WP), INTENT(INOUT) :: F(LDF,*)
 !     COMPLEX(KIND=WP), INTENT(OUT)   :: X(LDX,*), Y(LDY,*), &
 !                                        Z(LDZ,*), B(LDB,*), &
@@ -32,7 +32,7 @@
 !     COMPLEX(KIND=WP), INTENT(OUT)   :: EIGS(*)
 !     COMPLEX(KIND=WP), INTENT(OUT)   :: ZWORK(*)
 !     REAL(KIND=WP), INTENT(OUT)   :: RES(*)
-!     REAL(KIND=WP), INTENT(OUT)   :: WORK(*)  
+!     REAL(KIND=WP), INTENT(OUT)   :: WORK(*)
 !     INTEGER,       INTENT(OUT)   :: IWORK(*)
 !............................................................
 !>    \par Purpose:
@@ -44,13 +44,13 @@
 !>    X and Y such that Y = A*X with an unaccessible matrix
 !>    A, ZGEDMDQ computes a certain number of Ritz pairs of A using
 !>    the standard Rayleigh-Ritz extraction from a subspace of
-!>    range(X) that is determined using the leading left singular 
-!>    vectors of X. Optionally, ZGEDMDQ returns the residuals 
+!>    range(X) that is determined using the leading left singular
+!>    vectors of X. Optionally, ZGEDMDQ returns the residuals
 !>    of the computed Ritz pairs, the information needed for
 !>    a refinement of the Ritz vectors, or the eigenvectors of
 !>    the Exact DMD.
 !>    For further details see the references listed
-!>    below. For more details of the implementation see [3].      
+!>    below. For more details of the implementation see [3].
 !>    \endverbatim
 !............................................................
 !>    \par References:
@@ -64,8 +64,8 @@
 !>        SIAM J. on Sci. Comp. 40 (4), A2253-A2285, 2018.
 !>    [3] Z. Drmac: A LAPACK implementation of the Dynamic
 !>        Mode Decomposition I. Technical report. AIMDyn Inc.
-!>        and LAPACK Working Note 298.      
-!>    [4] J. Tu, C. W. Rowley, D. M. Luchtenburg, S. L. 
+!>        and LAPACK Working Note 298.
+!>    [4] J. Tu, C. W. Rowley, D. M. Luchtenburg, S. L.
 !>        Brunton, N. Kutz: On Dynamic Mode Decomposition:
 !>        Theory and Applications, Journal of Computational
 !>        Dynamics 1(2), 391 -421, 2014.
@@ -87,20 +87,20 @@
 !>    - DARPA MoDyL project "A Data-Driven, Operator-Theoretic
 !>    Framework for Space-Time Analysis of Process Dynamics"
 !>    Contract No: HR0011-16-C-0116
-!>    Any opinions, findings and conclusions or recommendations 
-!>    expressed in this material are those of the author and 
-!>    do not necessarily reflect the views of the DARPA SBIR 
-!>    Program Office.      
+!>    Any opinions, findings and conclusions or recommendations
+!>    expressed in this material are those of the author and
+!>    do not necessarily reflect the views of the DARPA SBIR
+!>    Program Office.
 !>    \endverbatim
 !......................................................................
 !>    \par Developed and supported by:
 !     ================================
 !>    \verbatim
-!>    Distribution Statement A: 
+!>    Distribution Statement A:
 !>    Approved for Public Release, Distribution Unlimited.
 !>    Cleared by DARPA on September 29, 2022
 !>    \endverbatim
-!============================================================      
+!============================================================
 !     Arguments
 !     =========
 !
@@ -110,7 +110,7 @@
 !>    Determines whether the initial data snapshots are scaled
 !>    by a diagonal matrix. The data snapshots are the columns
 !>    of F. The leading N-1 columns of F are denoted X and the
-!>    trailing N-1 columns are denoted Y. 
+!>    trailing N-1 columns are denoted Y.
 !>    'S' :: The data snapshots matrices X and Y are multiplied
 !>           with a diagonal matrix D so that X*D has unit
 !>           nonzero columns (in the Euclidean 2-norm)
@@ -121,8 +121,8 @@
 !>           zero and a warning flag is raised.
 !>    'Y' :: The data snapshots matrices X and Y are multiplied
 !>           by a diagonal matrix D so that Y*D has unit
-!>           nonzero columns (in the Euclidean 2-norm)    
-!>    'N' :: No data scaling.   
+!>           nonzero columns (in the Euclidean 2-norm)
+!>    'N' :: No data scaling.
 !>    \endverbatim
 !.....
 !>    \param[in] JOBZ
@@ -143,13 +143,13 @@
 !>           contains the eigenvectors of the compression of the
 !>           underlying discretized operator onto the span of
 !>           the data snapshots. See the descriptions of F, V, Z.
-!>           Q is from the initial QR factorization.  
-!>    'N' :: The eigenvectors are not computed.  
+!>           Q is from the initial QR factorization.
+!>    'N' :: The eigenvectors are not computed.
 !>    \endverbatim
 !.....
 !>    \param[in] JOBR
-!>    \verbatim    
-!>    JOBR (input) CHARACTER*1 
+!>    \verbatim
+!>    JOBR (input) CHARACTER*1
 !>    Determines whether to compute the residuals.
 !>    'R' :: The residuals for the computed eigenpairs will
 !>           be computed and stored in the array RES.
@@ -160,24 +160,24 @@
 !.....
 !>    \param[in] JOBQ
 !>    \verbatim
-!>    JOBQ (input) CHARACTER*1 
+!>    JOBQ (input) CHARACTER*1
 !>    Specifies whether to explicitly compute and return the
 !>    unitary matrix from the QR factorization.
 !>    'Q' :: The matrix Q of the QR factorization of the data
 !>           snapshot matrix is computed and stored in the
-!>           array F. See the description of F.       
+!>           array F. See the description of F.
 !>    'N' :: The matrix Q is not explicitly computed.
 !>    \endverbatim
 !.....
 !>    \param[in] JOBT
 !>    \verbatim
-!>    JOBT (input) CHARACTER*1 
+!>    JOBT (input) CHARACTER*1
 !>    Specifies whether to return the upper triangular factor
 !>    from the QR factorization.
-!>    'R' :: The matrix R of the QR factorization of the data 
+!>    'R' :: The matrix R of the QR factorization of the data
 !>           snapshot matrix F is returned in the array Y.
-!>           See the description of Y and Further details.       
-!>    'N' :: The matrix R is not returned. 
+!>           See the description of Y and Further details.
+!>    'N' :: The matrix R is not returned.
 !>    \endverbatim
 !.....
 !>    \param[in] JOBF
@@ -188,14 +188,15 @@
 !>    'R' :: The matrix needed for the refinement of the Ritz
 !>           vectors is computed and stored in the array B.
 !>           See the description of B.
-!>    'E' :: The unscaled eigenvectors of the Exact DMD are 
+!>    'E' :: The unscaled eigenvectors of the Exact DMD are
 !>           computed and returned in the array B. See the
 !>           description of B.
-!>    'N' :: No eigenvector refinement data is computed.   
-!>    To be useful on exit, this option needs JOBQ='Q'.    
+!>    'N' :: No eigenvector refinement data is computed.
+!>    To be useful on exit, this option needs JOBQ='Q'.
 !>    \endverbatim
 !.....
 !>    \param[in] WHTSVD
+!>    \verbatim
 !>    WHTSVD (input) INTEGER, WHSTVD in { 1, 2, 3, 4 }
 !>    Allows for a selection of the SVD algorithm from the
 !>    LAPACK library.
@@ -212,7 +213,7 @@
 !>    ill-conditioned. If small (smaller than EPS*||X||)
 !>    singular values are of interest and JOBS=='N',  then
 !>    the options (3, 4) give the most accurate results, where
-!>    the option 4 is slightly better and with stronger 
+!>    the option 4 is slightly better and with stronger
 !>    theoretical background.
 !>    If JOBS=='S', i.e. the columns of X will be normalized,
 !>    then all methods give nearly equally accurate results.
@@ -220,15 +221,15 @@
 !.....
 !>    \param[in] M
 !>    \verbatim
-!>    M (input) INTEGER, M >= 0 
+!>    M (input) INTEGER, M >= 0
 !>    The state space dimension (the number of rows of F).
 !>    \endverbatim
 !.....
 !>    \param[in] N
-!>    \verbatim     
+!>    \verbatim
 !>    N (input) INTEGER, 0 <= N <= M
 !>    The number of data snapshots from a single trajectory,
-!>    taken at equidistant discrete times. This is the 
+!>    taken at equidistant discrete times. This is the
 !>    number of columns of F.
 !>    \endverbatim
 !.....
@@ -236,25 +237,25 @@
 !>    \verbatim
 !>    F (input/output) COMPLEX(KIND=WP) M-by-N array
 !>    > On entry,
-!>    the columns of F are the sequence of data snapshots 
+!>    the columns of F are the sequence of data snapshots
 !>    from a single trajectory, taken at equidistant discrete
-!>    times. It is assumed that the column norms of F are 
-!>    in the range of the normalized floating point numbers. 
+!>    times. It is assumed that the column norms of F are
+!>    in the range of the normalized floating point numbers.
 !>    < On exit,
-!>    If JOBQ == 'Q', the array F contains the orthogonal 
-!>    matrix/factor of the QR factorization of the initial 
-!>    data snapshots matrix F. See the description of JOBQ. 
+!>    If JOBQ == 'Q', the array F contains the orthogonal
+!>    matrix/factor of the QR factorization of the initial
+!>    data snapshots matrix F. See the description of JOBQ.
 !>    If JOBQ == 'N', the entries in F strictly below the main
-!>    diagonal contain, column-wise, the information on the 
-!>    Householder vectors, as returned by ZGEQRF. The 
+!>    diagonal contain, column-wise, the information on the
+!>    Householder vectors, as returned by ZGEQRF. The
 !>    remaining information to restore the orthogonal matrix
-!>    of the initial QR factorization is stored in ZWORK(1:MIN(M,N)). 
+!>    of the initial QR factorization is stored in ZWORK(1:MIN(M,N)).
 !>    See the description of ZWORK.
 !>    \endverbatim
 !.....
 !>    \param[in] LDF
 !>    \verbatim
-!>    LDF (input) INTEGER, LDF >= M 
+!>    LDF (input) INTEGER, LDF >= M
 !>    The leading dimension of the array F.
 !>    \endverbatim
 !.....
@@ -267,33 +268,33 @@
 !>    On exit, the leading K columns of X contain the leading
 !>    K left singular vectors of the above described content
 !>    of X. To lift them to the space of the left singular
-!>    vectors U(:,1:K) of the input data, pre-multiply with the 
-!>    Q factor from the initial QR factorization. 
+!>    vectors U(:,1:K) of the input data, pre-multiply with the
+!>    Q factor from the initial QR factorization.
 !>    See the descriptions of F, K, V  and Z.
 !>    \endverbatim
 !.....
 !>    \param[in] LDX
-!>    \verbatim      
-!>    LDX (input) INTEGER, LDX >= N  
-!>    The leading dimension of the array X. 
+!>    \verbatim
+!>    LDX (input) INTEGER, LDX >= N
+!>    The leading dimension of the array X.
 !>    \endverbatim
 !.....
 !>    \param[in,out] Y
-!>    \verbatim      
+!>    \verbatim
 !>    Y (workspace/output) COMPLEX(KIND=WP) MIN(M,N)-by-(N) array
 !>    Y is used as workspace to hold representations of the
 !>    trailing N-1 snapshots in the orthonormal basis computed
 !>    in the QR factorization of F.
-!>    On exit, 
+!>    On exit,
 !>    If JOBT == 'R', Y contains the MIN(M,N)-by-N upper
 !>    triangular factor from the QR factorization of the data
 !>    snapshot matrix F.
 !>    \endverbatim
 !.....
 !>    \param[in] LDY
-!>    \verbatim      
+!>    \verbatim
 !>    LDY (input) INTEGER , LDY >= N
-!>    The leading dimension of the array Y.   
+!>    The leading dimension of the array Y.
 !>    \endverbatim
 !.....
 !>    \param[in] NRNK
@@ -304,14 +305,14 @@
 !>    matrix X. On input, if
 !>    NRNK = -1 :: i-th singular value sigma(i) is truncated
 !>                 if sigma(i) <= TOL*sigma(1)
-!>                 This option is recommended.  
+!>                 This option is recommended.
 !>    NRNK = -2 :: i-th singular value sigma(i) is truncated
 !>                 if sigma(i) <= TOL*sigma(i-1)
 !>                 This option is included for R&D purposes.
 !>                 It requires highly accurate SVD, which
-!>                 may not be feasible.      
-!>    The numerical rank can be enforced by using positive 
-!>    value of NRNK as follows: 
+!>                 may not be feasible.
+!>    The numerical rank can be enforced by using positive
+!>    value of NRNK as follows:
 !>    0 < NRNK <= N-1 :: at most NRNK largest singular values
 !>    will be used. If the number of the computed nonzero
 !>    singular values is less than NRNK, then only those
@@ -325,17 +326,17 @@
 !>    \verbatim
 !>    TOL (input) REAL(KIND=WP), 0 <= TOL < 1
 !>    The tolerance for truncating small singular values.
-!>    See the description of NRNK.  
+!>    See the description of NRNK.
 !>    \endverbatim
 !.....
 !>    \param[out] K
 !>    \verbatim
-!>    K (output) INTEGER,  0 <= K <= N 
+!>    K (output) INTEGER,  0 <= K <= N
 !>    The dimension of the SVD/POD basis for the leading N-1
-!>    data snapshots (columns of F) and the number of the 
+!>    data snapshots (columns of F) and the number of the
 !>    computed Ritz pairs. The value of K is determined
-!>    according to the rule set by the parameters NRNK and 
-!>    TOL. See the descriptions of NRNK and TOL. 
+!>    according to the rule set by the parameters NRNK and
+!>    TOL. See the descriptions of NRNK and TOL.
 !>    \endverbatim
 !.....
 !>    \param[out] EIGS
@@ -354,13 +355,13 @@
 !>    If JOBZ == 'F', then the Z(:,i)'s are given implicitly as
 !>    Z*V, where Z contains orthonormal matrix (the product of
 !>    Q from the initial QR factorization and the SVD/POD_basis
-!>    returned by ZGEDMD in X) and the second factor (the 
-!>    eigenvectors of the Rayleigh quotient) is in the array V, 
+!>    returned by ZGEDMD in X) and the second factor (the
+!>    eigenvectors of the Rayleigh quotient) is in the array V,
 !>    as returned by ZGEDMD. That is,  X(:,1:K)*V(:,i)
-!>    is an eigenvector corresponding to EIGS(i). The columns 
-!>    of V(1:K,1:K) are the computed eigenvectors of the 
-!>    K-by-K Rayleigh quotient.  
-!>    See the descriptions of EIGS, X and V.      
+!>    is an eigenvector corresponding to EIGS(i). The columns
+!>    of V(1:K,1:K) are the computed eigenvectors of the
+!>    K-by-K Rayleigh quotient.
+!>    See the descriptions of EIGS, X and V.
 !>    \endverbatim
 !.....
 !>    \param[in] LDZ
@@ -372,25 +373,25 @@
 !>    \param[out] RES
 !>    \verbatim
 !>    RES (output) REAL(KIND=WP) (N-1)-by-1 array
-!>    RES(1:K) contains the residuals for the K computed 
-!>    Ritz pairs, 
+!>    RES(1:K) contains the residuals for the K computed
+!>    Ritz pairs,
 !>    RES(i) = || A * Z(:,i) - EIGS(i)*Z(:,i))||_2.
-!>    See the description of EIGS and Z.      
+!>    See the description of EIGS and Z.
 !>    \endverbatim
 !.....
 !>    \param[out] B
 !>    \verbatim
 !>    B (output) COMPLEX(KIND=WP)  MIN(M,N)-by-(N-1) array.
 !>    IF JOBF =='R', B(1:N,1:K) contains A*U(:,1:K), and can
-!>    be used for computing the refined vectors; see further 
-!>    details in the provided references. 
-!>    If JOBF == 'E', B(1:N,1;K) contains 
+!>    be used for computing the refined vectors; see further
+!>    details in the provided references.
+!>    If JOBF == 'E', B(1:N,1;K) contains
 !>    A*U(:,1:K)*W(1:K,1:K), which are the vectors from the
-!>    Exact DMD, up to scaling by the inverse eigenvalues.   
-!>    In both cases, the content of B can be lifted to the 
+!>    Exact DMD, up to scaling by the inverse eigenvalues.
+!>    In both cases, the content of B can be lifted to the
 !>    original dimension of the input data by pre-multiplying
-!>    with the Q factor from the initial QR factorization.   
-!>    Here A denotes a compression of the underlying operator.      
+!>    with the Q factor from the initial QR factorization.
+!>    Here A denotes a compression of the underlying operator.
 !>    See the descriptions of F and X.
 !>    If JOBF =='N', then B is not referenced.
 !>    \endverbatim
@@ -407,7 +408,7 @@
 !>    On exit, V(1:K,1:K) V contains the K eigenvectors of
 !>    the Rayleigh quotient. The Ritz vectors
 !>    (returned in Z) are the product of Q from the initial QR
-!>    factorization (see the description of F) X (see the 
+!>    factorization (see the description of F) X (see the
 !>    description of X) and V.
 !>    \endverbatim
 !.....
@@ -428,22 +429,22 @@
 !.....
 !>    \param[in] LDS
 !>    \verbatim
-!>    LDS (input) INTEGER, LDS >= N-1        
+!>    LDS (input) INTEGER, LDS >= N-1
 !>    The leading dimension of the array S.
 !>    \endverbatim
 !.....
-!>    \param[out] LZWORK
+!>    \param[out] ZWORK
 !>    \verbatim
 !>    ZWORK (workspace/output) COMPLEX(KIND=WP) LWORK-by-1 array
-!>    On exit, 
-!>    ZWORK(1:MIN(M,N)) contains the scalar factors of the 
-!>    elementary reflectors as returned by ZGEQRF of the 
-!>    M-by-N input matrix F.   
+!>    On exit,
+!>    ZWORK(1:MIN(M,N)) contains the scalar factors of the
+!>    elementary reflectors as returned by ZGEQRF of the
+!>    M-by-N input matrix F.
 !>    If the call to ZGEDMDQ is only workspace query, then
 !>    ZWORK(1) contains the minimal complex workspace length and
-!>    ZWORK(2) is the optimal complex workspace length. 
+!>    ZWORK(2) is the optimal complex workspace length.
 !>    Hence, the length of work is at least 2.
-!>    See the description of LZWORK.      
+!>    See the description of LZWORK.
 !>    \endverbatim
 !.....
 !>    \param[in] LZWORK
@@ -454,24 +455,24 @@
 !>    Let MLWQR  = N (minimal workspace for ZGEQRF[M,N])
 !>        MLWDMD = minimal workspace for ZGEDMD (see the
 !>                 description of LWORK in ZGEDMD)
-!>        MLWMQR = N (minimal workspace for 
+!>        MLWMQR = N (minimal workspace for
 !>                   ZUNMQR['L','N',M,N,N])
 !>        MLWGQR = N (minimal workspace for ZUNGQR[M,N,N])
-!>        MINMN  = MIN(M,N)      
+!>        MINMN  = MIN(M,N)
 !>    Then
 !>    LZWORK = MAX(2, MIN(M,N)+MLWQR, MINMN+MLWDMD)
 !>    is further updated as follows:
-!>       if   JOBZ == 'V' or JOBZ == 'F' THEN 
+!>       if   JOBZ == 'V' or JOBZ == 'F' THEN
 !>            LZWORK = MAX(LZWORK, MINMN+MLWMQR)
 !>       if   JOBQ == 'Q' THEN
-!>            LZWORK = MAX(ZLWORK, MINMN+MLWGQR)      
+!>            LZWORK = MAX(ZLWORK, MINMN+MLWGQR)
 !>    \endverbatim
 !.....
 !>    \param[out] WORK
 !>    \verbatim
 !>    WORK (workspace/output) REAL(KIND=WP) LWORK-by-1 array
 !>    On exit,
-!>    WORK(1:N-1) contains the singular values of 
+!>    WORK(1:N-1) contains the singular values of
 !>    the input submatrix F(1:M,1:N-1).
 !>    If the call to ZGEDMDQ is only workspace query, then
 !>    WORK(1) contains the minimal workspace length and
@@ -486,10 +487,10 @@
 !>    The minimal length of the  workspace vector WORK.
 !>    LWORK is the same as in ZGEDMD, because in ZGEDMDQ
 !>    only ZGEDMD requires real workspace for snapshots
-!>    of dimensions MIN(M,N)-by-(N-1). 
+!>    of dimensions MIN(M,N)-by-(N-1).
 !>    If on entry LWORK = -1, then a workspace query is
 !>    assumed and the procedure only computes the minimal
-!>    and the optimal workspace length for WORK.          
+!>    and the optimal workspace length for WORK.
 !>    \endverbatim
 !.....
 !>    \param[out] IWORK
@@ -535,7 +536,7 @@
 !>              X(:,i) = 0 but Y(:,i) /= 0, then Y(:,i) is set
 !>              to zero if JOBS=='C'. The computation proceeds
 !>              with original or modified data and warning
-!>              flag is set with INFO=4.  
+!>              flag is set with INFO=4.
 !>    \endverbatim
 !
 !  Authors:
@@ -550,7 +551,7 @@
 SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
                     WHTSVD,   M, N, F, LDF,  X, LDX,  Y,   &
                     LDY,   NRNK,  TOL,   K,  EIGS,         &
-                    Z, LDZ, RES,  B,     LDB,   V, LDV,    & 
+                    Z, LDZ, RES,  B,     LDB,   V, LDV,    &
                     S, LDS, ZWORK, LZWORK, WORK,  LWORK,   &
                     IWORK, LIWORK, INFO )
 !
@@ -561,21 +562,21 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
 !  -- Colorado Denver and NAG Ltd..                                   --
 !
 !.....
-      USE                   iso_fortran_env
+      USE, INTRINSIC :: iso_fortran_env, only: real64
       IMPLICIT NONE
       INTEGER, PARAMETER :: WP = real64
 !
-!     Scalar arguments       
+!     Scalar arguments
 !     ~~~~~~~~~~~~~~~~
       CHARACTER, INTENT(IN)  :: JOBS, JOBZ, JOBR, JOBQ,    &
                                 JOBT, JOBF
       INTEGER,   INTENT(IN)  :: WHTSVD, M, N,   LDF, LDX,  &
                                 LDY, NRNK, LDZ, LDB, LDV,  &
                                 LDS, LZWORK,  LWORK, LIWORK
-      INTEGER,   INTENT(OUT) :: INFO,   K      
-      REAL(KIND=WP), INTENT(IN)    ::   TOL     
+      INTEGER,   INTENT(OUT) :: INFO,   K
+      REAL(KIND=WP), INTENT(IN)    ::   TOL
 !
-!     Array arguments      
+!     Array arguments
 !     ~~~~~~~~~~~~~~~
       COMPLEX(KIND=WP), INTENT(INOUT) :: F(LDF,*)
       COMPLEX(KIND=WP), INTENT(OUT)   :: X(LDX,*), Y(LDY,*), &
@@ -584,73 +585,73 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
       COMPLEX(KIND=WP), INTENT(OUT)   :: EIGS(*)
       COMPLEX(KIND=WP), INTENT(OUT)   :: ZWORK(*)
       REAL(KIND=WP), INTENT(OUT)   :: RES(*)
-      REAL(KIND=WP), INTENT(OUT)   :: WORK(*)  
+      REAL(KIND=WP), INTENT(OUT)   :: WORK(*)
       INTEGER,       INTENT(OUT)   :: IWORK(*)
 !
 !     Parameters
-!     ~~~~~~~~~~      
+!     ~~~~~~~~~~
       REAL(KIND=WP), PARAMETER ::  ONE = 1.0_WP
       REAL(KIND=WP), PARAMETER :: ZERO = 0.0_WP
 !     COMPLEX(KIND=WP), PARAMETER ::  ZONE = ( 1.0_WP, 0.0_WP )
       COMPLEX(KIND=WP), PARAMETER :: ZZERO = ( 0.0_WP, 0.0_WP )
-!      
-!     Local scalars      
+!
+!     Local scalars
 !     ~~~~~~~~~~~~~
       INTEGER           :: IMINWR, INFO1,  MINMN, MLRWRK,   &
-                           MLWDMD, MLWGQR, MLWMQR, MLWORK,  & 
+                           MLWDMD, MLWGQR, MLWMQR, MLWORK,  &
                            MLWQR,  OLWDMD, OLWGQR, OLWMQR,  &
                            OLWORK, OLWQR
       LOGICAL           :: LQUERY, SCCOLX, SCCOLY, WANTQ,  &
                            WNTTRF, WNTRES, WNTVEC, WNTVCF, &
                            WNTVCQ, WNTREF, WNTEX
       CHARACTER(LEN=1)  :: JOBVL
-!      
+!
 !     External functions (BLAS and LAPACK)
 !     ~~~~~~~~~~~~~~~~~
       LOGICAL       LSAME
-      EXTERNAL      LSAME 
+      EXTERNAL      LSAME
 !
 !     External subroutines (BLAS and LAPACK)
 !     ~~~~~~~~~~~~~~~~~~~~
-      EXTERNAL      ZGEDMD, ZGEQRF, ZLACPY, ZLASET, ZUNGQR, & 
+      EXTERNAL      ZGEDMD, ZGEQRF, ZLACPY, ZLASET, ZUNGQR, &
                     ZUNMQR, XERBLA
 !
 !     Intrinsic functions
 !     ~~~~~~~~~~~~~~~~~~~
-      INTRINSIC      MAX, MIN, INT         
-!..........................................................  
+      INTRINSIC      MAX, MIN, INT
+!..........................................................
 !
-!     Test the input arguments    
+!     Test the input arguments
       WNTRES = LSAME(JOBR,'R')
       SCCOLX = LSAME(JOBS,'S') .OR. LSAME( JOBS, 'C' )
       SCCOLY = LSAME(JOBS,'Y')
       WNTVEC = LSAME(JOBZ,'V')
       WNTVCF = LSAME(JOBZ,'F')
-      WNTVCQ = LSAME(JOBZ,'Q') 
-      WNTREF = LSAME(JOBF,'R') 
+      WNTVCQ = LSAME(JOBZ,'Q')
+      WNTREF = LSAME(JOBF,'R')
       WNTEX  = LSAME(JOBF,'E')
       WANTQ  = LSAME(JOBQ,'Q')
-      WNTTRF = LSAME(JOBT,'R')     
+      WNTTRF = LSAME(JOBT,'R')
       MINMN  = MIN(M,N)
-      INFO = 0 
+      INFO = 0
       LQUERY = ( (LZWORK == -1) .OR. (LWORK == -1) .OR. (LIWORK == -1) )
-!       
+!
       IF ( .NOT. (SCCOLX .OR. SCCOLY .OR.                &
-                                  LSAME(JOBS,'N')) )  THEN 
+                                  LSAME(JOBS,'N')) )  THEN
           INFO = -1
       ELSE IF ( .NOT. (WNTVEC .OR. WNTVCF .OR. WNTVCQ    &
                               .OR. LSAME(JOBZ,'N')) ) THEN
           INFO = -2
-      ELSE IF ( .NOT. (WNTRES .OR. LSAME(JOBR,'N')) .OR.    & 
+      ELSE IF ( .NOT. (WNTRES .OR. LSAME(JOBR,'N')) .OR.    &
           ( WNTRES .AND. LSAME(JOBZ,'N') ) ) THEN
           INFO = -3
       ELSE IF ( .NOT. (WANTQ .OR. LSAME(JOBQ,'N')) ) THEN
-           INFO = -4                 
+           INFO = -4
       ELSE IF ( .NOT. ( WNTTRF .OR. LSAME(JOBT,'N') ) )  THEN
           INFO = -5
-       ELSE IF ( .NOT. (WNTREF .OR. WNTEX .OR.             & 
+       ELSE IF ( .NOT. (WNTREF .OR. WNTEX .OR.             &
                 LSAME(JOBF,'N') ) )                     THEN
-          INFO = -6    
+          INFO = -6
       ELSE IF ( .NOT. ((WHTSVD == 1).OR.(WHTSVD == 2).OR.   &
                        (WHTSVD == 3).OR.(WHTSVD == 4)) ) THEN
           INFO = -7
@@ -664,7 +665,7 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
           INFO = -13
       ELSE IF ( LDY < MINMN ) THEN
           INFO = -15
-      ELSE IF ( .NOT. (( NRNK == -2).OR.(NRNK == -1).OR.    & 
+      ELSE IF ( .NOT. (( NRNK == -2).OR.(NRNK == -1).OR.    &
                        ((NRNK >= 1).AND.(NRNK <=N ))) )  THEN
           INFO = -16
       ELSE IF ( ( TOL < ZERO ) .OR. ( TOL >= ONE ) ) THEN
@@ -678,84 +679,84 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
       ELSE IF ( LDS < N-1 ) THEN
           INFO = -28
       END IF
-!      
+!
       IF ( WNTVEC .OR. WNTVCF .OR. WNTVCQ ) THEN
           JOBVL = 'V'
       ELSE
           JOBVL = 'N'
-      END IF     
-      IF ( INFO == 0 ) THEN  
+      END IF
+      IF ( INFO == 0 ) THEN
           ! Compute the minimal and the optimal workspace
-          ! requirements. Simulate running the code and 
-          ! determine minimal and optimal sizes of the 
-          ! workspace at any moment of the run.         
+          ! requirements. Simulate running the code and
+          ! determine minimal and optimal sizes of the
+          ! workspace at any moment of the run.
          IF ( ( N == 0 ) .OR. ( N == 1 ) ) THEN
              ! All output except K is void. INFO=1 signals
              ! the void input. In case of a workspace query,
              ! the minimal workspace lengths are returned.
-            IF ( LQUERY ) THEN  
+            IF ( LQUERY ) THEN
                IWORK(1) = 1
                ZWORK(1) = 2
                ZWORK(2) = 2
                WORK(1)  = 2
                WORK(2)  = 2
-            ELSE                
+            ELSE
                K = 0
-            END IF             
-            INFO = 1  
+            END IF
+            INFO = 1
             RETURN
-         END IF   
-         
+         END IF
+
          MLRWRK = 2
          MLWORK = 2
-         OLWORK = 2 
+         OLWORK = 2
          IMINWR = 1
          MLWQR  = MAX(1,N)  ! Minimal workspace length for ZGEQRF.
-         MLWORK = MAX(MLWORK,MINMN + MLWQR) 
-         
-         IF ( LQUERY ) THEN 
+         MLWORK = MAX(MLWORK,MINMN + MLWQR)
+
+         IF ( LQUERY ) THEN
              CALL ZGEQRF( M, N, F, LDF, ZWORK, ZWORK, -1, &
                           INFO1 )
              OLWQR  = INT(ZWORK(1))
-             OLWORK = MAX(OLWORK,MINMN + OLWQR)         
+             OLWORK = MAX(OLWORK,MINMN + OLWQR)
          END IF
-         CALL ZGEDMD( JOBS, JOBVL, JOBR, JOBF, WHTSVD, MINMN,& 
-                      N-1, X, LDX, Y, LDY, NRNK, TOL, K,     & 
-                      EIGS, Z, LDZ, RES,  B, LDB, V, LDV,    & 
+         CALL ZGEDMD( JOBS, JOBVL, JOBR, JOBF, WHTSVD, MINMN,&
+                      N-1, X, LDX, Y, LDY, NRNK, TOL, K,     &
+                      EIGS, Z, LDZ, RES,  B, LDB, V, LDV,    &
                       S, LDS, ZWORK, -1, WORK, -1, IWORK,&
                       -1, INFO1 )
          MLWDMD = INT(ZWORK(1))
          MLWORK = MAX(MLWORK, MINMN + MLWDMD)
          MLRWRK = MAX(MLRWRK, INT(WORK(1)))
          IMINWR = MAX(IMINWR, IWORK(1))
-         IF ( LQUERY ) THEN 
+         IF ( LQUERY ) THEN
              OLWDMD = INT(ZWORK(2))
              OLWORK = MAX(OLWORK, MINMN+OLWDMD)
          END IF
          IF ( WNTVEC .OR. WNTVCF ) THEN
-            MLWMQR = MAX(1,N) 
+            MLWMQR = MAX(1,N)
             MLWORK = MAX(MLWORK,MINMN+MLWMQR)
             IF ( LQUERY ) THEN
-               CALL ZUNMQR( 'L','N', M, N, MINMN, F, LDF,  & 
+               CALL ZUNMQR( 'L','N', M, N, MINMN, F, LDF,  &
                             ZWORK, Z, LDZ, ZWORK, -1, INFO1 )
                OLWMQR = INT(ZWORK(1))
                OLWORK = MAX(OLWORK,MINMN+OLWMQR)
             END IF
-         END IF  
+         END IF
          IF ( WANTQ ) THEN
             MLWGQR = MAX(1,N)
             MLWORK = MAX(MLWORK,MINMN+MLWGQR)
-            IF ( LQUERY ) THEN 
+            IF ( LQUERY ) THEN
                 CALL ZUNGQR( M, MINMN, MINMN, F, LDF, ZWORK, &
-                             ZWORK, -1, INFO1 )               
+                             ZWORK, -1, INFO1 )
                 OLWGQR = INT(ZWORK(1))
                 OLWORK = MAX(OLWORK,MINMN+OLWGQR)
-            END IF            
-         END IF         
+            END IF
+         END IF
          IF ( LIWORK < IMINWR .AND. (.NOT.LQUERY) ) INFO = -34
          IF ( LWORK  < MLRWRK .AND. (.NOT.LQUERY) ) INFO = -32
          IF ( LZWORK < MLWORK .AND. (.NOT.LQUERY) ) INFO = -30
-      END IF  
+      END IF
       IF( INFO /= 0 ) THEN
          CALL XERBLA( 'ZGEDMDQ', -INFO )
          RETURN
@@ -767,16 +768,16 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
           WORK(1)  = MLRWRK
           WORK(2)  = MLRWRK
           RETURN
-      END IF   
-!.....	  
+      END IF
+!.....
 !     Initial QR factorization that is used to represent the
 !     snapshots as elements of lower dimensional subspace.
-!     For large scale computation with M >> N, at this place 
+!     For large scale computation with M >> N, at this place
 !     one can use an out of core QRF.
-!   
-      CALL ZGEQRF( M, N, F, LDF, ZWORK,                & 
+!
+      CALL ZGEQRF( M, N, F, LDF, ZWORK,                &
                    ZWORK(MINMN+1), LZWORK-MINMN, INFO1 )
-!      
+!
 !     Define X and Y as the snapshots representations in the
 !     orthogonal basis computed in the QR factorization.
 !     X corresponds to the leading N-1 and Y to the trailing
@@ -786,14 +787,14 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
       CALL ZLACPY( 'A', MINMN, N-1, F(1,2), LDF, Y, LDY )
       IF ( M >= 3 ) THEN
           CALL ZLASET( 'L', MINMN-2, N-2, ZZERO,  ZZERO, &
-                       Y(3,1), LDY )  
+                       Y(3,1), LDY )
       END IF
 !
-!     Compute the DMD of the projected snapshot pairs (X,Y)   
+!     Compute the DMD of the projected snapshot pairs (X,Y)
       CALL ZGEDMD( JOBS, JOBVL, JOBR, JOBF, WHTSVD, MINMN, &
                   N-1,  X, LDX, Y, LDY, NRNK,   TOL, K,    &
                   EIGS, Z, LDZ, RES, B,  LDB,   V, LDV,    &
-                  S, LDS, ZWORK(MINMN+1), LZWORK-MINMN, & 
+                  S, LDS, ZWORK(MINMN+1), LZWORK-MINMN, &
                   WORK,   LWORK, IWORK, LIWORK, INFO1 )
       IF ( INFO1 == 2 .OR. INFO1 == 3 ) THEN
           ! Return with error code. See ZGEDMD for details.
@@ -801,52 +802,51 @@ SUBROUTINE ZGEDMDQ( JOBS,  JOBZ, JOBR, JOBQ, JOBT, JOBF,   &
           RETURN
       ELSE
           INFO = INFO1
-      END IF    
-!      
-!     The Ritz vectors (Koopman modes) can be explicitly 
+      END IF
+!
+!     The Ritz vectors (Koopman modes) can be explicitly
 !     formed or returned in factored form.
       IF ( WNTVEC ) THEN
-        ! Compute the eigenvectors explicitly.  
+        ! Compute the eigenvectors explicitly.
         IF ( M > MINMN ) CALL ZLASET( 'A', M-MINMN, K, ZZERO, &
                                      ZZERO, Z(MINMN+1,1), LDZ )
         CALL ZUNMQR( 'L','N', M, K, MINMN, F, LDF, ZWORK, Z,  &
              LDZ, ZWORK(MINMN+1), LZWORK-MINMN, INFO1 )
-      ELSE IF ( WNTVCF ) THEN   
+      ELSE IF ( WNTVCF ) THEN
         !   Return the Ritz vectors (eigenvectors) in factored
         !   form Z*V, where Z contains orthonormal matrix (the
-        !   product of Q from the initial QR factorization and 
-        !   the SVD/POD_basis returned by ZGEDMD in X) and the 
-        !   second factor (the eigenvectors of the Rayleigh 
+        !   product of Q from the initial QR factorization and
+        !   the SVD/POD_basis returned by ZGEDMD in X) and the
+        !   second factor (the eigenvectors of the Rayleigh
         !   quotient) is in the array V, as returned by ZGEDMD.
         CALL ZLACPY( 'A', N, K, X, LDX, Z, LDZ )
-        IF ( M > N ) CALL ZLASET( 'A', M-N, K, ZZERO, ZZERO, & 
+        IF ( M > N ) CALL ZLASET( 'A', M-N, K, ZZERO, ZZERO, &
                                  Z(N+1,1), LDZ )
         CALL ZUNMQR( 'L','N', M, K, MINMN, F, LDF, ZWORK, Z, &
                     LDZ, ZWORK(MINMN+1), LZWORK-MINMN, INFO1 )
       END IF
-!     
+!
 !     Some optional output variables:
 !
-!     The upper triangular factor R in the initial QR 
+!     The upper triangular factor R in the initial QR
 !     factorization is optionally returned in the array Y.
-!     This is useful if this call to ZGEDMDQ is to be 
-!     followed by a streaming DMD that is implemented in a 
+!     This is useful if this call to ZGEDMDQ is to be
+!     followed by a streaming DMD that is implemented in a
 !     QR compressed form.
-      IF ( WNTTRF ) THEN ! Return the upper triangular R in Y 
+      IF ( WNTTRF ) THEN ! Return the upper triangular R in Y
          CALL ZLASET( 'A', MINMN, N, ZZERO,  ZZERO, Y, LDY )
          CALL ZLACPY( 'U', MINMN, N, F, LDF,        Y, LDY )
-      END IF    
-!
-!     The orthonormal/unitary factor Q in the initial QR 
-!     factorization is optionally returned in the array F. 
-!     Same as with the triangular factor above, this is 
-!     useful in a streaming DMD.
-      IF ( WANTQ ) THEN                   ! Q overwrites F 
-         CALL ZUNGQR( M, MINMN, MINMN, F, LDF, ZWORK,     &
-                      ZWORK(MINMN+1), LZWORK-MINMN, INFO1 )  
       END IF
-!      
+!
+!     The orthonormal/unitary factor Q in the initial QR
+!     factorization is optionally returned in the array F.
+!     Same as with the triangular factor above, this is
+!     useful in a streaming DMD.
+      IF ( WANTQ ) THEN                   ! Q overwrites F
+         CALL ZUNGQR( M, MINMN, MINMN, F, LDF, ZWORK,     &
+                      ZWORK(MINMN+1), LZWORK-MINMN, INFO1 )
+      END IF
+!
       RETURN
-!      
+!
       END SUBROUTINE ZGEDMDQ
-    
