@@ -428,7 +428,8 @@
 *> \verbatim
 *>          LWORK is INTEGER
 *>          The dimension of the array WORK.
-*.          LWORK >= N+NRHS-1
+*>          LWORK >= 1, if MIN(M,N) = 0, and
+*>          LWORK >= N+NRHS-1, otherwise.
 *>          For optimal performance LWORK >= NB*( N+NRHS+1 ),
 *>          where NB is the optimal block size for ZGEQP3RK returned
 *>          by ILAENV. Minimal block size MINNB=2.
@@ -676,7 +677,7 @@
 *           Minimal workspace size in case of using only unblocked
 *           BLAS 2 code in ZLAQP2RK.
 *           1) ZLAQP2RK: N+NRHS-1 to use in WORK array that is used
-*              in ZLARF subroutine inside ZLAQP2RK to apply an
+*              in ZLARF1F subroutine inside ZLAQP2RK to apply an
 *              elementary reflector from the left.
 *           TOTAL_WORK_SIZE = 3*N + NRHS - 1
 *
@@ -692,7 +693,7 @@
 *           1) ZGEQP3RK, ZLAQP2RK, ZLAQP3RK: 2*N to store full and
 *              partial column 2-norms.
 *           2) ZLAQP2RK: N+NRHS-1 to use in WORK array that is used
-*              in ZLARF subroutine to apply an elementary reflector
+*              in ZLARF1F subroutine to apply an elementary reflector
 *              from the left.
 *           3) ZLAQP3RK: NB*(N+NRHS) to use in the work array F that
 *              is used to apply a block reflector from
@@ -891,7 +892,8 @@
 *        Determine when to cross over from blocked to unblocked code.
 *        (for N less than NX, unblocked code should be used).
 *
-         NX = MAX( 0, ILAENV( IXOVER, 'ZGEQP3RK', ' ', M, N, -1, -1 ) )
+         NX = MAX( 0, ILAENV( IXOVER, 'ZGEQP3RK', ' ', M, N, -1,
+     $                        -1 ) )
 *
          IF( NX.LT.MINMN ) THEN
 *
