@@ -53,12 +53,6 @@
 *>
 *> Note that the routine returns VT = V**H, not V.
 *>
-*> The divide and conquer algorithm makes very mild assumptions about
-*> floating point arithmetic. It will work on machines with a guard
-*> digit in add/subtract, or on those binary machines without guard
-*> digits which subtract like the Cray X-MP, Cray Y-MP, Cray C-90, or
-*> Cray-2. It could conceivably fail on hexadecimal or decimal machines
-*> without guard digits, but we know of none.
 *> \endverbatim
 *
 *  Arguments:
@@ -199,9 +193,10 @@
 *> \param[out] INFO
 *> \verbatim
 *>          INFO is INTEGER
-*>          = 0:  successful exit.
-*>          < 0:  if INFO = -i, the i-th argument had an illegal value.
-*>          > 0:  The updating process of DBDSDC did not converge.
+*>          <  0:  if INFO = -i, the i-th argument had an illegal value.
+*>          = -4:  if A had a NAN entry.
+*>          >  0:  The updating process of DBDSDC did not converge.
+*>          =  0:  successful exit.
 *> \endverbatim
 *
 *  Authors:
@@ -212,9 +207,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2016
-*
-*> \ingroup complex16GEsing
+*> \ingroup gesdd
 *
 *> \par Contributors:
 *  ==================
@@ -227,10 +220,9 @@
      $                   WORK, LWORK, RWORK, IWORK, INFO )
       implicit none
 *
-*  -- LAPACK driver routine (version 3.7.0) --
+*  -- LAPACK driver routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBZ
@@ -276,14 +268,16 @@
       COMPLEX*16         CDUM( 1 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DBDSDC, DLASCL, XERBLA, ZGEBRD, ZGELQF, ZGEMM,
+      EXTERNAL           DBDSDC, DLASCL, XERBLA, ZGEBRD, ZGELQF,
+     $                   ZGEMM,
      $                   ZGEQRF, ZLACP2, ZLACPY, ZLACRM, ZLARCM, ZLASCL,
      $                   ZLASET, ZUNGBR, ZUNGLQ, ZUNGQR, ZUNMBR
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME
-      DOUBLE PRECISION   DLAMCH, ZLANGE
-      EXTERNAL           LSAME, DLAMCH, ZLANGE
+      LOGICAL            LSAME, DISNAN
+      DOUBLE PRECISION   DLAMCH, ZLANGE, DROUNDUP_LWORK
+      EXTERNAL           LSAME, DLAMCH, ZLANGE, DISNAN, 
+     $                   DROUNDUP_LWORK
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          INT, MAX, MIN, SQRT
@@ -350,7 +344,8 @@
      $                   CDUM(1), CDUM(1), -1, IERR )
             LWORK_ZGEBRD_NN = INT( CDUM(1) )
 *
-            CALL ZGEQRF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1, IERR )
+            CALL ZGEQRF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1,
+     $                   IERR )
             LWORK_ZGEQRF_MN = INT( CDUM(1) )
 *
             CALL ZUNGBR( 'P', N, N, N, CDUM(1), N, CDUM(1), CDUM(1),
@@ -491,7 +486,8 @@
      $                   CDUM(1), CDUM(1), -1, IERR )
             LWORK_ZGEBRD_MM = INT( CDUM(1) )
 *
-            CALL ZGELQF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1, IERR )
+            CALL ZGELQF( M, N, CDUM(1), M, CDUM(1), CDUM(1), -1,
+     $                   IERR )
             LWORK_ZGELQF_MN = INT( CDUM(1) )
 *
             CALL ZUNGBR( 'P', M, N, M, CDUM(1), M, CDUM(1), CDUM(1),
@@ -619,7 +615,7 @@
          MAXWRK = MAX( MAXWRK, MINWRK )
       END IF
       IF( INFO.EQ.0 ) THEN
-         WORK( 1 ) = MAXWRK
+         WORK( 1 ) = DROUNDUP_LWORK( MAXWRK )
          IF( LWORK.LT.MINWRK .AND. .NOT. LQUERY ) THEN
             INFO = -12
          END IF
@@ -647,6 +643,10 @@
 *     Scale A if max element outside range [SMLNUM,BIGNUM]
 *
       ANRM = ZLANGE( 'M', M, N, A, LDA, DUM )
+      IF( DISNAN( ANRM ) ) THEN
+          INFO = -4
+          RETURN
+      END IF
       ISCL = 0
       IF( ANRM.GT.ZERO .AND. ANRM.LT.SMLNUM ) THEN
          ISCL = 1
@@ -677,7 +677,8 @@
 *              CWorkspace: prefer N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Zero out below R
@@ -694,7 +695,8 @@
 *              CWorkspace: prefer 2*N [tauq, taup] + 2*N*NB [work]
 *              RWorkspace: need   N [e]
 *
-               CALL ZGEBRD( N, N, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL ZGEBRD( N, N, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                NRWORK = IE + N
@@ -734,13 +736,15 @@
 *              CWorkspace: prefer N*N [U] + N*N [R] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy R to WORK( IR ), zeroing out below it
 *
                CALL ZLACPY( 'U', N, N, A, LDA, WORK( IR ), LDWRKR )
-               CALL ZLASET( 'L', N-1, N-1, CZERO, CZERO, WORK( IR+1 ),
+               CALL ZLASET( 'L', N-1, N-1, CZERO, CZERO,
+     $                      WORK( IR+1 ),
      $                      LDWRKR )
 *
 *              Generate Q in A
@@ -773,7 +777,8 @@
                IRU = IE + N
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -785,7 +790,8 @@
 *
                CALL ZLACP2( 'F', N, N, RWORK( IRU ), N, WORK( IU ),
      $                      LDWRKU )
-               CALL ZUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ), LDWRKR,
+               CALL ZUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUQ ), WORK( IU ), LDWRKU,
      $                      WORK( NWORK ), LWORK-NWORK+1, IERR )
 *
@@ -796,7 +802,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', N, N, RWORK( IRVT ), N, VT, LDVT )
-               CALL ZUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ), LDWRKR,
+               CALL ZUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -834,13 +841,15 @@
 *              CWorkspace: prefer N*N [R] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy R to WORK(IR), zeroing out below it
 *
                CALL ZLACPY( 'U', N, N, A, LDA, WORK( IR ), LDWRKR )
-               CALL ZLASET( 'L', N-1, N-1, CZERO, CZERO, WORK( IR+1 ),
+               CALL ZLASET( 'L', N-1, N-1, CZERO, CZERO,
+     $                      WORK( IR+1 ),
      $                      LDWRKR )
 *
 *              Generate Q in A
@@ -873,7 +882,8 @@
                IRU = IE + N
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -884,7 +894,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', N, N, RWORK( IRU ), N, U, LDU )
-               CALL ZUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ), LDWRKR,
+               CALL ZUNMBR( 'Q', 'L', 'N', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -895,7 +906,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', N, N, RWORK( IRVT ), N, VT, LDVT )
-               CALL ZUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ), LDWRKR,
+               CALL ZUNMBR( 'P', 'R', 'C', N, N, N, WORK( IR ),
+     $                      LDWRKR,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -905,7 +917,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACPY( 'F', N, N, U, LDU, WORK( IR ), LDWRKR )
-               CALL ZGEMM( 'N', 'N', M, N, N, CONE, A, LDA, WORK( IR ),
+               CALL ZGEMM( 'N', 'N', M, N, N, CONE, A, LDA,
+     $                     WORK( IR ),
      $                     LDWRKR, CZERO, U, LDU )
 *
             ELSE IF( WNTQA ) THEN
@@ -927,7 +940,8 @@
 *              CWorkspace: prefer N*N [U] + N [tau] + N*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGEQRF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
                CALL ZLACPY( 'L', M, N, A, LDA, U, LDU )
 *
@@ -953,7 +967,8 @@
 *              CWorkspace: prefer N*N [U] + 2*N [tauq, taup] + 2*N*NB [work]
 *              RWorkspace: need   N [e]
 *
-               CALL ZGEBRD( N, N, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL ZGEBRD( N, N, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                IRU = IE + N
@@ -966,7 +981,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -998,7 +1014,8 @@
 *              CWorkspace: need   N*N [U]
 *              RWorkspace: need   0
 *
-               CALL ZGEMM( 'N', 'N', M, N, N, CONE, U, LDU, WORK( IU ),
+               CALL ZGEMM( 'N', 'N', M, N, N, CONE, U, LDU,
+     $                     WORK( IU ),
      $                     LDWRKU, CZERO, A, LDA )
 *
 *              Copy left singular vectors of A from A to U
@@ -1036,7 +1053,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + BDSPAC
 *
-               CALL DBDSDC( 'U', 'N', N, S, RWORK( IE ), DUM, 1,DUM,1,
+               CALL DBDSDC( 'U', 'N', N, S, RWORK( IE ), DUM, 1,DUM,
+     $                      1,
      $                      DUM, IDUM, RWORK( NRWORK ), IWORK, INFO )
             ELSE IF( WNTQO ) THEN
                IU = NWORK
@@ -1081,7 +1099,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1104,7 +1123,8 @@
                NRWORK = IRVT
                DO 20 I = 1, M, LDWRKU
                   CHUNK = MIN( M-I+1, LDWRKU )
-                  CALL ZLACRM( CHUNK, N, A( I, 1 ), LDA, RWORK( IRU ),
+                  CALL ZLACRM( CHUNK, N, A( I, 1 ), LDA,
+     $                         RWORK( IRU ),
      $                         N, WORK( IU ), LDWRKU, RWORK( NRWORK ) )
                   CALL ZLACPY( 'F', CHUNK, N, WORK( IU ), LDWRKU,
      $                         A( I, 1 ), LDA )
@@ -1140,7 +1160,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1192,7 +1213,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1272,7 +1294,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   N [e] + N*N [RU] + N*N [RVT] + BDSPAC
 *
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1299,12 +1322,14 @@
 *
                   CALL ZLASET( 'F', M, N, CZERO, CZERO, WORK( IU ),
      $                         LDWRKU )
-                  CALL ZLACP2( 'F', N, N, RWORK( IRU ), N, WORK( IU ),
+                  CALL ZLACP2( 'F', N, N, RWORK( IRU ), N,
+     $                         WORK( IU ),
      $                         LDWRKU )
                   CALL ZUNMBR( 'Q', 'L', 'N', M, N, N, A, LDA,
      $                         WORK( ITAUQ ), WORK( IU ), LDWRKU,
      $                         WORK( NWORK ), LWORK-NWORK+1, IERR )
-                  CALL ZLACPY( 'F', M, N, WORK( IU ), LDWRKU, A, LDA )
+                  CALL ZLACPY( 'F', M, N, WORK( IU ), LDWRKU, A,
+     $                         LDA )
                ELSE
 *
 *                 Path 6o-slow
@@ -1346,7 +1371,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1384,7 +1410,8 @@
                IRU = NRWORK
                IRVT = IRU + N*N
                NRWORK = IRVT + N*N
-               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', N, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      N, RWORK( IRVT ), N, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1442,7 +1469,8 @@
 *              CWorkspace: prefer M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Zero out above L
@@ -1459,7 +1487,8 @@
 *              CWorkspace: prefer 2*M [tauq, taup] + 2*M*NB [work]
 *              RWorkspace: need   M [e]
 *
-               CALL ZGEBRD( M, M, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL ZGEBRD( M, M, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
                NRWORK = IE + M
@@ -1504,7 +1533,8 @@
 *              CWorkspace: prefer M*M [VT] + M*M [L] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy L to WORK(IL), zeroing about above it
@@ -1543,7 +1573,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1554,7 +1585,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', M, M, RWORK( IRU ), M, U, LDU )
-               CALL ZUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ), LDWRKL,
+               CALL ZUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1566,7 +1598,8 @@
 *
                CALL ZLACP2( 'F', M, M, RWORK( IRVT ), M, WORK( IVT ),
      $                      LDWKVT )
-               CALL ZUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ), LDWRKL,
+               CALL ZUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUP ), WORK( IVT ), LDWKVT,
      $                      WORK( NWORK ), LWORK-NWORK+1, IERR )
 *
@@ -1578,7 +1611,8 @@
 *
                DO 40 I = 1, N, CHUNK
                   BLK = MIN( N-I+1, CHUNK )
-                  CALL ZGEMM( 'N', 'N', M, BLK, M, CONE, WORK( IVT ), M,
+                  CALL ZGEMM( 'N', 'N', M, BLK, M, CONE, WORK( IVT ),
+     $                        M,
      $                        A( 1, I ), LDA, CZERO, WORK( IL ),
      $                        LDWRKL )
                   CALL ZLACPY( 'F', M, BLK, WORK( IL ), LDWRKL,
@@ -1604,7 +1638,8 @@
 *              CWorkspace: prefer M*M [L] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
 *              Copy L to WORK(IL), zeroing out above it
@@ -1643,7 +1678,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1654,7 +1690,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', M, M, RWORK( IRU ), M, U, LDU )
-               CALL ZUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ), LDWRKL,
+               CALL ZUNMBR( 'Q', 'L', 'N', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUQ ), U, LDU, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1665,7 +1702,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACP2( 'F', M, M, RWORK( IRVT ), M, VT, LDVT )
-               CALL ZUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ), LDWRKL,
+               CALL ZUNMBR( 'P', 'R', 'C', M, M, M, WORK( IL ),
+     $                      LDWRKL,
      $                      WORK( ITAUP ), VT, LDVT, WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
 *
@@ -1675,7 +1713,8 @@
 *              RWorkspace: need   0
 *
                CALL ZLACPY( 'F', M, M, VT, LDVT, WORK( IL ), LDWRKL )
-               CALL ZGEMM( 'N', 'N', M, N, M, CONE, WORK( IL ), LDWRKL,
+               CALL ZGEMM( 'N', 'N', M, N, M, CONE, WORK( IL ),
+     $                     LDWRKL,
      $                     A, LDA, CZERO, VT, LDVT )
 *
             ELSE IF( WNTQA ) THEN
@@ -1697,7 +1736,8 @@
 *              CWorkspace: prefer M*M [VT] + M [tau] + M*NB [work]
 *              RWorkspace: need   0
 *
-               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ), WORK( NWORK ),
+               CALL ZGELQF( M, N, A, LDA, WORK( ITAU ),
+     $                      WORK( NWORK ),
      $                      LWORK-NWORK+1, IERR )
                CALL ZLACPY( 'U', M, N, A, LDA, VT, LDVT )
 *
@@ -1723,7 +1763,8 @@
 *              CWorkspace: prefer M*M [VT] + 2*M [tauq, taup] + 2*M*NB [work]
 *              RWorkspace: need   M [e]
 *
-               CALL ZGEBRD( M, M, A, LDA, S, RWORK( IE ), WORK( ITAUQ ),
+               CALL ZGEBRD( M, M, A, LDA, S, RWORK( IE ),
+     $                      WORK( ITAUQ ),
      $                      WORK( ITAUP ), WORK( NWORK ), LWORK-NWORK+1,
      $                      IERR )
 *
@@ -1736,7 +1777,8 @@
                IRU = IE + M
                IRVT = IRU + M*M
                NRWORK = IRVT + M*M
-               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'U', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1768,7 +1810,8 @@
 *              CWorkspace: need   M*M [VT]
 *              RWorkspace: need   0
 *
-               CALL ZGEMM( 'N', 'N', M, N, M, CONE, WORK( IVT ), LDWKVT,
+               CALL ZGEMM( 'N', 'N', M, N, M, CONE, WORK( IVT ),
+     $                     LDWKVT,
      $                     VT, LDVT, CZERO, A, LDA )
 *
 *              Copy right singular vectors of A from A to VT
@@ -1854,7 +1897,8 @@
 *              CWorkspace: need   0
 *              RWorkspace: need   M [e] + M*M [RVT] + M*M [RU] + BDSPAC
 *
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1863,7 +1907,8 @@
 *              CWorkspace: need   2*M [tauq, taup] + M*M [VT]
 *              RWorkspace: need   M [e] + M*M [RVT] + M*M [RU] + 2*M*M [rwork]
 *
-               CALL ZLACRM( M, M, U, LDU, RWORK( IRU ), M, WORK( IVT ),
+               CALL ZLACRM( M, M, U, LDU, RWORK( IRU ), M,
+     $                      WORK( IVT ),
      $                      LDWKVT, RWORK( NRWORK ) )
                CALL ZLACPY( 'F', M, M, WORK( IVT ), LDWKVT, U, LDU )
 *
@@ -1877,7 +1922,8 @@
                NRWORK = IRU
                DO 50 I = 1, N, CHUNK
                   BLK = MIN( N-I+1, CHUNK )
-                  CALL ZLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ), LDA,
+                  CALL ZLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ),
+     $                         LDA,
      $                         WORK( IVT ), LDWKVT, RWORK( NRWORK ) )
                   CALL ZLACPY( 'F', M, BLK, WORK( IVT ), LDWKVT,
      $                         A( 1, I ), LDA )
@@ -1912,7 +1958,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -1964,7 +2011,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2047,7 +2095,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2072,12 +2121,14 @@
 *                 CWorkspace: prefer 2*M [tauq, taup] + M*N [VT] + M*NB [work]
 *                 RWorkspace: need   M [e] + M*M [RVT]
 *
-                  CALL ZLACP2( 'F', M, M, RWORK( IRVT ), M, WORK( IVT ),
+                  CALL ZLACP2( 'F', M, M, RWORK( IRVT ), M,
+     $                         WORK( IVT ),
      $                         LDWKVT )
                   CALL ZUNMBR( 'P', 'R', 'C', M, N, M, A, LDA,
      $                         WORK( ITAUP ), WORK( IVT ), LDWKVT,
      $                         WORK( NWORK ), LWORK-NWORK+1, IERR )
-                  CALL ZLACPY( 'F', M, N, WORK( IVT ), LDWKVT, A, LDA )
+                  CALL ZLACPY( 'F', M, N, WORK( IVT ), LDWKVT, A,
+     $                         LDA )
                ELSE
 *
 *                 Path 6to-slow
@@ -2099,7 +2150,8 @@
                   NRWORK = IRU
                   DO 60 I = 1, N, CHUNK
                      BLK = MIN( N-I+1, CHUNK )
-                     CALL ZLARCM( M, BLK, RWORK( IRVT ), M, A( 1, I ),
+                     CALL ZLARCM( M, BLK, RWORK( IRVT ), M, A( 1,
+     $                            I ),
      $                            LDA, WORK( IVT ), LDWKVT,
      $                            RWORK( NRWORK ) )
                      CALL ZLACPY( 'F', M, BLK, WORK( IVT ), LDWKVT,
@@ -2118,7 +2170,8 @@
                IRVT = NRWORK
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2157,7 +2210,8 @@
                IRU = IRVT + M*M
                NRWORK = IRU + M*M
 *
-               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ), RWORK( IRU ),
+               CALL DBDSDC( 'L', 'I', M, S, RWORK( IE ),
+     $                      RWORK( IRU ),
      $                      M, RWORK( IRVT ), M, DUM, IDUM,
      $                      RWORK( NRWORK ), IWORK, INFO )
 *
@@ -2211,7 +2265,7 @@
 *
 *     Return optimal workspace in WORK(1)
 *
-      WORK( 1 ) = MAXWRK
+      WORK( 1 ) = DROUNDUP_LWORK( MAXWRK )
 *
       RETURN
 *
