@@ -305,7 +305,8 @@
       DOUBLE PRECISION   DUM( 1 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZGEBRD, ZGELQF, ZGEQRF, ZLASCL, ZLASET, ZLACPY,
+      EXTERNAL           ZGEBRD, ZGELQF, ZGEQRF, ZLASCL, ZLASET,
+     $                   ZLACPY,
      $                   ZUNMLQ, ZUNMBR, ZUNMQR, DBDSVDX, DLASCL, XERBLA
 *     ..
 *     .. External Functions ..
@@ -394,7 +395,8 @@
          MAXWRK = 1
          IF( MINMN.GT.0 ) THEN
             IF( M.GE.N ) THEN
-               MNTHR = ILAENV( 6, 'ZGESVD', JOBU // JOBVT, M, N, 0, 0 )
+               MNTHR = ILAENV( 6, 'ZGESVD', JOBU // JOBVT, M, N, 0,
+     $                         0 )
                IF( M.GE.MNTHR ) THEN
 *
 *                 Path 1 (M much larger than N)
@@ -402,24 +404,28 @@
                   MINWRK = N*(N+5)
                   MAXWRK = N + N*ILAENV(1,'ZGEQRF',' ',M,N,-1,-1)
                   MAXWRK = MAX(MAXWRK,
-     $                     N*N+2*N+2*N*ILAENV(1,'ZGEBRD',' ',N,N,-1,-1))
+     $                     N*N+2*N+2*N*ILAENV(1,'ZGEBRD',' ',N,N,-1,
+     $                                         -1))
                   IF (WANTU .OR. WANTVT) THEN
                      MAXWRK = MAX(MAXWRK,
-     $                       N*N+2*N+N*ILAENV(1,'ZUNMQR','LN',N,N,N,-1))
+     $                       N*N+2*N+N*ILAENV(1,'ZUNMQR','LN',N,N,N,
+     $                                         -1))
                   END IF
                ELSE
 *
 *                 Path 2 (M at least N, but not much larger)
 *
                   MINWRK = 3*N + M
-                  MAXWRK = 2*N + (M+N)*ILAENV(1,'ZGEBRD',' ',M,N,-1,-1)
+                  MAXWRK = 2*N + (M+N)*ILAENV(1,'ZGEBRD',' ',M,N,-1,
+     $                             -1)
                   IF (WANTU .OR. WANTVT) THEN
                      MAXWRK = MAX(MAXWRK,
      $                        2*N+N*ILAENV(1,'ZUNMQR','LN',N,N,N,-1))
                   END IF
                END IF
             ELSE
-               MNTHR = ILAENV( 6, 'ZGESVD', JOBU // JOBVT, M, N, 0, 0 )
+               MNTHR = ILAENV( 6, 'ZGESVD', JOBU // JOBVT, M, N, 0,
+     $                         0 )
                IF( N.GE.MNTHR ) THEN
 *
 *                 Path 1t (N much larger than M)
@@ -427,10 +433,12 @@
                   MINWRK = M*(M+5)
                   MAXWRK = M + M*ILAENV(1,'ZGELQF',' ',M,N,-1,-1)
                   MAXWRK = MAX(MAXWRK,
-     $                     M*M+2*M+2*M*ILAENV(1,'ZGEBRD',' ',M,M,-1,-1))
+     $                     M*M+2*M+2*M*ILAENV(1,'ZGEBRD',' ',M,M,-1,
+     $                                         -1))
                   IF (WANTU .OR. WANTVT) THEN
                      MAXWRK = MAX(MAXWRK,
-     $                       M*M+2*M+M*ILAENV(1,'ZUNMQR','LN',M,M,M,-1))
+     $                       M*M+2*M+M*ILAENV(1,'ZUNMQR','LN',M,M,M,
+     $                                         -1))
                   END IF
                ELSE
 *
@@ -438,7 +446,8 @@
 *
 *
                   MINWRK = 3*M + N
-                  MAXWRK = 2*M + (M+N)*ILAENV(1,'ZGEBRD',' ',M,N,-1,-1)
+                  MAXWRK = 2*M + (M+N)*ILAENV(1,'ZGEBRD',' ',M,N,-1,
+     $                             -1)
                   IF (WANTU .OR. WANTVT) THEN
                      MAXWRK = MAX(MAXWRK,
      $                        2*M+M*ILAENV(1,'ZUNMQR','LN',M,M,M,-1))
@@ -559,7 +568,8 @@
                   END DO
                   K = K + N
                END DO
-               CALL ZLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ), LDU)
+               CALL ZLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ),
+     $                      LDU)
 *
 *              Call ZUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
@@ -635,7 +645,8 @@
                   END DO
                   K = K + N
                END DO
-               CALL ZLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ), LDU)
+               CALL ZLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ),
+     $                      LDU)
 *
 *              Call ZUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
