@@ -499,7 +499,8 @@
                                     T  = HALF / THETA
                                     CS = ONE
 
-                                    CALL ZROT( M, A(1,p), 1, A(1,q), 1,
+                                    CALL ZROT( M, A(1,p), 1, A(1,q),
+     $                                         1,
      $                                          CS, CONJG(OMPQ)*T )
                                     IF ( RSVEC ) THEN
                                         CALL ZROT( MVL, V(1,p), 1,
@@ -528,7 +529,8 @@
                                     AAPP = AAPP*SQRT( MAX( ZERO,
      $                                      ONE-T*AQOAP*AAPQ1 ) )
 *
-                                    CALL ZROT( M, A(1,p), 1, A(1,q), 1,
+                                    CALL ZROT( M, A(1,p), 1, A(1,q),
+     $                                         1,
      $                                          CS, CONJG(OMPQ)*SN )
                                     IF ( RSVEC ) THEN
                                         CALL ZROT( MVL, V(1,p), 1,
@@ -541,14 +543,17 @@
 *              .. have to use modified Gram-Schmidt like transformation
                                  CALL ZCOPY( M, A( 1, p ), 1,
      $                                       WORK, 1 )
-                                 CALL ZLASCL( 'G', 0, 0, AAPP, ONE, M,
+                                 CALL ZLASCL( 'G', 0, 0, AAPP, ONE,
+     $                                        M,
      $                                        1, WORK, LDA,
      $                                        IERR )
-                                 CALL ZLASCL( 'G', 0, 0, AAQQ, ONE, M,
+                                 CALL ZLASCL( 'G', 0, 0, AAQQ, ONE,
+     $                                        M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  CALL ZAXPY( M, -AAPQ, WORK, 1,
      $                                       A( 1, q ), 1 )
-                                 CALL ZLASCL( 'G', 0, 0, ONE, AAQQ, M,
+                                 CALL ZLASCL( 'G', 0, 0, ONE, AAQQ,
+     $                                        M,
      $                                        1, A( 1, q ), LDA, IERR )
                                  SVA( q ) = AAQQ*SQRT( MAX( ZERO,
      $                                      ONE-AAPQ1*AAPQ1 ) )
@@ -563,7 +568,8 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = DZNRM2( M, A( 1, q ), 1 )
+                                    SVA( q ) = DZNRM2( M, A( 1, q ),
+     $                                   1 )
                                  ELSE
                                     T = ZERO
                                     AAQQ = ONE
@@ -715,7 +721,8 @@
                                  IF( ABS( THETA ).GT.BIGTHETA ) THEN
                                     T  = HALF / THETA
                                     CS = ONE
-                                    CALL ZROT( M, A(1,p), 1, A(1,q), 1,
+                                    CALL ZROT( M, A(1,p), 1, A(1,q),
+     $                                         1,
      $                                          CS, CONJG(OMPQ)*T )
                                     IF( RSVEC ) THEN
                                         CALL ZROT( MVL, V(1,p), 1,
@@ -742,7 +749,8 @@
                                     AAPP = AAPP*SQRT( MAX( ZERO,
      $                                         ONE-T*AQOAP*AAPQ1 ) )
 *
-                                    CALL ZROT( M, A(1,p), 1, A(1,q), 1,
+                                    CALL ZROT( M, A(1,p), 1, A(1,q),
+     $                                         1,
      $                                          CS, CONJG(OMPQ)*SN )
                                     IF( RSVEC ) THEN
                                         CALL ZROT( MVL, V(1,p), 1,
@@ -756,15 +764,18 @@
                                IF( AAPP.GT.AAQQ ) THEN
                                     CALL ZCOPY( M, A( 1, p ), 1,
      $                                          WORK, 1 )
-                                    CALL ZLASCL( 'G', 0, 0, AAPP, ONE,
+                                    CALL ZLASCL( 'G', 0, 0, AAPP,
+     $                                           ONE,
      $                                           M, 1, WORK,LDA,
      $                                           IERR )
-                                    CALL ZLASCL( 'G', 0, 0, AAQQ, ONE,
+                                    CALL ZLASCL( 'G', 0, 0, AAQQ,
+     $                                           ONE,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     CALL ZAXPY( M, -AAPQ, WORK,
      $                                          1, A( 1, q ), 1 )
-                                    CALL ZLASCL( 'G', 0, 0, ONE, AAQQ,
+                                    CALL ZLASCL( 'G', 0, 0, ONE,
+     $                                           AAQQ,
      $                                           M, 1, A( 1, q ), LDA,
      $                                           IERR )
                                     SVA( q ) = AAQQ*SQRT( MAX( ZERO,
@@ -773,15 +784,18 @@
                                ELSE
                                    CALL ZCOPY( M, A( 1, q ), 1,
      $                                          WORK, 1 )
-                                    CALL ZLASCL( 'G', 0, 0, AAQQ, ONE,
+                                    CALL ZLASCL( 'G', 0, 0, AAQQ,
+     $                                           ONE,
      $                                           M, 1, WORK,LDA,
      $                                           IERR )
-                                    CALL ZLASCL( 'G', 0, 0, AAPP, ONE,
+                                    CALL ZLASCL( 'G', 0, 0, AAPP,
+     $                                           ONE,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     CALL ZAXPY( M, -CONJG(AAPQ),
      $                                   WORK, 1, A( 1, p ), 1 )
-                                    CALL ZLASCL( 'G', 0, 0, ONE, AAPP,
+                                    CALL ZLASCL( 'G', 0, 0, ONE,
+     $                                           AAPP,
      $                                           M, 1, A( 1, p ), LDA,
      $                                           IERR )
                                     SVA( p ) = AAPP*SQRT( MAX( ZERO,
@@ -797,7 +811,8 @@
      $                            THEN
                                  IF( ( AAQQ.LT.ROOTBIG ) .AND.
      $                               ( AAQQ.GT.ROOTSFMIN ) ) THEN
-                                    SVA( q ) = DZNRM2( M, A( 1, q ), 1)
+                                    SVA( q ) = DZNRM2( M, A( 1, q ),
+     $                                   1)
                                   ELSE
                                     T = ZERO
                                     AAQQ = ONE
