@@ -163,7 +163,8 @@
 *> \ingroup hfrk
 *
 *  =====================================================================
-      SUBROUTINE ZHFRK( TRANSR, UPLO, TRANS, N, K, ALPHA, A, LDA, BETA,
+      SUBROUTINE ZHFRK( TRANSR, UPLO, TRANS, N, K, ALPHA, A, LDA,
+     $                  BETA,
      $                  C )
 *
 *  -- LAPACK computational routine --
@@ -290,9 +291,11 @@
 *
                   CALL ZHERK( 'L', 'N', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 1 ), N )
-                  CALL ZHERK( 'U', 'N', N2, K, ALPHA, A( N1+1, 1 ), LDA,
+                  CALL ZHERK( 'U', 'N', N2, K, ALPHA, A( N1+1, 1 ),
+     $                        LDA,
      $                        BETA, C( N+1 ), N )
-                  CALL ZGEMM( 'N', 'C', N2, N1, K, CALPHA, A( N1+1, 1 ),
+                  CALL ZGEMM( 'N', 'C', N2, N1, K, CALPHA, A( N1+1,
+     $                        1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( N1+1 ), N )
 *
                ELSE
@@ -301,9 +304,11 @@
 *
                   CALL ZHERK( 'L', 'C', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 1 ), N )
-                  CALL ZHERK( 'U', 'C', N2, K, ALPHA, A( 1, N1+1 ), LDA,
+                  CALL ZHERK( 'U', 'C', N2, K, ALPHA, A( 1, N1+1 ),
+     $                        LDA,
      $                        BETA, C( N+1 ), N )
-                  CALL ZGEMM( 'C', 'N', N2, N1, K, CALPHA, A( 1, N1+1 ),
+                  CALL ZGEMM( 'C', 'N', N2, N1, K, CALPHA, A( 1,
+     $                        N1+1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( N1+1 ), N )
 *
                END IF
@@ -318,7 +323,8 @@
 *
                   CALL ZHERK( 'L', 'N', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( N2+1 ), N )
-                  CALL ZHERK( 'U', 'N', N2, K, ALPHA, A( N2, 1 ), LDA,
+                  CALL ZHERK( 'U', 'N', N2, K, ALPHA, A( N2, 1 ),
+     $                        LDA,
      $                        BETA, C( N1+1 ), N )
                   CALL ZGEMM( 'N', 'C', N1, N2, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( N2, 1 ), LDA, CBETA, C( 1 ), N )
@@ -329,7 +335,8 @@
 *
                   CALL ZHERK( 'L', 'C', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( N2+1 ), N )
-                  CALL ZHERK( 'U', 'C', N2, K, ALPHA, A( 1, N2 ), LDA,
+                  CALL ZHERK( 'U', 'C', N2, K, ALPHA, A( 1, N2 ),
+     $                        LDA,
      $                        BETA, C( N1+1 ), N )
                   CALL ZGEMM( 'C', 'N', N1, N2, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( 1, N2 ), LDA, CBETA, C( 1 ), N )
@@ -352,7 +359,8 @@
 *
                   CALL ZHERK( 'U', 'N', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 1 ), N1 )
-                  CALL ZHERK( 'L', 'N', N2, K, ALPHA, A( N1+1, 1 ), LDA,
+                  CALL ZHERK( 'L', 'N', N2, K, ALPHA, A( N1+1, 1 ),
+     $                        LDA,
      $                        BETA, C( 2 ), N1 )
                   CALL ZGEMM( 'N', 'C', N1, N2, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( N1+1, 1 ), LDA, CBETA,
@@ -364,7 +372,8 @@
 *
                   CALL ZHERK( 'U', 'C', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 1 ), N1 )
-                  CALL ZHERK( 'L', 'C', N2, K, ALPHA, A( 1, N1+1 ), LDA,
+                  CALL ZHERK( 'L', 'C', N2, K, ALPHA, A( 1, N1+1 ),
+     $                        LDA,
      $                        BETA, C( 2 ), N1 )
                   CALL ZGEMM( 'C', 'N', N1, N2, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( 1, N1+1 ), LDA, CBETA,
@@ -382,9 +391,11 @@
 *
                   CALL ZHERK( 'U', 'N', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( N2*N2+1 ), N2 )
-                  CALL ZHERK( 'L', 'N', N2, K, ALPHA, A( N1+1, 1 ), LDA,
+                  CALL ZHERK( 'L', 'N', N2, K, ALPHA, A( N1+1, 1 ),
+     $                        LDA,
      $                        BETA, C( N1*N2+1 ), N2 )
-                  CALL ZGEMM( 'N', 'C', N2, N1, K, CALPHA, A( N1+1, 1 ),
+                  CALL ZGEMM( 'N', 'C', N2, N1, K, CALPHA, A( N1+1,
+     $                        1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( 1 ), N2 )
 *
                ELSE
@@ -393,9 +404,11 @@
 *
                   CALL ZHERK( 'U', 'C', N1, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( N2*N2+1 ), N2 )
-                  CALL ZHERK( 'L', 'C', N2, K, ALPHA, A( 1, N1+1 ), LDA,
+                  CALL ZHERK( 'L', 'C', N2, K, ALPHA, A( 1, N1+1 ),
+     $                        LDA,
      $                        BETA, C( N1*N2+1 ), N2 )
-                  CALL ZGEMM( 'C', 'N', N2, N1, K, CALPHA, A( 1, N1+1 ),
+                  CALL ZGEMM( 'C', 'N', N2, N1, K, CALPHA, A( 1,
+     $                        N1+1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( 1 ), N2 )
 *
                END IF
@@ -422,9 +435,11 @@
 *
                   CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 2 ), N+1 )
-                  CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( NK+1, 1 ), LDA,
+                  CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( NK+1, 1 ),
+     $                        LDA,
      $                        BETA, C( 1 ), N+1 )
-                  CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( NK+1, 1 ),
+                  CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( NK+1,
+     $                        1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( NK+2 ),
      $                        N+1 )
 *
@@ -434,9 +449,11 @@
 *
                   CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( 2 ), N+1 )
-                  CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, NK+1 ), LDA,
+                  CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, NK+1 ),
+     $                        LDA,
      $                        BETA, C( 1 ), N+1 )
-                  CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1, NK+1 ),
+                  CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1,
+     $                        NK+1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( NK+2 ),
      $                        N+1 )
 *
@@ -452,7 +469,8 @@
 *
                   CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK+2 ), N+1 )
-                  CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( NK+1, 1 ), LDA,
+                  CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( NK+1, 1 ),
+     $                        LDA,
      $                        BETA, C( NK+1 ), N+1 )
                   CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( NK+1, 1 ), LDA, CBETA, C( 1 ),
@@ -464,7 +482,8 @@
 *
                   CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK+2 ), N+1 )
-                  CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, NK+1 ), LDA,
+                  CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, NK+1 ),
+     $                        LDA,
      $                        BETA, C( NK+1 ), N+1 )
                   CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( 1, NK+1 ), LDA, CBETA, C( 1 ),
@@ -488,7 +507,8 @@
 *
                   CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK+1 ), NK )
-                  CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( NK+1, 1 ), LDA,
+                  CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( NK+1, 1 ),
+     $                        LDA,
      $                        BETA, C( 1 ), NK )
                   CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( NK+1, 1 ), LDA, CBETA,
@@ -500,7 +520,8 @@
 *
                   CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK+1 ), NK )
-                  CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, NK+1 ), LDA,
+                  CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, NK+1 ),
+     $                        LDA,
      $                        BETA, C( 1 ), NK )
                   CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1, 1 ),
      $                        LDA, A( 1, NK+1 ), LDA, CBETA,
@@ -518,9 +539,11 @@
 *
                   CALL ZHERK( 'U', 'N', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK*( NK+1 )+1 ), NK )
-                  CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( NK+1, 1 ), LDA,
+                  CALL ZHERK( 'L', 'N', NK, K, ALPHA, A( NK+1, 1 ),
+     $                        LDA,
      $                        BETA, C( NK*NK+1 ), NK )
-                  CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( NK+1, 1 ),
+                  CALL ZGEMM( 'N', 'C', NK, NK, K, CALPHA, A( NK+1,
+     $                        1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( 1 ), NK )
 *
                ELSE
@@ -529,9 +552,11 @@
 *
                   CALL ZHERK( 'U', 'C', NK, K, ALPHA, A( 1, 1 ), LDA,
      $                        BETA, C( NK*( NK+1 )+1 ), NK )
-                  CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, NK+1 ), LDA,
+                  CALL ZHERK( 'L', 'C', NK, K, ALPHA, A( 1, NK+1 ),
+     $                        LDA,
      $                        BETA, C( NK*NK+1 ), NK )
-                  CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1, NK+1 ),
+                  CALL ZGEMM( 'C', 'N', NK, NK, K, CALPHA, A( 1,
+     $                        NK+1 ),
      $                        LDA, A( 1, 1 ), LDA, CBETA, C( 1 ), NK )
 *
                END IF
