@@ -385,7 +385,8 @@
 *> \ingroup la_herfsx_extended
 *
 *  =====================================================================
-      SUBROUTINE ZLA_HERFSX_EXTENDED( PREC_TYPE, UPLO, N, NRHS, A, LDA,
+      SUBROUTINE ZLA_HERFSX_EXTENDED( PREC_TYPE, UPLO, N, NRHS, A,
+     $                                LDA,
      $                                AF, LDAF, IPIV, COLEQU, C, B, LDB,
      $                                Y, LDY, BERR_OUT, N_NORMS,
      $                                ERR_BNDS_NORM, ERR_BNDS_COMP, RES,
@@ -457,7 +458,8 @@
       INTEGER            ILAUPLO
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZAXPY, ZCOPY, ZHETRS, ZHEMV, BLAS_ZHEMV_X,
+      EXTERNAL           ZAXPY, ZCOPY, ZHETRS, ZHEMV,
+     $                   BLAS_ZHEMV_X,
      $                   BLAS_ZHEMV2_X, ZLA_HEAMV, ZLA_WWADDW,
      $                   ZLA_LIN_BERR
       DOUBLE PRECISION   DLAMCH
@@ -537,7 +539,8 @@
 *
             CALL ZCOPY( N, B( 1, J ), 1, RES, 1 )
             IF ( Y_PREC_STATE .EQ. BASE_RESIDUAL ) THEN
-               CALL ZHEMV( UPLO, N, DCMPLX(-1.0D+0), A, LDA, Y( 1, J ),
+               CALL ZHEMV( UPLO, N, DCMPLX(-1.0D+0), A, LDA, Y( 1,
+     $                     J ),
      $              1, DCMPLX(1.0D+0), RES, 1 )
             ELSE IF ( Y_PREC_STATE .EQ. EXTRA_RESIDUAL ) THEN
                CALL BLAS_ZHEMV_X( UPLO2, N, DCMPLX(-1.0D+0), A, LDA,
