@@ -162,9 +162,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date November 2013
-*
-*> \ingroup complex16HEcomputational
+*> \ingroup lahef_rook
 *
 *> \par Contributors:
 *  ==================
@@ -184,10 +182,9 @@
       SUBROUTINE ZLAHEF_ROOK( UPLO, N, NB, KB, A, LDA, IPIV, W, LDW,
      $                        INFO )
 *
-*  -- LAPACK computational routine (version 3.5.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2013
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -223,7 +220,8 @@
       EXTERNAL           LSAME, IZAMAX, DLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZCOPY, ZDSCAL, ZGEMM, ZGEMV, ZLACGV, ZSWAP
+      EXTERNAL           ZCOPY, ZDSCAL, ZGEMM, ZGEMV, ZLACGV,
+     $                   ZSWAP
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, DCONJG, DIMAG, MAX, MIN, SQRT
@@ -275,7 +273,8 @@
      $      CALL ZCOPY( K-1, A( 1, K ), 1, W( 1, KW ), 1 )
          W( K, KW ) = DBLE( A( K, K ) )
          IF( K.LT.N ) THEN
-            CALL ZGEMV( 'No transpose', K, N-K, -CONE, A( 1, K+1 ), LDA,
+            CALL ZGEMV( 'No transpose', K, N-K, -CONE, A( 1, K+1 ),
+     $                  LDA,
      $                  W( K, KW+1 ), LDW, CONE, W( 1, KW ), 1 )
             W( K, KW ) = DBLE( W( K, KW ) )
          END IF
@@ -335,7 +334,8 @@
 *                 Copy column IMAX to column KW-1 of W and update it
 *
                   IF( IMAX.GT.1 )
-     $               CALL ZCOPY( IMAX-1, A( 1, IMAX ), 1, W( 1, KW-1 ),
+     $               CALL ZCOPY( IMAX-1, A( 1, IMAX ), 1, W( 1,
+     $                           KW-1 ),
      $                           1 )
                   W( IMAX, KW-1 ) = DBLE( A( IMAX, IMAX ) )
 *
@@ -373,7 +373,7 @@
 *
 *                 Case(2)
 *                 Equivalent to testing for
-*                 ABS( REAL( W( IMAX,KW-1 ) ) ).GE.ALPHA*ROWMAX
+*                 ABS( DBLE( W( IMAX,KW-1 ) ) ).GE.ALPHA*ROWMAX
 *                 (used to handle NaN and Inf)
 *
                   IF( .NOT.( ABS( DBLE( W( IMAX,KW-1 ) ) )
@@ -512,7 +512,7 @@
 *                 A(1:k-1,k) := U(1:k-1,k) = W(1:k-1,kw)/D(k,k)
 *
 *              (NOTE: No need to use for Hermitian matrix
-*              A( K, K ) = REAL( W( K, K) ) to separately copy diagonal
+*              A( K, K ) = DBLE( W( K, K) ) to separately copy diagonal
 *              element D(k,k) from W (potentially saves only one load))
                CALL ZCOPY( K, W( 1, KW ), 1, A( 1, K ), 1 )
                IF( K.GT.1 ) THEN
@@ -799,7 +799,8 @@
 *
 *                 Copy column IMAX to column k+1 of W and update it
 *
-                  CALL ZCOPY( IMAX-K, A( IMAX, K ), LDA, W( K, K+1 ), 1)
+                  CALL ZCOPY( IMAX-K, A( IMAX, K ), LDA, W( K, K+1 ),
+     $                        1)
                   CALL ZLACGV( IMAX-K, W( K, K+1 ), 1 )
                   W( IMAX, K+1 ) = DBLE( A( IMAX, IMAX ) )
 *
@@ -826,7 +827,8 @@
                   END IF
 *
                   IF( IMAX.LT.N ) THEN
-                     ITEMP = IMAX + IZAMAX( N-IMAX, W( IMAX+1, K+1 ), 1)
+                     ITEMP = IMAX + IZAMAX( N-IMAX, W( IMAX+1, K+1 ),
+     $                                      1)
                      DTEMP = CABS1( W( ITEMP, K+1 ) )
                      IF( DTEMP.GT.ROWMAX ) THEN
                         ROWMAX = DTEMP
@@ -836,7 +838,7 @@
 *
 *                 Case(2)
 *                 Equivalent to testing for
-*                 ABS( REAL( W( IMAX,K+1 ) ) ).GE.ALPHA*ROWMAX
+*                 ABS( DBLE( W( IMAX,K+1 ) ) ).GE.ALPHA*ROWMAX
 *                 (used to handle NaN and Inf)
 *
                   IF( .NOT.( ABS( DBLE( W( IMAX,K+1 ) ) )
@@ -849,7 +851,8 @@
 *
 *                    copy column K+1 of W to column K of W
 *
-                     CALL ZCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ), 1 )
+                     CALL ZCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ),
+     $                           1 )
 *
                      DONE = .TRUE.
 *
@@ -878,7 +881,8 @@
 *
 *                    Copy updated JMAXth (next IMAXth) column to Kth of W
 *
-                     CALL ZCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ), 1 )
+                     CALL ZCOPY( N-K+1, W( K, K+1 ), 1, W( K, K ),
+     $                           1 )
 *
                   END IF
 *
@@ -938,7 +942,8 @@
      $                     LDA )
                CALL ZLACGV( KP-KK-1, A( KP, KK+1 ), LDA )
                IF( KP.LT.N )
-     $            CALL ZCOPY( N-KP, A( KP+1, KK ), 1, A( KP+1, KP ), 1 )
+     $            CALL ZCOPY( N-KP, A( KP+1, KK ), 1, A( KP+1, KP ),
+     $                        1 )
 *
 *              Interchange rows KK and KP in first K-1 columns of A
 *              (column K (or K and K+1 for 2-by-2 pivot) of A will be
@@ -966,7 +971,7 @@
 *                 A(k+1:N,k) := L(k+1:N,k) = W(k+1:N,k)/D(k,k)
 *
 *              (NOTE: No need to use for Hermitian matrix
-*              A( K, K ) = REAL( W( K, K) ) to separately copy diagonal
+*              A( K, K ) = DBLE( W( K, K) ) to separately copy diagonal
 *              element D(k,k) from W (potentially saves only one load))
                CALL ZCOPY( N-K+1, W( K, K ), 1, A( K, K ), 1 )
                IF( K.LT.N ) THEN
