@@ -242,7 +242,8 @@
 *> \endverbatim
 *>
 *  =====================================================================
-      DOUBLE PRECISION FUNCTION ZLANHF( NORM, TRANSR, UPLO, N, A, WORK )
+      DOUBLE PRECISION FUNCTION ZLANHF( NORM, TRANSR, UPLO, N, A,
+     $                                  WORK )
 *
 *  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
@@ -677,7 +678,8 @@
                END IF
             END IF
          END IF
-      ELSE IF( ( LSAME( NORM, 'I' ) ) .OR. ( LSAME( NORM, 'O' ) ) .OR.
+      ELSE IF( ( LSAME( NORM, 'I' ) ) .OR.
+     $         ( LSAME( NORM, 'O' ) ) .OR.
      $         ( NORM.EQ.'1' ) ) THEN
 *
 *       Find normI(A) ( = norm1(A), since A is Hermitian).
@@ -1129,7 +1131,8 @@
                END IF
             END IF
          END IF
-      ELSE IF( ( LSAME( NORM, 'F' ) ) .OR. ( LSAME( NORM, 'E' ) ) ) THEN
+      ELSE IF( ( LSAME( NORM, 'F' ) ) .OR.
+     $         ( LSAME( NORM, 'E' ) ) ) THEN
 *
 *       Find normF(A).
 *
@@ -1143,7 +1146,8 @@
                IF( ILU.EQ.0 ) THEN
 *                 A is upper
                   DO J = 0, K - 3
-                     CALL ZLASSQ( K-J-2, A( K+J+1+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( K-J-2, A( K+J+1+J*LDA ), 1, SCALE,
+     $                            S )
 *                    L at A(k,0)
                   END DO
                   DO J = 0, K - 1
@@ -1190,11 +1194,13 @@
                ELSE
 *                 ilu=1 & A is lower
                   DO J = 0, K - 1
-                     CALL ZLASSQ( N-J-1, A( J+1+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( N-J-1, A( J+1+J*LDA ), 1, SCALE,
+     $                            S )
 *                    trap L at A(0,0)
                   END DO
                   DO J = 1, K - 2
-                     CALL ZLASSQ( J, A( 0+( 1+J )*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( J, A( 0+( 1+J )*LDA ), 1, SCALE,
+     $                            S )
 *                    U at A(0,1)
                   END DO
                   S = S + S
@@ -1240,7 +1246,8 @@
                IF( ILU.EQ.0 ) THEN
 *                 A**H is upper
                   DO J = 1, K - 2
-                     CALL ZLASSQ( J, A( 0+( K+J )*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( J, A( 0+( K+J )*LDA ), 1, SCALE,
+     $                            S )
 *                    U at A(0,k)
                   END DO
                   DO J = 0, K - 2
@@ -1302,7 +1309,8 @@
 *                    k by k-1 rect. at A(0,k)
                   END DO
                   DO J = 0, K - 3
-                     CALL ZLASSQ( K-J-2, A( J+2+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( K-J-2, A( J+2+J*LDA ), 1, SCALE,
+     $                            S )
 *                    L at A(1,0)
                   END DO
                   S = S + S
@@ -1352,7 +1360,8 @@
                IF( ILU.EQ.0 ) THEN
 *                 A is upper
                   DO J = 0, K - 2
-                     CALL ZLASSQ( K-J-1, A( K+J+2+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( K-J-1, A( K+J+2+J*LDA ), 1, SCALE,
+     $                            S )
 *                 L at A(k+1,0)
                   END DO
                   DO J = 0, K - 1
@@ -1389,7 +1398,8 @@
                ELSE
 *                 ilu=1 & A is lower
                   DO J = 0, K - 1
-                     CALL ZLASSQ( N-J-1, A( J+2+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( N-J-1, A( J+2+J*LDA ), 1, SCALE,
+     $                            S )
 *                    trap L at A(1,0)
                   END DO
                   DO J = 1, K - 1
@@ -1429,7 +1439,8 @@
                IF( ILU.EQ.0 ) THEN
 *                 A**H is upper
                   DO J = 1, K - 1
-                     CALL ZLASSQ( J, A( 0+( K+1+J )*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( J, A( 0+( K+1+J )*LDA ), 1, SCALE,
+     $                            S )
 *                 U at A(0,k+1)
                   END DO
                   DO J = 0, K - 1
@@ -1437,7 +1448,8 @@
 *                 k by k rect. at A(0,0)
                   END DO
                   DO J = 0, K - 2
-                     CALL ZLASSQ( K-J-1, A( J+1+( J+K )*LDA ), 1, SCALE,
+                     CALL ZLASSQ( K-J-1, A( J+1+( J+K )*LDA ), 1,
+     $                            SCALE,
      $                            S )
 *                 L at A(0,k)
                   END DO
@@ -1495,7 +1507,8 @@
                ELSE
 *                 A**H is lower
                   DO J = 1, K - 1
-                     CALL ZLASSQ( J, A( 0+( J+1 )*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( J, A( 0+( J+1 )*LDA ), 1, SCALE,
+     $                            S )
 *                 U at A(0,1)
                   END DO
                   DO J = K + 1, N
@@ -1503,7 +1516,8 @@
 *                 k by k rect. at A(0,k+1)
                   END DO
                   DO J = 0, K - 2
-                     CALL ZLASSQ( K-J-1, A( J+1+J*LDA ), 1, SCALE, S )
+                     CALL ZLASSQ( K-J-1, A( J+1+J*LDA ), 1, SCALE,
+     $                            S )
 *                 L at A(0,0)
                   END DO
                   S = S + S
