@@ -266,7 +266,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complex16OTHERauxiliary
+*> \ingroup larrv
 *
 *> \par Contributors:
 *  ==================
@@ -334,7 +334,8 @@
       EXTERNAL           DLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DCOPY, DLARRB, DLARRF, ZDSCAL, ZLAR1V,
+      EXTERNAL           DCOPY, DLARRB, DLARRF, ZDSCAL,
+     $                   ZLAR1V,
      $                   ZLASET
 *     ..
 *     .. Intrinsic Functions ..
@@ -348,7 +349,7 @@
 *
 *     Quick return if possible
 *
-      IF( N.LE.0 ) THEN
+      IF( (N.LE.0).OR.(M.LE.0) ) THEN
          RETURN
       END IF
 *
