@@ -158,7 +158,11 @@
 *> \endverbatim
 *>
 *> \param[in] LWORK
+*> \verbatim
 *>          LWORK is INTEGER
+*>          The dimension of the array WORK.
+*>
+*>          If MIN(N,NRHS) = 0, LWORK >= 1, else
 *>          LWORK >= MAX(1, 2*NBA * MAX(NBA, MIN(NRHS, 32)), where
 *>          NBA = (N + NB - 1)/NB and NB is the optimal block size.
 *>
@@ -166,6 +170,7 @@
 *>          only calculates the optimal dimensions of the WORK array, returns
 *>          this value as the first entry of the WORK array, and no error
 *>          message related to LWORK is issued by XERBLA.
+*> \endverbatim
 *>
 *> \param[out] INFO
 *> \verbatim
@@ -257,7 +262,7 @@
       LOGICAL            LQUERY, NOTRAN, NOUNIT, UPPER
       INTEGER            AWRK, I, IFIRST, IINC, ILAST, II, I1, I2, J,
      $                   JFIRST, JINC, JLAST, J1, J2, K, KK, K1, K2,
-     $                   LANRM, LDS, LSCALE, NB, NBA, NBX, RHS
+     $                   LANRM, LDS, LSCALE, NB, NBA, NBX, RHS, LWMIN
       DOUBLE PRECISION   ANRM, BIGNUM, BNRM, RSCAL, SCAL, SCALOC,
      $                   SCAMIN, SMLNUM, TMAX
 *     ..
@@ -265,7 +270,8 @@
       LOGICAL            LSAME
       INTEGER            ILAENV
       DOUBLE PRECISION   DLAMCH, ZLANGE, DLARMM
-      EXTERNAL           ILAENV, LSAME, DLAMCH, ZLANGE, DLARMM
+      EXTERNAL           ILAENV, LSAME, DLAMCH, ZLANGE,
+     $                   DLARMM
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ZLATRS, ZDSCAL, XERBLA
@@ -296,15 +302,24 @@
 *     row. WORK( I + KK * LDS ) is the scale factor of the vector
 *     segment associated with the I-th block row and the KK-th vector
 *     in the block column.
+*
       LSCALE = NBA * MAX( NBA, MIN( NRHS, NBRHS ) )
       LDS = NBA
+*
 *     The second part stores upper bounds of the triangular A. There are
 *     a total of NBA x NBA blocks, of which only the upper triangular
 *     part or the lower triangular part is referenced. The upper bound of
 *     the block A( I, J ) is stored as WORK( AWRK + I + J * NBA ).
+*
       LANRM = NBA * NBA
       AWRK = LSCALE
-      WORK( 1 ) = LSCALE + LANRM
+*
+      IF( MIN( N, NRHS ).EQ.0 ) THEN
+         LWMIN = 1
+      ELSE
+         LWMIN = LSCALE + LANRM
+      END IF
+      WORK( 1 ) = LWMIN
 *
 *     Test the input parameters.
 *
@@ -326,7 +341,7 @@
          INFO = -8
       ELSE IF( LDX.LT.MAX( 1, N ) ) THEN
          INFO = -10
-      ELSE IF( .NOT.LQUERY .AND. LWORK.LT.WORK( 1 ) ) THEN
+      ELSE IF( .NOT.LQUERY .AND. LWORK.LT.LWMIN ) THEN
          INFO = -14
       END IF
       IF( INFO.NE.0 ) THEN
@@ -358,7 +373,8 @@
          CALL ZLATRS( UPLO, TRANS, DIAG, NORMIN, N, A, LDA, X( 1, 1),
      $                SCALE( 1 ), CNORM, INFO )
          DO K = 2, NRHS
-            CALL ZLATRS( UPLO, TRANS, DIAG, 'Y', N, A, LDA, X( 1, K ),
+            CALL ZLATRS( UPLO, TRANS, DIAG, 'Y', N, A, LDA, X( 1,
+     $                   K ),
      $                   SCALE( K ), CNORM, INFO )
          END DO
          RETURN
@@ -385,10 +401,12 @@
 *           Compute upper bound of A( I1:I2-1, J1:J2-1 ).
 *
             IF( NOTRAN ) THEN
-               ANRM = ZLANGE( 'I', I2-I1, J2-J1, A( I1, J1 ), LDA, W )
+               ANRM = ZLANGE( 'I', I2-I1, J2-J1, A( I1, J1 ), LDA,
+     $                        W )
                WORK( AWRK + I+(J-1)*NBA ) = ANRM
             ELSE
-               ANRM = ZLANGE( '1', I2-I1, J2-J1, A( I1, J1 ), LDA, W )
+               ANRM = ZLANGE( '1', I2-I1, J2-J1, A( I1, J1 ), LDA,
+     $                        W )
                WORK( AWRK + J+(I-1) * NBA ) = ANRM
             END IF
             TMAX = MAX( TMAX, ANRM )
@@ -405,7 +423,8 @@
 *        in the computation of the column norms CNORM.
 *
          DO K = 1, NRHS
-            CALL ZLATRS( UPLO, TRANS, DIAG, 'N', N, A, LDA, X( 1, K ),
+            CALL ZLATRS( UPLO, TRANS, DIAG, 'N', N, A, LDA, X( 1,
+     $                   K ),
      $                   SCALE( K ), CNORM, INFO )
          END DO
          RETURN
@@ -588,7 +607,8 @@
 *                 Compute scaling factor to survive the linear update
 *                 simulating consistent scaling.
 *
-                  BNRM = ZLANGE( 'I', I2-I1, 1, X( I1, RHS ), LDX, W )
+                  BNRM = ZLANGE( 'I', I2-I1, 1, X( I1, RHS ), LDX,
+     $                           W )
                   BNRM = BNRM*( SCAMIN / WORK( I+KK*LDS ) )
                   XNRM( KK ) = XNRM( KK )*( SCAMIN / WORK( J+KK*LDS) )
                   ANRM = WORK( AWRK + I+(J-1)*NBA )
