@@ -184,7 +184,8 @@
 *           Compute elements 1:J-1 of column J.
 *
             IF( J.GT.1 )
-     $         CALL ZTPSV( 'Upper', 'Conjugate transpose', 'Non-unit',
+     $         CALL ZTPSV( 'Upper', 'Conjugate transpose',
+     $                     'Non-unit',
      $                     J-1, AP, AP( JC ), 1 )
 *
 *           Compute U(J,J) and test for non-positive-definiteness.
