@@ -101,17 +101,14 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
-*> \ingroup complex16OTHERcomputational
+*> \ingroup pptrs
 *
 *  =====================================================================
       SUBROUTINE ZPPTRS( UPLO, N, NRHS, AP, B, LDB, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -170,7 +167,8 @@
 *
 *           Solve U**H *X = B, overwriting B with X.
 *
-            CALL ZTPSV( 'Upper', 'Conjugate transpose', 'Non-unit', N,
+            CALL ZTPSV( 'Upper', 'Conjugate transpose', 'Non-unit',
+     $                  N,
      $                  AP, B( 1, I ), 1 )
 *
 *           Solve U*X = B, overwriting B with X.
@@ -191,7 +189,8 @@
 *
 *           Solve L**H *X = Y, overwriting B with X.
 *
-            CALL ZTPSV( 'Lower', 'Conjugate transpose', 'Non-unit', N,
+            CALL ZTPSV( 'Lower', 'Conjugate transpose', 'Non-unit',
+     $                  N,
      $                  AP, B( 1, I ), 1 )
    20    CONTINUE
       END IF
