@@ -199,7 +199,8 @@
 *> \endverbatim
 *
 *  =====================================================================
-      SUBROUTINE ZSYSV_ROOK( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, WORK,
+      SUBROUTINE ZSYSV_ROOK( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+     $                       WORK,
      $                  LWORK, INFO )
 *
 *  -- LAPACK driver routine --
@@ -237,7 +238,8 @@
 *
       INFO = 0
       LQUERY = ( LWORK.EQ.-1 )
-      IF( .NOT.LSAME( UPLO, 'U' ) .AND. .NOT.LSAME( UPLO, 'L' ) ) THEN
+      IF( .NOT.LSAME( UPLO, 'U' ) .AND.
+     $    .NOT.LSAME( UPLO, 'L' ) ) THEN
          INFO = -1
       ELSE IF( N.LT.0 ) THEN
          INFO = -2
@@ -277,7 +279,8 @@
 *
 *        Solve with TRS_ROOK ( Use Level 2 BLAS)
 *
-         CALL ZSYTRS_ROOK( UPLO, N, NRHS, A, LDA, IPIV, B, LDB, INFO )
+         CALL ZSYTRS_ROOK( UPLO, N, NRHS, A, LDA, IPIV, B, LDB,
+     $                     INFO )
 *
       END IF
 *
