@@ -142,9 +142,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2017
-*
-*> \ingroup complex16SYcomputational
+*> \ingroup hetri_3x
 *
 *> \par Contributors:
 *  ==================
@@ -157,12 +155,12 @@
 *> \endverbatim
 *
 *  =====================================================================
-      SUBROUTINE ZSYTRI_3X( UPLO, N, A, LDA, E, IPIV, WORK, NB, INFO )
+      SUBROUTINE ZSYTRI_3X( UPLO, N, A, LDA, E, IPIV, WORK, NB,
+     $                      INFO )
 *
-*  -- LAPACK computational routine (version 3.7.1) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2017
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -191,7 +189,8 @@
       EXTERNAL           LSAME
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZGEMM, ZSYSWAPR, ZTRTRI, ZTRMM, XERBLA
+      EXTERNAL           ZGEMM, ZSYSWAPR, ZTRTRI, ZTRMM,
+     $                   XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MOD
@@ -436,8 +435,10 @@
          DO I = 1, N
              IP = ABS( IPIV( I ) )
              IF( IP.NE.I ) THEN
-                IF (I .LT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, I ,IP )
-                IF (I .GT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, IP ,I )
+                IF (I .LT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, I ,
+     $               IP )
+                IF (I .GT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, IP ,
+     $               I )
              END IF
          END DO
 *
@@ -632,8 +633,10 @@
          DO I = N, 1, -1
              IP = ABS( IPIV( I ) )
              IF( IP.NE.I ) THEN
-                IF (I .LT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, I ,IP )
-                IF (I .GT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, IP ,I )
+                IF (I .LT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, I ,
+     $               IP )
+                IF (I .GT. IP) CALL ZSYSWAPR( UPLO, N, A, LDA, IP ,
+     $               I )
              END IF
          END DO
 *
