@@ -142,7 +142,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complex16SYcomputational
+*> \ingroup hetrs_3
 *
 *> \par Contributors:
 *  ==================
@@ -246,7 +246,8 @@
 *
 *        Compute (U \P**T * B) -> B    [ (U \P**T * B) ]
 *
-         CALL ZTRSM( 'L', 'U', 'N', 'U', N, NRHS, ONE, A, LDA, B, LDB )
+         CALL ZTRSM( 'L', 'U', 'N', 'U', N, NRHS, ONE, A, LDA, B,
+     $               LDB )
 *
 *        Compute D \ B -> B   [ D \ (U \P**T * B) ]
 *
@@ -272,7 +273,8 @@
 *
 *        Compute (U**T \ B) -> B   [ U**T \ (D \ (U \P**T * B) ) ]
 *
-         CALL ZTRSM( 'L', 'U', 'T', 'U', N, NRHS, ONE, A, LDA, B, LDB )
+         CALL ZTRSM( 'L', 'U', 'T', 'U', N, NRHS, ONE, A, LDA, B,
+     $               LDB )
 *
 *        P * B  [ P * (U**T \ (D \ (U \P**T * B) )) ]
 *
@@ -313,7 +315,8 @@
 *
 *        Compute (L \P**T * B) -> B    [ (L \P**T * B) ]
 *
-         CALL ZTRSM( 'L', 'L', 'N', 'U', N, NRHS, ONE, A, LDA, B, LDB )
+         CALL ZTRSM( 'L', 'L', 'N', 'U', N, NRHS, ONE, A, LDA, B,
+     $               LDB )
 *
 *        Compute D \ B -> B   [ D \ (L \P**T * B) ]
 *
@@ -339,7 +342,8 @@
 *
 *        Compute (L**T \ B) -> B   [ L**T \ (D \ (L \P**T * B) ) ]
 *
-         CALL ZTRSM('L', 'L', 'T', 'U', N, NRHS, ONE, A, LDA, B, LDB )
+         CALL ZTRSM('L', 'L', 'T', 'U', N, NRHS, ONE, A, LDA, B,
+     $               LDB )
 *
 *        P * B  [ P * (L**T \ (D \ (L \P**T * B) )) ]
 *
