@@ -37,7 +37,7 @@
 *>\verbatim
 *>
 *> ZUNBDB2 simultaneously bidiagonalizes the blocks of a tall and skinny
-*> matrix X with orthonomal columns:
+*> matrix X with orthonormal columns:
 *>
 *>                            [ B11 ]
 *>      [ X11 ]   [ P1 |    ] [  0  ]
@@ -172,7 +172,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complex16OTHERcomputational
+*> \ingroup unbdb2
 *
 *> \par Further Details:
 *  =====================
@@ -196,7 +196,8 @@
 *>      Algorithms, 50(1):33-65, 2009.
 *>
 *  =====================================================================
-      SUBROUTINE ZUNBDB2( M, P, Q, X11, LDX11, X21, LDX21, THETA, PHI,
+      SUBROUTINE ZUNBDB2( M, P, Q, X11, LDX11, X21, LDX21, THETA,
+     $                    PHI,
      $                    TAUP1, TAUP2, TAUQ1, WORK, LWORK, INFO )
 *
 *  -- LAPACK computational routine --
@@ -226,7 +227,8 @@
       LOGICAL            LQUERY
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ZLARF, ZLARFGP, ZUNBDB5, ZDROT, ZSCAL, ZLACGV,
+      EXTERNAL           ZLARF1F, ZLARFGP, ZUNBDB5, ZDROT, ZSCAL,
+     $                   ZLACGV,
      $                   XERBLA
 *     ..
 *     .. External Functions ..
@@ -287,11 +289,10 @@
          CALL ZLACGV( Q-I+1, X11(I,I), LDX11 )
          CALL ZLARFGP( Q-I+1, X11(I,I), X11(I,I+1), LDX11, TAUQ1(I) )
          C = DBLE( X11(I,I) )
-         X11(I,I) = ONE
-         CALL ZLARF( 'R', P-I, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
-     $               X11(I+1,I), LDX11, WORK(ILARF) )
-         CALL ZLARF( 'R', M-P-I+1, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
-     $               X21(I,I), LDX21, WORK(ILARF) )
+         CALL ZLARF1F( 'R', P-I, Q-I+1, X11(I,I), LDX11, TAUQ1(I),
+     $                 X11(I+1,I), LDX11, WORK(ILARF) )
+         CALL ZLARF1F( 'R', M-P-I+1, Q-I+1, X11(I,I), LDX11,
+     $                 TAUQ1(I), X21(I,I), LDX21, WORK(ILARF) )
          CALL ZLACGV( Q-I+1, X11(I,I), LDX11 )
          S = SQRT( DZNRM2( P-I, X11(I+1,I), 1 )**2
      $           + DZNRM2( M-P-I+1, X21(I,I), 1 )**2 )
@@ -307,13 +308,13 @@
             PHI(I) = ATAN2( DBLE( X11(I+1,I) ), DBLE( X21(I,I) ) )
             C = COS( PHI(I) )
             S = SIN( PHI(I) )
-            X11(I+1,I) = ONE
-            CALL ZLARF( 'L', P-I, Q-I, X11(I+1,I), 1, DCONJG(TAUP1(I)),
-     $                  X11(I+1,I+1), LDX11, WORK(ILARF) )
+            CALL ZLARF1F( 'L', P-I, Q-I, X11(I+1,I), 1,
+     $                    CONJG(TAUP1(I)),
+     $                    X11(I+1,I+1), LDX11, WORK(ILARF) )
          END IF
-         X21(I,I) = ONE
-         CALL ZLARF( 'L', M-P-I+1, Q-I, X21(I,I), 1, DCONJG(TAUP2(I)),
-     $               X21(I,I+1), LDX21, WORK(ILARF) )
+         CALL ZLARF1F( 'L', M-P-I+1, Q-I, X21(I,I), 1,
+     $                 CONJG(TAUP2(I)), X21(I,I+1), LDX21,
+     $                 WORK(ILARF) )
 *
       END DO
 *
@@ -321,9 +322,9 @@
 *
       DO I = P + 1, Q
          CALL ZLARFGP( M-P-I+1, X21(I,I), X21(I+1,I), 1, TAUP2(I) )
-         X21(I,I) = ONE
-         CALL ZLARF( 'L', M-P-I+1, Q-I, X21(I,I), 1, DCONJG(TAUP2(I)),
-     $               X21(I,I+1), LDX21, WORK(ILARF) )
+         CALL ZLARF1F( 'L', M-P-I+1, Q-I, X21(I,I), 1,
+     $                 CONJG(TAUP2(I)), X21(I,I+1), LDX21,
+     $                 WORK(ILARF) )
       END DO
 *
       RETURN
