@@ -21,7 +21,7 @@
 *       .. Array Arguments ..
 *       LOGICAL            DOTYPE( * ), SELECT( * )
 *       INTEGER            ISEED( 4 ), IWORK( * ), NN( * )
-*       REAL               RESULT( 14 ), RWORK( * )
+*       REAL               RESULT( 16 ), RWORK( * )
 *       COMPLEX            A( LDA, * ), EVECTL( LDU, * ),
 *      $                   EVECTR( LDU, * ), EVECTX( LDU, * ),
 *      $                   EVECTY( LDU, * ), H( LDA, * ), T1( LDA, * ),
@@ -64,10 +64,15 @@
 *>            eigenvectors of H.  Y is lower triangular, and X is
 *>            upper triangular.
 *>
+*>            CTREVC3 computes left and right eigenvector matrices
+*>            from a Schur matrix T and backtransforms them with Z
+*>            to eigenvector matrices L and R for A. L and R are
+*>            GE matrices.
+*>
 *>    When CCHKHS is called, a number of matrix "sizes" ("n's") and a
 *>    number of matrix "types" are specified.  For each size ("n")
 *>    and each type of matrix, one matrix will be generated and used
-*>    to test the nonsymmetric eigenroutines.  For each matrix, 14
+*>    to test the nonsymmetric eigenroutines.  For each matrix, 16
 *>    tests will be performed:
 *>
 *>    (1)     | A - U H U**H | / ( |A| n ulp )
@@ -98,6 +103,10 @@
 *>
 *>    (14)    | Y**H A - W**H Y | / ( |A| |Y| ulp )
 *>
+*>    (15)    | AR - RW | / ( |A| |R| ulp )
+*>
+*>    (16)    | LA - WL | / ( |A| |L| ulp )
+*>
 *>    The "sizes" are specified by an array NN(1:NSIZES); the value of
 *>    each element NN(j) specifies one size.
 *>    The "types" are specified by a logical array DOTYPE( 1:NTYPES );
@@ -331,7 +340,7 @@
 *>           Workspace.  Could be equivalenced to IWORK, but not RWORK.
 *>           Modified.
 *>
-*>  RESULT - REAL array, dimension (14)
+*>  RESULT - REAL array, dimension (16)
 *>           The values computed by the fourteen tests described above.
 *>           The values are currently limited to 1/ulp, to avoid
 *>           overflow.
@@ -401,8 +410,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup complex_eig
 *
 *  =====================================================================
@@ -412,10 +419,9 @@
      $                   WORK, NWORK, RWORK, IWORK, SELECT, RESULT,
      $                   INFO )
 *
-*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDU, NOUNIT, NSIZES, NTYPES, NWORK
@@ -424,7 +430,7 @@
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * ), SELECT( * )
       INTEGER            ISEED( 4 ), IWORK( * ), NN( * )
-      REAL               RESULT( 14 ), RWORK( * )
+      REAL               RESULT( 16 ), RWORK( * )
       COMPLEX            A( LDA, * ), EVECTL( LDU, * ),
      $                   EVECTR( LDU, * ), EVECTX( LDU, * ),
      $                   EVECTY( LDU, * ), H( LDA, * ), T1( LDA, * ),
@@ -466,8 +472,8 @@
 *     .. External Subroutines ..
       EXTERNAL           CCOPY, CGEHRD, CGEMM, CGET10, CGET22, CHSEIN,
      $                   CHSEQR, CHST01, CLACPY, CLASET, CLATME, CLATMR,
-     $                   CLATMS, CTREVC, CUNGHR, CUNMHR, SLABAD, SLAFTS,
-     $                   SLASUM, XERBLA
+     $                   CLATMS, CTREVC, CTREVC3, CUNGHR, CUNMHR,
+     $                   SLAFTS, SLASUM, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MIN, REAL, SQRT
@@ -527,7 +533,6 @@
 *
       UNFL = SLAMCH( 'Safe minimum' )
       OVFL = SLAMCH( 'Overflow' )
-      CALL SLABAD( UNFL, OVFL )
       ULP = SLAMCH( 'Epsilon' )*SLAMCH( 'Base' )
       ULPINV = ONE / ULP
       RTUNFL = SQRT( UNFL )
@@ -1070,6 +1075,66 @@
      $            RESULT( 14 ) = DUMMA( 3 )*ANINV
             END IF
 *
+*           Compute Left and Right Eigenvectors of A
+*
+*           Compute a Right eigenvector matrix:
+*
+            NTEST = 15
+            RESULT( 15 ) = ULPINV
+*
+            CALL CLACPY( ' ', N, N, UZ, LDU, EVECTR, LDU )
+*
+            CALL CTREVC3( 'Right', 'Back', SELECT, N, T1, LDA, CDUMMA,
+     $                    LDU, EVECTR, LDU, N, IN, WORK, NWORK, RWORK,
+     $                    N, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC3(R,B)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 250
+            END IF
+*
+*           Test 15:  | AR - RW | / ( |A| |R| ulp )
+*
+*                     (from Schur decomposition)
+*
+            CALL CGET22( 'N', 'N', 'N', N, A, LDA, EVECTR, LDU, W1,
+     $                   WORK, RWORK, DUMMA( 1 ) )
+            RESULT( 15 ) = DUMMA( 1 )
+            IF( DUMMA( 2 ).GT.THRESH ) THEN
+               WRITE( NOUNIT, FMT = 9998 )'Right', 'CTREVC3',
+     $            DUMMA( 2 ), N, JTYPE, IOLDSD
+            END IF
+*
+*           Compute a Left eigenvector matrix:
+*
+            NTEST = 16
+            RESULT( 16 ) = ULPINV
+*
+            CALL CLACPY( ' ', N, N, UZ, LDU, EVECTL, LDU )
+*
+            CALL CTREVC3( 'Left', 'Back', SELECT, N, T1, LDA, EVECTL,
+     $                    LDU, CDUMMA, LDU, N, IN, WORK, NWORK, RWORK,
+     $                    N, IINFO )
+            IF( IINFO.NE.0 ) THEN
+               WRITE( NOUNIT, FMT = 9999 )'CTREVC3(L,B)', IINFO, N,
+     $            JTYPE, IOLDSD
+               INFO = ABS( IINFO )
+               GO TO 250
+            END IF
+*
+*           Test 16:  | LA - WL | / ( |A| |L| ulp )
+*
+*                     (from Schur decomposition)
+*
+            CALL CGET22( 'Conj', 'N', 'Conj', N, A, LDA, EVECTL, LDU,
+     $                   W1, WORK, RWORK, DUMMA( 3 ) )
+            RESULT( 16 ) = DUMMA( 3 )
+            IF( DUMMA( 4 ).GT.THRESH ) THEN
+               WRITE( NOUNIT, FMT = 9998 )'Left', 'CTREVC3', DUMMA( 4 ),
+     $            N, JTYPE, IOLDSD
+            END IF
+*
 *           End of Loop -- Check for RESULT(j) > THRESH
 *
   240       CONTINUE
