@@ -2,8 +2,8 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *  Definition:
 *  ===========
@@ -11,7 +11,7 @@
 *       SUBROUTINE CCSDTS( M, P, Q, X, XF, LDX, U1, LDU1, U2, LDU2, V1T,
 *                          LDV1T, V2T, LDV2T, THETA, IWORK, WORK, LWORK,
 *                          RWORK, RESULT )
-* 
+*
 *       .. Scalar Arguments ..
 *       INTEGER            LDX, LDU1, LDU2, LDV1T, LDV2T, LWORK, M, P, Q
 *       ..
@@ -22,7 +22,7 @@
 *      $                   V2T( LDV2T, * ), WORK( LWORK ), X( LDX, * ),
 *      $                   XF( LDX, * )
 *       ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -215,12 +215,10 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
-*
-*> \date November 2015
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
 *> \ingroup complex_eig
 *
@@ -229,10 +227,9 @@
      $                   LDV1T, V2T, LDV2T, THETA, IWORK, WORK, LWORK,
      $                   RWORK, RESULT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
 *
 *     .. Scalar Arguments ..
       INTEGER            LDX, LDU1, LDU2, LDV1T, LDV2T, LWORK, M, P, Q
@@ -248,11 +245,12 @@
 *  =====================================================================
 *
 *     .. Parameters ..
-      REAL               PIOVER2, REALONE, REALZERO
-      PARAMETER          ( PIOVER2 = 1.57079632679489662E0,
-     $                     REALONE = 1.0E0, REALZERO = 0.0E0 )
+      REAL               REALONE, REALZERO
+      PARAMETER          ( REALONE = 1.0E0, REALZERO = 0.0E0 )
       COMPLEX            ZERO, ONE
       PARAMETER          ( ZERO = (0.0E0,0.0E0), ONE = (1.0E0,0.0E0) )
+      REAL               PIOVER2
+      PARAMETER ( PIOVER2 = 1.57079632679489661923132169163975144210E0 )
 *     ..
 *     .. Local Scalars ..
       INTEGER            I, INFO, R
@@ -280,7 +278,7 @@
       CALL CHERK( 'Upper', 'Conjugate transpose', M, M, -REALONE,
      $            X, LDX, REALONE, WORK, LDX )
       IF (M.GT.0) THEN
-         EPS2 = MAX( ULP, 
+         EPS2 = MAX( ULP,
      $               CLANGE( '1', M, M, WORK, LDX, RWORK ) / REAL( M ) )
       ELSE
          EPS2 = ULP
@@ -446,7 +444,7 @@
       CALL CHERK( 'Upper', 'Conjugate transpose', Q, M, -REALONE,
      $            X, LDX, REALONE, WORK, LDX )
       IF (M.GT.0) THEN
-         EPS2 = MAX( ULP, 
+         EPS2 = MAX( ULP,
      $               CLANGE( '1', Q, Q, WORK, LDX, RWORK ) / REAL( M ) )
       ELSE
          EPS2 = ULP
@@ -553,7 +551,7 @@
       END DO
 *
       RETURN
-*      
+*
 *     End of CCSDTS
 *
       END
