@@ -393,8 +393,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date February 2015
-*
 *> \ingroup double_eig
 *
 *  =====================================================================
@@ -403,10 +401,9 @@
      $                    ALPHAI, BETA, WORK, LWORK, RESULT, BWORK,
      $                    INFO )
 *
-*  -- LAPACK test routine (version 3.6.1) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     February 2015
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDQ, LWORK, NOUNIT, NSIZES, NTYPES
@@ -454,8 +451,8 @@
       EXTERNAL           DLCTES, ILAENV, DLAMCH, DLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASVM, DGET51, DGET53, DGET54, DGGES3, DLABAD,
-     $                   DLACPY, DLARFG, DLASET, DLATM4, DORM2R, XERBLA
+      EXTERNAL           ALASVM, DGET51, DGET53, DGET54, DGGES3, DLACPY,
+     $                   DLARFG, DLASET, DLATM4, DORM2R, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, MAX, MIN, SIGN
@@ -544,7 +541,6 @@
       ULP = DLAMCH( 'Epsilon' )*DLAMCH( 'Base' )
       SAFMIN = SAFMIN / ULP
       SAFMAX = ONE / SAFMIN
-      CALL DLABAD( SAFMIN, SAFMAX )
       ULPINV = ONE / ULP
 *
 *     The values RMAGN(2:3) depend on N, see below.
@@ -749,6 +745,14 @@
                   RSUB = 5
                END IF
 *
+*              Call XLAENV to set the parameters used in DLAQZ0
+*
+               CALL XLAENV( 12, 10 )
+               CALL XLAENV( 13, 12 )
+               CALL XLAENV( 14, 13 )
+               CALL XLAENV( 15, 2 )
+               CALL XLAENV( 17, 10 )
+*
 *              Call DGGES3 to compute H, T, Q, Z, alpha, and beta.
 *
                CALL DLACPY( 'Full', N, N, A, LDA, S, LDA )
