@@ -1,9 +1,97 @@
+*> \brief \b DGET31
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DGET31( RMAX, LMAX, NINFO, KNT )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            KNT, LMAX
+*       DOUBLE PRECISION   RMAX
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            NINFO( 2 )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> DGET31 tests DLALN2, a routine for solving
+*>
+*>    (ca A - w D)X = sB
+*>
+*> where A is an NA by NA matrix (NA=1 or 2 only), w is a real (NW=1) or
+*> complex (NW=2) constant, ca is a real constant, D is an NA by NA real
+*> diagonal matrix, and B is an NA by NW matrix (when NW=2 the second
+*> column of B contains the imaginary part of the solution).  The code
+*> returns X and s, where s is a scale factor, less than or equal to 1,
+*> which is chosen to avoid overflow in X.
+*>
+*> If any singular values of ca A-w D are less than another input
+*> parameter SMIN, they are perturbed up to SMIN.
+*>
+*> The test condition is that the scaled residual
+*>
+*>     norm( (ca A-w D)*X - s*B ) /
+*>           ( max( ulp*norm(ca A-w D), SMIN )*norm(X) )
+*>
+*> should be on the order of 1.  Here, ulp is the machine precision.
+*> Also, it is verified that SCALE is less than or equal to 1, and that
+*> XNORM = infinity-norm(X).
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[out] RMAX
+*> \verbatim
+*>          RMAX is DOUBLE PRECISION
+*>          Value of the largest test ratio.
+*> \endverbatim
+*>
+*> \param[out] LMAX
+*> \verbatim
+*>          LMAX is INTEGER
+*>          Example number where largest test ratio achieved.
+*> \endverbatim
+*>
+*> \param[out] NINFO
+*> \verbatim
+*>          NINFO is INTEGER array, dimension (2)
+*>          NINFO(1) = number of examples with INFO less than 0
+*>          NINFO(2) = number of examples with INFO greater than 0
+*> \endverbatim
+*>
+*> \param[out] KNT
+*> \verbatim
+*>          KNT is INTEGER
+*>          Total number of examples tested.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup double_eig
+*
+*  =====================================================================
       SUBROUTINE DGET31( RMAX, LMAX, NINFO, KNT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, LMAX
@@ -13,48 +101,6 @@
       INTEGER            NINFO( 2 )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  DGET31 tests DLALN2, a routine for solving
-*
-*     (ca A - w D)X = sB
-*
-*  where A is an NA by NA matrix (NA=1 or 2 only), w is a real (NW=1) or
-*  complex (NW=2) constant, ca is a real constant, D is an NA by NA real
-*  diagonal matrix, and B is an NA by NW matrix (when NW=2 the second
-*  column of B contains the imaginary part of the solution).  The code
-*  returns X and s, where s is a scale factor, less than or equal to 1,
-*  which is chosen to avoid overflow in X.
-*
-*  If any singular values of ca A-w D are less than another input
-*  parameter SMIN, they are perturbed up to SMIN.
-*
-*  The test condition is that the scaled residual
-*
-*      norm( (ca A-w D)*X - s*B ) /
-*            ( max( ulp*norm(ca A-w D), SMIN )*norm(X) )
-*
-*  should be on the order of 1.  Here, ulp is the machine precision.
-*  Also, it is verified that SCALE is less than or equal to 1, and that
-*  XNORM = infinity-norm(X).
-*
-*  Arguments
-*  ==========
-*
-*  RMAX    (output) DOUBLE PRECISION
-*          Value of the largest test ratio.
-*
-*  LMAX    (output) INTEGER
-*          Example number where largest test ratio achieved.
-*
-*  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = number of examples with INFO less than 0
-*          NINFO(2) = number of examples with INFO greater than 0
-*
-*  KNT     (output) INTEGER
-*          Total number of examples tested.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -84,7 +130,7 @@
       EXTERNAL           DLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLABAD, DLALN2
+      EXTERNAL           DLALN2
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, SQRT
@@ -100,7 +146,6 @@
       UNFL = DLAMCH( 'U' )
       SMLNUM = DLAMCH( 'S' ) / EPS
       BIGNUM = ONE / SMLNUM
-      CALL DLABAD( SMLNUM, BIGNUM )
 *
 *     Set up test case parameters
 *
@@ -228,9 +273,9 @@
                                  IF( INFO.GT.0 )
      $                              NINFO( 2 ) = NINFO( 2 ) + 1
                                  RES = ABS( ( CA*A( 1, 1 )-WR*D1 )*
-     $                                 X( 1, 1 )+WI*D1*X( 1, 2 )-SCALE*
-     $                                 B( 1, 1 ) )
-                                 RES = RES + ABS( -WI*D1*X( 1, 1 )+
+     $                                 X( 1, 1 )+( WI*D1 )*X( 1, 2 )-
+     $                                 SCALE*B( 1, 1 ) )
+                                 RES = RES + ABS( ( -WI*D1 )*X( 1, 1 )+
      $                                 ( CA*A( 1, 1 )-WR*D1 )*X( 1, 2 )-
      $                                 SCALE*B( 1, 2 ) )
                                  IF( INFO.EQ.0 ) THEN
@@ -299,11 +344,11 @@
                                  A( 2, 1 ) = TMP
                               END IF
                               RES = ABS( ( CA*A( 1, 1 )-WR*D1 )*
-     $                              X( 1, 1 )+CA*A( 1, 2 )*X( 2, 1 )-
-     $                              SCALE*B( 1, 1 ) )
-                              RES = RES + ABS( CA*A( 2, 1 )*X( 1, 1 )+
-     $                              ( CA*A( 2, 2 )-WR*D2 )*X( 2, 1 )-
-     $                              SCALE*B( 2, 1 ) )
+     $                              X( 1, 1 )+( CA*A( 1, 2 ) )*
+     $                              X( 2, 1 )-SCALE*B( 1, 1 ) )
+                              RES = RES + ABS( ( CA*A( 2, 1 ) )*
+     $                              X( 1, 1 )+( CA*A( 2, 2 )-WR*D2 )*
+     $                              X( 2, 1 )-SCALE*B( 2, 1 ) )
                               IF( INFO.EQ.0 ) THEN
                                  DEN = MAX( EPS*( MAX( ABS( CA*A( 1,
      $                                 1 )-WR*D1 )+ABS( CA*A( 1, 2 ) ),
@@ -386,20 +431,22 @@
                                     A( 2, 1 ) = TMP
                                  END IF
                                  RES = ABS( ( CA*A( 1, 1 )-WR*D1 )*
-     $                                 X( 1, 1 )+CA*A( 1, 2 )*X( 2, 1 )+
-     $                                 WI*D1*X( 1, 2 )-SCALE*B( 1, 1 ) )
+     $                                 X( 1, 1 )+( CA*A( 1, 2 ) )*
+     $                                 X( 2, 1 )+( WI*D1 )*X( 1, 2 )-
+     $                                 SCALE*B( 1, 1 ) )
                                  RES = RES + ABS( ( CA*A( 1,
-     $                                 1 )-WR*D1 )*X( 1, 2 )+CA*
-     $                                 A( 1, 2 )*X( 2, 2 )-WI*D1*
-     $                                 X( 1, 1 )-SCALE*B( 1, 2 ) )
-                                 RES = RES + ABS( CA*A( 2, 1 )*
+     $                                 1 )-WR*D1 )*X( 1, 2 )+
+     $                                 ( CA*A( 1, 2 ) )*X( 2, 2 )-
+     $                                 ( WI*D1 )*X( 1, 1 )-SCALE*
+     $                                 B( 1, 2 ) )
+                                 RES = RES + ABS( ( CA*A( 2, 1 ) )*
      $                                 X( 1, 1 )+( CA*A( 2, 2 )-WR*D2 )*
-     $                                 X( 2, 1 )+WI*D2*X( 2, 2 )-SCALE*
-     $                                 B( 2, 1 ) )
-                                 RES = RES + ABS( CA*A( 2, 1 )*
+     $                                 X( 2, 1 )+( WI*D2 )*X( 2, 2 )-
+     $                                 SCALE*B( 2, 1 ) )
+                                 RES = RES + ABS( ( CA*A( 2, 1 ) )*
      $                                 X( 1, 2 )+( CA*A( 2, 2 )-WR*D2 )*
-     $                                 X( 2, 2 )-WI*D2*X( 2, 1 )-SCALE*
-     $                                 B( 2, 2 ) )
+     $                                 X( 2, 2 )-( WI*D2 )*X( 2, 1 )-
+     $                                 SCALE*B( 2, 2 ) )
                                  IF( INFO.EQ.0 ) THEN
                                     DEN = MAX( EPS*( MAX( ABS( CA*A( 1,
      $                                    1 )-WR*D1 )+ABS( CA*A( 1,
