@@ -52,7 +52,7 @@
 *> number of matrix "TYPES" are specified.  For each size ("N")
 *> and each TYPE of matrix, a pair of matrices (A, B) will be generated
 *> and used for testing. For each matrix pair, the following 13 tests
-*> will be performed and compared with the threshhold THRESH except
+*> will be performed and compared with the threshold THRESH except
 *> the tests (5), (11) and (13).
 *>
 *>
@@ -393,8 +393,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date February 2015
-*
 *> \ingroup single_eig
 *
 *  =====================================================================
@@ -403,10 +401,9 @@
      $                    ALPHAI, BETA, WORK, LWORK, RESULT, BWORK,
      $                    INFO )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     February 2015
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDQ, LWORK, NOUNIT, NSIZES, NTYPES
@@ -454,8 +451,8 @@
       EXTERNAL           SLCTES, ILAENV, SLAMCH, SLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASVM, SGET51, SGET53, SGET54, SGGES3, SLABAD,
-     $                   SLACPY, SLARFG, SLASET, SLATM4, SORM2R, XERBLA
+      EXTERNAL           ALASVM, SGET51, SGET53, SGET54, SGGES3, SLACPY,
+     $                   SLARFG, SLASET, SLATM4, SORM2R, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MIN, REAL, SIGN
@@ -544,7 +541,6 @@
       ULP = SLAMCH( 'Epsilon' )*SLAMCH( 'Base' )
       SAFMIN = SAFMIN / ULP
       SAFMAX = ONE / SAFMIN
-      CALL SLABAD( SAFMIN, SAFMAX )
       ULPINV = ONE / ULP
 *
 *     The values RMAGN(2:3) depend on N, see below.
@@ -749,6 +745,14 @@
                   RSUB = 5
                END IF
 *
+*              Call XLAENV to set the parameters used in SLAQZ0
+*
+               CALL XLAENV( 12, 10 )
+               CALL XLAENV( 13, 12 )
+               CALL XLAENV( 14, 13 )
+               CALL XLAENV( 15, 2 )
+               CALL XLAENV( 17, 10 )
+*
 *              Call SGGES3 to compute H, T, Q, Z, alpha, and beta.
 *
                CALL SLACPY( 'Full', N, N, A, LDA, S, LDA )
