@@ -1,51 +1,94 @@
+*> \brief \b SGET32
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SGET32( RMAX, LMAX, NINFO, KNT )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            KNT, LMAX, NINFO
+*       REAL               RMAX
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SGET32 tests SLASY2, a routine for solving
+*>
+*>         op(TL)*X + ISGN*X*op(TR) = SCALE*B
+*>
+*> where TL is N1 by N1, TR is N2 by N2, and N1,N2 =1 or 2 only.
+*> X and B are N1 by N2, op() is an optional transpose, an
+*> ISGN = 1 or -1. SCALE is chosen less than or equal to 1 to
+*> avoid overflow in X.
+*>
+*> The test condition is that the scaled residual
+*>
+*> norm( op(TL)*X + ISGN*X*op(TR) = SCALE*B )
+*>      / ( max( ulp*norm(TL), ulp*norm(TR)) * norm(X), SMLNUM )
+*>
+*> should be on the order of 1. Here, ulp is the machine precision.
+*> Also, it is verified that SCALE is less than or equal to 1, and
+*> that XNORM = infinity-norm(X).
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[out] RMAX
+*> \verbatim
+*>          RMAX is REAL
+*>          Value of the largest test ratio.
+*> \endverbatim
+*>
+*> \param[out] LMAX
+*> \verbatim
+*>          LMAX is INTEGER
+*>          Example number where largest test ratio achieved.
+*> \endverbatim
+*>
+*> \param[out] NINFO
+*> \verbatim
+*>          NINFO is INTEGER
+*>          Number of examples returned with INFO.NE.0.
+*> \endverbatim
+*>
+*> \param[out] KNT
+*> \verbatim
+*>          KNT is INTEGER
+*>          Total number of examples tested.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup single_eig
+*
+*  =====================================================================
       SUBROUTINE SGET32( RMAX, LMAX, NINFO, KNT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     February 29, 1992
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, LMAX, NINFO
       REAL               RMAX
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SGET32 tests SLASY2, a routine for solving
-*
-*          op(TL)*X + ISGN*X*op(TR) = SCALE*B
-*
-*  where TL is N1 by N1, TR is N2 by N2, and N1,N2 =1 or 2 only.
-*  X and B are N1 by N2, op() is an optional transpose, an
-*  ISGN = 1 or -1. SCALE is chosen less than or equal to 1 to
-*  avoid overflow in X.
-*
-*  The test condition is that the scaled residual
-*
-*  norm( op(TL)*X + ISGN*X*op(TR) = SCALE*B )
-*       / ( max( ulp*norm(TL), ulp*norm(TR)) * norm(X), SMLNUM )
-*
-*  should be on the order of 1. Here, ulp is the machine precision.
-*  Also, it is verified that SCALE is less than or equal to 1, and
-*  that XNORM = infinity-norm(X).
-*
-*  Arguments
-*  ==========
-*
-*  RMAX    (output) REAL
-*          Value of the largest test ratio.
-*
-*  LMAX    (output) INTEGER
-*          Example number where largest test ratio achieved.
-*
-*  NINFO   (output) INTEGER
-*          Number of examples returned with INFO.NE.0.
-*
-*  KNT     (output) INTEGER
-*          Total number of examples tested.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -71,7 +114,7 @@
       EXTERNAL           SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SLABAD, SLASY2
+      EXTERNAL           SLASY2
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MIN, SQRT
@@ -88,7 +131,6 @@
       EPS = SLAMCH( 'P' )
       SMLNUM = SLAMCH( 'S' ) / EPS
       BIGNUM = ONE / SMLNUM
-      CALL SLABAD( SMLNUM, BIGNUM )
 *
 *     Set up test case parameters
 *
