@@ -50,17 +50,14 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date November 2015
-*
 *> \ingroup complex16_eig
 *
 *  =====================================================================
       SUBROUTINE ZERRGG( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
@@ -83,7 +80,7 @@
 *     ..
 *     .. Local Arrays ..
       LOGICAL            BW( NMAX ), SEL( NMAX )
-      INTEGER            IW( LW )
+      INTEGER            IW( LW ), IDUM(NMAX)
       DOUBLE PRECISION   LS( NMAX ), R1( NMAX ), R2( NMAX ),
      $                   RCE( NMAX ), RCV( NMAX ), RS( NMAX ), RW( LW )
       COMPLEX*16         A( NMAX, NMAX ), ALPHA( NMAX ),
@@ -100,7 +97,7 @@
      $                   ZGGHRD, ZGGLSE, ZGGQRF, ZGGRQF,
      $                   ZHGEQZ, ZTGEVC, ZTGEXC, ZTGSEN, ZTGSJA, ZTGSNA,
      $                   ZTGSYL, ZUNCSD, ZGGES3, ZGGEV3, ZGGHD3,
-     $                   ZGGSVD3, ZGGSVP3
+     $                   ZGGSVD3, ZGGSVP3, XLAENV
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
@@ -138,6 +135,14 @@
       NT = 0
       LWORK = 1
 *
+*     Call XLAENV to set the parameters used in CLAQZ0
+*
+      CALL XLAENV( 12, 10 )
+      CALL XLAENV( 13, 12 )
+      CALL XLAENV( 14, 13 )
+      CALL XLAENV( 15, 2 )
+      CALL XLAENV( 17, 10 )
+*
 *     Test error exits for the GG path.
 *
       IF( LSAMEN( 2, C2, 'GG' ) ) THEN
@@ -214,7 +219,7 @@
      $                INFO )
          CALL CHKXER( 'ZGGHD3', INFOT, NOUT, LERR, OK )
          NT = NT + 9
-*     
+*
 *        ZHGEQZ
 *
          SRNAMT = 'ZHGEQZ'
@@ -306,57 +311,57 @@
          SRNAMT = 'ZGGSVD3'
          INFOT = 1
          CALL ZGGSVD3( '/', 'N', 'N', 0, 0, 0, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 2
          CALL ZGGSVD3( 'N', '/', 'N', 0, 0, 0, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 3
          CALL ZGGSVD3( 'N', 'N', '/', 0, 0, 0, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 4
          CALL ZGGSVD3( 'N', 'N', 'N', -1, 0, 0, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 5
          CALL ZGGSVD3( 'N', 'N', 'N', 0, -1, 0, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 6
          CALL ZGGSVD3( 'N', 'N', 'N', 0, 0, -1, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 10
          CALL ZGGSVD3( 'N', 'N', 'N', 2, 1, 1, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 12
          CALL ZGGSVD3( 'N', 'N', 'N', 1, 1, 2, DUMMYK, DUMMYL, A, 1, B,
-     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 1, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 16
          CALL ZGGSVD3( 'U', 'N', 'N', 2, 2, 2, DUMMYK, DUMMYL, A, 2, B,
-     $                 2, R1, R2, U, 1, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 2, R1, R2, U, 1, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 18
          CALL ZGGSVD3( 'N', 'V', 'N', 2, 2, 2, DUMMYK, DUMMYL, A, 2, B,
-     $                 2, R1, R2, U, 2, V, 1, Q, 1, W, RW, IW, LWORK,
+     $                 2, R1, R2, U, 2, V, 1, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          INFOT = 20
          CALL ZGGSVD3( 'N', 'N', 'Q', 2, 2, 2, DUMMYK, DUMMYL, A, 2, B,
-     $                 2, R1, R2, U, 2, V, 2, Q, 1, W, RW, IW, LWORK,
+     $                 2, R1, R2, U, 2, V, 2, Q, 1, W, LWORK, RW, IDUM,
      $                 INFO )
          CALL CHKXER( 'ZGGSVD3', INFOT, NOUT, LERR, OK )
          NT = NT + 11
@@ -573,56 +578,56 @@
          INFOT = 7
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 -1, 0, 0, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 8
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, -1, 0, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 9
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, -1, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 11
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, 1, A, -1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 20
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, 1, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, -1, A, 1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 22
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, 1, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, -1, A, 1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 24
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, 1, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, -1, A,
      $                 1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
          INFOT = 26
          CALL ZUNCSD( 'Y', 'Y', 'Y', 'Y', 'N', 'N',
      $                 1, 1, 1, A, 1, A,
-     $                 1, A, 1, A, 1, A,
+     $                 1, A, 1, A, 1, RS,
      $                 A, 1, A, 1, A, 1, A,
      $                 -1, W, LW, RW, LW, IW, INFO )
          CALL CHKXER( 'ZUNCSD', INFOT, NOUT, LERR, OK )
