@@ -1,9 +1,97 @@
+*> \brief \b ZGET38
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZGET38( RMAX, LMAX, NINFO, KNT, NIN )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            KNT, NIN
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            LMAX( 3 ), NINFO( 3 )
+*       DOUBLE PRECISION   RMAX( 3 )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZGET38 tests ZTRSEN, a routine for estimating condition numbers of a
+*> cluster of eigenvalues and/or its associated right invariant subspace
+*>
+*> The test matrices are read from a file with logical unit number NIN.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[out] RMAX
+*> \verbatim
+*>          RMAX is DOUBLE PRECISION array, dimension (3)
+*>          Values of the largest test ratios.
+*>          RMAX(1) = largest residuals from ZHST01 or comparing
+*>                    different calls to ZTRSEN
+*>          RMAX(2) = largest error in reciprocal condition
+*>                    numbers taking their conditioning into account
+*>          RMAX(3) = largest error in reciprocal condition
+*>                    numbers not taking their conditioning into
+*>                    account (may be larger than RMAX(2))
+*> \endverbatim
+*>
+*> \param[out] LMAX
+*> \verbatim
+*>          LMAX is INTEGER array, dimension (3)
+*>          LMAX(i) is example number where largest test ratio
+*>          RMAX(i) is achieved. Also:
+*>          If ZGEHRD returns INFO nonzero on example i, LMAX(1)=i
+*>          If ZHSEQR returns INFO nonzero on example i, LMAX(2)=i
+*>          If ZTRSEN returns INFO nonzero on example i, LMAX(3)=i
+*> \endverbatim
+*>
+*> \param[out] NINFO
+*> \verbatim
+*>          NINFO is INTEGER array, dimension (3)
+*>          NINFO(1) = No. of times ZGEHRD returned INFO nonzero
+*>          NINFO(2) = No. of times ZHSEQR returned INFO nonzero
+*>          NINFO(3) = No. of times ZTRSEN returned INFO nonzero
+*> \endverbatim
+*>
+*> \param[out] KNT
+*> \verbatim
+*>          KNT is INTEGER
+*>          Total number of examples tested.
+*> \endverbatim
+*>
+*> \param[in] NIN
+*> \verbatim
+*>          NIN is INTEGER
+*>          Input logical unit number.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup complex16_eig
+*
+*  =====================================================================
       SUBROUTINE ZGET38( RMAX, LMAX, NINFO, KNT, NIN )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, NIN
@@ -13,45 +101,6 @@
       DOUBLE PRECISION   RMAX( 3 )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZGET38 tests ZTRSEN, a routine for estimating condition numbers of a
-*  cluster of eigenvalues and/or its associated right invariant subspace
-*
-*  The test matrices are read from a file with logical unit number NIN.
-*
-*  Arguments
-*  ==========
-*
-*  RMAX    (output) DOUBLE PRECISION array, dimension (3)
-*          Values of the largest test ratios.
-*          RMAX(1) = largest residuals from ZHST01 or comparing
-*                    different calls to ZTRSEN
-*          RMAX(2) = largest error in reciprocal condition
-*                    numbers taking their conditioning into account
-*          RMAX(3) = largest error in reciprocal condition
-*                    numbers not taking their conditioning into
-*                    account (may be larger than RMAX(2))
-*
-*  LMAX    (output) INTEGER array, dimension (3)
-*          LMAX(i) is example number where largest test ratio
-*          RMAX(i) is achieved. Also:
-*          If ZGEHRD returns INFO nonzero on example i, LMAX(1)=i
-*          If ZHSEQR returns INFO nonzero on example i, LMAX(2)=i
-*          If ZTRSEN returns INFO nonzero on example i, LMAX(3)=i
-*
-*  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = No. of times ZGEHRD returned INFO nonzero
-*          NINFO(2) = No. of times ZHSEQR returned INFO nonzero
-*          NINFO(3) = No. of times ZTRSEN returned INFO nonzero
-*
-*  KNT     (output) INTEGER
-*          Total number of examples tested.
-*
-*  NIN     (input) INTEGER
-*          Input logical unit number.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -86,8 +135,8 @@
       EXTERNAL           DLAMCH, ZLANGE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLABAD, ZDSCAL, ZGEHRD, ZHSEQR, ZHST01, ZLACPY,
-     $                   ZTRSEN, ZUNGHR
+      EXTERNAL           ZDSCAL, ZGEHRD, ZHSEQR, ZHST01, ZLACPY, ZTRSEN,
+     $                   ZUNGHR
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, DIMAG, MAX, SQRT
@@ -97,7 +146,6 @@
       EPS = DLAMCH( 'P' )
       SMLNUM = DLAMCH( 'S' ) / EPS
       BIGNUM = ONE / SMLNUM
-      CALL DLABAD( SMLNUM, BIGNUM )
 *
 *     EPSIN = 2**(-24) = precision to which input data computed
 *
