@@ -1,92 +1,190 @@
-      SUBROUTINE CCHKTR( DOTYPE, NN, NVAL, NNB, NBVAL, NRHS, THRESH,
-     $                   TSTERR, NMAX, A, AINV, B, X, XACT, WORK, RWORK,
-     $                   NOUT )
+*> \brief \b CCHKTR
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE CCHKTR( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
+*                          THRESH, TSTERR, NMAX, A, AINV, B, X, XACT,
+*                          WORK, RWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NNB, NNS, NOUT
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            NBVAL( * ), NSVAL( * ), NVAL( * )
+*       REAL               RWORK( * )
+*       COMPLEX            A( * ), AINV( * ), B( * ), WORK( * ), X( * ),
+*      $                   XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS(3)
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix column dimension N.
+*> \endverbatim
+*>
+*> \param[in] NNB
+*> \verbatim
+*>          NNB is INTEGER
+*>          The number of values of NB contained in the vector NBVAL.
+*> \endverbatim
+*>
+*> \param[in] NBVAL
+*> \verbatim
+*>          NBVAL is INTEGER array, dimension (NNB)
+*>          The values of the blocksize NB.
+*> \endverbatim
+*>
+*> \param[in] NNS
+*> \verbatim
+*>          NNS is INTEGER
+*>          The number of values of NRHS contained in the vector NSVAL.
+*> \endverbatim
+*>
+*> \param[in] NSVAL
+*> \verbatim
+*>          NSVAL is INTEGER array, dimension (NNS)
+*>          The values of the number of right hand sides NRHS.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The leading dimension of the work arrays.
+*>          NMAX >= the maximum value of N in NVAL.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AINV
+*> \verbatim
+*>          AINV is COMPLEX array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX array, dimension (NMAX*NSMAX)
+*>          where NSMAX is the largest entry in NSVAL.
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX array, dimension (NMAX*NSMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX array, dimension
+*>                      (NMAX*max(3,NSMAX))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension
+*>                      (max(NMAX,2*NSMAX))
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup complex_lin
+*
+*  =====================================================================
+      SUBROUTINE CCHKTR( DOTYPE, NN, NVAL, NNB, NBVAL, NNS, NSVAL,
+     $                   THRESH, TSTERR, NMAX, A, AINV, B, X, XACT,
+     $                   WORK, RWORK, NOUT )
+*
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
-      INTEGER            NMAX, NN, NNB, NOUT, NRHS
+      INTEGER            NMAX, NN, NNB, NNS, NOUT
       REAL               THRESH
 *     ..
 *     .. Array Arguments ..
       LOGICAL            DOTYPE( * )
-      INTEGER            NBVAL( * ), NVAL( * )
+      INTEGER            NBVAL( * ), NSVAL( * ), NVAL( * )
       REAL               RWORK( * )
       COMPLEX            A( * ), AINV( * ), B( * ), WORK( * ), X( * ),
      $                   XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  CCHKTR tests CTRTRI, -TRS, -RFS, and -CON, and CLATRS
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix column dimension N.
-*
-*  NNB     (input) INTEGER
-*          The number of values of NB contained in the vector NBVAL.
-*
-*  NBVAL   (input) INTEGER array, dimension (NNB)
-*          The values of the blocksize NB.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) REAL
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The leading dimension of the work arrays.
-*          NMAX >= the maximum value of N in NVAL.
-*
-*  A       (workspace) COMPLEX array, dimension (NMAX*NMAX)
-*
-*  AINV    (workspace) COMPLEX array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX array, dimension (NMAX*NRHS)
-*
-*  WORK    (workspace) COMPLEX array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) REAL array, dimension
-*                      (max(NMAX,2*NRHS))
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
       INTEGER            NTYPE1, NTYPES
       PARAMETER          ( NTYPE1 = 10, NTYPES = 18 )
       INTEGER            NTESTS
-      PARAMETER          ( NTESTS = 9 )
+      PARAMETER          ( NTESTS = 10 )
       INTEGER            NTRAN
       PARAMETER          ( NTRAN = 3 )
       REAL               ONE, ZERO
@@ -95,15 +193,16 @@
 *     .. Local Scalars ..
       CHARACTER          DIAG, NORM, TRANS, UPLO, XTYPE
       CHARACTER*3        PATH
-      INTEGER            I, IDIAG, IMAT, IN, INB, INFO, ITRAN, IUPLO, K,
-     $                   K1, LDA, N, NB, NERRS, NFAIL, NRUN, NT
-      REAL               AINVNM, ANORM, DUMMY, RCOND, RCONDC, RCONDI,
-     $                   RCONDO, SCALE
+      INTEGER            I, IDIAG, IMAT, IN, INB, INFO, IRHS, ITRAN,
+     $                   IUPLO, K, LDA, N, NB, NERRS, NFAIL, NRHS, NRUN
+      REAL               AINVNM, ANORM, BIGNUM, DUMMY, RCOND, RCONDC,
+     $                   RCONDI, RCONDO, RES, SCALE, SLAMCH
 *     ..
 *     .. Local Arrays ..
       CHARACTER          TRANSS( NTRAN ), UPLOS( 2 )
       INTEGER            ISEED( 4 ), ISEEDY( 4 )
-      REAL               RESULT( NTESTS )
+      REAL               RESULT( NTESTS ), RWORK2( 2*NMAX ),
+     $                   SCALE3( 2 )
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -112,13 +211,13 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           ALAERH, ALAHD, ALASUM, CCOPY, CERRTR, CGET04,
-     $                   CLACPY, CLARHS, CLATRS, CLATTR, CTRCON, CTRRFS,
-     $                   CTRT01, CTRT02, CTRT03, CTRT05, CTRT06, CTRTRI,
-     $                   CTRTRS, XLAENV
+     $                   CLACPY, CLARHS, CLATRS, CLATRS3, CLATTR,
+     $                   CSSCAL, CTRCON, CTRRFS, CTRT01, CTRT02, CTRT03,
+     $                   CTRT05, CTRT06, CTRTRI, CTRTRS, XLAENV, SLAMCH
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, IOUNIT
 *     ..
 *     .. Common blocks ..
@@ -136,8 +235,9 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'C'
+      PATH( 1: 1 ) = 'Complex precision'
       PATH( 2: 3 ) = 'TR'
+      BIGNUM = SLAMCH('Overflow') / SLAMCH('Precision')
       NRUN = 0
       NFAIL = 0
       NERRS = 0
@@ -151,7 +251,7 @@
      $   CALL CERRTR( PATH, NOUT )
       INFOT = 0
 *
-      DO 100 IN = 1, NN
+      DO 120 IN = 1, NN
 *
 *        Do for each value of N in NVAL
 *
@@ -159,14 +259,14 @@
          LDA = MAX( 1, N )
          XTYPE = 'N'
 *
-         DO 60 IMAT = 1, NTYPE1
+         DO 80 IMAT = 1, NTYPE1
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 60
+     $         GO TO 80
 *
-            DO 50 IUPLO = 1, 2
+            DO 70 IUPLO = 1, 2
 *
 *              Do first for UPLO = 'U', then for UPLO = 'L'
 *
@@ -186,7 +286,7 @@
                   IDIAG = 2
                END IF
 *
-               DO 40 INB = 1, NNB
+               DO 60 INB = 1, NNB
 *
 *                 Do for each blocksize in NBVAL
 *
@@ -224,27 +324,38 @@
 *
                   CALL CTRT01( UPLO, DIAG, N, A, LDA, AINV, LDA, RCONDO,
      $                         RWORK, RESULT( 1 ) )
-                  K1 = 1
-                  NT = 1
+*                 Print the test ratio if it is .GE. THRESH.
 *
-                  DO 30 ITRAN = 1, NTRAN
+                  IF( RESULT( 1 ).GE.THRESH ) THEN
+                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                  CALL ALAHD( NOUT, PATH )
+                     WRITE( NOUT, FMT = 9999 )UPLO, DIAG, N, NB, IMAT,
+     $                  1, RESULT( 1 )
+                     NFAIL = NFAIL + 1
+                  END IF
+                  NRUN = NRUN + 1
+*
+*                 Skip remaining tests if not the first block size.
+*
+                  IF( INB.NE.1 )
+     $               GO TO 60
+*
+                  DO 40 IRHS = 1, NNS
+                     NRHS = NSVAL( IRHS )
+                     XTYPE = 'N'
+*
+                     DO 30 ITRAN = 1, NTRAN
 *
 *                    Do for op(A) = A, A**T, or A**H.
 *
-                     TRANS = TRANSS( ITRAN )
-                     IF( ITRAN.EQ.1 ) THEN
-                        NORM = 'O'
-                        RCONDC = RCONDO
-                     ELSE
-                        NORM = 'I'
-                        RCONDC = RCONDI
-                        K1 = 2
-                     END IF
-*
-*                    Do the rest of the tests only if this is the first
-*                    blocksize.
-*
-                     IF( INB.EQ.1 ) THEN
+                        TRANS = TRANSS( ITRAN )
+                        IF( ITRAN.EQ.1 ) THEN
+                           NORM = 'O'
+                           RCONDC = RCONDO
+                        ELSE
+                           NORM = 'I'
+                           RCONDC = RCONDI
+                        END IF
 *
 *+    TEST 2
 *                       Solve and compute residual for op(A)*x = b.
@@ -271,7 +382,7 @@
 *                       This line is needed on a Sun SPARCstation.
 *
                         IF( N.GT.0 )
-     $                     DUMMY = A( 1 )
+     $                     DUMMY = REAL( A( 1 ) )
 *
                         CALL CTRT02( UPLO, TRANS, DIAG, N, NRHS, A, LDA,
      $                               X, LDA, B, LDA, WORK, RWORK,
@@ -307,59 +418,77 @@
      $                               B, LDA, X, LDA, XACT, LDA, RWORK,
      $                               RWORK( NRHS+1 ), RESULT( 5 ) )
 *
+*                       Print information about the tests that did not
+*                       pass the threshold.
+*
+                        DO 20 K = 2, 6
+                           IF( RESULT( K ).GE.THRESH ) THEN
+                              IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                           CALL ALAHD( NOUT, PATH )
+                              WRITE( NOUT, FMT = 9998 )UPLO, TRANS,
+     $                           DIAG, N, NRHS, IMAT, K, RESULT( K )
+                              NFAIL = NFAIL + 1
+                           END IF
+   20                   CONTINUE
+                        NRUN = NRUN + 5
+   30                CONTINUE
+   40             CONTINUE
+*
 *+    TEST 7
 *                       Get an estimate of RCOND = 1/CNDNUM.
 *
-                        SRNAMT = 'CTRCON'
-                        CALL CTRCON( NORM, UPLO, DIAG, N, A, LDA, RCOND,
-     $                               WORK, RWORK, INFO )
+                  DO 50 ITRAN = 1, 2
+                     IF( ITRAN.EQ.1 ) THEN
+                        NORM = 'O'
+                        RCONDC = RCONDO
+                     ELSE
+                        NORM = 'I'
+                        RCONDC = RCONDI
+                     END IF
+                     SRNAMT = 'CTRCON'
+                     CALL CTRCON( NORM, UPLO, DIAG, N, A, LDA, RCOND,
+     $                            WORK, RWORK, INFO )
 *
 *                       Check error code from CTRCON.
 *
-                        IF( INFO.NE.0 )
-     $                     CALL ALAERH( PATH, 'CTRCON', INFO, 0,
-     $                                  NORM // UPLO // DIAG, N, N, -1,
-     $                                  -1, -1, IMAT, NFAIL, NERRS,
-     $                                  NOUT )
+                     IF( INFO.NE.0 )
+     $                  CALL ALAERH( PATH, 'CTRCON', INFO, 0,
+     $                               NORM // UPLO // DIAG, N, N, -1, -1,
+     $                               -1, IMAT, NFAIL, NERRS, NOUT )
 *
-                        CALL CTRT06( RCOND, RCONDC, UPLO, DIAG, N, A,
-     $                               LDA, RWORK, RESULT( 7 ) )
-                        NT = 7
+                     CALL CTRT06( RCOND, RCONDC, UPLO, DIAG, N, A, LDA,
+     $                            RWORK, RESULT( 7 ) )
+*
+*                    Print the test ratio if it is .GE. THRESH.
+*
+                     IF( RESULT( 7 ).GE.THRESH ) THEN
+                        IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                     CALL ALAHD( NOUT, PATH )
+                        WRITE( NOUT, FMT = 9997 )NORM, UPLO, N, IMAT,
+     $                     7, RESULT( 7 )
+                        NFAIL = NFAIL + 1
                      END IF
-*
-*                    Print information about the tests that did not pass
-*                    the threshold.
-*
-                     DO 20 K = K1, NT
-                        IF( RESULT( K ).GE.THRESH ) THEN
-                           IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
-     $                        CALL ALAHD( NOUT, PATH )
-                           WRITE( NOUT, FMT = 9999 )UPLO, TRANS, N, NB,
-     $                        IMAT, K, RESULT( K )
-                           NFAIL = NFAIL + 1
-                        END IF
-   20                CONTINUE
-                     NRUN = NRUN + NT - K1 + 1
-   30             CONTINUE
-   40          CONTINUE
-   50       CONTINUE
-   60    CONTINUE
+                     NRUN = NRUN + 1
+   50             CONTINUE
+   60          CONTINUE
+   70       CONTINUE
+   80    CONTINUE
 *
 *        Use pathological test matrices to test CLATRS.
 *
-         DO 90 IMAT = NTYPE1 + 1, NTYPES
+         DO 110 IMAT = NTYPE1 + 1, NTYPES
 *
 *           Do the tests only if DOTYPE( IMAT ) is true.
 *
             IF( .NOT.DOTYPE( IMAT ) )
-     $         GO TO 90
+     $         GO TO 110
 *
-            DO 80 IUPLO = 1, 2
+            DO 100 IUPLO = 1, 2
 *
 *              Do first for UPLO = 'U', then for UPLO = 'L'
 *
                UPLO = UPLOS( IUPLO )
-               DO 70 ITRAN = 1, NTRAN
+               DO 90 ITRAN = 1, NTRAN
 *
 *                 Do for op(A) = A, A**T, and A**H.
 *
@@ -408,37 +537,76 @@
      $                         RWORK, ONE, B( N+1 ), LDA, X, LDA, WORK,
      $                         RESULT( 9 ) )
 *
+*+    TEST 10
+*                 Solve op(A)*X = B.
+*
+                  SRNAMT = 'CLATRS3'
+                  CALL CCOPY( N, X, 1, B, 1 )
+                  CALL CCOPY( N, X, 1, B( N+1 ), 1 )
+                  CALL CSSCAL( N, BIGNUM, B( N+1 ), 1 )
+                  CALL CLATRS3( UPLO, TRANS, DIAG, 'N', N, 2, A, LDA,
+     $                          B, MAX(1, N), SCALE3, RWORK, RWORK2,
+     $                          2*NMAX, INFO )
+*
+*                 Check error code from CLATRS3.
+*
+                  IF( INFO.NE.0 )
+     $               CALL ALAERH( PATH, 'CLATRS3', INFO, 0,
+     $                            UPLO // TRANS // DIAG // 'N', N, N,
+     $                            -1, -1, -1, IMAT, NFAIL, NERRS, NOUT )
+                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
+     $                         SCALE3( 1 ), RWORK, ONE, B( 1 ), LDA,
+     $                         X, LDA, WORK, RESULT( 10 ) )
+                  CALL CSSCAL( N, BIGNUM, X, 1 )
+                  CALL CTRT03( UPLO, TRANS, DIAG, N, 1, A, LDA,
+     $                         SCALE3( 2 ), RWORK, ONE, B( N+1 ), LDA,
+     $                         X, LDA, WORK, RES )
+                  RESULT( 10 ) = MAX( RESULT( 10 ), RES )
+*
 *                 Print information about the tests that did not pass
 *                 the threshold.
 *
                   IF( RESULT( 8 ).GE.THRESH ) THEN
                      IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9998 )'CLATRS', UPLO, TRANS,
-     $                  DIAG, 'N', N, IMAT, RESULT( 8 )
+                     WRITE( NOUT, FMT = 9996 )'CLATRS', UPLO, TRANS,
+     $                  DIAG, 'N', N, IMAT, 8, RESULT( 8 )
                      NFAIL = NFAIL + 1
                   END IF
                   IF( RESULT( 9 ).GE.THRESH ) THEN
                      IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                  CALL ALAHD( NOUT, PATH )
-                     WRITE( NOUT, FMT = 9998 )'CLATRS', UPLO, TRANS,
-     $                  DIAG, 'Y', N, IMAT, RESULT( 9 )
+                     WRITE( NOUT, FMT = 9996 )'CLATRS', UPLO, TRANS,
+     $                  DIAG, 'Y', N, IMAT, 9, RESULT( 9 )
                      NFAIL = NFAIL + 1
                   END IF
-                  NRUN = NRUN + 2
-   70          CONTINUE
-   80       CONTINUE
-   90    CONTINUE
-  100 CONTINUE
+                  IF( RESULT( 10 ).GE.THRESH ) THEN
+                     IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
+     $                  CALL ALAHD( NOUT, PATH )
+                     WRITE( NOUT, FMT = 9996 )'CLATRS3', UPLO, TRANS,
+     $                  DIAG, 'N', N, IMAT, 10, RESULT( 10 )
+                     NFAIL = NFAIL + 1
+                  END IF
+                  NRUN = NRUN + 3
+   90          CONTINUE
+  100       CONTINUE
+  110    CONTINUE
+  120 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASUM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', N=', I5, ', NB=',
+ 9999 FORMAT( ' UPLO=''', A1, ''', DIAG=''', A1, ''', N=', I5, ', NB=',
      $      I4, ', type ', I2, ', test(', I2, ')= ', G12.5 )
- 9998 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
-     $      A1, ''',', I5, ', ... ), type ', I2, ', ratio =', G12.5 )
+ 9998 FORMAT( ' UPLO=''', A1, ''', TRANS=''', A1, ''', DIAG=''', A1,
+     $      ''', N=', I5, ', NB=', I4, ', type ', I2, ',
+     $      test(', I2, ')= ', G12.5 )
+ 9997 FORMAT( ' NORM=''', A1, ''', UPLO =''', A1, ''', N=', I5, ',',
+     $      11X, ' type ', I2, ', test(', I2, ')=', G12.5 )
+ 9996 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ''', A1, ''', ''',
+     $      A1, ''',', I5, ', ... ), type ', I2, ', test(', I2, ')=',
+     $      G12.5 )
       RETURN
 *
 *     End of CCHKTR
