@@ -175,7 +175,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CCOPY, CLARNV, CLATB4, CLATMS, CROT, CROTG,
-     $                   CSSCAL, CSWAP, SLABAD, SLARNV
+     $                   CSSCAL, CSWAP, SLARNV
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, CMPLX, CONJG, MAX, REAL, SQRT
@@ -188,7 +188,6 @@
       ULP = SLAMCH( 'Epsilon' )*SLAMCH( 'Base' )
       SMLNUM = UNFL
       BIGNUM = ( ONE-ULP ) / SMLNUM
-      CALL SLABAD( SMLNUM, BIGNUM )
       IF( ( IMAT.GE.7 .AND. IMAT.LE.10 ) .OR. IMAT.EQ.18 ) THEN
          DIAG = 'U'
       ELSE
