@@ -9,7 +9,7 @@
 *  ===========
 *
 *       SUBROUTINE SGBT02( TRANS, M, N, KL, KU, NRHS, A, LDA, X, LDX, B,
-*                          LDB, RESID )
+*                          LDB, RWORK, RESID )
 *
 *       .. Scalar Arguments ..
 *       CHARACTER          TRANS
@@ -17,7 +17,8 @@
 *       REAL               RESID
 *       ..
 *       .. Array Arguments ..
-*       REAL               A( LDA, * ), B( LDB, * ), X( LDX, * )
+*       REAL               A( LDA, * ), B( LDB, * ), X( LDX, * ),
+*                          RWORK( * )
 *       ..
 *
 *
@@ -27,9 +28,11 @@
 *> \verbatim
 *>
 *> SGBT02 computes the residual for a solution of a banded system of
-*> equations  A*x = b  or  A'*x = b:
-*>    RESID = norm( B - A*X ) / ( norm(A) * norm(X) * EPS).
-*> where EPS is the machine precision.
+*> equations op(A)*X = B:
+*>    RESID = norm(B - op(A)*X) / ( norm(op(A)) * norm(X) * EPS ),
+*> where op(A) = A or A**T, depending on TRANS, and EPS is the
+*> machine epsilon.
+*> The norm used is the 1-norm.
 *> \endverbatim
 *
 *  Arguments:
@@ -39,9 +42,9 @@
 *> \verbatim
 *>          TRANS is CHARACTER*1
 *>          Specifies the form of the system of equations:
-*>          = 'N':  A *x = b
-*>          = 'T':  A'*x = b, where A' is the transpose of A
-*>          = 'C':  A'*x = b, where A' is the transpose of A
+*>          = 'N':  A    * X = B  (No transpose)
+*>          = 'T':  A**T * X = B  (Transpose)
+*>          = 'C':  A**H * X = B  (Conjugate transpose = Transpose)
 *> \endverbatim
 *>
 *> \param[in] M
@@ -116,11 +119,18 @@
 *>          LDB >= max(1,M); if TRANS = 'T' or 'C', LDB >= max(1,N).
 *> \endverbatim
 *>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is REAL array, dimension (MAX(1,LRWORK)),
+*>          where LRWORK >= M when TRANS = 'T' or 'C'; otherwise, RWORK
+*>          is not referenced.
+*> \endverbatim
+*
 *> \param[out] RESID
 *> \verbatim
 *>          RESID is REAL
 *>          The maximum over the number of right hand sides of
-*>          norm(B - A*X) / ( norm(A) * norm(X) * EPS ).
+*>          norm(B - op(A)*X) / ( norm(op(A)) * norm(X) * EPS ).
 *> \endverbatim
 *
 *  Authors:
@@ -131,18 +141,15 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup single_lin
 *
 *  =====================================================================
       SUBROUTINE SGBT02( TRANS, M, N, KL, KU, NRHS, A, LDA, X, LDX, B,
-     $                   LDB, RESID )
+     $                   LDB, RWORK, RESID )
 *
-*  -- LAPACK test routine (version 3.7.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS
@@ -150,7 +157,8 @@
       REAL               RESID
 *     ..
 *     .. Array Arguments ..
-      REAL               A( LDA, * ), B( LDB, * ), X( LDX, * )
+      REAL               A( LDA, * ), B( LDB, * ), X( LDX, * ),
+     $                   RWORK( * )
 *     ..
 *
 *  =====================================================================
@@ -161,18 +169,18 @@
 *     ..
 *     .. Local Scalars ..
       INTEGER            I1, I2, J, KD, N1
-      REAL               ANORM, BNORM, EPS, XNORM
+      REAL               ANORM, BNORM, EPS, TEMP, XNORM
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME
+      LOGICAL            LSAME, SISNAN
       REAL               SASUM, SLAMCH
-      EXTERNAL           LSAME, SASUM, SLAMCH
+      EXTERNAL           LSAME, SASUM, SISNAN, SLAMCH
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           SGBMV
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          MAX, MIN
+      INTRINSIC          ABS, MAX, MIN
 *     ..
 *     .. Executable Statements ..
 *
@@ -186,13 +194,38 @@
 *     Exit with RESID = 1/EPS if ANORM = 0.
 *
       EPS = SLAMCH( 'Epsilon' )
-      KD = KU + 1
       ANORM = ZERO
-      DO 10 J = 1, N
-         I1 = MAX( KD+1-J, 1 )
-         I2 = MIN( KD+M-J, KL+KD )
-         ANORM = MAX( ANORM, SASUM( I2-I1+1, A( I1, J ), 1 ) )
-   10 CONTINUE
+      IF( LSAME( TRANS, 'N' ) ) THEN
+*
+*        Find norm1(A).
+*
+         KD = KU + 1
+         DO 10 J = 1, N
+            I1 = MAX( KD+1-J, 1 )
+            I2 = MIN( KD+M-J, KL+KD )
+            IF( I2.GE.I1 ) THEN
+               TEMP = SASUM( I2-I1+1, A( I1, J ), 1 )
+               IF( ANORM.LT.TEMP .OR. SISNAN( TEMP ) ) ANORM = TEMP
+            END IF
+   10    CONTINUE
+      ELSE
+*
+*        Find normI(A).
+*
+         DO 12 I1 = 1, M
+            RWORK( I1 ) = ZERO
+   12    CONTINUE
+         DO 16 J = 1, N
+            KD = KU + 1 - J
+            DO 14 I1 = MAX( 1, J-KU ), MIN( M, J+KL )
+               RWORK( I1 ) = RWORK( I1 ) + ABS( A( KD+I1, J ) )
+   14       CONTINUE
+   16    CONTINUE
+         DO 18 I1 = 1, M
+            TEMP = RWORK( I1 )
+            IF( ANORM.LT.TEMP .OR. SISNAN( TEMP ) ) ANORM = TEMP
+   18    CONTINUE
+      END IF
       IF( ANORM.LE.ZERO ) THEN
          RESID = ONE / EPS
          RETURN
@@ -204,7 +237,7 @@
          N1 = M
       END IF
 *
-*     Compute  B - A*X (or  B - A'*X )
+*     Compute B - op(A)*X
 *
       DO 20 J = 1, NRHS
          CALL SGBMV( TRANS, M, N, KL, KU, -ONE, A, LDA, X( 1, J ), 1,
@@ -212,7 +245,7 @@
    20 CONTINUE
 *
 *     Compute the maximum over the number of right hand sides of
-*        norm(B - A*X) / ( norm(A) * norm(X) * EPS ).
+*        norm(B - op(A)*X) / ( norm(op(A)) * norm(X) * EPS ).
 *
       RESID = ZERO
       DO 30 J = 1, NRHS
