@@ -1,11 +1,165 @@
+*> \brief \b ZDRVPB
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE ZDRVPB( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
+*                          A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
+*                          RWORK, NOUT )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            TSTERR
+*       INTEGER            NMAX, NN, NOUT, NRHS
+*       DOUBLE PRECISION   THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            DOTYPE( * )
+*       INTEGER            NVAL( * )
+*       DOUBLE PRECISION   RWORK( * ), S( * )
+*       COMPLEX*16         A( * ), AFAC( * ), ASAV( * ), B( * ),
+*      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> ZDRVPB tests the driver routines ZPBSV and -SVX.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          The matrix types to be used for testing.  Matrices of type j
+*>          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
+*>          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER
+*>          The number of values of N contained in the vector NVAL.
+*> \endverbatim
+*>
+*> \param[in] NVAL
+*> \verbatim
+*>          NVAL is INTEGER array, dimension (NN)
+*>          The values of the matrix dimension N.
+*> \endverbatim
+*>
+*> \param[in] NRHS
+*> \verbatim
+*>          NRHS is INTEGER
+*>          The number of right hand side vectors to be generated for
+*>          each linear system.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is DOUBLE PRECISION
+*>          The threshold value for the test ratios.  A result is
+*>          included in the output file if RESULT >= THRESH.  To have
+*>          every test ratio printed, use THRESH = 0.
+*> \endverbatim
+*>
+*> \param[in] TSTERR
+*> \verbatim
+*>          TSTERR is LOGICAL
+*>          Flag that indicates whether error exits are to be tested.
+*> \endverbatim
+*>
+*> \param[in] NMAX
+*> \verbatim
+*>          NMAX is INTEGER
+*>          The maximum value permitted for N, used in dimensioning the
+*>          work arrays.
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] AFAC
+*> \verbatim
+*>          AFAC is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] ASAV
+*> \verbatim
+*>          ASAV is COMPLEX*16 array, dimension (NMAX*NMAX)
+*> \endverbatim
+*>
+*> \param[out] B
+*> \verbatim
+*>          B is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] BSAV
+*> \verbatim
+*>          BSAV is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] X
+*> \verbatim
+*>          X is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] XACT
+*> \verbatim
+*>          XACT is COMPLEX*16 array, dimension (NMAX*NRHS)
+*> \endverbatim
+*>
+*> \param[out] S
+*> \verbatim
+*>          S is DOUBLE PRECISION array, dimension (NMAX)
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is COMPLEX*16 array, dimension
+*>                      (NMAX*max(3,NRHS))
+*> \endverbatim
+*>
+*> \param[out] RWORK
+*> \verbatim
+*>          RWORK is DOUBLE PRECISION array, dimension (NMAX+2*NRHS)
+*> \endverbatim
+*>
+*> \param[in] NOUT
+*> \verbatim
+*>          NOUT is INTEGER
+*>          The unit number for output.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup complex16_lin
+*
+*  =====================================================================
       SUBROUTINE ZDRVPB( DOTYPE, NN, NVAL, NRHS, THRESH, TSTERR, NMAX,
      $                   A, AFAC, ASAV, B, BSAV, X, XACT, S, WORK,
      $                   RWORK, NOUT )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       LOGICAL            TSTERR
@@ -20,65 +174,6 @@
      $                   BSAV( * ), WORK( * ), X( * ), XACT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  ZDRVPB tests the driver routines ZPBSV and -SVX.
-*
-*  Arguments
-*  =========
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          The matrix types to be used for testing.  Matrices of type j
-*          (for 1 <= j <= NTYPES) are used for testing if DOTYPE(j) =
-*          .TRUE.; if DOTYPE(j) = .FALSE., then type j is not used.
-*
-*  NN      (input) INTEGER
-*          The number of values of N contained in the vector NVAL.
-*
-*  NVAL    (input) INTEGER array, dimension (NN)
-*          The values of the matrix dimension N.
-*
-*  NRHS    (input) INTEGER
-*          The number of right hand side vectors to be generated for
-*          each linear system.
-*
-*  THRESH  (input) DOUBLE PRECISION
-*          The threshold value for the test ratios.  A result is
-*          included in the output file if RESULT >= THRESH.  To have
-*          every test ratio printed, use THRESH = 0.
-*
-*  TSTERR  (input) LOGICAL
-*          Flag that indicates whether error exits are to be tested.
-*
-*  NMAX    (input) INTEGER
-*          The maximum value permitted for N, used in dimensioning the
-*          work arrays.
-*
-*  A       (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  AFAC    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  ASAV    (workspace) COMPLEX*16 array, dimension (NMAX*NMAX)
-*
-*  B       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  BSAV    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  X       (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  XACT    (workspace) COMPLEX*16 array, dimension (NMAX*NRHS)
-*
-*  S       (workspace) DOUBLE PRECISION array, dimension (NMAX)
-*
-*  WORK    (workspace) COMPLEX*16 array, dimension
-*                      (NMAX*max(3,NRHS))
-*
-*  RWORK   (workspace) DOUBLE PRECISION array, dimension (NMAX+2*NRHS)
-*
-*  NOUT    (input) INTEGER
-*          The unit number for output.
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -121,7 +216,7 @@
 *     ..
 *     .. Scalars in Common ..
       LOGICAL            LERR, OK
-      CHARACTER*6        SRNAMT
+      CHARACTER*32       SRNAMT
       INTEGER            INFOT, NUNIT
 *     ..
 *     .. Common blocks ..
@@ -136,7 +231,7 @@
 *
 *     Initialize constants and the random number seed.
 *
-      PATH( 1: 1 ) = 'Z'
+      PATH( 1: 1 ) = 'Zomplex precision'
       PATH( 2: 3 ) = 'PB'
       NRUN = 0
       NFAIL = 0
@@ -161,7 +256,7 @@
 *
 *     Do for each value of N in NVAL
 *
-      DO 120 IN = 1, NN
+      DO 110 IN = 1, NN
          N = NVAL( IN )
          LDA = MAX( N, 1 )
          XTYPE = 'N'
@@ -177,7 +272,7 @@
          KDVAL( 3 ) = ( 3*N-1 ) / 4
          KDVAL( 4 ) = ( N+1 ) / 4
 *
-         DO 110 IKD = 1, NKD
+         DO 100 IKD = 1, NKD
 *
 *           Do for KD = 0, (5*N+1)/4, (3N-1)/4, and (N+1)/4. This order
 *           makes it easier to skip redundant values for small values
@@ -188,7 +283,7 @@
 *
 *           Do first for UPLO = 'U', then for UPLO = 'L'
 *
-            DO 100 IUPLO = 1, 2
+            DO 90 IUPLO = 1, 2
                KOFF = 1
                IF( IUPLO.EQ.1 ) THEN
                   UPLO = 'U'
@@ -199,18 +294,18 @@
                   PACKIT = 'B'
                END IF
 *
-               DO 90 IMAT = 1, NIMAT
+               DO 80 IMAT = 1, NIMAT
 *
 *                 Do the tests only if DOTYPE( IMAT ) is true.
 *
                   IF( .NOT.DOTYPE( IMAT ) )
-     $               GO TO 90
+     $               GO TO 80
 *
 *                 Skip types 2, 3, or 4 if the matrix size is too small.
 *
                   ZEROT = IMAT.GE.2 .AND. IMAT.LE.4
                   IF( ZEROT .AND. N.LT.IMAT-1 )
-     $               GO TO 90
+     $               GO TO 80
 *
                   IF( .NOT.ZEROT .OR. .NOT.DOTYPE( 1 ) ) THEN
 *
@@ -231,7 +326,7 @@
                         CALL ALAERH( PATH, 'ZLATMS', INFO, 0, UPLO, N,
      $                               N, -1, -1, -1, IMAT, NFAIL, NERRS,
      $                               NOUT )
-                        GO TO 90
+                        GO TO 80
                      END IF
                   ELSE IF( IZERO.GT.0 ) THEN
 *
@@ -311,7 +406,7 @@
 *
                   CALL ZLACPY( 'Full', KD+1, N, A, LDAB, ASAV, LDAB )
 *
-                  DO 80 IEQUED = 1, 2
+                  DO 70 IEQUED = 1, 2
                      EQUED = EQUEDS( IEQUED )
                      IF( IEQUED.EQ.1 ) THEN
                         NFACT = 3
@@ -319,7 +414,7 @@
                         NFACT = 1
                      END IF
 *
-                     DO 70 IFACT = 1, NFACT
+                     DO 60 IFACT = 1, NFACT
                         FACT = FACTS( IFACT )
                         PREFAC = LSAME( FACT, 'F' )
                         NOFACT = LSAME( FACT, 'N' )
@@ -327,7 +422,7 @@
 *
                         IF( ZEROT ) THEN
                            IF( PREFAC )
-     $                        GO TO 70
+     $                        GO TO 60
                            RCONDC = ZERO
 *
                         ELSE IF( .NOT.LSAME( FACT, 'N' ) ) THEN
@@ -389,7 +484,6 @@
                               RCONDC = ( ONE / ANORM ) / AINVNM
                            END IF
                         END IF
-   30                   CONTINUE
 *
 *                       Restore the matrix A.
 *
@@ -429,9 +523,9 @@
                               CALL ALAERH( PATH, 'ZPBSV ', INFO, IZERO,
      $                                     UPLO, N, N, KD, KD, NRHS,
      $                                     IMAT, NFAIL, NERRS, NOUT )
-                              GO TO 50
+                              GO TO 40
                            ELSE IF( INFO.NE.0 ) THEN
-                              GO TO 50
+                              GO TO 40
                            END IF
 *
 *                          Reconstruct matrix from factors and compute
@@ -457,7 +551,7 @@
 *                          Print information about the tests that did
 *                          not pass the threshold.
 *
-                           DO 40 K = 1, NT
+                           DO 30 K = 1, NT
                               IF( RESULT( K ).GE.THRESH ) THEN
                                  IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                              CALL ALADHD( NOUT, PATH )
@@ -465,9 +559,9 @@
      $                              UPLO, N, KD, IMAT, K, RESULT( K )
                                  NFAIL = NFAIL + 1
                               END IF
-   40                      CONTINUE
+   30                      CONTINUE
                            NRUN = NRUN + NT
-   50                      CONTINUE
+   40                      CONTINUE
                         END IF
 *
 *                       --- Test ZPBSVX ---
@@ -501,7 +595,7 @@
                            CALL ALAERH( PATH, 'ZPBSVX', INFO, IZERO,
      $                                  FACT // UPLO, N, N, KD, KD,
      $                                  NRHS, IMAT, NFAIL, NERRS, NOUT )
-                           GO TO 70
+                           GO TO 60
                         END IF
 *
                         IF( INFO.EQ.0 ) THEN
@@ -556,7 +650,7 @@
 *                       Print information about the tests that did not
 *                       pass the threshold.
 *
-                        DO 60 K = K1, 6
+                        DO 50 K = K1, 6
                            IF( RESULT( K ).GE.THRESH ) THEN
                               IF( NFAIL.EQ.0 .AND. NERRS.EQ.0 )
      $                           CALL ALADHD( NOUT, PATH )
@@ -571,24 +665,24 @@
                               END IF
                               NFAIL = NFAIL + 1
                            END IF
-   60                   CONTINUE
+   50                   CONTINUE
                         NRUN = NRUN + 7 - K1
-   70                CONTINUE
-   80             CONTINUE
-   90          CONTINUE
-  100       CONTINUE
-  110    CONTINUE
-  120 CONTINUE
+   60                CONTINUE
+   70             CONTINUE
+   80          CONTINUE
+   90       CONTINUE
+  100    CONTINUE
+  110 CONTINUE
 *
 *     Print a summary of the results.
 *
       CALL ALASVM( PATH, NOUT, NFAIL, NRUN, NERRS )
 *
- 9999 FORMAT( 1X, A6, ', UPLO=''', A1, ''', N =', I5, ', KD =', I5,
+ 9999 FORMAT( 1X, A, ', UPLO=''', A1, ''', N =', I5, ', KD =', I5,
      $      ', type ', I1, ', test(', I1, ')=', G12.5 )
- 9998 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ', I5, ', ', I5,
+ 9998 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ', I5, ', ', I5,
      $      ', ... ), type ', I1, ', test(', I1, ')=', G12.5 )
- 9997 FORMAT( 1X, A6, '( ''', A1, ''', ''', A1, ''', ', I5, ', ', I5,
+ 9997 FORMAT( 1X, A, '( ''', A1, ''', ''', A1, ''', ', I5, ', ', I5,
      $      ', ... ), EQUED=''', A1, ''', type ', I1, ', test(', I1,
      $      ')=', G12.5 )
       RETURN
