@@ -168,8 +168,8 @@
       EXTERNAL           LSAME, IZAMAX, DLAMCH, ZLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLABAD, DLARNV, ZDSCAL, ZLARNV, ZLATB4, ZLATMS,
-     $                   ZROT, ZROTG
+      EXTERNAL           DLARNV, ZDSCAL, ZLARNV, ZLATB4, ZLATMS, ZROT,
+     $                   ZROTG
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, DCMPLX, DCONJG, MAX, SQRT
@@ -182,7 +182,6 @@
       ULP = DLAMCH( 'Epsilon' )*DLAMCH( 'Base' )
       SMLNUM = UNFL
       BIGNUM = ( ONE-ULP ) / SMLNUM
-      CALL DLABAD( SMLNUM, BIGNUM )
       IF( ( IMAT.GE.7 .AND. IMAT.LE.10 ) .OR. IMAT.EQ.18 ) THEN
          DIAG = 'U'
       ELSE
