@@ -530,7 +530,8 @@
       LOGICAL            LSAME
       REAL               CLANGB, CLANGE, CLANSB, CLANSP, CLANSY
       COMPLEX            CLATM2, CLATM3
-      EXTERNAL           LSAME, CLANGB, CLANGE, CLANSB, CLANSP, CLANSY,
+      EXTERNAL           LSAME, CLANGB, CLANGE,
+     $                   CLANSB, CLANSP, CLANSY,
      $                   CLATM2, CLATM3
 *     ..
 *     .. External Subroutines ..
@@ -897,7 +898,8 @@
 *
             DO 170 J = 1, N
                DO 160 I = 1, J
-                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -916,7 +918,8 @@
 *
             DO 190 J = 1, N
                DO 180 I = 1, J
-                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -935,7 +938,8 @@
 *
             DO 210 J = 1, N
                DO 200 I = 1, J
-                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
 *
@@ -963,7 +967,8 @@
 *
             DO 230 J = 1, N
                DO 220 I = 1, J
-                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
 *
@@ -1016,7 +1021,8 @@
 *
             DO 270 J = 1, N
                DO 260 I = J - KUU, J
-                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  CTEMP = CLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                    IDIST,
      $                    ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                    SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -1106,7 +1112,8 @@
 *
             DO 390 J = 1, N
                DO 380 I = 1, J
-                  A( I, J ) = CLATM2( M, N, I, J, KL, KU, IDIST, ISEED,
+                  A( I, J ) = CLATM2( M, N, I, J, KL, KU, IDIST,
+     $                        ISEED,
      $                        D, IGRADE, DL, DR, IPVTNG, IWORK, SPARSE )
                   IF( I.NE.J )
      $               A( J, I ) = CZERO
@@ -1142,7 +1149,8 @@
                      ISUB = 1
                      JSUB = JSUB + 1
                   END IF
-                  A( ISUB, JSUB ) = CLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( ISUB, JSUB ) = CLATM2( M, N, I, J, KL, KU,
+     $                              IDIST,
      $                              ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                              IWORK, SPARSE )
   420          CONTINUE
@@ -1200,7 +1208,8 @@
                      A( J-I+1, I+N ) = CZERO
                   ELSE
                      IF( ISYM.EQ.0 ) THEN
-                        A( J-I+1, I ) = CONJG( CLATM2( M, N, I, J, KL,
+                        A( J-I+1, I ) = CONJG( CLATM2( M, N, I, J,
+     $                                  KL,
      $                                  KU, IDIST, ISEED, D, IGRADE, DL,
      $                                  DR, IPVTNG, IWORK, SPARSE ) )
                      ELSE
@@ -1216,7 +1225,8 @@
 *
             DO 510 J = 1, N
                DO 500 I = J - KUU, J
-                  A( I-J+KUU+1, J ) = CLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( I-J+KUU+1, J ) = CLATM2( M, N, I, J, KL, KU,
+     $                                IDIST,
      $                                ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                                IWORK, SPARSE )
   500          CONTINUE
