@@ -1,10 +1,327 @@
+*> \brief \b DLATMS
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DLATMS( M, N, DIST, ISEED, SYM, D, MODE, COND, DMAX,
+*                          KL, KU, PACK, A, LDA, WORK, INFO )
+*
+*       .. Scalar Arguments ..
+*       CHARACTER          DIST, PACK, SYM
+*       INTEGER            INFO, KL, KU, LDA, M, MODE, N
+*       DOUBLE PRECISION   COND, DMAX
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            ISEED( 4 )
+*       DOUBLE PRECISION   A( LDA, * ), D( * ), WORK( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*>    DLATMS generates random matrices with specified singular values
+*>    (or symmetric/hermitian with specified eigenvalues)
+*>    for testing LAPACK programs.
+*>
+*>    DLATMS operates by applying the following sequence of
+*>    operations:
+*>
+*>      Set the diagonal to D, where D may be input or
+*>         computed according to MODE, COND, DMAX, and SYM
+*>         as described below.
+*>
+*>      Generate a matrix with the appropriate band structure, by one
+*>         of two methods:
+*>
+*>      Method A:
+*>          Generate a dense M x N matrix by multiplying D on the left
+*>              and the right by random unitary matrices, then:
+*>
+*>          Reduce the bandwidth according to KL and KU, using
+*>          Householder transformations.
+*>
+*>      Method B:
+*>          Convert the bandwidth-0 (i.e., diagonal) matrix to a
+*>              bandwidth-1 matrix using Givens rotations, "chasing"
+*>              out-of-band elements back, much as in QR; then
+*>              convert the bandwidth-1 to a bandwidth-2 matrix, etc.
+*>              Note that for reasonably small bandwidths (relative to
+*>              M and N) this requires less storage, as a dense matrix
+*>              is not generated.  Also, for symmetric matrices, only
+*>              one triangle is generated.
+*>
+*>      Method A is chosen if the bandwidth is a large fraction of the
+*>          order of the matrix, and LDA is at least M (so a dense
+*>          matrix can be stored.)  Method B is chosen if the bandwidth
+*>          is small (< 1/2 N for symmetric, < .3 N+M for
+*>          non-symmetric), or LDA is less than M and not less than the
+*>          bandwidth.
+*>
+*>      Pack the matrix if desired. Options specified by PACK are:
+*>         no packing
+*>         zero out upper half (if symmetric)
+*>         zero out lower half (if symmetric)
+*>         store the upper half columnwise (if symmetric or upper
+*>               triangular)
+*>         store the lower half columnwise (if symmetric or lower
+*>               triangular)
+*>         store the lower triangle in banded format (if symmetric
+*>               or lower triangular)
+*>         store the upper triangle in banded format (if symmetric
+*>               or upper triangular)
+*>         store the entire matrix in banded format
+*>      If Method B is chosen, and band format is specified, then the
+*>         matrix will be generated in the band format, so no repacking
+*>         will be necessary.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] M
+*> \verbatim
+*>          M is INTEGER
+*>           The number of rows of A. Not modified.
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>           The number of columns of A. Not modified.
+*> \endverbatim
+*>
+*> \param[in] DIST
+*> \verbatim
+*>          DIST is CHARACTER*1
+*>           On entry, DIST specifies the type of distribution to be used
+*>           to generate the random eigen-/singular values.
+*>           'U' => UNIFORM( 0, 1 )  ( 'U' for uniform )
+*>           'S' => UNIFORM( -1, 1 ) ( 'S' for symmetric )
+*>           'N' => NORMAL( 0, 1 )   ( 'N' for normal )
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in,out] ISEED
+*> \verbatim
+*>          ISEED is INTEGER array, dimension ( 4 )
+*>           On entry ISEED specifies the seed of the random number
+*>           generator. They should lie between 0 and 4095 inclusive,
+*>           and ISEED(4) should be odd. The random number generator
+*>           uses a linear congruential sequence limited to small
+*>           integers, and so should produce machine independent
+*>           random numbers. The values of ISEED are changed on
+*>           exit, and can be used in the next call to DLATMS
+*>           to continue the same random number sequence.
+*>           Changed on exit.
+*> \endverbatim
+*>
+*> \param[in] SYM
+*> \verbatim
+*>          SYM is CHARACTER*1
+*>           If SYM='S' or 'H', the generated matrix is symmetric, with
+*>             eigenvalues specified by D, COND, MODE, and DMAX; they
+*>             may be positive, negative, or zero.
+*>           If SYM='P', the generated matrix is symmetric, with
+*>             eigenvalues (= singular values) specified by D, COND,
+*>             MODE, and DMAX; they will not be negative.
+*>           If SYM='N', the generated matrix is nonsymmetric, with
+*>             singular values specified by D, COND, MODE, and DMAX;
+*>             they will not be negative.
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in,out] D
+*> \verbatim
+*>          D is DOUBLE PRECISION array, dimension ( MIN( M , N ) )
+*>           This array is used to specify the singular values or
+*>           eigenvalues of A (see SYM, above.)  If MODE=0, then D is
+*>           assumed to contain the singular/eigenvalues, otherwise
+*>           they will be computed according to MODE, COND, and DMAX,
+*>           and placed in D.
+*>           Modified if MODE is nonzero.
+*> \endverbatim
+*>
+*> \param[in] MODE
+*> \verbatim
+*>          MODE is INTEGER
+*>           On entry this describes how the singular/eigenvalues are to
+*>           be specified:
+*>           MODE = 0 means use D as input
+*>           MODE = 1 sets D(1)=1 and D(2:N)=1.0/COND
+*>           MODE = 2 sets D(1:N-1)=1 and D(N)=1.0/COND
+*>           MODE = 3 sets D(I)=COND**(-(I-1)/(N-1))
+*>           MODE = 4 sets D(i)=1 - (i-1)/(N-1)*(1 - 1/COND)
+*>           MODE = 5 sets D to random numbers in the range
+*>                    ( 1/COND , 1 ) such that their logarithms
+*>                    are uniformly distributed.
+*>           MODE = 6 set D to random numbers from same distribution
+*>                    as the rest of the matrix.
+*>           MODE < 0 has the same meaning as ABS(MODE), except that
+*>              the order of the elements of D is reversed.
+*>           Thus if MODE is positive, D has entries ranging from
+*>              1 to 1/COND, if negative, from 1/COND to 1,
+*>           If SYM='S' or 'H', and MODE is neither 0, 6, nor -6, then
+*>              the elements of D will also be multiplied by a random
+*>              sign (i.e., +1 or -1.)
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in] COND
+*> \verbatim
+*>          COND is DOUBLE PRECISION
+*>           On entry, this is used as described under MODE above.
+*>           If used, it must be >= 1. Not modified.
+*> \endverbatim
+*>
+*> \param[in] DMAX
+*> \verbatim
+*>          DMAX is DOUBLE PRECISION
+*>           If MODE is neither -6, 0 nor 6, the contents of D, as
+*>           computed according to MODE and COND, will be scaled by
+*>           DMAX / max(abs(D(i))); thus, the maximum absolute eigen- or
+*>           singular value (which is to say the norm) will be abs(DMAX).
+*>           Note that DMAX need not be positive: if DMAX is negative
+*>           (or zero), D will be scaled by a negative number (or zero).
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in] KL
+*> \verbatim
+*>          KL is INTEGER
+*>           This specifies the lower bandwidth of the  matrix. For
+*>           example, KL=0 implies upper triangular, KL=1 implies upper
+*>           Hessenberg, and KL being at least M-1 means that the matrix
+*>           has full lower bandwidth.  KL must equal KU if the matrix
+*>           is symmetric.
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in] KU
+*> \verbatim
+*>          KU is INTEGER
+*>           This specifies the upper bandwidth of the  matrix. For
+*>           example, KU=0 implies lower triangular, KU=1 implies lower
+*>           Hessenberg, and KU being at least N-1 means that the matrix
+*>           has full upper bandwidth.  KL must equal KU if the matrix
+*>           is symmetric.
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in] PACK
+*> \verbatim
+*>          PACK is CHARACTER*1
+*>           This specifies packing of matrix as follows:
+*>           'N' => no packing
+*>           'U' => zero out all subdiagonal entries (if symmetric)
+*>           'L' => zero out all superdiagonal entries (if symmetric)
+*>           'C' => store the upper triangle columnwise
+*>                  (only if the matrix is symmetric or upper triangular)
+*>           'R' => store the lower triangle columnwise
+*>                  (only if the matrix is symmetric or lower triangular)
+*>           'B' => store the lower triangle in band storage scheme
+*>                  (only if matrix symmetric or lower triangular)
+*>           'Q' => store the upper triangle in band storage scheme
+*>                  (only if matrix symmetric or upper triangular)
+*>           'Z' => store the entire matrix in band storage scheme
+*>                      (pivoting can be provided for by using this
+*>                      option to store A in the trailing rows of
+*>                      the allocated storage)
+*>
+*>           Using these options, the various LAPACK packed and banded
+*>           storage schemes can be obtained:
+*>           GB               - use 'Z'
+*>           PB, SB or TB     - use 'B' or 'Q'
+*>           PP, SP or TP     - use 'C' or 'R'
+*>
+*>           If two calls to DLATMS differ only in the PACK parameter,
+*>           they will generate mathematically equivalent matrices.
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[in,out] A
+*> \verbatim
+*>          A is DOUBLE PRECISION array, dimension ( LDA, N )
+*>           On exit A is the desired test matrix.  A is first generated
+*>           in full (unpacked) form, and then packed, if so specified
+*>           by PACK.  Thus, the first M elements of the first N
+*>           columns will always be modified.  If PACK specifies a
+*>           packed or banded storage scheme, all LDA elements of the
+*>           first N columns will be modified; the elements of the
+*>           array which do not correspond to elements of the generated
+*>           matrix are set to zero.
+*>           Modified.
+*> \endverbatim
+*>
+*> \param[in] LDA
+*> \verbatim
+*>          LDA is INTEGER
+*>           LDA specifies the first dimension of A as declared in the
+*>           calling program.  If PACK='N', 'U', 'L', 'C', or 'R', then
+*>           LDA must be at least M.  If PACK='B' or 'Q', then LDA must
+*>           be at least MIN( KL, M-1) (which is equal to MIN(KU,N-1)).
+*>           If PACK='Z', LDA must be large enough to hold the packed
+*>           array: MIN( KU, N-1) + MIN( KL, M-1) + 1.
+*>           Not modified.
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is DOUBLE PRECISION array, dimension ( 3*MAX( N , M ) )
+*>           Workspace.
+*>           Modified.
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>           Error code.  On exit, INFO will be set to one of the
+*>           following values:
+*>             0 => normal return
+*>            -1 => M negative or unequal to N and SYM='S', 'H', or 'P'
+*>            -2 => N negative
+*>            -3 => DIST illegal string
+*>            -5 => SYM illegal string
+*>            -7 => MODE not in range -6 to 6
+*>            -8 => COND less than 1.0, and MODE neither -6, 0 nor 6
+*>           -10 => KL negative
+*>           -11 => KU negative, or SYM='S' or 'H' and KU not equal to KL
+*>           -12 => PACK illegal string, or PACK='U' or 'L', and SYM='N';
+*>                  or PACK='C' or 'Q' and SYM='N' and KL is not zero;
+*>                  or PACK='R' or 'B' and SYM='N' and KU is not zero;
+*>                  or PACK='U', 'L', 'C', 'R', 'B', or 'Q', and M is not
+*>                  N.
+*>           -14 => LDA is less than M, or PACK='Z' and LDA is less than
+*>                  MIN(KU,N-1) + MIN(KL,M-1) + 1.
+*>            1  => Error return from DLATM1
+*>            2  => Cannot scale to DMAX (max. sing. value is 0)
+*>            3  => Error return from DLAGGE or SLAGSY
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup double_matgen
+*
+*  =====================================================================
       SUBROUTINE DLATMS( M, N, DIST, ISEED, SYM, D, MODE, COND, DMAX,
      $                   KL, KU, PACK, A, LDA, WORK, INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK computational routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, PACK, SYM
@@ -16,238 +333,6 @@
       DOUBLE PRECISION   A( LDA, * ), D( * ), WORK( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*     DLATMS generates random matrices with specified singular values
-*     (or symmetric/hermitian with specified eigenvalues)
-*     for testing LAPACK programs.
-*
-*     DLATMS operates by applying the following sequence of
-*     operations:
-*
-*       Set the diagonal to D, where D may be input or
-*          computed according to MODE, COND, DMAX, and SYM
-*          as described below.
-*
-*       Generate a matrix with the appropriate band structure, by one
-*          of two methods:
-*
-*       Method A:
-*           Generate a dense M x N matrix by multiplying D on the left
-*               and the right by random unitary matrices, then:
-*
-*           Reduce the bandwidth according to KL and KU, using
-*           Householder transformations.
-*
-*       Method B:
-*           Convert the bandwidth-0 (i.e., diagonal) matrix to a
-*               bandwidth-1 matrix using Givens rotations, "chasing"
-*               out-of-band elements back, much as in QR; then
-*               convert the bandwidth-1 to a bandwidth-2 matrix, etc.
-*               Note that for reasonably small bandwidths (relative to
-*               M and N) this requires less storage, as a dense matrix
-*               is not generated.  Also, for symmetric matrices, only
-*               one triangle is generated.
-*
-*       Method A is chosen if the bandwidth is a large fraction of the
-*           order of the matrix, and LDA is at least M (so a dense
-*           matrix can be stored.)  Method B is chosen if the bandwidth
-*           is small (< 1/2 N for symmetric, < .3 N+M for
-*           non-symmetric), or LDA is less than M and not less than the
-*           bandwidth.
-*
-*       Pack the matrix if desired. Options specified by PACK are:
-*          no packing
-*          zero out upper half (if symmetric)
-*          zero out lower half (if symmetric)
-*          store the upper half columnwise (if symmetric or upper
-*                triangular)
-*          store the lower half columnwise (if symmetric or lower
-*                triangular)
-*          store the lower triangle in banded format (if symmetric
-*                or lower triangular)
-*          store the upper triangle in banded format (if symmetric
-*                or upper triangular)
-*          store the entire matrix in banded format
-*       If Method B is chosen, and band format is specified, then the
-*          matrix will be generated in the band format, so no repacking
-*          will be necessary.
-*
-*  Arguments
-*  =========
-*
-*  M      - INTEGER
-*           The number of rows of A. Not modified.
-*
-*  N      - INTEGER
-*           The number of columns of A. Not modified.
-*
-*  DIST   - CHARACTER*1
-*           On entry, DIST specifies the type of distribution to be used
-*           to generate the random eigen-/singular values.
-*           'U' => UNIFORM( 0, 1 )  ( 'U' for uniform )
-*           'S' => UNIFORM( -1, 1 ) ( 'S' for symmetric )
-*           'N' => NORMAL( 0, 1 )   ( 'N' for normal )
-*           Not modified.
-*
-*  ISEED  - INTEGER array, dimension ( 4 )
-*           On entry ISEED specifies the seed of the random number
-*           generator. They should lie between 0 and 4095 inclusive,
-*           and ISEED(4) should be odd. The random number generator
-*           uses a linear congruential sequence limited to small
-*           integers, and so should produce machine independent
-*           random numbers. The values of ISEED are changed on
-*           exit, and can be used in the next call to DLATMS
-*           to continue the same random number sequence.
-*           Changed on exit.
-*
-*  SYM    - CHARACTER*1
-*           If SYM='S' or 'H', the generated matrix is symmetric, with
-*             eigenvalues specified by D, COND, MODE, and DMAX; they
-*             may be positive, negative, or zero.
-*           If SYM='P', the generated matrix is symmetric, with
-*             eigenvalues (= singular values) specified by D, COND,
-*             MODE, and DMAX; they will not be negative.
-*           If SYM='N', the generated matrix is nonsymmetric, with
-*             singular values specified by D, COND, MODE, and DMAX;
-*             they will not be negative.
-*           Not modified.
-*
-*  D      - DOUBLE PRECISION array, dimension ( MIN( M , N ) )
-*           This array is used to specify the singular values or
-*           eigenvalues of A (see SYM, above.)  If MODE=0, then D is
-*           assumed to contain the singular/eigenvalues, otherwise
-*           they will be computed according to MODE, COND, and DMAX,
-*           and placed in D.
-*           Modified if MODE is nonzero.
-*
-*  MODE   - INTEGER
-*           On entry this describes how the singular/eigenvalues are to
-*           be specified:
-*           MODE = 0 means use D as input
-*           MODE = 1 sets D(1)=1 and D(2:N)=1.0/COND
-*           MODE = 2 sets D(1:N-1)=1 and D(N)=1.0/COND
-*           MODE = 3 sets D(I)=COND**(-(I-1)/(N-1))
-*           MODE = 4 sets D(i)=1 - (i-1)/(N-1)*(1 - 1/COND)
-*           MODE = 5 sets D to random numbers in the range
-*                    ( 1/COND , 1 ) such that their logarithms
-*                    are uniformly distributed.
-*           MODE = 6 set D to random numbers from same distribution
-*                    as the rest of the matrix.
-*           MODE < 0 has the same meaning as ABS(MODE), except that
-*              the order of the elements of D is reversed.
-*           Thus if MODE is positive, D has entries ranging from
-*              1 to 1/COND, if negative, from 1/COND to 1,
-*           If SYM='S' or 'H', and MODE is neither 0, 6, nor -6, then
-*              the elements of D will also be multiplied by a random
-*              sign (i.e., +1 or -1.)
-*           Not modified.
-*
-*  COND   - DOUBLE PRECISION
-*           On entry, this is used as described under MODE above.
-*           If used, it must be >= 1. Not modified.
-*
-*  DMAX   - DOUBLE PRECISION
-*           If MODE is neither -6, 0 nor 6, the contents of D, as
-*           computed according to MODE and COND, will be scaled by
-*           DMAX / max(abs(D(i))); thus, the maximum absolute eigen- or
-*           singular value (which is to say the norm) will be abs(DMAX).
-*           Note that DMAX need not be positive: if DMAX is negative
-*           (or zero), D will be scaled by a negative number (or zero).
-*           Not modified.
-*
-*  KL     - INTEGER
-*           This specifies the lower bandwidth of the  matrix. For
-*           example, KL=0 implies upper triangular, KL=1 implies upper
-*           Hessenberg, and KL being at least M-1 means that the matrix
-*           has full lower bandwidth.  KL must equal KU if the matrix
-*           is symmetric.
-*           Not modified.
-*
-*  KU     - INTEGER
-*           This specifies the upper bandwidth of the  matrix. For
-*           example, KU=0 implies lower triangular, KU=1 implies lower
-*           Hessenberg, and KU being at least N-1 means that the matrix
-*           has full upper bandwidth.  KL must equal KU if the matrix
-*           is symmetric.
-*           Not modified.
-*
-*  PACK   - CHARACTER*1
-*           This specifies packing of matrix as follows:
-*           'N' => no packing
-*           'U' => zero out all subdiagonal entries (if symmetric)
-*           'L' => zero out all superdiagonal entries (if symmetric)
-*           'C' => store the upper triangle columnwise
-*                  (only if the matrix is symmetric or upper triangular)
-*           'R' => store the lower triangle columnwise
-*                  (only if the matrix is symmetric or lower triangular)
-*           'B' => store the lower triangle in band storage scheme
-*                  (only if matrix symmetric or lower triangular)
-*           'Q' => store the upper triangle in band storage scheme
-*                  (only if matrix symmetric or upper triangular)
-*           'Z' => store the entire matrix in band storage scheme
-*                      (pivoting can be provided for by using this
-*                      option to store A in the trailing rows of
-*                      the allocated storage)
-*
-*           Using these options, the various LAPACK packed and banded
-*           storage schemes can be obtained:
-*           GB               - use 'Z'
-*           PB, SB or TB     - use 'B' or 'Q'
-*           PP, SP or TP     - use 'C' or 'R'
-*
-*           If two calls to DLATMS differ only in the PACK parameter,
-*           they will generate mathematically equivalent matrices.
-*           Not modified.
-*
-*  A      - DOUBLE PRECISION array, dimension ( LDA, N )
-*           On exit A is the desired test matrix.  A is first generated
-*           in full (unpacked) form, and then packed, if so specified
-*           by PACK.  Thus, the first M elements of the first N
-*           columns will always be modified.  If PACK specifies a
-*           packed or banded storage scheme, all LDA elements of the
-*           first N columns will be modified; the elements of the
-*           array which do not correspond to elements of the generated
-*           matrix are set to zero.
-*           Modified.
-*
-*  LDA    - INTEGER
-*           LDA specifies the first dimension of A as declared in the
-*           calling program.  If PACK='N', 'U', 'L', 'C', or 'R', then
-*           LDA must be at least M.  If PACK='B' or 'Q', then LDA must
-*           be at least MIN( KL, M-1) (which is equal to MIN(KU,N-1)).
-*           If PACK='Z', LDA must be large enough to hold the packed
-*           array: MIN( KU, N-1) + MIN( KL, M-1) + 1.
-*           Not modified.
-*
-*  WORK   - DOUBLE PRECISION array, dimension ( 3*MAX( N , M ) )
-*           Workspace.
-*           Modified.
-*
-*  INFO   - INTEGER
-*           Error code.  On exit, INFO will be set to one of the
-*           following values:
-*             0 => normal return
-*            -1 => M negative or unequal to N and SYM='S', 'H', or 'P'
-*            -2 => N negative
-*            -3 => DIST illegal string
-*            -5 => SYM illegal string
-*            -7 => MODE not in range -6 to 6
-*            -8 => COND less than 1.0, and MODE neither -6, 0 nor 6
-*           -10 => KL negative
-*           -11 => KU negative, or SYM='S' or 'H' and KU not equal to KL
-*           -12 => PACK illegal string, or PACK='U' or 'L', and SYM='N';
-*                  or PACK='C' or 'Q' and SYM='N' and KL is not zero;
-*                  or PACK='R' or 'B' and SYM='N' and KU is not zero;
-*                  or PACK='U', 'L', 'C', 'R', 'B', or 'Q', and M is not
-*                  N.
-*           -14 => LDA is less than M, or PACK='Z' and LDA is less than
-*                  MIN(KU,N-1) + MIN(KL,M-1) + 1.
-*            1  => Error return from DLATM1
-*            2  => Cannot scale to DMAX (max. sing. value is 0)
-*            3  => Error return from DLAGGE or SLAGSY
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -256,7 +341,7 @@
       DOUBLE PRECISION   ONE
       PARAMETER          ( ONE = 1.0D0 )
       DOUBLE PRECISION   TWOPI
-      PARAMETER          ( TWOPI = 6.2831853071795864769252867663D+0 )
+      PARAMETER  ( TWOPI = 6.28318530717958647692528676655900576839D+0 )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            GIVENS, ILEXTR, ILTEMP, TOPDWN
@@ -273,7 +358,8 @@
       EXTERNAL           LSAME, DLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DCOPY, DLAGGE, DLAGSY, DLAROT, DLARTG, DLASET,
+      EXTERNAL           DCOPY, DLAGGE, DLAGSY,
+     $                   DLAROT, DLARTG, DLASET,
      $                   DLATM1, DSCAL, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
@@ -428,7 +514,8 @@
 *
 *             Compute D according to COND and MODE
 *
-      CALL DLATM1( MODE, COND, IRSIGN, IDIST, ISEED, D, MNMIN, IINFO )
+      CALL DLATM1( MODE, COND, IRSIGN, IDIST, ISEED, D, MNMIN,
+     $             IINFO )
       IF( IINFO.NE.0 ) THEN
          INFO = 1
          RETURN
@@ -535,7 +622,8 @@
                      ICOL = MAX( 1, JR-JKL )
                      IF( JR.LT.M ) THEN
                         IL = MIN( N, JR+JKU ) + 1 - ICOL
-                        CALL DLAROT( .TRUE., JR.GT.JKL, .FALSE., IL, C,
+                        CALL DLAROT( .TRUE., JR.GT.JKL, .FALSE., IL,
+     $                               C,
      $                               S, A( JR-ISKEW*ICOL+IOFFST, ICOL ),
      $                               ILDA, EXTRA, DUMMY )
                      END IF
@@ -553,7 +641,8 @@
                         IL = IR + 2 - IROW
                         TEMP = ZERO
                         ILTEMP = JCH.GT.JKU
-                        CALL DLAROT( .FALSE., ILTEMP, .TRUE., IL, C, -S,
+                        CALL DLAROT( .FALSE., ILTEMP, .TRUE., IL, C,
+     $                               -S,
      $                               A( IROW-ISKEW*IC+IOFFST, IC ),
      $                               ILDA, TEMP, EXTRA )
                         IF( ILTEMP ) THEN
@@ -562,7 +651,8 @@
                            ICOL = MAX( 1, JCH-JKU-JKL )
                            IL = IC + 2 - ICOL
                            EXTRA = ZERO
-                           CALL DLAROT( .TRUE., JCH.GT.JKU+JKL, .TRUE.,
+                           CALL DLAROT( .TRUE., JCH.GT.JKU+JKL,
+     $                                  .TRUE.,
      $                                  IL, C, -S, A( IROW-ISKEW*ICOL+
      $                                  IOFFST, ICOL ), ILDA, EXTRA,
      $                                  TEMP )
@@ -586,7 +676,8 @@
                      IROW = MAX( 1, JC-JKU )
                      IF( JC.LT.N ) THEN
                         IL = MIN( M, JC+JKL ) + 1 - IROW
-                        CALL DLAROT( .FALSE., JC.GT.JKU, .FALSE., IL, C,
+                        CALL DLAROT( .FALSE., JC.GT.JKU, .FALSE., IL,
+     $                               C,
      $                               S, A( IROW-ISKEW*JC+IOFFST, JC ),
      $                               ILDA, EXTRA, DUMMY )
                      END IF
@@ -604,7 +695,8 @@
                         IL = IC + 2 - ICOL
                         TEMP = ZERO
                         ILTEMP = JCH.GT.JKL
-                        CALL DLAROT( .TRUE., ILTEMP, .TRUE., IL, C, -S,
+                        CALL DLAROT( .TRUE., ILTEMP, .TRUE., IL, C,
+     $                               -S,
      $                               A( IR-ISKEW*ICOL+IOFFST, ICOL ),
      $                               ILDA, TEMP, EXTRA )
                         IF( ILTEMP ) THEN
@@ -613,7 +705,8 @@
                            IROW = MAX( 1, JCH-JKL-JKU )
                            IL = IR + 2 - IROW
                            EXTRA = ZERO
-                           CALL DLAROT( .FALSE., JCH.GT.JKL+JKU, .TRUE.,
+                           CALL DLAROT( .FALSE., JCH.GT.JKL+JKU,
+     $                                  .TRUE.,
      $                                  IL, C, -S, A( IROW-ISKEW*ICOL+
      $                                  IOFFST, ICOL ), ILDA, EXTRA,
      $                                  TEMP )
@@ -645,7 +738,8 @@
                      IROW = MAX( 1, JC-JKU+1 )
                      IF( JC.GT.0 ) THEN
                         IL = MIN( M, JC+JKL+1 ) + 1 - IROW
-                        CALL DLAROT( .FALSE., .FALSE., JC+JKL.LT.M, IL,
+                        CALL DLAROT( .FALSE., .FALSE., JC+JKL.LT.M,
+     $                               IL,
      $                               C, S, A( IROW-ISKEW*JC+IOFFST,
      $                               JC ), ILDA, DUMMY, EXTRA )
                      END IF
@@ -663,7 +757,8 @@
                         ICOL = MIN( N-1, JCH+JKU )
                         ILTEMP = JCH + JKU.LT.N
                         TEMP = ZERO
-                        CALL DLAROT( .TRUE., ILEXTR, ILTEMP, ICOL+2-IC,
+                        CALL DLAROT( .TRUE., ILEXTR, ILTEMP,
+     $                               ICOL+2-IC,
      $                               C, S, A( JCH-ISKEW*IC+IOFFST, IC ),
      $                               ILDA, EXTRA, TEMP )
                         IF( ILTEMP ) THEN
@@ -698,7 +793,8 @@
                      ICOL = MAX( 1, JR-JKL+1 )
                      IF( JR.GT.0 ) THEN
                         IL = MIN( N, JR+JKU+1 ) + 1 - ICOL
-                        CALL DLAROT( .TRUE., .FALSE., JR+JKU.LT.N, IL,
+                        CALL DLAROT( .TRUE., .FALSE., JR+JKU.LT.N,
+     $                               IL,
      $                               C, S, A( JR-ISKEW*ICOL+IOFFST,
      $                               ICOL ), ILDA, DUMMY, EXTRA )
                      END IF
@@ -716,7 +812,8 @@
                         IROW = MIN( M-1, JCH+JKL )
                         ILTEMP = JCH + JKL.LT.M
                         TEMP = ZERO
-                        CALL DLAROT( .FALSE., ILEXTR, ILTEMP, IROW+2-IR,
+                        CALL DLAROT( .FALSE., ILEXTR, ILTEMP,
+     $                               IROW+2-IR,
      $                               C, S, A( IR-ISKEW*JCH+IOFFST,
      $                               JCH ), ILDA, EXTRA, TEMP )
                         IF( ILTEMP ) THEN
@@ -778,13 +875,15 @@
                         CALL DLARTG( A( JCH+1-ISKEW*( ICOL+1 )+IOFFG,
      $                               ICOL+1 ), EXTRA, C, S, DUMMY )
                         TEMP = A( JCH-ISKEW*( JCH+1 )+IOFFG, JCH+1 )
-                        CALL DLAROT( .TRUE., .TRUE., .TRUE., K+2, C, -S,
+                        CALL DLAROT( .TRUE., .TRUE., .TRUE., K+2, C,
+     $                               -S,
      $                               A( ( 1-ISKEW )*JCH+IOFFG, JCH ),
      $                               ILDA, TEMP, EXTRA )
                         IROW = MAX( 1, JCH-K )
                         IL = MIN( JCH+1, K+2 )
                         EXTRA = ZERO
-                        CALL DLAROT( .FALSE., JCH.GT.K, .TRUE., IL, C,
+                        CALL DLAROT( .FALSE., JCH.GT.K, .TRUE., IL,
+     $                               C,
      $                               -S, A( IROW-ISKEW*JCH+IOFFG, JCH ),
      $                               ILDA, EXTRA, TEMP )
                         ICOL = JCH
@@ -836,11 +935,13 @@
                      ANGLE = TWOPI*DLARND( 1, ISEED )
                      C = COS( ANGLE )
                      S = -SIN( ANGLE )
-                     CALL DLAROT( .FALSE., .TRUE., N-JC.GT.K, IL, C, S,
+                     CALL DLAROT( .FALSE., .TRUE., N-JC.GT.K, IL, C,
+     $                            S,
      $                            A( ( 1-ISKEW )*JC+IOFFG, JC ), ILDA,
      $                            TEMP, EXTRA )
                      ICOL = MAX( 1, JC-K+1 )
-                     CALL DLAROT( .TRUE., .FALSE., .TRUE., JC+2-ICOL, C,
+                     CALL DLAROT( .TRUE., .FALSE., .TRUE., JC+2-ICOL,
+     $                            C,
      $                            S, A( JC-ISKEW*ICOL+IOFFG, ICOL ),
      $                            ILDA, DUMMY, TEMP )
 *
@@ -851,12 +952,14 @@
                         CALL DLARTG( A( JCH-ISKEW*ICOL+IOFFG, ICOL ),
      $                               EXTRA, C, S, DUMMY )
                         TEMP = A( 1+( 1-ISKEW )*JCH+IOFFG, JCH )
-                        CALL DLAROT( .TRUE., .TRUE., .TRUE., K+2, C, S,
+                        CALL DLAROT( .TRUE., .TRUE., .TRUE., K+2, C,
+     $                               S,
      $                               A( JCH-ISKEW*ICOL+IOFFG, ICOL ),
      $                               ILDA, EXTRA, TEMP )
                         IL = MIN( N+1-JCH, K+2 )
                         EXTRA = ZERO
-                        CALL DLAROT( .FALSE., .TRUE., N-JCH.GT.K, IL, C,
+                        CALL DLAROT( .FALSE., .TRUE., N-JCH.GT.K, IL,
+     $                               C,
      $                               S, A( ( 1-ISKEW )*JCH+IOFFG, JCH ),
      $                               ILDA, TEMP, EXTRA )
                         ICOL = JCH
