@@ -461,8 +461,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup real_matgen
 *
 *  =====================================================================
@@ -471,10 +469,9 @@
      $                   CONDR, PIVTNG, IPIVOT, KL, KU, SPARSE, ANORM,
      $                   PACK, A, LDA, IWORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, GRADE, PACK, PIVTNG, RSIGN, SYM
@@ -506,9 +503,11 @@
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
-      REAL               SLANGB, SLANGE, SLANSB, SLANSP, SLANSY, SLATM2,
+      REAL               SLANGB, SLANGE, SLANSB,
+     $                   SLANSP, SLANSY, SLATM2,
      $                   SLATM3
-      EXTERNAL           LSAME, SLANGB, SLANGE, SLANSB, SLANSP, SLANSY,
+      EXTERNAL           LSAME, SLANGB, SLANGE,
+     $                   SLANSB, SLANSP, SLANSY,
      $                   SLATM2, SLATM3
 *     ..
 *     .. External Subroutines ..
@@ -849,7 +848,8 @@
 *
             DO 140 J = 1, N
                DO 130 I = 1, J
-                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                   IDIST,
      $                   ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                   SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -864,7 +864,8 @@
 *
             DO 160 J = 1, N
                DO 150 I = 1, J
-                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                   IDIST,
      $                   ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                   SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -879,7 +880,8 @@
 *
             DO 180 J = 1, N
                DO 170 I = 1, J
-                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                   IDIST,
      $                   ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                   SPARSE )
 *
@@ -903,7 +905,8 @@
 *
             DO 200 J = 1, N
                DO 190 I = 1, J
-                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                   IDIST,
      $                   ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                   SPARSE )
 *
@@ -948,7 +951,8 @@
 *
             DO 240 J = 1, N
                DO 230 I = J - KUU, J
-                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU, IDIST,
+                  TEMP = SLATM3( M, N, I, J, ISUB, JSUB, KL, KU,
+     $                   IDIST,
      $                   ISEED, D, IGRADE, DL, DR, IPVTNG, IWORK,
      $                   SPARSE )
                   MNSUB = MIN( ISUB, JSUB )
@@ -1015,7 +1019,8 @@
 *
             DO 340 J = 1, N
                DO 330 I = 1, J
-                  A( I, J ) = SLATM2( M, N, I, J, KL, KU, IDIST, ISEED,
+                  A( I, J ) = SLATM2( M, N, I, J, KL, KU, IDIST,
+     $                        ISEED,
      $                        D, IGRADE, DL, DR, IPVTNG, IWORK, SPARSE )
                   IF( I.NE.J )
      $               A( J, I ) = ZERO
@@ -1026,7 +1031,8 @@
 *
             DO 360 J = 1, N
                DO 350 I = 1, J
-                  A( J, I ) = SLATM2( M, N, I, J, KL, KU, IDIST, ISEED,
+                  A( J, I ) = SLATM2( M, N, I, J, KL, KU, IDIST,
+     $                        ISEED,
      $                        D, IGRADE, DL, DR, IPVTNG, IWORK, SPARSE )
                   IF( I.NE.J )
      $               A( I, J ) = ZERO
@@ -1044,7 +1050,8 @@
                      ISUB = 1
                      JSUB = JSUB + 1
                   END IF
-                  A( ISUB, JSUB ) = SLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( ISUB, JSUB ) = SLATM2( M, N, I, J, KL, KU,
+     $                              IDIST,
      $                              ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                              IWORK, SPARSE )
   370          CONTINUE
@@ -1099,7 +1106,8 @@
                   IF( I.LT.1 ) THEN
                      A( J-I+1, I+N ) = ZERO
                   ELSE
-                     A( J-I+1, I ) = SLATM2( M, N, I, J, KL, KU, IDIST,
+                     A( J-I+1, I ) = SLATM2( M, N, I, J, KL, KU,
+     $                               IDIST,
      $                               ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                               IWORK, SPARSE )
                   END IF
@@ -1110,7 +1118,8 @@
 *
             DO 460 J = 1, N
                DO 450 I = J - KUU, J
-                  A( I-J+KUU+1, J ) = SLATM2( M, N, I, J, KL, KU, IDIST,
+                  A( I-J+KUU+1, J ) = SLATM2( M, N, I, J, KL, KU,
+     $                                IDIST,
      $                                ISEED, D, IGRADE, DL, DR, IPVTNG,
      $                                IWORK, SPARSE )
   450          CONTINUE
