@@ -324,18 +324,15 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date December 2016
-*
 *> \ingroup complex16_matgen
 *
 *  =====================================================================
       SUBROUTINE ZLATMS( M, N, DIST, ISEED, SYM, D, MODE, COND, DMAX,
      $                   KL, KU, PACK, A, LDA, WORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     December 2016
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, PACK, SYM
@@ -358,7 +355,7 @@
       COMPLEX*16         CZERO
       PARAMETER          ( CZERO = ( 0.0D+0, 0.0D+0 ) )
       DOUBLE PRECISION   TWOPI
-      PARAMETER          ( TWOPI = 6.2831853071795864769252867663D+0 )
+      PARAMETER  ( TWOPI = 6.28318530717958647692528676655900576839D+0 )
 *     ..
 *     .. Local Scalars ..
       LOGICAL            GIVENS, ILEXTR, ILTEMP, TOPDWN, ZSYM
@@ -377,7 +374,8 @@
       EXTERNAL           LSAME, DLARND, ZLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DLATM1, DSCAL, XERBLA, ZLAGGE, ZLAGHE, ZLAGSY,
+      EXTERNAL           DLATM1, DSCAL, XERBLA,
+     $                   ZLAGGE, ZLAGHE, ZLAGSY,
      $                   ZLAROT, ZLARTG, ZLASET
 *     ..
 *     .. Intrinsic Functions ..
@@ -537,7 +535,8 @@
 *
 *             Compute D according to COND and MODE
 *
-      CALL DLATM1( MODE, COND, IRSIGN, IDIST, ISEED, D, MNMIN, IINFO )
+      CALL DLATM1( MODE, COND, IRSIGN, IDIST, ISEED, D, MNMIN,
+     $             IINFO )
       IF( IINFO.NE.0 ) THEN
          INFO = 1
          RETURN
@@ -650,7 +649,8 @@
                      ICOL = MAX( 1, JR-JKL )
                      IF( JR.LT.M ) THEN
                         IL = MIN( N, JR+JKU ) + 1 - ICOL
-                        CALL ZLAROT( .TRUE., JR.GT.JKL, .FALSE., IL, C,
+                        CALL ZLAROT( .TRUE., JR.GT.JKL, .FALSE., IL,
+     $                               C,
      $                               S, A( JR-ISKEW*ICOL+IOFFST, ICOL ),
      $                               ILDA, EXTRA, DUMMY )
                      END IF
@@ -671,7 +671,8 @@
                         IL = IR + 2 - IROW
                         CTEMP = CZERO
                         ILTEMP = JCH.GT.JKU
-                        CALL ZLAROT( .FALSE., ILTEMP, .TRUE., IL, C, S,
+                        CALL ZLAROT( .FALSE., ILTEMP, .TRUE., IL, C,
+     $                               S,
      $                               A( IROW-ISKEW*IC+IOFFST, IC ),
      $                               ILDA, CTEMP, EXTRA )
                         IF( ILTEMP ) THEN
@@ -684,7 +685,8 @@
                            ICOL = MAX( 1, JCH-JKU-JKL )
                            IL = IC + 2 - ICOL
                            EXTRA = CZERO
-                           CALL ZLAROT( .TRUE., JCH.GT.JKU+JKL, .TRUE.,
+                           CALL ZLAROT( .TRUE., JCH.GT.JKU+JKL,
+     $                                  .TRUE.,
      $                                  IL, C, S, A( IROW-ISKEW*ICOL+
      $                                  IOFFST, ICOL ), ILDA, EXTRA,
      $                                  CTEMP )
@@ -708,7 +710,8 @@
                      IROW = MAX( 1, JC-JKU )
                      IF( JC.LT.N ) THEN
                         IL = MIN( M, JC+JKL ) + 1 - IROW
-                        CALL ZLAROT( .FALSE., JC.GT.JKU, .FALSE., IL, C,
+                        CALL ZLAROT( .FALSE., JC.GT.JKU, .FALSE., IL,
+     $                               C,
      $                               S, A( IROW-ISKEW*JC+IOFFST, JC ),
      $                               ILDA, EXTRA, DUMMY )
                      END IF
@@ -729,7 +732,8 @@
                         IL = IC + 2 - ICOL
                         CTEMP = CZERO
                         ILTEMP = JCH.GT.JKL
-                        CALL ZLAROT( .TRUE., ILTEMP, .TRUE., IL, C, S,
+                        CALL ZLAROT( .TRUE., ILTEMP, .TRUE., IL, C,
+     $                               S,
      $                               A( IR-ISKEW*ICOL+IOFFST, ICOL ),
      $                               ILDA, CTEMP, EXTRA )
                         IF( ILTEMP ) THEN
@@ -742,7 +746,8 @@
                            IROW = MAX( 1, JCH-JKL-JKU )
                            IL = IR + 2 - IROW
                            EXTRA = CZERO
-                           CALL ZLAROT( .FALSE., JCH.GT.JKL+JKU, .TRUE.,
+                           CALL ZLAROT( .FALSE., JCH.GT.JKL+JKU,
+     $                                  .TRUE.,
      $                                  IL, C, S, A( IROW-ISKEW*ICOL+
      $                                  IOFFST, ICOL ), ILDA, EXTRA,
      $                                  CTEMP )
@@ -774,7 +779,8 @@
                      IROW = MAX( 1, JC-JKU+1 )
                      IF( JC.GT.0 ) THEN
                         IL = MIN( M, JC+JKL+1 ) + 1 - IROW
-                        CALL ZLAROT( .FALSE., .FALSE., JC+JKL.LT.M, IL,
+                        CALL ZLAROT( .FALSE., .FALSE., JC+JKL.LT.M,
+     $                               IL,
      $                               C, S, A( IROW-ISKEW*JC+IOFFST,
      $                               JC ), ILDA, DUMMY, EXTRA )
                      END IF
@@ -795,7 +801,8 @@
                         ICOL = MIN( N-1, JCH+JKU )
                         ILTEMP = JCH + JKU.LT.N
                         CTEMP = CZERO
-                        CALL ZLAROT( .TRUE., ILEXTR, ILTEMP, ICOL+2-IC,
+                        CALL ZLAROT( .TRUE., ILEXTR, ILTEMP,
+     $                               ICOL+2-IC,
      $                               C, S, A( JCH-ISKEW*IC+IOFFST, IC ),
      $                               ILDA, EXTRA, CTEMP )
                         IF( ILTEMP ) THEN
@@ -833,7 +840,8 @@
                      ICOL = MAX( 1, JR-JKL+1 )
                      IF( JR.GT.0 ) THEN
                         IL = MIN( N, JR+JKU+1 ) + 1 - ICOL
-                        CALL ZLAROT( .TRUE., .FALSE., JR+JKU.LT.N, IL,
+                        CALL ZLAROT( .TRUE., .FALSE., JR+JKU.LT.N,
+     $                               IL,
      $                               C, S, A( JR-ISKEW*ICOL+IOFFST,
      $                               ICOL ), ILDA, DUMMY, EXTRA )
                      END IF
@@ -854,7 +862,8 @@
                         IROW = MIN( M-1, JCH+JKL )
                         ILTEMP = JCH + JKL.LT.M
                         CTEMP = CZERO
-                        CALL ZLAROT( .FALSE., ILEXTR, ILTEMP, IROW+2-IR,
+                        CALL ZLAROT( .FALSE., ILEXTR, ILTEMP,
+     $                               IROW+2-IR,
      $                               C, S, A( IR-ISKEW*JCH+IOFFST,
      $                               JCH ), ILDA, EXTRA, CTEMP )
                         IF( ILTEMP ) THEN
@@ -943,13 +952,15 @@
                            CT = DCONJG( C )
                            ST = DCONJG( S )
                         END IF
-                        CALL ZLAROT( .TRUE., .TRUE., .TRUE., K+2, C, S,
+                        CALL ZLAROT( .TRUE., .TRUE., .TRUE., K+2, C,
+     $                               S,
      $                               A( ( 1-ISKEW )*JCH+IOFFG, JCH ),
      $                               ILDA, CTEMP, EXTRA )
                         IROW = MAX( 1, JCH-K )
                         IL = MIN( JCH+1, K+2 )
                         EXTRA = CZERO
-                        CALL ZLAROT( .FALSE., JCH.GT.K, .TRUE., IL, CT,
+                        CALL ZLAROT( .FALSE., JCH.GT.K, .TRUE., IL,
+     $                               CT,
      $                               ST, A( IROW-ISKEW*JCH+IOFFG, JCH ),
      $                               ILDA, EXTRA, CTEMP )
                         ICOL = JCH
@@ -1019,7 +1030,8 @@
                         CT = DCONJG( C )
                         ST = DCONJG( S )
                      END IF
-                     CALL ZLAROT( .FALSE., .TRUE., N-JC.GT.K, IL, C, S,
+                     CALL ZLAROT( .FALSE., .TRUE., N-JC.GT.K, IL, C,
+     $                            S,
      $                            A( ( 1-ISKEW )*JC+IOFFG, JC ), ILDA,
      $                            CTEMP, EXTRA )
                      ICOL = MAX( 1, JC-K+1 )
@@ -1045,7 +1057,8 @@
                            CT = DCONJG( C )
                            ST = DCONJG( S )
                         END IF
-                        CALL ZLAROT( .TRUE., .TRUE., .TRUE., K+2, C, S,
+                        CALL ZLAROT( .TRUE., .TRUE., .TRUE., K+2, C,
+     $                               S,
      $                               A( JCH-ISKEW*ICOL+IOFFG, ICOL ),
      $                               ILDA, EXTRA, CTEMP )
                         IL = MIN( N+1-JCH, K+2 )
